---
title: Асинхронное получение данных
slug: bsp/асинхронное-получение-данных
---


## ИдентификаторХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор хранилища в виде строки.
// @skip-check module-empty-method - особенность реализации.
// @skip-warning - обратная совместимость.
//
// Возвращаемое значение:
//	Строка - идентификатор хранилища.
//
Функция ИдентификаторХранилища() Экспорт
```

Пример вызова
```bsl
Результат = АсинхронноеПолучениеДанных.ИдентификаторХранилища() 
```
</details>

## НовыйОписаниеВозвращаемыхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую структуру описания возвращаемых данных.
// @skip-check module-empty-method - особенность реализации.
// @skip-warning - обратная совместимость.
//
// Возвращаемое значение:
//	Структура:
//	 * МодульМенеджер - ОбщийМодуль, СправочникиМенеджер, ОтчетыМенеджер - модуль менеджера получения данных.
//	 * Наименование - Строка - наименование возвращаемых данных.
//	 * Описание - Строка - подробное описание возвращаемых данных.
//	 * ТипыРезультата - Массив из Строка - типы возвращаемых данных.
//
Функция НовыйОписаниеВозвращаемыхДанных() Экспорт
```

Пример вызова
```bsl
Результат = АсинхронноеПолучениеДанных.НовыйОписаниеВозвращаемыхДанных() 
```
</details>

## ДоступныеВозвращаемыеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает перечень доступных данных
// @skip-check module-empty-method - особенность реализации.
// @skip-warning - обратная совместимость.
//
// Возвращаемое значение:
//	Соответствие из КлючИЗначение - перечень доступных возвращаемых данных:
//	 * Ключ - Строка - идентификатор данных.
//	 * Значение - см. АсинхронноеПолучениеДанных.НовыйОписаниеВозвращаемыхДанных
//
Функция ДоступныеВозвращаемыеДанные() Экспорт
```

Пример вызова
```bsl
Результат = АсинхронноеПолучениеДанных.ДоступныеВозвращаемыеДанные() 
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков.
// @skip-check module-empty-method - особенность реализации.
// @skip-warning - обратная совместимость.
//
// Параметры:
//  СоответствиеИменПсевдонимам - см. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков.СоответствиеИменПсевдонимам
//
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
АсинхронноеПолучениеДанных.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

## ПодготовитьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует данные для ответа по полученным параметрам.
// @skip-check module-empty-method - особенность реализации.
// @skip-warning - обратная совместимость.
//
// Параметры:
//	ИдентификаторДанных - Строка - идентификатор данных, которые нужно получить.
//	ИдентификаторПараметров - УникальныйИдентификатор - идентификатор файла параметров получения данных.
//
Процедура ПодготовитьДанные(ИдентификаторДанных, ИдентификаторПараметров) Экспорт
```

Пример вызова
```bsl
АсинхронноеПолучениеДанных.ПодготовитьДанные(ИдентификаторДанных, ИдентификаторПараметров) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
