---
title: Бизнес процессы и задачи сервер
slug: bsp/бизнес-процессы-и-задачи-сервер
---


## ФормаЗадачиПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует общие параметры формы выполнения задачи.
//
// Параметры:
//  ФормаЗадачи            - ФормаКлиентскогоПриложения - форма выполнения задачи.
//  ЗадачаОбъект           - ЗадачаОбъект     - объект задачи.
//  ЭлементГруппаСостояние - ГруппаФормы      - группа с информации о состоянии задачи.
//  ЭлементДатаИсполнения  - ПолеФормы        - поле с датой исполнения задачи.
//
Процедура ФормаЗадачиПриСозданииНаСервере(ФормаЗадачи, ЗадачаОбъект, Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ФормаЗадачиПриСозданииНаСервере(ФормаЗадачи, ЗадачаОбъект, );
```
</details>

## УстановитьОформлениеЗадач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании формы списка задач на сервере.
//
// Параметры:
//  СписокЗадачИлиЕгоУсловноеОформление - ДинамическийСписок
//                                      - УсловноеОформлениеКомпоновкиДанных - условное оформление списка задач.
//
Процедура УстановитьОформлениеЗадач(Знач СписокЗадачИлиЕгоУсловноеОформление) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.УстановитьОформлениеЗадач(СписокЗадачИлиЕгоУсловноеОформление) 
```
</details>

## УстановитьОформлениеБизнесПроцессов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании формы списка бизнес-процессов на сервере.
//
// Параметры:
//  УсловноеОформлениеБизнесПроцессов - УсловноеОформлениеКомпоновкиДанных - условное оформление списка бизнес-процессов.
//
Процедура УстановитьОформлениеБизнесПроцессов(Знач УсловноеОформлениеБизнесПроцессов) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.УстановитьОформлениеБизнесПроцессов(УсловноеОформлениеБизнесПроцессов) 
```
</details>

## ИсполнительСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление исполнителя задачи Исполнитель,
// либо указанного в параметрах РольИсполнителя, ОсновнойОбъектАдресации и ДополнительныйОбъектАдресации.
//
// Параметры:
//  Исполнитель                   - СправочникСсылка.Пользователи - исполнитель задачи.
//  РольИсполнителя               - СправочникСсылка.РолиИсполнителей - роль.
//  ОсновнойОбъектАдресации       - ЛюбаяСсылка - ссылка на основной объект адресации.
//  ДополнительныйОбъектАдресации - ЛюбаяСсылка - ссылка на дополнительный объект адресации.
//
// Возвращаемое значение:
//  Строка - строковое представление исполнителя задачи, например:
//           "Иванов Иван Иванович" - исполнитель, как указано в параметре Исполнитель;
//           "Главный бухгалтер" - роль исполнителя, указанная в параметре РольИсполнителя;
//           "Главный бухгалтер (ООО Солнышко)" - если роль указана вместе с основным объектом адресации;
//           "Главный бухгалтер (ОАО Солнышко, Филиал в г.Москва)" - если роль указана вместе с обоими объектами
//                                                                   адресации.
//
Функция ИсполнительСтрокой(Знач Исполнитель, Знач РольИсполнителя, Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ИсполнительСтрокой(Исполнитель, РольИсполнителя, );
```
</details>

## РольСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление роли РольИсполнителя и ее объектов адресации, если они заданы.
//
// Параметры:
//  РольИсполнителя               - СправочникСсылка.РолиИсполнителей - роль.
//  ОсновнойОбъектАдресации       - ЛюбаяСсылка - ссылка на основной объект адресации.
//  ДополнительныйОбъектАдресации - ЛюбаяСсылка - ссылка на дополнительный объект адресации.
//
// Возвращаемое значение:
//  Строка - строковое представление роли, например:
//            "Главный бухгалтер" - роль исполнителя, указанная в параметре РольИсполнителя;
//            "Главный бухгалтер (ООО Солнышко)" - если роль указана вместе с основным объектом адресации;
//            "Главный бухгалтер (ОАО Солнышко, Филиал в г.Москва)" - если роль указана вместе с обоими объектами
//                                                                    адресации.
//
Функция РольСтрокой(Знач РольИсполнителя, Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.РольСтрокой(РольИсполнителя, );
```
</details>

## УстановитьПометкуУдаленияЗадач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает на удаление все задачи указанного бизнес-процесса (или снимает отметку).
//
// Параметры:
//  БизнесПроцессСсылка - ОпределяемыйТип.БизнесПроцесс - бизнес-процесс, задачи которого нужно пометить на удаление.
//  ПометкаУдаления     - Булево - значение свойства ПометкаУдаления для задач.
//
Процедура УстановитьПометкуУдаленияЗадач(БизнесПроцессСсылка, ПометкаУдаления) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.УстановитьПометкуУдаленияЗадач(БизнесПроцессСсылка, ПометкаУдаления) 
```
</details>

## УстановитьФорматДаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить формат отображения и редактирования поля формы типа Дата
// в зависимости от настроек подсистемы.
//
// Параметры:
//  ПолеДаты - ПолеФормы - элемент управления формы, поле со значением типа Дата.
//
Процедура УстановитьФорматДаты(ПолеДаты) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.УстановитьФорматДаты(ПолеДаты) 
```
</details>

## БизнесПроцессыВедущейЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить бизнес-процессы ведущей задачи ЗадачаСсылка.
//
// Параметры:
//   ЗадачаСсылка - ЗадачаСсылка.ЗадачаИсполнителя - ведущая задача.
//   ДляИзменения - Булево - если Истина, то следует установить исключительную управляемую блокировку
//                           на все бизнес-процессы указанной ведущей задачи. По умолчанию, Ложь.
// Возвращаемое значение:
//    Массив из ОпределяемыйТип.БизнесПроцесс
//
Функция БизнесПроцессыВедущейЗадачи(ЗадачаСсылка, ДляИзменения = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.БизнесПроцессыВедущейЗадачи(ЗадачаСсылка, ДляИзменения);
```
</details>

## ДатаЗавершенияБизнесПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату завершения указанного бизнес-процесса,
// полученную как максимальная дата исполнения задач бизнес-процесса.
//
// Параметры:
//  БизнесПроцессСсылка - ОпределяемыйТип.БизнесПроцесс
//
// Возвращаемое значение:
//  Дата
//
Функция ДатаЗавершенияБизнесПроцесса(БизнесПроцессСсылка) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ДатаЗавершенияБизнесПроцесса(БизнесПроцессСсылка) 
```
</details>

## БизнесПроцессыГлавнойЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает бизнес-процессы, подчиненные указанной задаче.
//
// Параметры:
//  ЗадачаСсылка  - ЗадачаСсылка.ЗадачаИсполнителя
//  ДляИзменения  - Булево - если Истина, то следует установить исключительную управляемую блокировку
//                           на все бизнес-процессы, подчиненные указанной задаче. По умолчанию, Ложь.
//
// Возвращаемое значение:
//   Массив из ОпределяемыйТип.БизнесПроцесс
//
Функция БизнесПроцессыГлавнойЗадачи(ЗадачаСсылка, ДляИзменения = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.БизнесПроцессыГлавнойЗадачи(ЗадачаСсылка, ДляИзменения);
```
</details>

## ПроверитьПраваНаИзменениеСостоянияБизнесПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет у текущего пользователя наличие прав на изменение состояния бизнес-процесса.
//
// Параметры:
//  БизнесПроцессОбъект - ОпределяемыйТип.БизнесПроцессОбъект
//
Процедура ПроверитьПраваНаИзменениеСостоянияБизнесПроцесса(БизнесПроцессОбъект) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ПроверитьПраваНаИзменениеСостоянияБизнесПроцесса(БизнесПроцессОбъект) 
```
</details>

## ЗаблокироватьБизнесПроцессы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить исключительную управляемую блокировку на указанные бизнес-процессы.
// Для вызова из обработчиков команд в динамических списках.
// Строки группировки динамического списка игнорируются.
//
// Параметры:
//   БизнесПроцессы - ОпределяемыйТип.БизнесПроцесс
//                  - Массив из ОпределяемыйТип.БизнесПроцесс
//
Процедура ЗаблокироватьБизнесПроцессы(БизнесПроцессы) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ЗаблокироватьБизнесПроцессы(БизнесПроцессы) 
```
</details>

## ЗаблокироватьЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить исключительную управляемую блокировку на указанные задачи.
// Для вызова из обработчиков команд в динамических списках.
// Строки группировки динамического списка игнорируются.
//
// Параметры:
//   Задачи - Массив из ЗадачаСсылка.ЗадачаИсполнителя
//          - ЗадачаСсылка.ЗадачаИсполнителя
//
Процедура ЗаблокироватьЗадачи(Задачи) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ЗаблокироватьЗадачи(Задачи) 
```
</details>

## ЗаполнитьГлавнуюЗадачу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизит ГлавнаяЗадача при создании бизнес-процесса на основании другого бизнес-процесса.
// См. также БизнесПроцессыИЗадачиПереопределяемый.ПриЗаполненииГлавнойЗадачиБизнесПроцесса.
//
// Параметры:
//  БизнесПроцессОбъект	 - ОпределяемыйТип.БизнесПроцессОбъект
//  ДанныеЗаполнения	 - ЗадачаСсылка
//                  	 - Произвольный - данные заполнения, которые передаются в обработчик заполнения.
//
Процедура ЗаполнитьГлавнуюЗадачу(БизнесПроцессОбъект, ДанныеЗаполнения) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ЗаполнитьГлавнуюЗадачу(БизнесПроцессОбъект, ДанныеЗаполнения) 
```
</details>

## ГруппаИсполнителейЗадач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить группу исполнителей задач, которая соответствует реквизитам адресации.
//  Если группа еще не существует, то создается и возвращается новая.
//
// Параметры:
//  РольИсполнителя               - СправочникСсылка.РолиИсполнителей - роль исполнителя.
//  ОсновнойОбъектАдресации       - Характеристика.ОбъектыАдресацииЗадач - ссылка на основной объект адресации.
//  ДополнительныйОбъектАдресации - Характеристика.ОбъектыАдресацииЗадач - ссылка на дополнительный объект адресации.
//
// Возвращаемое значение:
//  СправочникСсылка.ГруппыИсполнителейЗадач
//
Функция ГруппаИсполнителейЗадач(РольИсполнителя, ОсновнойОбъектАдресации, ДополнительныйОбъектАдресации) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ГруппаИсполнителейЗадач(РольИсполнителя, ОсновнойОбъектАдресации, ДополнительныйОбъектАдресации) 
```
</details>

## ФормаВыполненияЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить структуру с описанием формы выполнения задачи.
//
// Параметры:
//  ЗадачаСсылка - ЗадачаСсылка.ЗадачаИсполнителя
//
// Возвращаемое значение:
//   см. БизнесПроцессыИЗадачиПереопределяемый.ПриПолученииФормыВыполненияЗадачи.ПараметрыФормы
//
Функция ФормаВыполненияЗадачи(Знач ЗадачаСсылка) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ФормаВыполненияЗадачи(ЗадачаСсылка) 
```
</details>

## ЭтоЗадачаИсполнителю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, находится ли в ячейке отчета ссылка на задачу и в параметре
// ЗначениеРасшифровки возвращает значение расшифровки.
//
// Параметры:
//  Расшифровка             - Строка - имя ячейки.
//  ДанныеРасшифровкиОтчета - Строка - адрес во временном хранилище.
//  ЗначениеРасшифровки     - ЗадачаСсылка.ЗадачаИсполнителя
//                          - Произвольный - значение расшифровки из ячейки.
//
// Возвращаемое значение:
//  Булево - Истина, если это задача исполнителю.
//
Функция ЭтоЗадачаИсполнителю(Знач Расшифровка, Знач ДанныеРасшифровкиОтчета, ЗначениеРасшифровки) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ЭтоЗадачаИсполнителю(Расшифровка, ДанныеРасшифровкиОтчета, ЗначениеРасшифровки) 
```
</details>

## ВыполнитьЗадачу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить задачу ЗадачаСсылка, при необходимости выполнив обработчик.
// ОбработкаВыполненияПоУмолчанию модуля менеджера бизнес-процесса,
// к которому относится задача ЗадачаСсылка.
//
// Параметры:
//  ЗадачаСсылка        - ЗадачаСсылка
//  ДействиеПоУмолчанию - Булево       - признак необходимости вызова процедуры
//                                       ОбработкаВыполненияПоУмолчанию у бизнес-процесса задачи.
//
Процедура ВыполнитьЗадачу(ЗадачаСсылка, ДействиеПоУмолчанию = Ложь) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ВыполнитьЗадачу(ЗадачаСсылка, ДействиеПоУмолчанию);
```
</details>

## ПеренаправитьЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перенаправить задачи МассивЗадач новому исполнителю, указанному в структуре ИнфоОПеренаправлении.
//
// Параметры:
//  ПеренаправляемыеЗадачи - Массив из ЗадачаСсылка.ЗадачаИсполнителя
//  ИнфоОПеренаправлении   - Структура - новые значения реквизитов адресации задачи.
//  ТолькоПроверка         - Булево    - если Истина, то функция не будет выполнять
//                                       физического перенаправления задач, а только
//                                       проверит возможность перенаправления.
//  ПеренаправленныеЗадачи - Массив из ЗадачаСсылка.ЗадачаИсполнителя - перенаправленные задачи.
//                                       Может отличаться по составу элементов от массива
//                                       ПеренаправляемыеЗадачи, если не все задачи удалось перенаправить.
//
// Возвращаемое значение:
//   Булево   - Истина, если перенаправление выполнено успешно.
//
Функция ПеренаправитьЗадачи(Знач ПеренаправляемыеЗадачи, Знач ИнфоОПеренаправлении, Знач ТолькоПроверка = Ложь, Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ПеренаправитьЗадачи(ПеренаправляемыеЗадачи, ИнфоОПеренаправлении, ТолькоПроверка, );
```
</details>

## ЭтоВедущаяЗадача
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли указанная задача ведущей.
//
// Параметры:
//  ЗадачаСсылка  - ЗадачаСсылка.ЗадачаИсполнителя
//
// Возвращаемое значение:
//   Булево
//
Функция ЭтоВедущаяЗадача(ЗадачаСсылка) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ЭтоВедущаяЗадача(ЗадачаСсылка) 
```
</details>

## СформироватьДанныеВыбораИсполнителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список подбора для указания исполнителя в полях ввода составного типа (Пользователь и Роль).
//
// Параметры:
//  Текст - Строка - фрагмент текста для поиска возможных исполнителей.
//
// Возвращаемое значение:
//  СписокЗначений - список подбора, содержащий возможных исполнителей.
//
Функция СформироватьДанныеВыбораИсполнителя(Текст) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.СформироватьДанныеВыбораИсполнителя(Текст) 
```
</details>

## СделатьАктивнымБизнесПроцессы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает указанные бизнес-процессы как активные.
//
// Параметры:
//  БизнесПроцессы - Массив из ОпределяемыйТип.БизнесПроцесс
//
Процедура СделатьАктивнымБизнесПроцессы(БизнесПроцессы) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.СделатьАктивнымБизнесПроцессы(БизнесПроцессы) 
```
</details>

## СделатьАктивнымБизнесПроцесс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает указанный бизнес-процесс как активный.
//
// Параметры:
//  БизнесПроцесс - ОпределяемыйТип.БизнесПроцесс
//
Процедура СделатьАктивнымБизнесПроцесс(БизнесПроцесс) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.СделатьАктивнымБизнесПроцесс(БизнесПроцесс) 
```
</details>

## ОстановитьБизнесПроцессы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает указанные бизнес-процессы как остановленные.
//
// Параметры:
//  БизнесПроцессы - Массив из ОпределяемыйТип.БизнесПроцесс
//
Процедура ОстановитьБизнесПроцессы(БизнесПроцессы) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ОстановитьБизнесПроцессы(БизнесПроцессы) 
```
</details>

## ОстановитьБизнесПроцесс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает указанный бизнес-процесс как остановленный.
//
// Параметры:
//  БизнесПроцесс - ОпределяемыйТип.БизнесПроцесс
//
Процедура ОстановитьБизнесПроцесс(БизнесПроцесс) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ОстановитьБизнесПроцесс(БизнесПроцесс) 
```
</details>

## ПринятьЗадачиКИсполнению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает указанные задачи как принятые к исполнению.
//
// Параметры:
//   Задачи - Массив из ЗадачаСсылка.ЗадачаИсполнителя
//
Процедура ПринятьЗадачиКИсполнению(Задачи) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ПринятьЗадачиКИсполнению(Задачи) 
```
</details>

## ОтменитьПринятиеЗадачКИсполнению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает указанные задачи как не принятые к исполнению.
//
// Параметры:
//   Задачи - Массив из ЗадачаСсылка.ЗадачаИсполнителя
//
Процедура ОтменитьПринятиеЗадачКИсполнению(Задачи) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ОтменитьПринятиеЗадачКИсполнению(Задачи) 
```
</details>

## ДобавитьПроцессДляОтложенногоСтарта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет процесс в очередь для отложенного старта.
//
// Параметры:
//  Процесс    - ОпределяемыйТип.БизнесПроцесс
//  ДатаСтарта - Дата - дата отложенного старта.
//
Процедура ДобавитьПроцессДляОтложенногоСтарта(Процесс, ДатаСтарта) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ДобавитьПроцессДляОтложенногоСтарта(Процесс, ДатаСтарта) 
```
</details>

## ОтключитьОтложенныйСтартПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает отложенный старт процесса.
//
// Параметры:
//  Процесс - ОпределяемыйТип.БизнесПроцесс
//
Процедура ОтключитьОтложенныйСтартПроцесса(Процесс) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ОтключитьОтложенныйСтартПроцесса(Процесс) 
```
</details>

## СтартоватьОтложенныйПроцесс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Стартует отложенный бизнес-процесс, устанавливая признак старта.
//
// Параметры:
//   БизнесПроцесс - ОпределяемыйТип.БизнесПроцесс
//
Процедура СтартоватьОтложенныйПроцесс(БизнесПроцесс) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.СтартоватьОтложенныйПроцесс(БизнесПроцесс) 
```
</details>

## ПараметрыОтложенногоПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о запуске для процесса.
//
// Параметры:
//  Процесс - ОпределяемыйТип.БизнесПроцесс
//
// Возвращаемое значение:
//  - Неопределено - если сведений нет.
//  - Структура:
//     * БизнесПроцесс - ОпределяемыйТип.БизнесПроцесс.
//     * ДатаОтложенногоСтарта - Дата
//     * Состояние - ПеречислениеСсылка.СостоянияПроцессовДляЗапуска.
//     * ПричинаОтменыСтарта - Строка - причина отмены старта.
//
Функция ПараметрыОтложенногоПроцесса(Процесс) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ПараметрыОтложенногоПроцесса(Процесс) 
```
</details>

## ДатаОтложенногоСтартаПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату старта отложенного бизнес-процесса в том случае, когда БизнесПроцесс
// ожидает отложенного старта. В противном случае возвращает пустую дату.
//
// Параметры:
//  БизнесПроцесс - ОпределяемыйТип.БизнесПроцесс
//
// Возвращаемое значение:
//  Дата
//
Функция ДатаОтложенногоСтартаПроцесса(БизнесПроцесс) Экспорт
```

Пример вызова
```bsl
Результат = БизнесПроцессыИЗадачиСервер.ДатаОтложенногоСтартаПроцесса(БизнесПроцесс) 
```
</details>

## УведомитьИсполнителейОНовыхЗадачах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет рассылку уведомлений исполнителям о новых задачах за период с момента предыдущей рассылки.
// Рассылка выполняется по почте от системной учетной записи.
// Также является обработчиком регламентного задания УведомлениеИсполнителейОНовыхЗадачах.
//
Процедура УведомитьИсполнителейОНовыхЗадачах() Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.УведомитьИсполнителейОНовыхЗадачах() 
```
</details>

## ПроконтролироватьЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет рассылку уведомлений исполнителям и авторам задач о задачах, не выполненных в срок.
// Рассылка выполняется по почте от системной учетной записи.
// Если задача направлена "в никуда", т.е. роли с пустым списком исполнителей,
// то создается новая задача ответственным за настройку ролей.
//
// Также является обработчиком регламентного задания МониторингЗадач.
//
Процедура ПроконтролироватьЗадачи() Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ПроконтролироватьЗадачи() 
```
</details>

## НачатьОбновлениеПорцииНаборовЗначенийДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить первую порцию объектов для отложенной обработки прав доступа.
// Для вызова из отложенных обработчиков обновления при изменении логики формирования наборов значений доступа.
//
// Параметры:
//   Параметры     - Структура - структура параметров отложенного обработчика обновления.
//   БизнесПроцесс - ОбъектМетаданныхБизнесПроцесс  - метаданные бизнес-процесса, наборы значений доступа
//                   которого требуется обновить.
//   ИмяПроцедуры  - Строка - имя процедуры отложенного обработчика обновления для журнала регистрации.
//   РазмерПорции  - Число  - количество объектов, обрабатываемых за один вызов.
//
Процедура НачатьОбновлениеПорцииНаборовЗначенийДоступа(Параметры, БизнесПроцесс, ИмяПроцедуры, РазмерПорции = 1000) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.НачатьОбновлениеПорцииНаборовЗначенийДоступа(Параметры, БизнесПроцесс, ИмяПроцедуры, РазмерПорции);
```
</details>

## ЗавершитьОбновлениеПорцииНаборовЗначенийДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Завершить обработку первой порции объектов для отложенной обработки прав доступа.
// Для вызова из отложенных обработчиков обновления при изменении логики формирования наборов значений доступа.
//
// Параметры:
//   Параметры - Структура - параметры отложенного обработчика обновления.
//
Процедура ЗавершитьОбновлениеПорцииНаборовЗначенийДоступа(Параметры) Экспорт
```

Пример вызова
```bsl
БизнесПроцессыИЗадачиСервер.ЗавершитьОбновлениеПорцииНаборовЗначенийДоступа(Параметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
