---
title: Варианты отчетов
slug: bsp/варианты-отчетов
---


## ВариантОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на вариант отчета.
//
// Параметры:
//  Отчет - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//        - СправочникСсылка.ДополнительныеОтчетыИОбработки
//        - Строка - ссылка на отчет или полное имя внешнего отчета.
//  КлючВарианта - Строка - имя варианта отчета.
//
// Возвращаемое значение:
//  СправочникСсылка.ВариантыОтчетов, Неопределено - вариант отчета,
//          либо Неопределено, если отчет отсутствует или недоступен по правам.
//
Функция ВариантОтчета(Отчет, КлючВарианта) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ВариантОтчета(Отчет, КлючВарианта) 
```
</details>

## ОтчетыТекущегоПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает отчеты (СправочникСсылка.ВариантыОтчетов), доступные текущему пользователю.
// Их следует использовать во всех запросах к таблице
// справочника "ВариантыОтчетов" как отбор по реквизиту "Отчет",
// кроме случаев выборки вариантов из внешних отчетов.
//
// Возвращаемое значение:
//  Массив - отчеты, доступные текущему пользователю (СправочникСсылка.ИдентификаторыОбъектовРасширений,
//           Строка, СправочникСсылка.ДополнительныеОтчетыИОбработки,
//           СправочникСсылка.ИдентификаторыОбъектовМетаданных).
//           Тип элементов совпадает с типом реквизита Справочники.ВариантыОтчетов.Реквизиты.Отчет.
//
Функция ОтчетыТекущегоПользователя() Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ОтчетыТекущегоПользователя() 
```
</details>

## КлючиВариантовОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список вариантов отчета из хранилища настроек ХранилищеВариантовОтчетов.
// См. также СтандартноеХранилищеНастроекМенеджер.ПолучитьСписок в синтакс-помощнике.
// В отличие от метода платформы, вместо права "АдминистрированиеДанных" проверяются права доступа к отчету.
//
// Параметры:
//  КлючОтчета - Строка - полное имя отчета с точкой.
//  Пользователь - Строка
//               - УникальныйИдентификатор
//               - ПользовательИнформационнойБазы
//               - Неопределено
//               - СправочникСсылка.Пользователи - имя, идентификатор или ссылка на пользователя,
//                                                 настройки которого требуется получить.
//                                                 Если Неопределено, то текущий пользователь.
//
// Возвращаемое значение:
//   СписокЗначений - список вариантов отчета, где:
//       * Значение - Строка - ключ варианта отчета.
//       * Представление - Строка - представление варианта отчета.
//
//
Функция КлючиВариантовОтчета(КлючОтчета, Знач Пользователь = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.КлючиВариантовОтчета(КлючОтчета, Пользователь);
```
</details>

## УдалитьВариантОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет варианты указанного отчета или всех отчетов.
// См. также СтандартноеХранилищеНастроекМенеджер.Удалить в синтакс-помощнике.
//
// Параметры:
//  КлючОтчета - Строка
//             - Неопределено - полное имя отчета с точкой.
//                              Если Неопределено, то удаляются настройки всех отчетов.
//  КлючВарианта - Строка
//               - Неопределено - ключ удаляемого варианта отчета.
//                                Если Неопределено, то удаляются все варианты отчета.
//  Пользователь - Строка
//               - УникальныйИдентификатор
//               - ПользовательИнформационнойБазы
//               - Неопределено
//               - СправочникСсылка.Пользователи - имя, идентификатор или ссылка на пользователя,
//                                                 настройки которого удаляются.
//                                                 Если Неопределено, то удаляются настройки всех пользователей.
//
Процедура УдалитьВариантОтчета(КлючОтчета, КлючВарианта, Знач Пользователь) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.УдалитьВариантОтчета(КлючОтчета, КлючВарианта, Пользователь) 
```
</details>

## НастроитьОтчетВМодулеМенеджера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает модуль менеджера отчета для заполнения его настроек.
// Для вызова из процедуры ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.
//
// Параметры:
//  Настройки - см. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.Настройки.
//  ОтчетМетаданные - ОбъектМетаданных - метаданные отчета, в модуле менеджера которого расположена
//                                       экспортная процедура НастроитьВариантыОтчета(Настройки, НастройкиОтчета).
//
Процедура НастроитьОтчетВМодулеМенеджера(Настройки, ОтчетМетаданные) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.НастроитьОтчетВМодулеМенеджера(Настройки, ОтчетМетаданные) 
```
</details>

## ОписаниеОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки указанного отчета. Используется для настройки размещения и общих параметров отчета
//   в ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.
//
// Параметры:
//  Настройки - см. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.Настройки.
//  Отчет     - ОбъектМетаданныхОтчет
//            - СправочникСсылка.ИдентификаторыОбъектовМетаданных - метаданные или ссылка отчета.
//
// Возвращаемое значение:
//   СтрокаДереваЗначений - настройки отчета и настройки "по умолчанию" для вариантов этого отчета, где:
//       * Включен              - Булево - если Ложь, то вариант отчета не выводится в панели отчетов.
//       * ВидимостьПоУмолчанию - Булево - если Ложь, то вариант отчета по умолчанию скрыт в панели отчетов.
//       * ПоказыватьВПодменюВариантов - Булево - если Ложь, то вариант отчета не отображается в подменю выбора вариантов
//                                                отчета в форме отчета. Используется, когда Включен - Ложь.
//       * Размещение           - Соответствие из КлючИЗначение - настройки размещения варианта отчета в разделах, где:
//           ** Ключ     - ОбъектМетаданных - подсистема, в которой размещается отчет или вариант отчета.
//           ** Значение - Строка           - настройки размещения в подсистеме (группе), с вариантами значений:
//               ""        - вывод отчета в подсистеме без специального выделение.
//               "Важный"  - вывод отчета в подсистеме с выделением жирным шрифтом.
//               "СмТакже" - вывод отчета в группе "См. также".
//       * ФункциональныеОпции - Массив из Строка - имена функциональных опций варианта отчета.
//       * НастройкиДляПоиска  - Структура - дополнительные настройки для поиска этого варианта отчета, где:
//             ** НаименованияПолей - Строка - имена полей варианта отчета.
//             ** НаименованияПараметровИОтборов - Строка - имена настроек варианта отчета.
//             ** КлючевыеСлова - Строка - дополнительная терминология (в т.ч. специализированная или устаревшая).
//             ** ИменаМакетов  - Строка - используется вместо НаименованияПолей.
//       * ФорматНастроекСКД - Булево - отчет использует типовой формат хранения настроек на механике СКД,
//           а его основные формы поддерживают стандартную схему взаимодействия между формами (параметры и тип
//           возвращаемого значения).
//           Если Ложь, тогда для отчета отключаются проверки консистентности и некоторые механизмы, которые
//           рассчитывают на типовой формат.
//       * ОпределитьНастройкиФормы - Булево - отчет имеет программный интерфейс для тесной интеграции с формой отчета,
//           в том числе может переопределять некоторые настройки формы и подписываться на ее события.
//           Если Истина и отчет подключен к общей форме ФормаОтчета,
//           тогда в модуле объекта отчета следует определить процедуру по шаблону:
//
//               // Задать настройки формы отчета.
//               //
//               // Параметры:
//               //   Форма - ФормаКлиентскогоПриложения, Неопределено
//               //   КлючВарианта - Строка, Неопределено
//               //   Настройки - см. ОтчетыКлиентСервер.НастройкиОтчетаПоУмолчанию
//               //
//               Процедура ОпределитьНастройкиФормы(Форма, КлючВарианта, Настройки) Экспорт
//               	// Код процедуры.
//               КонецПроцедуры
//
//       * Отчет - СправочникСсылка.ИдентификаторыОбъектовРасширений
//               - СправочникСсылка.ДополнительныеОтчетыИОбработки
//               - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//               - Строка - полное имя или ссылка на отчет.
//       * Метаданные - ОбъектМетаданныхОтчет - метаданные отчета.
//       * КлючВарианта - Строка - имя варианта отчета.
//       * ОписаниеПолучено - Булево - флажок что описание строки уже получено.
//           Описание получается методом ОписаниеВарианта().
//       * СистемнаяИнформация - Структура - другая служебная информация.
//     При этом колонки Отчет, Метаданные, КлючВарианта, ОписаниеПолучено, СистемнаяИнформация
//     являются служебными и предназначены только для чтения.
//
Функция ОписаниеОтчета(Настройки, Отчет) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ОписаниеОтчета(Настройки, Отчет) 
```
</details>

## ОписаниеВарианта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит настройки варианта отчета. Используется для настройки размещения.
// Для использования в ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.
//
// Параметры:
//  Настройки    - см. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.Настройки.
//  Отчет        - СтрокаДереваЗначений
//               - ОбъектМетаданных - описание настроек, метаданные или ссылка отчета.
//  КлючВарианта - Строка - имя варианта отчета как оно задано в схеме компоновки данных.
//
// Возвращаемое значение:
//   СтрокаДереваЗначений - настройки варианта отчета, где:
//       * Включен              - Булево - если Ложь, то вариант отчета не выводится в панели отчетов.
//       * ВидимостьПоУмолчанию - Булево - если Ложь, то вариант отчета по умолчанию скрыт в панели отчетов.
//       * ПоказыватьВПодменюВариантов - Булево - если Ложь, то вариант отчета не отображается в подменю выбора вариантов
//                                                отчета в форме отчета. Используется, когда Включен - Ложь.
//       * Наименование         - Строка - наименование варианта отчета.
//       * Описание             - Строка - подсказка к варианту отчета.
//       * Размещение           - Соответствие из КлючИЗначение - настройки размещения варианта отчета в разделах, где:
//           ** Ключ     - ОбъектМетаданных - подсистема, в которой размещается отчет или вариант отчета.
//           ** Значение - Строка           - настройки размещения в подсистеме (группе), с вариантами значений:
//               ""        - вывод варианта в подсистеме без специального выделение.
//               "Важный"  - вывод варианта в подсистеме с выделением жирным шрифтом.
//               "СмТакже" - вывод варианта в группе "См. также".
//       * ФункциональныеОпции - Массив из Строка - имена функциональных опций варианта отчета.
//       * НастройкиДляПоиска  - Структура - дополнительные настройки для поиска этого варианта отчета, где:
//           ** НаименованияПолей              - Строка - имена полей варианта отчета.
//           ** НаименованияПараметровИОтборов - Строка - имена настроек варианта отчета.
//           ** КлючевыеСлова                  - Строка - дополнительная терминология (в т.ч. специализированная или устаревшая).
//           ** ИменаМакетов                   - Строка - используется вместо НаименованияПолей.
//       * ФорматНастроекСКД - Булево - отчет использует типовой формат хранения настроек на механике СКД,
//           а его основные формы поддерживают стандартную схему взаимодействия между формами (параметры и тип
//           возвращаемого значения).
//           Если Ложь, тогда для отчета отключаются проверки консистентности и некоторые механизмы, которые
//           рассчитывают на типовой формат.
//       * ОпределитьНастройкиФормы - Булево - отчет имеет программный интерфейс для тесной интеграции с формой отчета,
//           в том числе может переопределять некоторые настройки формы и подписываться на ее события.
//           Если Истина и отчет подключен к общей форме ФормаОтчета,
//           тогда в модуле объекта отчета следует определить процедуру по шаблону:
//
//               // Задать настройки формы отчета.
//               //
//               // Параметры:
//               //   Форма - ФормаКлиентскогоПриложения, Неопределено
//               //   КлючВарианта - Строка, Неопределено
//               //   Настройки - см. значение ОтчетыКлиентСервер.НастройкиОтчетаПоУмолчанию
//               //
//               Процедура ОпределитьНастройкиФормы(Форма, КлючВарианта, Настройки) Экспорт
//               	// Код процедуры.
//               КонецПроцедуры
//
//       * Отчет - СправочникСсылка.ИдентификаторыОбъектовРасширений
//               - СправочникСсылка.ДополнительныеОтчетыИОбработки
//               - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//               - Строка - полное имя или ссылка на отчет.
//       * Описание - Строка
//       * Метаданные - ОбъектМетаданныхОтчет - метаданные отчета.
//       * КлючВарианта - Строка - имя варианта отчета.
//       * Назначение - ПеречислениеСсылка.НазначенияВариантовОтчетов - назначение использования варианта отчета (по
//                                                                      умолчанию - ДляКомпьютеровИПланшетов)
//       * ОписаниеПолучено - Булево - флажок что описание строки уже получено.
//           Описание получается методом ОписаниеВарианта().
//       * СистемнаяИнформация - Структура - другая служебная информация.
//     При этом колонки Отчет, Метаданные, КлючВарианта, ОписаниеПолучено, СистемнаяИнформация
//     являются служебными и предназначены только для чтения.
//
Функция ОписаниеВарианта(Настройки, Отчет, КлючВарианта) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ОписаниеВарианта(Настройки, Отчет, КлючВарианта) 
```
</details>

## УстановитьРежимВыводаВПанеляхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает режим вывода Отчетов и Вариантов в панелях отчетов.
// Для вызова из процедуры ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов переопределяемого модуля
// и из процедуры НастроитьВариантыОтчета модуля объекта отчета.
//
// Параметры:
//  Настройки - см. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.Настройки.
//  ОтчетИлиПодсистема - СтрокаДереваЗначений
//                     - ОбъектМетаданныхОтчет
//                     - ОбъектМетаданныхПодсистема - описание отчета или
//                       подсистемы, для которой устанавливается режим вывода. Когда передана подсистема режим
//                       устанавливается рекурсивно для всех отчетов из ее состава.
//  ГруппироватьПоОтчетам - Булево
//                        - Строка - режим вывода гиперссылок этого отчета в панели отчетов:
//                          Если Истина, "ПоОтчетам" - варианты группируются по отчету.
//                          По умолчанию в панелях отчетов выводится только основной вариант отчета,
//                          а все прочие варианты этого отчета выводятся "под" основным и по умолчанию скрыты
//                          (но могут быть найдены поиском или включены при помощи флажков в режиме настройки).
//                          Основным вариантом считается первый предопределенный вариант в схеме отчета.
//                          Этот режим появился в версии 2.2.2 и позволяет уменьшить количество гиперссылок, выводимых в
//                          панелях отчетов. Если Ложь, "ПоВариантам" - все варианты отчета считаются самостоятельными,
//                          по умолчанию видны и выводятся независимо в панелях отчетов.
//                          Этот режим использовался в версии 2.2.1 и ранее.
//
Процедура УстановитьРежимВыводаВПанеляхОтчетов(Настройки, ОтчетИлиПодсистема, ГруппироватьПоОтчетам) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.УстановитьРежимВыводаВПанеляхОтчетов(Настройки, ОтчетИлиПодсистема, ГруппироватьПоОтчетам) 
```
</details>

## ПриСохраненииПользовательскихНастроекНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет состав справочника ПользовательскиеНастройкиОтчетов после сохранения новой настройки.
// Вызывается в одноименном обработчике формы отчета после выполнения кода формы.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма отчета.
//  Настройки - ПользовательскиеНастройкиКомпоновкиДанных - передается "как есть" из процедуры ПриСохраненииПользовательскихНастроекНаСервере.
//
Процедура ПриСохраненииПользовательскихНастроекНаСервере(Форма, Настройки) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ПриСохраненииПользовательскихНастроекНаСервере(Форма, Настройки) 
```
</details>

## ИспользуемыеТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлекает информацию о таблицах, используемых в схеме или запросе.
// Обработка исключений (например, в случае передачи некорректного текста запроса) выполняется вызывающим кодом.
//
// Параметры:
//  Объект - СхемаКомпоновкиДанных
//         - Строка - схема отчета или текст запроса.
//
// Возвращаемое значение:
//   Массив - имена таблиц, используемые в схеме или запросе.
//
// Пример:
//  // Вызов из собственной формы отчета, использующего СКД.
//  ИспользуемыеТаблицы = ВариантыОтчетов.ИспользуемыеТаблицы(РеквизитФормыВЗначение("Отчет").СхемаКомпоновкиДанных);
//  ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(ИспользуемыеТаблицы);
//  // Вызов из обработчика ПриКомпоновкеРезультата отчета, использующего СКД.
//  ИспользуемыеТаблицы = ВариантыОтчетов.ИспользуемыеТаблицы(СхемаКомпоновкиДанных);
//  ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(ИспользуемыеТаблицы);
//  // Вызов из обработчика ПриКомпоновкеРезультата отчета, использующего запрос.
//  ИспользуемыеТаблицы = ВариантыОтчетов.ИспользуемыеТаблицы(ТекстЗапроса);
//  ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(ИспользуемыеТаблицы);
//
Функция ИспользуемыеТаблицы(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ИспользуемыеТаблицы(Объект) 
```
</details>

## ИспользуемыеТаблицыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлекает информацию о таблицах, используемых в схеме или запросе.
//
// Параметры:
//  Отчет - ОбъектМетаданныхОтчет
//        - ОтчетОбъект
//
// Возвращаемое значение:
//   Массив из см. ИспользуемыеТаблицы
//
Функция ИспользуемыеТаблицыОтчета(Отчет) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ИспользуемыеТаблицыОтчета(Отчет) 
```
</details>

## ПроверитьИспользуемыеТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет что таблицы, используемые в схеме или запросе, еще обновляются, и сообщает об этом пользователю.
// Проверка выполняется методом ОбновлениеИнформационнойБазы.ОбъектОбработан().
// Обработка исключений (например, в случае передачи некорректного текста запроса) выполняется вызывающим кодом.
//
// Параметры:
//  Объект - СхемаКомпоновкиДанных - схема отчета.
//         - Строка - текст запроса.
//         - Массив - имена таблиц, используемые отчетом:
//           * Строка - имя таблицы.
//  Сообщать - Булево - когда Истина и таблицы, используемые отчетом, еще не обновлены,
//             то будет выведено сообщение вида "Отчет может содержать некорректные данные".
//             Необязательный. По умолчанию Истина.
//
// Возвращаемое значение:
//   Булево - Истина когда в списке таблиц есть таблицы, которые еще не обновлены.
//
// Пример:
//  // Вызов из собственной формы отчета.
//  ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(РеквизитФормыВЗначение("Отчет").СхемаКомпоновкиДанных);
//  // Вызов из обработчика ПриКомпоновкеРезультата отчета.
//  ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(СхемаКомпоновкиДанных);
//  // Вызов при выполнении запроса.
//  ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(ТекстЗапроса);
//
Функция ПроверитьИспользуемыеТаблицы(Объект, Сообщать = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ПроверитьИспользуемыеТаблицы(Объект, Сообщать);
```
</details>

## СброситьПользовательскиеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сбрасывает пользовательские настройки указанных отчетов.
//
// Параметры:
//  Ключ - ОбъектМетаданныхОтчет - метаданные отчета, для которого требуется сбросить настройки.
//       - СправочникСсылка.ВариантыОтчетов - вариант отчета, для которого требуется сбросить настройки.
//       - Строка - полное имя варианта отчета, для которого требуется сбросить настройки.
//                  Заполняется в формате "<ИмяОтчета>/<ИмяВарианта>".
//                  Если передать "*", то будут сброшены настройки всех отчетов конфигурации.
//  ТипыНастроек - Структура - типы пользовательских настроек, которые требуется сбросить.
//      Ключи структуры тоже являются необязательными. Значение по умолчанию указано в скобках:
//      * ЭлементОтбора - Булево - (Ложь) сбрасывать настройку "ЭлементОтбораКомпоновкиДанных".
//      * ЗначениеПараметраНастроек - Булево - (Ложь) сбрасывать настройку "ЗначениеПараметраНастроекКомпоновкиДанных".
//      * ВыбранныеПоля - Булево - (берется из ключа Прочие) сбрасывать настройку "ВыбранныеПоляКомпоновкиДанных".
//      * Порядок - Булево - (берется из ключа Прочие) сбрасывать настройку "ПорядокКомпоновкиДанных".
//      * ЭлементУсловногоОформления - Булево - (берется из ключа Прочие) сбрасывать настройку "ЭлементУсловногоОформленияКомпоновкиДанных".
//      * Прочие - Булево - (Истина) сбрасывать прочие настройки, не описанные в структуре явно.
//
Процедура СброситьПользовательскиеНастройки(Ключ, ТипыНастроек = Неопределено) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.СброситьПользовательскиеНастройки(Ключ, ТипыНастроек);
```
</details>

## ПеренестиПользовательскиеИзСтандартногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переносит пользовательские варианты из стандартного хранилища вариантов в хранилище подсистемы.
// Используется при частичном внедрении - когда ХранилищеВариантовОтчетов установлено не для всей конфигурации,
// а в свойствах конкретных отчетов, подключенных к подсистеме.
// Рекомендуется использовать в обработчиках обновления на конкретную версию.
//
// Параметры:
//  ИменаОтчетов - Строка - имена отчетов, разделенные запятыми.
//                          Если параметр не указан, то переносятся все отчеты
//                          стандартного хранилища, после чего оно полностью очищается.
//
// Пример:
//  // Перенос всех пользовательских вариантов отчетов при обновлении.
//  ВариантыОтчетов.ПеренестиПользовательскиеИзСтандартногоХранилища();
//  // Перенос пользовательских вариантов отчетов, переведенных в хранилище подсистемы "Варианты отчетов".
//  ВариантыОтчетов.ПеренестиПользовательскиеИзСтандартногоХранилища("АнализЖурналаРегистрации, ЗадачиИстекающиеНаДату");
//
Процедура ПеренестиПользовательскиеИзСтандартногоХранилища(ИменаОтчетов = "") Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ПеренестиПользовательскиеИзСтандартногоХранилища(ИменаОтчетов);
```
</details>

## ЗагрузитьПользовательские
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает в хранилище подсистемы варианты отчетов, предварительно сохраненные
// из системного хранилища вариантов в хранилище общих настроек.
// Используется для загрузки вариантов отчетов при полном или частичном внедрении.
// При полном внедрении может вызваться из обработки "ПереносВариантовОтчетов".
// Рекомендуется использовать в обработчиках обновления на конкретную версию.
//
// Параметры:
//  ПользовательскиеВарианты - ТаблицаЗначений
//                           - Неопределено - необязательный. Используется в служебных сценариях:
//       * Отчет - Строка - полное имя отчета в формате "Отчет.<ИмяОтчета>".
//       * Вариант - Строка - имя варианта отчета.
//       * Автор - Строка - имя пользователя.
//       * Настройка - ХранилищеЗначения - пользовательскиеНастройкиКомпоновкиДанных.
//       * ПредставлениеОтчета - Строка - представление отчета.
//       * ПредставлениеВарианта - Строка - представление варианта.
//       * ИдентификаторАвтора - УникальныйИдентификатор - идентификатор пользователя.
//
Процедура ЗагрузитьПользовательские(ПользовательскиеВарианты = Неопределено) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ЗагрузитьПользовательские(ПользовательскиеВарианты);
```
</details>

## ПоделитьсяПользовательскимиНастройками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//   ВыбранныеПользователи - СписокЗначений:
//     * Значение - СправочникСсылка.Пользователи
//                - СправочникСсылка.ГруппыПользователей
//                - СправочникСсылка.ГруппыВнешнихПользователей
//  ШаблонОписанияНастроек - Структура - параметры открытия формы выбора пользователей, (групп) пользователей, где:
//      * Настройки - ПользовательскиеНастройкиКомпоновкиДанных - настройки, которыми обмениваются.
//      * ВариантОтчета - СправочникСсылка.ВариантыОтчетов - ссылка на хранилище свойств варианта отчета.
//      * КлючОбъекта - Строка - измерение хранения настроек.
//      * КлючНастроек - Строка - измерение - идентификатор пользовательских настроек.
//      * Представление - Строка - наименование пользовательских настроек.
//      * ВариантМодифицирован - Булево - признак того, что вариант отчета изменен.
//
Процедура ПоделитьсяПользовательскимиНастройками(ВыбранныеПользователи, ШаблонОписанияНастроек) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ПоделитьсяПользовательскимиНастройками(ВыбранныеПользователи, ШаблонОписанияНастроек) 
```
</details>

## СвойстваПользователейНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//  ВыбранныеПользователи - СписокЗначений:
//    * Значение - СправочникСсылка.Пользователи
//               - СправочникСсылка.ГруппыПользователей
//               - СправочникСсылка.ГруппыВнешнихПользователей
//  ТекущийПользователь - СправочникСсылка.ВнешниеПользователи
//                      - СправочникСсылка.Пользователи
//
// Возвращаемое значение:
//  Структура:
//    * Недействительных - Массив из Структура
//    * Действительных - Массив из Структура
//
Функция СвойстваПользователейНастроек(ВыбранныеПользователи, ТекущийПользователь) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.СвойстваПользователейНастроек(ВыбранныеПользователи, ТекущийПользователь));
```
</details>

## СвойстваПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//  Ссылка - СправочникСсылка.Пользователи
//         - СправочникСсылка.ВнешниеПользователи
//  ИмяПользователяИБ - Строка
//  ИдентификаторПользователяИБ - УникальныйИдентификатор
//
// Возвращаемое значение:
//  Структура:
//    * Ссылка - СправочникСсылка.Пользователи
//             - СправочникСсылка.ВнешниеПользователи
//    * Имя - Строка
//    * ИдентификаторПользователяИБ - УникальныйИдентификатор
//
Функция СвойстваПользователя(Ссылка, ИмяПользователяИБ, ИдентификаторПользователяИБ) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.СвойстваПользователя(Ссылка, ИмяПользователяИБ, ИдентификаторПользователяИБ));
```
</details>

## ПроверитьДоступностьВариантаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверитьДоступностьВариантаОтчета(ВариантОтчета, ВыбранныеПользователи) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ПроверитьДоступностьВариантаОтчета(ВариантОтчета, ВыбранныеПользователи));
```
</details>

## НормализоватьШаблонОписанияНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НормализоватьШаблонОписанияНастроек(ШаблонОписанияНастроек, ТекущийПользователь) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.НормализоватьШаблонОписанияНастроек(ШаблонОписанияНастроек, ТекущийПользователь));
```
</details>

## УстановитьПредставлениеПользовательскихНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПредставлениеПользовательскихНастроек(ШаблонОписанияНастроек, ТекущийПользователь) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.УстановитьПредставлениеПользовательскихНастроек(ШаблонОписанияНастроек, ТекущийПользователь));
```
</details>

## ОбновитьСлужебнуюИнформациюПользовательскихНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСлужебнуюИнформациюПользовательскихНастроек(Пользователь, ОписаниеНастроек, Настройки) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ОбновитьСлужебнуюИнформациюПользовательскихНастроек(Пользователь, ОписаниеНастроек, Настройки));
```
</details>

## ОповеститьПользователейНастроекОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОповеститьПользователейНастроекОтчета(СвойстваПользователей, ОписаниеНастроек) Экспорт
```

Пример вызова
```bsl
ВариантыОтчетов.ОповеститьПользователейНастроекОтчета(СвойстваПользователей, ОписаниеНастроек));
```
</details>

## КоллекцияПредопределенныхВариантовОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции предопределенных вариантов отчетов.
//
// Возвращаемое значение:
//   см. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов.Настройки.
//
Функция КоллекцияПредопределенныхВариантовОтчетов() Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.КоллекцияПредопределенныхВариантовОтчетов());
```
</details>

## ОписаниеОтчетаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание указанного отчета по умолчанию.
//
// Параметры:
//  ОписанияОтчетов - см. КоллекцияПредопределенныхВариантовОтчетов
//  МетаданныеОтчета - ОбъектМетаданныхОтчет
//  СсылкаОтчета - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//               - СправочникСсылка.ИдентификаторыОбъектовРасширений
//  ТипОтчета - см. ТипОтчетаСтрокой
//  ГруппироватьПоОтчетам - см. ГлобальныеНастройки
//
// Возвращаемое значение:
//   СтрокаТаблицыЗначений - см. КоллекцияПредопределенныхВариантовОтчетов
//
Функция ОписаниеОтчетаПоУмолчанию(ОписанияОтчетов, МетаданныеОтчета, СсылкаОтчета, Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ОписаниеОтчетаПоУмолчанию(ОписанияОтчетов, МетаданныеОтчета, СсылкаОтчета, );
```
</details>

## НайденныеОписанияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив с одним элементом - описание по умолчанию указанного отчета.
//
// Параметры:
//  Отчет - ОбъектМетаданныхОтчет
//        - СправочникСсылка.ИдентификаторыОбъектовМетаданных - метаданные или ссылка отчета.
//
// Возвращаемое значение:
//   Массив из см. КоллекцияПредопределенныхВариантовОтчетов
//
Функция НайденныеОписанияОтчета(Отчет) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.НайденныеОписанияОтчета(Отчет));
```
</details>

## РезультатАктуализацииВариантовОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор результата актуализации вариантов отчетов.
//
// Возвращаемое значение:
//   Структура - коллекция свойств результата актуализации вариантов отчетов, где:
//       * ЕстьИзменения - Булево - признак наличия изменений в вариантах отчетов.
//       * ЕстьВажныеИзменения - Булево - признак наличия важных изменений в вариантах отчетов.
//       * ПустаяСсылка - СправочникСсылка.ВариантыОтчетов - ссылка на пустой вариант отчета.
//       * ОбработанныеПредопределенные - Соответствие - индекс обработанных вариантов отчетов.
//       * ОсновныеВарианты - см. КоллекцияОсновныхВариантовОтчетов
//
Функция РезультатАктуализацииВариантовОтчетов() Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.РезультатАктуализацииВариантовОтчетов());
```
</details>

## КоллекцияОсновныхВариантовОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции основных вариантов отчетов.
//
// Возвращаемое значение:
//   ТаблицаЗначений - коллекция основных вариантов отчетов, где:
//       * Отчет - СправочникСсылка.ИдентификаторыОбъектовРасширений
//               - СправочникСсылка.ДополнительныеОтчетыИОбработки
//               - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//               - Строка - ссылка на идентификатор метаданных отчета.
//       * Вариант - СправочникСсылка.ВариантыОтчетов - ссылка на вариант отчета.
//
Функция КоллекцияОсновныхВариантовОтчетов() Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.КоллекцияОсновныхВариантовОтчетов());
```
</details>

## РезультатОбновленияОбщихДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор результата обновления общих данных.
//
// Параметры:
//  Режим - Строка - вид обновления данных.
//  РазделенныеОбработчики - Структура
//
// Возвращаемое значение:
//   Структура - свойства результата обновления общих данных, где:
//       * ОбновлятьКонфигурацию - Булево - признак необходимости обновления данных конфигурации.
//       * ОбновлятьРасширения - Булево - признак необходимости обновления данных расширений.
//       * РазделенныеОбработчики - Структура
//       * ЕстьИзменения - Булево - признак наличия изменений в вариантах отчетов.
//       * ЕстьВажныеИзменения - Булево - признак наличия важных изменений в вариантах отчетов.
//       * ВариантыОтчетов - ТаблицаЗначений
//       * ОбновлятьЗамеры - Булево - признак наличия подсистемы ОценкаПроизводительности.
//       * ТаблицаЗамеров - см. ТаблицаЗамеров
//       * МодельСервиса - Булево - признак работы в модели сервиса.
//
Функция РезультатОбновленияОбщихДанных(Знач Режим, Знач РазделенныеОбработчики) Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.РезультатОбновленияОбщихДанных(Режим, РазделенныеОбработчики));
```
</details>

## ТаблицаЗамеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор таблицы замеров.
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//       * СтароеИмя - Строка - не актуальный ключ замеров.
//       * АктуальноеИмя - Строка - текущий ключ замеров.
//       * АктуальноеНаименование - Строка - текущее наименование отчета.
//
Функция ТаблицаЗамеров() Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ТаблицаЗамеров());
```
</details>

## ВариантыОтчетовДляВывода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, содержащей результат поиск доступных вариантов отчетов.
//
// Возвращаемое значение:
//  Структура:
//    * ТолькоТекущийРаздел - Булево
//    * ТаблицаПодсистем - ТаблицаЗначений:
//        ** Ссылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                  - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** Представление - Строка
//        ** Имя - Строка
//        ** ПолноеИмя - Строка
//        ** Приоритет - Строка
//        ** НомерЭлемента - Число
//        ** ИмяЭлемента - Строка
//        ** РодительСсылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                          - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** РазделСсылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                        - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** ВидимыхВариантов - Число
//    * ДругиеРазделы - Массив
//    * Варианты - ТаблицаЗначений:
//        ** Ссылка - СправочникСсылка.ВариантыОтчетов
//        ** Подсистема - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                      - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** ПодсистемаПредставление - Строка
//        ** ПодсистемаПриоритет - Строка
//        ** РазделСсылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                        - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** БезГруппы - Булево
//        ** Важный - Булево
//        ** СмТакже - Булево
//        ** Дополнительный - Булево
//        ** Видимость - Булево
//        ** БыстрыйДоступ - Булево
//        ** ИмяОтчета - Строка
//        ** Наименование - Строка
//        ** Описание - Строка
//        ** Автор - СправочникСсылка.Пользователи
//                 - СправочникСсылка.ВнешниеПользователи
//        ** Отчет - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                 - СправочникСсылка.ИдентификаторыОбъектовРасширений
//                 - СправочникСсылка.ДополнительныеОтчетыИОбработки
//                 - Строка
//        ** ТипОтчета - ПеречислениеСсылка.ТипыОтчетов
//        ** КлючВарианта - Строка
//        ** Родитель - СправочникСсылка.ВариантыОтчетов
//        ** ВерхнийУровень - Булево
//        ** КлючЗамеров - Строка
//    * ВариантыРаздела - см. ВариантыОтчетовДляВывода.Варианты
//    * ИспользоватьПодсветку - Булево
//    * РезультатПоиска - см. НайтиВариантыОтчетов
//    * МассивСлов - Массив
//    * ИмяГруппы - Строка
//    * ДобавляемыеРеквизиты - Массив из РеквизитФормы
//    * ДобавленоПустыхДекораций - Число
//    * ПределВывода - Число
//    * ОсталосьВывести - Число
//    * НеВыведено - Число
//    * ВыведеноЭлементовВариантов - Число
//    * ПоискВариантов - Соответствие
//    * Шаблоны - Структура:
//        ** ГруппаВарианта - Структура:
//             *** Вид - ВидГруппыФормы
//             *** РастягиватьПоГоризонтали - Булево
//             *** Отображение - ОтображениеОбычнойГруппы
//             *** Группировка - ГруппировкаПодчиненныхЭлементовФормы
//             *** ОтображатьЗаголовок - Булево
//        ** КартинкаБыстрогоДоступа - Структура:
//             *** Вид - ВидДекорацииФормы
//             *** Ширина - Число
//             *** Высота - Число
//             *** Картинка - Картинка
//             *** РастягиватьПоГоризонтали - Булево
//             *** РастягиватьПоВертикали - Булево
//        ** КартинкаОтступа - Структура:
//             *** Вид - ВидДекорацииФормы
//             *** Ширина - Число
//             *** Высота - Число
//             *** РастягиватьПоГоризонтали - Булево
//             *** РастягиватьПоВертикали - Булево
//        ** НадписьВарианта - Структура:
//             *** Вид - ВидДекорацииФормы
//             *** Гиперссылка - Булево
//             *** ЦветТекста - Цвет
//             *** РастягиватьПоВертикали - Булево
//             *** Высота - Число
//             *** РастягиватьПоГоризонтали - Булево
//             *** АвтоМаксимальнаяШирина - Булево
//             *** МаксимальнаяШирина - Число
//    * КонтекстноеМеню - Структура:
//        ** УбратьИзБыстрогоДоступа - Структура:
//             *** Видимость - Булево
//        ** ПереместитьВБыстрыйДоступ - Структура:
//             *** Видимость - Булево
//        ** Изменить - Структура:
//             *** Видимость - Булево
//    * ГруппыВажности - Массив из Строка
//    * БыстрыйДоступ - Структура:
//        ** Отбор - Структура:
//             *** БыстрыйДоступ - Булево
//        ** Варианты - Массив из СтрокаТаблицыЗначений
//        ** Количество - Число
//    * БезГруппы - Структура:
//        ** Отбор - Структура:
//             *** БыстрыйДоступ - Булево
//             *** БезГруппы - Булево
//        ** Варианты - Массив из СтрокаТаблицыЗначений
//        ** Количество - Число
//    * СГруппой - Структура:
//        ** Отбор - Структура:
//             *** БыстрыйДоступ - Булево
//             *** БезГруппы - Булево
//             *** СмТакже - Булево
//        ** Варианты - Массив из СтрокаТаблицыЗначений
//        ** Количество - Число
//    * СмТакже - Структура:
//        ** Отбор - Структура:
//             *** БыстрыйДоступ - Булево
//             *** БезГруппы - Булево
//             *** СмТакже - Булево
//        ** Варианты - Массив из СтрокаТаблицыЗначений
//        ** Количество - Число
//    * ВыводятсяВариантыТекущегоРаздела - Булево
//    * ВариантыКоличество - Число
//    * ПодсистемыРаздела - ТаблицаЗначений:
//        ** Ссылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                  - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** Представление - Строка
//        ** Имя - Строка
//        ** ПолноеИмя - Строка
//        ** Приоритет - Строка
//        ** НомерЭлемента - Число
//        ** ИмяЭлемента - Строка
//        ** РодительСсылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                          - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** РазделСсылка - СправочникСсылка.ИдентификаторыОбъектовМетаданных
//                        - СправочникСсылка.ИдентификаторыОбъектовРасширений
//        ** ВидимыхВариантов - Число
//
Функция ВариантыОтчетовДляВывода() Экспорт
```

Пример вызова
```bsl
Результат = ВариантыОтчетов.ВариантыОтчетовДляВывода() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
