---
title: Версионирование объектов
slug: bsp/версионирование-объектов
---


## ЗаписатьНастройкуВерсионированияПоОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает настройку версионирования объекта.
//
// Параметры:
//  ТипОбъекта - Строка
//             - Тип
//             - ОбъектМетаданных
//             - СправочникСсылка.ИдентификаторыОбъектовМетаданных - объект метаданных;
//  ВариантВерсионирования - ПеречислениеСсылка.ВариантыВерсионированияОбъектов - условие записи версий;
//  СрокХраненияВерсий - ПеречислениеСсылка.СрокиХраненияВерсий - срок, после которого версии подлежат очистке.
//
Процедура ЗаписатьНастройкуВерсионированияПоОбъекту(Знач ТипОбъекта, Знач ВариантВерсионирования, Знач СрокХраненияВерсий = Неопределено) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектов.ЗаписатьНастройкуВерсионированияПоОбъекту(ТипОбъекта, ВариантВерсионирования, СрокХраненияВерсий);
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет с формой действия, необходимые для подключения подсистемы версионирования.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма для подключения механизма версионирования.
//
Процедура ПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектов.ПриСозданииНаСервере(Форма) 
```
</details>

## ВключеноВерсионированиеОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования версионирования для указанного объекта метаданных.
//
// Параметры:
//  ИмяОбъекта - Строка - полный путь к объекту метаданных. Например, "Справочник.Номенклатура".
//
// Возвращаемое значение:
//  Булево - Истина, если включено.
//
Функция ВключеноВерсионированиеОбъекта(ИмяОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ВерсионированиеОбъектов.ВключеноВерсионированиеОбъекта(ИмяОбъекта) 
```
</details>

## ВключеноВерсионированиеОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования версионирования для списка объектов.
//
// Параметры:
//  СписокОбъектов - Массив - список имен объектов метаданных.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//   * Ключ - Строка - имя объекта метаданных.
//   * Значение - Булево - включено или выключено версионирование.
//
Функция ВключеноВерсионированиеОбъектов(СписокОбъектов) Экспорт
```

Пример вызова
```bsl
Результат = ВерсионированиеОбъектов.ВключеноВерсионированиеОбъектов(СписокОбъектов) 
```
</details>

## ВключитьВерсионированиеОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включает запись истории изменения для указанного объекта метаданных.
//
// Параметры:
//  ИмяОбъекта - Строка - полный путь к объекту метаданных. Например, "Справочник.Номенклатура".
//  ВариантВерсионирования - ПеречислениеСсылка.ВариантыВерсионированияОбъектов - вариант версионирования объекта.
//
Процедура ВключитьВерсионированиеОбъекта(ИмяОбъекта, Знач ВариантВерсионирования = Неопределено) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектов.ВключитьВерсионированиеОбъекта(ИмяОбъекта, ВариантВерсионирования);
```
</details>

## ВключитьВерсионированиеОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включает запись истории изменения для указанных объектов метаданных.
//
// Параметры:
//  Объекты - Соответствие из КлючИЗначение - объекты, для которых надо включить версионирование:
//   * Ключ    - Строка - полный путь к объекту метаданных. Например, "Справочник.Номенклатура".
//   * Значение - ПеречислениеСсылка.ВариантыВерсионированияОбъектов - вариант версионирования объекта.
//
Процедура ВключитьВерсионированиеОбъектов(Объекты) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектов.ВключитьВерсионированиеОбъектов(Объекты) 
```
</details>

## ЗначениеФлажкаХранитьИсторию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак хранения истории для формы настроек версионирования объекта.
//
// Возвращаемое значение:
//   Булево
//
// Пример:
//	Если ОбщегоНазначения.ПодсистемаСуществует("СтандартныеПодсистемы.ВерсионированиеОбъектов") Тогда
//		МодульВерсионированиеОбъектов = ОбщегоНазначения.ОбщийМодуль("ВерсионированиеОбъектов");
//		ИспользоватьВерсионированиеОбъектов = МодульВерсионированиеОбъектов.ЗначениеФлажкаХранитьИсторию();
//	Иначе
//		Элементы.ГруппаУправлениеВерсионированиемОбъектов.Видимость = Ложь;
//	КонецЕсли;
//
Функция ЗначениеФлажкаХранитьИсторию() Экспорт
```

Пример вызова
```bsl
Результат = ВерсионированиеОбъектов.ЗначениеФлажкаХранитьИсторию() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
