---
title: Версионирование объектов клиент
slug: bsp/версионирование-объектов-клиент
---


## ОткрытьОтчетПоИзменениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает отчет по версиям объекта в режиме сравнения версий.
//
// Параметры:
//  Ссылка                       - ЛюбаяСсылка - ссылка на версионируемый объект;
//  АдресСериализованногоОбъекта - Строка - адрес двоичных данных сравниваемой версии
//                                          объекта во временном хранилище.
//
Процедура ОткрытьОтчетПоИзменениям(Ссылка, АдресСериализованногоОбъекта) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектовКлиент.ОткрытьОтчетПоИзменениям(Ссылка, АдресСериализованногоОбъекта) 
```
</details>

## ОткрытьОтчетПоВерсииОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает сохраненную версию объекта.
//
// Параметры:
//  Ссылка                       - ЛюбаяСсылка - ссылка на версионируемый объект;
//  АдресСериализованногоОбъекта - Строка - адрес двоичных данных версии объекта во временном хранилище.
//
Процедура ОткрытьОтчетПоВерсииОбъекта(Ссылка, АдресСериализованногоОбъекта) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектовКлиент.ОткрытьОтчетПоВерсииОбъекта(Ссылка, АдресСериализованногоОбъекта) 
```
</details>

## ОбработкаОповещенияИзмененияФлажкаХранитьИсторию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаОповещения для формы, на которой требуется отобразить флажок хранения истории изменения.
//
// Параметры:
//   ИмяСобытия - Строка - имя события, которое было получено обработчиком события на форме.
//   ХранитьИсториюИзменений - Число - реквизит, в который будет помещено значение.
//
// Пример:
//	Если ОбщегоНазначенияКлиент.ПодсистемаСуществует("СтандартныеПодсистемы.ВерсионированиеОбъектов") Тогда
//		МодульВерсионированиеОбъектовКлиент = ОбщегоНазначенияКлиент.ОбщийМодуль("ВерсионированиеОбъектовКлиент");
//		МодульВерсионированиеОбъектовКлиент.ОбработкаОповещенияИзмененияФлажкаХранитьИсторию(
//			ИмяСобытия,
//			ХранитьИсториюИзменений);
//	КонецЕсли;
//
Процедура ОбработкаОповещенияИзмененияФлажкаХранитьИсторию(Знач ИмяСобытия, ХранитьИсториюИзменений) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектовКлиент.ОбработкаОповещенияИзмененияФлажкаХранитьИсторию(ИмяСобытия, ХранитьИсториюИзменений) 
```
</details>

## ПриИзмененииФлажкаХранитьИсторию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПриИзменении для флажка, выполняющего переключение режима хранения истории изменений.
// Флажок должен быть связан с реквизитом типа Булево.
//
// Параметры:
//   ЗначениеФлажкаХранитьИсториюИзменений - Булево - новое значение флажка, которое требуется обработать.
//
// Пример:
//	Если ОбщегоНазначенияКлиент.ПодсистемаСуществует("СтандартныеПодсистемы.ВерсионированиеОбъектов") Тогда
//		МодульВерсионированиеОбъектовКлиент = ОбщегоНазначенияКлиент.ОбщийМодуль("ВерсионированиеОбъектовКлиент");
//		МодульВерсионированиеОбъектовКлиент.ПриИзмененииФлажкаХранитьИсторию(ХранитьИсториюИзменений);
//	КонецЕсли;
//
Процедура ПриИзмененииФлажкаХранитьИсторию(ЗначениеФлажкаХранитьИсториюИзменений) Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектовКлиент.ПриИзмененииФлажкаХранитьИсторию(ЗначениеФлажкаХранитьИсториюИзменений) 
```
</details>

## ПоказатьНастройку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму управления версионированием объектов.
// Не забудьте команду, выполняющую вызов процедуры,
// установить зависимой от функциональной опции ИспользоватьВерсионированиеОбъектов.
//
// Пример:
//	Если ОбщегоНазначенияКлиент.ПодсистемаСуществует("СтандартныеПодсистемы.ВерсионированиеОбъектов") Тогда
//		МодульВерсионированиеОбъектовКлиент = ОбщегоНазначенияКлиент.ОбщийМодуль("ВерсионированиеОбъектовКлиент");
//		МодульВерсионированиеОбъектовКлиент.ПоказатьНастройку();
//	КонецЕсли;
//
Процедура ПоказатьНастройку() Экспорт
```

Пример вызова
```bsl
ВерсионированиеОбъектовКлиент.ПоказатьНастройку() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
