---
title: Взаимодействия клиент сервер
slug: bsp/взаимодействия-клиент-сервер
---


## НовоеОписаниеКонтакта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новое описание контакта взаимодействий.
// Для использования в ВзаимодействияКлиентСерверПереопределяемый.ПриОпределенииВозможныхКонтактов.
//
// Возвращаемое значение:
//   Структура - свойства контакта взаимодействий:
//     * Тип                                - Тип     - тип ссылки контакта.
//     * Имя                                 - Строка - имя типа контакта , как оно определено в метаданных.
//     * Представление                       - Строка - представление типа контакта для отображения пользователю.
//     * Иерархический                       - Булево - признак того, является ли справочник иерархическим.
//     * ЕстьВладелец                        - Булево - признак того, что у контакта есть владелец.
//     * ИмяВладельца                        - Строка - имя владельца контакта, как оно определено в метаданных.
//     * ИскатьПоДомену                      - Булево - признак того, что контакты данного типа будет подбираться
//                                                      по совпадению домена, а не по полному адресу электронной почты.
//     * Связь                               - Строка - описывает возможную связь данного контакта с другим контактом, в
//                                                      случае когда текущий контакт является реквизитом другого контакта.
//                                                      Описывается следующей строкой "ИмяТаблицы.ИмяРеквизита".
//     * ИмяРеквизитаПредставлениеКонтакта   - Строка - имя реквизита контакта, из которого будет получено
//                                                      представление контакта. Если не указано, то используется
//                                                      стандартный реквизит Наименование.
//     * ВозможностьИнтерактивногоСоздания   - Булево - признак возможности интерактивного создания контакта из
//                                                      документов - взаимодействий.
//     * ИмяФормыНовогоКонтакта              - Строка - полное имя формы для создания нового контакта,
//                                                      например, "Справочник.Партнеры.Форма.ПомощникНового".
//                                                      Если не заполнено, то открывается форма элемента по умолчанию.
//
Функция НовоеОписаниеКонтакта() Экспорт
```

Пример вызова
```bsl
Результат = ВзаимодействияКлиентСервер.НовоеОписаниеКонтакта() 
```
</details>

## ДобавитьЭлементМассиваОписанияВозможныхТиповКонтактов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ВзаимодействияКлиентСервер.НовоеОписаниеКонтакта.
// Добавляет элемент в массив структур контакта.
//
// Параметры:
//  МассивОписания                     - Массив - массив, в который будут добавлена структура описания контакта.
//  Тип                                - Тип    - тип ссылки контакта.
//  ВозможностьИнтерактивногоСоздания  - Булево - признак возможности интерактивного создания контакта из документов -
//                                                взаимодействий.
//  Имя                                 - Строка - имя типа контакта , как оно определено в метаданных.
//  Представление                       - Строка - представление типа контакта для отображения пользователю.
//  Иерархический                       - Булево - признак того, является ли справочник иерархическим.
//  ЕстьВладелец                        - Булево - признак того, что у контакта есть владелец.
//  ИмяВладельца                        - Строка - имя владельца контакта, как оно определено в метаданных.
//  ИскатьПоДомену                      - Булево - признак того, что по данному типу контакта будет осуществляться
//                                                 поиск по домену.
//  Связь                               - Строка - описывает возможную связь данного контакта с другим контактом, в
//                                                 случае когда текущий контакт является реквизитом другого контакта.
//                                                 Описывается следующей строкой "ИмяТаблицы.ИмяРеквизита".
//  ИмяРеквизитаПредставлениеКонтакта   - Строка - имя реквизита контакта, из которого будет получено представление контакта.
//
Процедура ДобавитьЭлементМассиваОписанияВозможныхТиповКонтактов( Экспорт
```

Пример вызова
```bsl
ВзаимодействияКлиентСервер.ДобавитьЭлементМассиваОписанияВозможныхТиповКонтактов();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
