---
title: Внешние пользователи
slug: bsp/внешние-пользователи
---


## ИспользоватьВнешнихПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что в приложение настроен доступ внешним пользователям
// (значение функциональной опции ИспользоватьВнешнихПользователей).
//
// Возвращаемое значение:
//  Булево - если Истина, внешние пользователи включены.
//
Функция ИспользоватьВнешнихПользователей() Экспорт
```

Пример вызова
```bsl
Результат = ВнешниеПользователи.ИспользоватьВнешнихПользователей() 
```
</details>

## ТекущийВнешнийПользователь
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текущего внешнего пользователя.
// Рекомендуется использовать в коде, который поддерживает только внешних пользователей.
//
// Если вход в сеанс выполнил не внешний пользователь, тогда будет вызвано исключение.
//
// Возвращаемое значение:
//  СправочникСсылка.ВнешниеПользователи - внешний пользователь.
//
Функция ТекущийВнешнийПользователь() Экспорт
```

Пример вызова
```bsl
Результат = ВнешниеПользователи.ТекущийВнешнийПользователь() 
```
</details>

## ГруппаВсеВнешниеПользователи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на стандартную группу ВсеВнешниеПользователи.
//
// Возвращаемое значение:
//  СправочникСсылка.ГруппыВнешнихПользователей
//
Функция ГруппаВсеВнешниеПользователи() Экспорт
```

Пример вызова
```bsl
Результат = ВнешниеПользователи.ГруппаВсеВнешниеПользователи() 
```
</details>

## ПолучитьОбъектАвторизацииВнешнегоПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на объект авторизации внешнего пользователя, полученный из информационной базы.
// Объект авторизации - это ссылка на объект информационной базы, используемый
// для связи с внешним пользователем, например: контрагент, физическое лицо и т.д.
//
// Параметры:
//  ВнешнийПользователь - Неопределено - вернуть для текущего внешнего пользователя.
//                      - СправочникСсылка.ВнешниеПользователи
//
// Возвращаемое значение:
//  ОпределяемыйТип.ВнешнийПользователь
//
Функция ПолучитьОбъектАвторизацииВнешнегоПользователя(ВнешнийПользователь = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВнешниеПользователи.ПолучитьОбъектАвторизацииВнешнегоПользователя(ВнешнийПользователь);
```
</details>

## НастроитьОтображениеСпискаВнешнихПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется для настройки отображения состояния внешних пользователей
// в списках справочников (партнеры, респонденты и др.), которые
// являются объектом авторизации в справочнике ВнешниеПользователи.
//
// Когда нет прав к справочнику ВнешниеПользователи или он не используется, тогда
// отключается видимость колонки ВнешнийДоступ и легенды ВнешнийДоступЛегенда.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения
//  ДополнительныеПараметры - см. ПараметрыНастройкиОтображенияСпискаВнешнихПользователей
//
Процедура НастроитьОтображениеСпискаВнешнихПользователей(Форма, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ВнешниеПользователи.НастроитьОтображениеСпискаВнешнихПользователей(Форма, ДополнительныеПараметры);
```
</details>

## ПараметрыНастройкиОтображенияСпискаВнешнихПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор дополнительных параметров процедуры НастроитьОтображениеСпискаВнешнихПользователей.
//
// Возвращаемое значение:
//  Структура:
//   * ИмяСписка        - Строка - имя реквизита формы с динамическим списком.
//   * ИмяПоля          - Строка - имя поля запроса динамического списка.
//   * ИмяЭлемента      - Строка - имя элемента формы колонки динамического списка.
//   * ИмяГруппыЛегенды - Строка - имя элемента формы, содержащую легенду состояний внешнего доступа.
//
Функция ПараметрыНастройкиОтображенияСпискаВнешнихПользователей() Экспорт
```

Пример вызова
```bsl
Результат = ВнешниеПользователи.ПараметрыНастройкиОтображенияСпискаВнешнихПользователей() 
```
</details>

## СписокВнешнихПользователейПриПолученииДанныхНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется для заполнения значений поля состояния внешних пользователей
// в списках справочников (партнеры, респонденты и др.), которые
// являются объектом авторизации в справочнике ВнешниеПользователи.
//
// Вызов выполняется из события ПриПолученииДанныхНаСервере динамического списка
// справочника, при этом заполняется поле ВнешнийДоступ на основе данных поля Ссылка.
//
// Параметры:
//  ИмяЭлемента - Строка
//  Настройки - НастройкиКомпоновкиДанных
//  Строки - СтрокиДинамическогоСписка
//  ИмяПоля - Строка - имя поля номера картинки строк в динамическом списке.
//
Процедура СписокВнешнихПользователейПриПолученииДанныхНаСервере(ИмяЭлемента, Настройки, Строки, Экспорт
```

Пример вызова
```bsl
ВнешниеПользователи.СписокВнешнихПользователейПриПолученииДанныхНаСервере(ИмяЭлемента, Настройки, Строки, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
