---
title: Выгрузка загрузка предопределенных данных
slug: bsp/выгрузка-загрузка-предопределенных-данных
---


## ПриЗаполненииТиповТребующихАннотациюСсылокПриВыгрузке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет массив типов, для которых при выгрузке необходимо использовать аннотацию
// ссылок в файлах выгрузки.
//
// Параметры:
//  Типы - Массив Из ОбъектМетаданных - объекты метаданных.
//
Процедура ПриЗаполненииТиповТребующихАннотациюСсылокПриВыгрузке(Типы) Экспорт
```

Пример вызова
```bsl
ВыгрузкаЗагрузкаПредопределенныхДанных.ПриЗаполненииТиповТребующихАннотациюСсылокПриВыгрузке(Типы) 
```
</details>

## ПриРегистрацииОбработчиковВыгрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при регистрации произвольных обработчиков выгрузки данных.
// В данной процедуре требуется дополнить эту таблицу значений информацией
// о регистрируемых произвольных обработчиках выгрузки данных.
//
// Параметры:
//	ТаблицаОбработчиков - ТаблицаЗначений - колонки:
//	 * ОбъектМетаданных - ОбъектМетаданных - при выгрузке данных которого должен вызываться регистрируемый обработчик,
//	 * Обработчик - ОбщийМодуль - общий модуль, в котором реализован произвольный обработчик выгрузки данных.
//	    Набор экспортных процедур, которые должны быть реализованы в обработчике, зависит от установки значений
//	    следующих колонок таблицы значений.
//	 * Версия - Строка - номер версии интерфейса обработчиков выгрузки / загрузки данных, поддерживаемого обработчиком.
//	 * ПередВыгрузкойТипа - Булево - флаг необходимости вызова обработчика перед выгрузкой всех объектов информационной
//	    базы, относящихся к данному объекту метаданных. Если присвоено значение Истина - в общем модуле обработчика
//	    должна быть реализована экспортируемая процедура ПередВыгрузкойТипа(), поддерживающая следующие параметры:
//        Контейнер - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерКонтейнера - менеджер контейнера, используемый
//          в процессе выгрузи данных. Подробнее см. комментарий к программному интерфейсу обработки.
//        Сериализатор - СериализаторXDTO - инициализированный с поддержкой выполнения аннотации ссылок. В случае,
//          если в произвольном обработчике выгрузки требуется выполнять выгрузку дополнительных данных - следует
//          использовать СериализаторXDTO, переданный в процедуру ПередВыгрузкойТипа() в качестве значения параметра
//          Сериализатор, а не полученных с помощью свойства глобального контекста СериализаторXDTO.
//        ОбъектМетаданных - ОбъектМетаданных - перед выгрузкой данных которого был вызван обработчик.
//        Отказ - Булево - если в процедуре ПередВыгрузкойТипа() установить значение данного параметра равным
//          Истина - выгрузка объектов, соответствующих текущему объекту метаданных, выполняться не будет.
//	 * ПередВыгрузкойОбъекта - Булево - флаг необходимости вызова обработчика перед выгрузкой конкретного объекта
//	    информационной базы. Если присвоено значение Истина - в общем модуле обработчика должна быть реализована
//	    экспортируемая процедура ПередВыгрузкойОбъекта(), поддерживающая следующие параметры:
//        Контейнер - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерКонтейнера - менеджер контейнера, используемый
//          в процессе выгрузи данных. Подробнее см. комментарий к программному интерфейсу обработки.
//        МенеджерВыгрузкиОбъекта - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерВыгрузкиДанныхИнформационнойБазы -
//          менеджер выгрузки текущего объекта. Подробнее см. комментарий к программному интерфейсу обработки
//          ВыгрузкаЗагрузкаДанныхМенеджерВыгрузкиДанныхИнформационнойБазы. Параметр передается только при вызове
//          процедур обработчиков, для которых при регистрации указана версия не ниже 1.0.0.1.
//        Сериализатор - СериализаторXDTO - инициализированный с поддержкой выполнения аннотации ссылок. В случае,
//          если в произвольном обработчике выгрузки требуется выполнять выгрузку дополнительных данных - следует
//          использовать СериализаторXDTO, переданный в процедуру ПередВыгрузкойОбъекта() в качестве значения
//          параметра Сериализатор, а не полученных с помощью свойства глобального контекста СериализаторXDTO.
//        Объект - КонстантаМенеджерЗначения, СправочникОбъект, ДокументОбъект, БизнесПроцессОбъект, ЗадачаОбъект,
//          ПланСчетовОбъект, ПланОбменаОбъект, ПланВидовХарактеристикОбъект, ПланВидовРасчетаОбъект,
//          РегистрСведенийНаборЗаписей, РегистрНакопленияНаборЗаписей, РегистрБухгалтерииНаборЗаписей,
//          РегистрРасчетаНаборЗаписей, ПоследовательностьНаборЗаписей, ПерерасчетНаборЗаписей - объект данных
//          информационной базы, перед выгрузкой которого был вызван обработчик. Значение, переданное в процедуру
//          ПередВыгрузкойОбъекта() в качестве значения параметра Объект может быть модифицировано внутри обработчика
//          ПередВыгрузкойОбъекта(), при этом внесенные изменения будут отражены в сериализации объекта в файлах
//          выгрузки, но не будут зафиксированы в информационной базе
//        Артефакты - Массив Из ОбъектXDTO - набор дополнительной информации, логически неразрывно связанной с объектом,
//          но не являющейся его частью (артефакты объекта). Артефакты должны сформированы внутри обработчика
//          ПередВыгрузкойОбъекта() и добавлены в массив, переданный в качестве значения параметра Артефакты.
//          Каждый артефакт должен являться XDTO-объектом, для типа которого в качестве базового типа используется
//          абстрактный XDTO-тип {HTTP://www.1c.ru/1cFresh/Data/Dump/1.0.2.1}Artefact. Допускается использовать
//          XDTO-пакеты, помимо изначально поставляемых в составе подсистемы ВыгрузкаЗагрузкаДанных. В дальнейшем
//          артефакты, сформированные в процедуре ПередВыгрузкойОбъекта(), будут доступны в процедурах
//          обработчиков загрузки данных (см. комментарий к процедуре ПриРегистрацииОбработчиковЗагрузкиДанных().
//        Отказ - Булево - если в процедуре ПередВыгрузкойОбъекта() установить значение данного параметра
//        равным Истина - выгрузка объекта, для которого был вызван обработчик, выполняться не будет.
//	 * ПослеВыгрузкиТипа - Булево - флаг необходимости вызова обработчика после выгрузки всех объектов информационной
//	    базы, относящихся к данному объекту метаданных. Если присвоено значение Истина - в общем модуле обработчика
//	    должна быть реализована экспортируемая процедура ПослеВыгрузкиТипа(), поддерживающая следующие параметры:
//        Контейнер - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерКонтейнера - менеджер контейнера, используемый
//          в процессе выгрузи данных. Подробнее см. комментарий к программному интерфейсу обработки.
//        Сериализатор - СериализаторXDTO - инициализированный с поддержкой выполнения аннотации ссылок. В случае,
//          если в произвольном обработчике выгрузки требуется выполнять выгрузку дополнительных данных - следует
//          использовать СериализаторXDTO, переданный в процедуру ПослеВыгрузкиТипа() в качестве значения параметра
//          Сериализатор, а не полученных с помощью свойства глобального контекста СериализаторXDTO,
//        ОбъектМетаданных - ОбъектМетаданных - после выгрузки данных которого был вызван обработчик.
//
Процедура ПриРегистрацииОбработчиковВыгрузкиДанных(ТаблицаОбработчиков) Экспорт
```

Пример вызова
```bsl
ВыгрузкаЗагрузкаПредопределенныхДанных.ПриРегистрацииОбработчиковВыгрузкиДанных(ТаблицаОбработчиков) 
```
</details>

## ПослеВыгрузкиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеВыгрузкиОбъекта(Контейнер, МенеджерВыгрузкиОбъекта, Сериализатор, Объект, Артефакты) Экспорт
```

Пример вызова
```bsl
ВыгрузкаЗагрузкаПредопределенныхДанных.ПослеВыгрузкиОбъекта(Контейнер, МенеджерВыгрузкиОбъекта, Сериализатор, Объект, Артефакты) 
```
</details>

## ПриРегистрацииОбработчиковЗагрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
// 	ТаблицаОбработчиков - см. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриРегистрацииОбработчиковЗагрузкиДанных.ТаблицаОбработчиков
Процедура ПриРегистрацииОбработчиковЗагрузкиДанных(ТаблицаОбработчиков) Экспорт
```

Пример вызова
```bsl
ВыгрузкаЗагрузкаПредопределенныхДанных.ПриРегистрацииОбработчиковЗагрузкиДанных(ТаблицаОбработчиков) 
```
</details>

## ПередСопоставлениемСсылок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
// 	Контейнер - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерКонтейнера - менеджер контейнера.
// 	ОбъектМетаданных - ОбъектМетаданных - объект метаданных.
// 	ТаблицаИсходныхСсылок - ТаблицаЗначений - таблица ссылок.
// 	СтандартнаяОбработка - Булево - признак страндартной обработки.
// 	Отказ - Булево - признак отказа от обработки.
Процедура ПередСопоставлениемСсылок(Контейнер, ОбъектМетаданных, ТаблицаИсходныхСсылок, СтандартнаяОбработка, Отказ) Экспорт
```

Пример вызова
```bsl
ВыгрузкаЗагрузкаПредопределенныхДанных.ПередСопоставлениемСсылок(Контейнер, ОбъектМетаданных, ТаблицаИсходныхСсылок, СтандартнаяОбработка, Отказ) 
```
</details>

## СопоставитьСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//	Контейнер - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерКонтейнера - менеджер контейнера, используемый в процессе
//	 загрузки данных. Подробнее см. комментарий к программному интерфейсу обработки.
//	МенеджерСопоставленияСсылок - ОбработкаОбъект.ВыгрузкаЗагрузкаДанныхМенеджерСопоставленияСсылок -
//	ТаблицаИсходныхСсылок - ТаблицаЗначений - содержащая информацию о ссылках, выгруженных из исходной ИБ. Колонки:
//	* ИсходнаяСсылка - ЛюбаяСсылка - ссылка объекта исходной ИБ, которую требуется сопоставить c ссылкой в текущей ИБ,
//		Остальные колонки равным полям естественного ключа объекта.
// Возвращаемое значение:
//	ТаблицаЗначений - колонки:
//	 * ИсходнаяСсылка - ЛюбаяСсылка -  ссылка объекта, выгруженная из исходной ИБ,
//	 * Ссылка - ЛюбаяСсылка - сопоставленная исходной ссылка в текущей ИБ.
Функция СопоставитьСсылки(Контейнер, МенеджерСопоставленияСсылок, ТаблицаИсходныхСсылок) Экспорт
```

Пример вызова
```bsl
Результат = ВыгрузкаЗагрузкаПредопределенныхДанных.СопоставитьСсылки(Контейнер, МенеджерСопоставленияСсылок, ТаблицаИсходныхСсылок) 
```
</details>

## ПередЗагрузкойОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПередЗагрузкойОбъекта(Контейнер, Объект, Артефакты, Отказ) Экспорт
```

Пример вызова
```bsl
ВыгрузкаЗагрузкаПредопределенныхДанных.ПередЗагрузкойОбъекта(Контейнер, Объект, Артефакты, Отказ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
