---
title: Журнал регистрации клиент
slug: bsp/журнал-регистрации-клиент
---


## ДобавитьСообщениеДляЖурналаРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает сообщение в журнал регистрации.
// Если параметр ЗаписатьСобытия = Истина, то запись выполняется сразу (обращение к серверу).
// Если ЗаписатьСобытия = Ложь (по умолчанию), то сообщение помещается в очередь, которая
// будет записана позднее (обычно в течение 60 сек), либо при следующем вызове этой процедуры
// с признаком ЗаписатьСобытия = Истина, либо при вызове процедуры ЗаписатьСобытияВЖурналРегистрации.
//
//  Параметры:
//   ИмяСобытия          - Строка - имя события для журнала регистрации;
//   ПредставлениеУровня - Строка - описание уровня события, по нему будет определен уровень события при записи на
//                                  сервере;
//                                  Например: "Ошибка", "Предупреждение".
//                                  Соответствуют именам элементов перечисления УровеньЖурналаРегистрации.
//   Комментарий         - Строка - комментарий для события журнала;
//   ДатаСобытия         - Дата   - точная дата возникновения события, описанного в сообщении. Будет добавлена в начало
//                                  комментария;
//   ЗаписатьСобытия     - Булево - выполнить запись всех ранее накопленных сообщений в журнал регистрации (обращение к
//                                  серверу).
//
// Пример:
//  ЖурналРегистрацииКлиент.ДобавитьСообщениеДляЖурналаРегистрации(СобытиеЖурналаРегистрации(), "Предупреждение",
//     НСтр("ru = 'Невозможно подключиться к сети Интернет для проверки обновлений.'"));
//
Процедура ДобавитьСообщениеДляЖурналаРегистрации(Знач ИмяСобытия, Знач ПредставлениеУровня = "Информация", Экспорт
```

Пример вызова
```bsl
ЖурналРегистрацииКлиент.ДобавитьСообщениеДляЖурналаРегистрации(ИмяСобытия, ПредставлениеУровня, );
```
</details>

## ОткрытьЖурналРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму журнала регистрации с установленным отбором.
//
// Параметры:
//  Отбор - Структура:
//     * Пользователь              - Строка
//                                 - СписокЗначений - имя или список пользователей
//                                                    информационной базы.
//     * СобытиеЖурналаРегистрации - Строка
//                                 - Массив - идентификатор события.
//     * ДатаНачала                - Дата           - начало интервала отображаемых событий.
//     * ДатаОкончания             - Дата           - конец интервала отображаемых событий.
//     * Данные                    - Произвольный   - данные любого типа.
//     * Сеанс                     - СписокЗначений - список выбираемых сеансов.
//     * Уровень                   - Строка
//                                 - Массив - представление уровня важности
//                                            события журнала регистрации.
//     * ИмяПриложения             - Массив         - массив идентификаторов приложения.
//  Владелец - ФормаКлиентскогоПриложения - форма, из которой открывается журнал регистрации.
//
Процедура ОткрытьЖурналРегистрации(Знач Отбор = Неопределено, Владелец = Неопределено) Экспорт
```

Пример вызова
```bsl
ЖурналРегистрацииКлиент.ОткрытьЖурналРегистрации(Отбор, Владелец);
```
</details>

## ЗаписатьСобытияВЖурналРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает накопленные сообщения из очереди в журнал регистрации (обращение к серверу).
// Сообщения добавляются в очередь с помощью процедуры ДобавитьСообщениеДляЖурналаРегистрации.
//
Процедура ЗаписатьСобытияВЖурналРегистрации() Экспорт
```

Пример вызова
```bsl
ЖурналРегистрацииКлиент.ЗаписатьСобытияВЖурналРегистрации() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
