---
title: Загрузка данных из файла
slug: bsp/загрузка-данных-из-файла
---


## СформироватьОписаниеКолонок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание колонок табличной части или таблицы значений.
//
// Параметры:
//  Таблица - ТаблицаЗначений - ОписаниеТабличнойЧасти с колонками.
//          - ДанныеФормыКоллекция - таблица размещенная на форме
//          - Строка - для получения списка колонок табличной части
//              необходимо указать его полное имя строкой, как в метаданных, например "Документы.СчетНаОплату.ТабличныеЧасти.Товары".
//  Колонки - Строка - список извлекаемых колонок, разделенный запятыми. Например: "Номер, Товар, Количество".
//
// Возвращаемое значение:
//   Массив из см. ЗагрузкаДанныхИзФайлаКлиентСервер.ОписаниеКолонкиМакета.
//
Функция СформироватьОписаниеКолонок(Таблица, Колонки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайла.СформироватьОписаниеКолонок(Таблица, Колонки);
```
</details>

## НастройкиЗагрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настройки загрузки новых и существующих элементов.
//
// Возвращаемое значение:
//  Структура:
//    * СоздаватьНовые - Булево
//    * ОбновлятьСуществующие - Булево
//
Функция НастройкиЗагрузкиДанных() Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайла.НастройкиЗагрузкиДанных() 
```
</details>

## ОписаниеЗагружаемыхДанныхДляСправочников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в таблицу загружаемых данных служебные колонки.
// Список колонок таблицы динамический и формируется на основе макета загружаемых данных.
// В возвращаемом значении описаны только служебные колонки, которые присутствуют всегда.
//
// Параметры:
//  ЗагружаемыеДанные - ТаблицаЗначений
//  ОписаниеТипаОбъектаСопоставления - ОписаниеТипов -  описание типа объекта сопоставления.
//  ЗаголовокКолонкиОбъектаСопоставления - Строка - заголовок колонки объекта сопоставления.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//       * СопоставленныйОбъект         - СправочникСсылка - ссылка на сопоставленный объект.
//       * РезультатСопоставленияСтроки - Строка       - статус загрузки, возможны варианты: Создан, Обновлен, Пропущен.
//       * ОписаниеОшибки               - Строка       - расшифровка ошибки загрузки данных.
//       * Идентификатор                - Число        - уникальный номер строки
//       * СписокНеоднозначностей       - СписокЗначений -список неоднозначностей возникших при загрузке данных.
//
Функция ОписаниеЗагружаемыхДанныхДляСправочников(ЗагружаемыеДанные, ОписаниеТипаОбъектаСопоставления, ЗаголовокКолонкиОбъектаСопоставления) Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайла.ОписаниеЗагружаемыхДанныхДляСправочников(ЗагружаемыеДанные, ОписаниеТипаОбъектаСопоставления, ЗаголовокКолонкиОбъектаСопоставления) 
```
</details>

## НовыйСписокНеоднозначностей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создать таблицу со списком неоднозначностей для которых в ИБ имеется несколько подходящих вариантов данных.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//     * Колонка       - Строка - имя колонки, в которой была обнаружена неоднозначность;
//     * Идентификатор - Число  - идентификатор строки, в которой была обнаружена неоднозначность.
//
Функция НовыйСписокНеоднозначностей() Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайла.НовыйСписокНеоднозначностей() 
```
</details>

## ТаблицаСопоставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, извлеченную из временного хранилища для сопоставления загружаемых данных с данными в приложении.
// Список колонок извлекаемой таблицы динамический и формируется на основе макета загружаемых данных.
// В возвращаемом значении описана только служебная колонка, которая присутствует всегда.
//
// Параметры:
//  АдресРезультата - Строка - адрес во временном хранилища
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//     * СопоставленныйОбъект - СправочникСсылка - ссылка на сопоставленный объект. Заполняется внутри процедуры.
//
Функция ТаблицаСопоставления(АдресРезультата) Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайла.ТаблицаСопоставления(АдресРезультата) 
```
</details>

## ЗаписатьСвойстваОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет значения дополнительных реквизитов и свойств из строки таблицы загружаемых данных в объект-владелец.
// Внутри функции код сам находит колонки содержащие значения дополнительных реквизитов или свойств и записывает их.
// Вызывается из процедуры ЗагрузитьИзФайла при прикладной загрузке данных в модуле менеджере объекта.
//
// Параметры:
//  СсылкаНаОбъект - ЛюбаяСсылка - ссылка на объект-владельца свойств куда загружаются данные.
//  СтрокаТаблицы - СтрокаТаблицыЗначений из см. ЗагрузкаДанныхИзФайла.ОписаниеЗагружаемыхДанныхДляСправочников
//
Процедура ЗаписатьСвойстваОбъекта(СсылкаНаОбъект, СтрокаТаблицы) Экспорт
```

Пример вызова
```bsl
ЗагрузкаДанныхИзФайла.ЗаписатьСвойстваОбъекта(СсылкаНаОбъект, СтрокаТаблицы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
