---
title: Загрузка данных из файла клиент сервер
slug: bsp/загрузка-данных-из-файла-клиент-сервер
---


## ОписаниеКолонкиМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает структуру описания колонок для макета загрузки данных из файла.
//
// Параметры:
//  Имя        -Строка - имя колонки.
//  Тип       - ОписаниеТипов - тип колонки.
//  Заголовок - Строка - заголовок колонки выводимый в бланке для загрузки.
//  Ширина    - Число - ширина колонки.
//  Подсказка - Строка - подсказка, выводимая в заголовке колонки.
//
// Возвращаемое значение:
//  Структура - структура с описание колонки:
//    * Имя                      - Строка - имя колонки.
//    * Заголовок                - Строка - заголовок колонки выводимый в бланке для загрузки.
//    * Тип                      - ОписаниеТипов - тип колонки.
//    * Ширина                   - Число  - ширина колонки.
//    * Позиция                  - Число  - позиция колонки в таблице
//    * Подсказка                - Строка - подсказка выводимая в заголовке колонки.
//    * ОбязательнаДляЗаполнения - Булево - истина, если колонка обязательно должна содержать значения.
//    * Группа                   - Строка - имя группы колонок.
//    * Родитель                 - Строка - используется для связи динамической колонки с реквизитом табличной части объекта.
//
Функция ОписаниеКолонкиМакета(Имя, Тип, Заголовок = Неопределено, Ширина = 0, Подсказка = "") Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайлаКлиентСервер.ОписаниеКолонкиМакета(Имя, Тип, Заголовок, Ширина, Подсказка);
```
</details>

## КолонкаМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает колонку макета по имени.
//
// Параметры:
//  Имя				 - Строка - имя колонки.
//  СписокКолонок	 - Массив из см. ЗагрузкаДанныхИзФайлаКлиентСервер.ОписаниеКолонкиМакета
//
// Возвращаемое значение:
//   - см. ОписаниеКолонкиМакета
//   - Неопределено - если колонка не существует.
//
Функция КолонкаМакета(Имя, СписокКолонок) Экспорт
```

Пример вызова
```bsl
Результат = ЗагрузкаДанныхИзФайлаКлиентСервер.КолонкаМакета(Имя, СписокКолонок) 
```
</details>

## УдалитьКолонкуМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет колонку макета из массива.
//
// Параметры:
//  Имя           - Строка - имя колонки.
//  СписокКолонок - Массив из см. ЗагрузкаДанныхИзФайлаКлиентСервер.ОписаниеКолонкиМакета
//
Процедура УдалитьКолонкуМакета(Имя, СписокКолонок) Экспорт
```

Пример вызова
```bsl
ЗагрузкаДанныхИзФайлаКлиентСервер.УдалитьКолонкуМакета(Имя, СписокКолонок) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
