---
title: Запрет редактирования реквизитов объектов
slug: bsp/запрет-редактирования-реквизитов-объектов
---


## ЗаблокироватьРеквизиты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Принимает в качестве параметра форму объекта, к которому подключена подсистема,
//  и запрещает редактирование заданных реквизитов,
//  а также добавляет во "Все действия" команду для разрешения их редактирования.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения
//        - РасширениеУправляемойФормыДляОбъектов - форма объекта, где:
//    * Объект - ДанныеФормыСтруктура
//             - СправочникОбъект
//             - ДокументОбъект
//    * Элементы - ВсеЭлементыФормы:
//        ** РазрешитьРедактированиеРеквизитовОбъекта - КнопкаФормы
//  ГруппаДляКнопкиЗапрета  - ГруппаФормы - переопределяет стандартное размещение
//                            кнопки запрета в форме объекта.
//  ЗаголовокКнопкиЗапрета  - Строка - заголовок кнопки. По умолчанию "Разрешить редактирование реквизитов".
//  Объект                  - Неопределено - взять объект из реквизита формы "Объект".
//                          - ДанныеФормыСтруктура - по типу объекта.
//                          - СправочникОбъект
//                          - ДокументОбъект
//
Процедура ЗаблокироватьРеквизиты(Форма, ГруппаДляКнопкиЗапрета = Неопределено, ЗаголовокКнопкиЗапрета = "", Экспорт
```

Пример вызова
```bsl
ЗапретРедактированияРеквизитовОбъектов.ЗаблокироватьРеквизиты(Форма, ГруппаДляКнопкиЗапрета, ЗаголовокКнопкиЗапрета, );
```
</details>

## БлокируемыеРеквизитыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список реквизитов и табличных частей объекта, по которым установлен запрет редактирования.
//
// Параметры:
//  ИмяОбъекта - Строка - полное имя объекта метаданных.
//
// Возвращаемое значение:
//  Массив из Строка
//
Функция БлокируемыеРеквизитыОбъекта(ИмяОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ЗапретРедактированияРеквизитовОбъектов.БлокируемыеРеквизитыОбъекта(ИмяОбъекта) 
```
</details>

## НовыйБлокируемыйРеквизит
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства нового расширенного описания блокируемого реквизита
// для использования в функциях ПолучитьБлокируемыеРеквизитыОбъекта модулей менеджеров объектов.
//
// Возвращаемое значение:
//  Структура:
//   * Имя - Строка - имя реквизита, например, "Объект.Автор", "ПриниматьВыручкуОбщейСуммой".
//                    Можно оставлять пустым для описания группы отдельно от реквизита.
//   * ЭлементыФормы - Массив из Строка - имена элементов формы, соответствующие реквизиту.
//        Требуется заполнить, когда их нельзя определить по пути элемента формы к имени реквизита,
//        например, "ПриниматьВыручкуОбщейСуммойПереключатель".
//   * Предупреждение - Строка - текст предупреждения о последствиях разблокировки, который выводится
//                       в форме разблокировки над реквизитом или группой реквизитов, если указана.
//   * Группа - Строка - имя группы реквизитов, которая используется в форме разблокировки.
//                       Не требуется заполнять, когда реквизит выводится отдельно.
//                       Не учитывается при вызове из группового изменения реквизитов, кроме ОбщаяНадпись.
//   * ПредставлениеГруппы - Строка - представление группы реквизитов, которое выводится в форме разблокировки.
//                       Не требуется заполнять, когда реквизит выводится отдельно.
//                       Не учитывается при вызове из группового изменения реквизитов, кроме ОбщаяНадпись.
//   * ПредупреждениеГруппы - Строка - текст предупреждения о последствиях разблокировки, который выводится
//                       в форме разблокировки только над группой реквизитов, если указана.
//   * Предупреждение - Строка - текст предупреждения о последствиях разблокировки, который выводится
//                       в форме разблокировки над реквизитом или группой реквизитов, если указана.
//
Функция НовыйБлокируемыйРеквизит() Экспорт
```

Пример вызова
```bsl
Результат = ЗапретРедактированияРеквизитовОбъектов.НовыйБлокируемыйРеквизит() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
