---
title: Защита персональных данных
slug: bsp/защита-персональных-данных
---


## ДобавитьКомандуПечатиСогласияНаОбработкуПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура предназначена для использования из метода ДобавитьКомандыПечати
// стандартной подсистемы Печать в объектах, являющимися субъектами персональных данных.
// Добавляет в список команд печати команду перехода к подготовке согласия на обработку персональных данных субъекта.
//
// Параметры:
//  КомандыПечати - см. УправлениеПечатью.СоздатьКоллекциюКомандПечати
//
Процедура ДобавитьКомандуПечатиСогласияНаОбработкуПерсональныхДанных(КомандыПечати) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ДобавитьКомандуПечатиСогласияНаОбработкуПерсональныхДанных(КомандыПечати) 
```
</details>

## ИзменитьНастройкиУничтоженияПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет настройки уничтожения персональных данных субъектов в соответствии с новыми настройками системы.
//
// Параметры:
//  Параметры - Структура - параметры выполнения процедуры:
//   * ИспользоватьУничтожениеПерсональныхДанных - Булево - новое значение признака.
//  АдресРезультата - Строка - адрес временного хранилища, в которое нужно поместить результат работы процедуры.
//
Процедура ИзменитьНастройкиУничтоженияПерсональныхДанных(Параметры, АдресРезультата = "") Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ИзменитьНастройкиУничтоженияПерсональныхДанных(Параметры, АдресРезультата);
```
</details>

## ЭтоОбъектСУничтоженнымиПерсональнымиДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет наличие уничтоженных персональных данных в объекте. В качестве объекта может быть передан и сам субъект.
//
// Параметры:
//  Объект - СправочникОбъект, СправочникСсылка, ДокументОбъект, ДокументСсылка, РегистрСведенийНаборЗаписей -
//  	проверяемый объект.
// 		Также в качестве значения параметра могут быть указаны наборы записей других регистров.
//
// Возвращаемое значение:
//  Булево - признак наличия уничтоженных персональных данных.
//
Функция ЭтоОбъектСУничтоженнымиПерсональнымиДанными(Знач Объект) Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.ЭтоОбъектСУничтоженнымиПерсональнымиДанными(Объект) 
```
</details>

## ПриСозданииНаСервереФормыСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В форме списка добавляет колонку с картинкой, сигнализирующей об отсутствии требуемого согласия
// на обработку персональных данных по субъектам в строках. Добавляет команду показа субъектов со
// скрытыми персональными данными.
// Вызывается из события ПриСозданииНаСервере формы списка.
// У динамических списков должна быть определена основная таблица.
//
// Параметры:
//   Форма		 - ФормаКлиентскогоПриложения - форма списка.
//   СписокФормы - ТаблицаФормы - элемент формы динамического списка субъектов.
//
Процедура ПриСозданииНаСервереФормыСписка(Форма, СписокФормы) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ПриСозданииНаСервереФормыСписка(Форма, СписокФормы) 
```
</details>

## ПриПолученииДанныхНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В форме списка заполняет колонку с картинкой, сигнализирующей об отсутствии требуемого согласия
// на обработку персональных данных по субъектам в строках.
// Вызывается из события ПриПолученииДанныхНаСервере формы списка.
//
// Параметры:
//   Настройки - НастройкиКомпоновкиДанных - содержит копию полных настроек динамического списка.
//   Строки - СтрокиДинамическогоСписка - коллекция содержит данные и оформление всех строк, получаемых в списке,
//     кроме строк группировок.
//
Процедура ПриПолученииДанныхНаСервере(Настройки, Строки) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ПриПолученииДанныхНаСервере(Настройки, Строки) 
```
</details>

## ДатаУничтоженияДанныхСубъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату уничтожения персональных данных субъекта.
//
// Параметры:
//  Субъект - ОпределяемыйТип.СубъектПерсональныхДанных
//
// Возвращаемое значение:
//  Дата
//
Функция ДатаУничтоженияДанныхСубъекта(Субъект) Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.ДатаУничтоженияДанныхСубъекта(Субъект) 
```
</details>

## ИспользоватьУничтожениеПерсональныхДанныхСубъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина если используется уничтожение персональных данных, иначе Ложь.
//
// Возвращаемое значение:
//  Булево
//
Функция ИспользоватьУничтожениеПерсональныхДанныхСубъектов() Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.ИспользоватьУничтожениеПерсональныхДанныхСубъектов() 
```
</details>

## ДобавитьСубъектыДляРасчетаСроковХранения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует субъекты для расчета срока хранения персональных данных.
//
// Параметры:
//  Субъекты - Массив из ОпределяемыйТип.СубъектПерсональныхДанных
//  ДатаСобытия - Дата
//  ИспользоватьУничтожениеПДн - Булево
//
Процедура ДобавитьСубъектыДляРасчетаСроковХранения(Знач Субъекты, Знач ДатаСобытия, Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ДобавитьСубъектыДляРасчетаСроковХранения(Субъекты, ДатаСобытия, );
```
</details>

## ПриЗаписиФормыНастройкиРегистрацииСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет преобразование данных формы настройки системы
// и установку использования события доступ для отмеченных категорий данных.
// В форме должны быть созданы
//	- реквизит типа дерево значений, имя которого - "КатегорииПерсональныхДанных",
//	- таблица формы, связанная с этим реквизитом,
//		имя которой так же - "КатегорииПерсональныхДанных".
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма настройки системы.
//
Процедура ПриЗаписиФормыНастройкиРегистрацииСобытий(Форма) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ПриЗаписиФормыНастройкиРегистрацииСобытий(Форма) 
```
</details>

## УстановитьИспользованиеСобытияДоступ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает режим использования события "Доступ. Доступ"
// журнала регистрации, контроль которого предусмотрен требованиями.
// Федерального закона от 27.07.2006 N152-ФЗ "О персональных данных"
// и подзаконных актов.
// Использование события "Доступ.Доступ" устанавливается для категорий персональных данных,
// сведения о которых перечислены в методе ЗаполнитьСведенияОПерсональныхДанных
// общего модуля ЗащитаПерсональныхДанныхПереопределяемый.
//
// Параметры:
//   Использование - Булево - если Истина, то события будут регистрироваться.
//   КатегорииДанных - Массив - массив категорий персональных данных, для которых производится установка
//   использования (необязательный).
//
Процедура УстановитьИспользованиеСобытияДоступ(Использование, КатегорииДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.УстановитьИспользованиеСобытияДоступ(Использование, КатегорииДанных);
```
</details>

## ИспользованиеСобытияДоступ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Составляет дерево используемых областей персональных данных.
//
// Возвращаемое значение:
//   ДеревоЗначений - дерево областей данных с колонками:
//    * Имя - Строка - идентификатор области персональных данных.
//    * Представление - Строка - пользовательское представление области данных.
//    * Использование - Булево - признак того, что для области данных
//					             установлена регистрация события "Доступ. Доступ".
//
Функция ИспользованиеСобытияДоступ() Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.ИспользованиеСобытияДоступ() 
```
</details>

## ДействующееСогласиеНаОбработкуПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о действующем на указанную дату согласии субъекта на обработку персональных данных.
// Получение сведений производится в привилегированном режиме.
//
// Параметры:
//  Субъект     - ОпределяемыйТип.СубъектПерсональныхДанных - субъект, наличие согласия которого определяется,
//  Организация - ОпределяемыйТип.Организация - оператор персональных данных, которому предоставлено согласие,
//  Дата        - Дата - дата, на которую запрашивается состояние, если не указана, выбирается последняя запись.
//  ИсключаемыйРегистратор - ДокументСсылка.СогласиеНаОбработкуПерсональныхДанных - текущий документ;
//         передается для того, чтобы при поиске согласия игнорировать выполненные текущим документом движения.
//
// Возвращаемое значение:
//  Неопределено, Структура - Неопределено, если согласие не предоставлялось,
//                            или срок действия предоставленного согласия истек;
//                            Если обнаружено действующее согласие, то Структура со свойствами:
//    * ДатаПолучения     - Дата - дата получения согласия.
//    * СрокДействия      - Дата - дата, до которой будет действовать согласие.
//                                 Если не указана, то согласие действует бессрочно.
//    * ДокументОснование - ДокументСсылка.СогласиеНаОбработкуПерсональныхДанных - документ-основание.
//
Функция ДействующееСогласиеНаОбработкуПерсональныхДанных(Субъект, Организация = Неопределено, Знач Дата = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.ДействующееСогласиеНаОбработкуПерсональныхДанных(Субъект, Организация, Дата, );
```
</details>

## ЗаполнитьСубъектыДляРасчетаСроковХраненияПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует всех субъектов с неуничтоженными персональными данными для расчета сроков хранения персональных данных.
Процедура ЗаполнитьСубъектыДляРасчетаСроковХраненияПерсональныхДанных() Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ЗаполнитьСубъектыДляРасчетаСроковХраненияПерсональныхДанных() 
```
</details>

## СубъектыСИстекшимСрокомХранения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает субъекты с истекшим сроком хранения персональных данных.
//
// Параметры:
//  Субъекты - см. РегистрыСведений.СрокиХраненияПерсональныхДанных.СубъектыСИстекшимСрокомХранения.Субъекты
//  ДатаАктуальности - см. РегистрыСведений.СрокиХраненияПерсональныхДанных.СубъектыСИстекшимСрокомХранения.ДатаАктуальности
//
// Возвращаемое значение:
//  Массив из ОпределяемыйТип.СубъектПерсональныхДанных
//
Функция СубъектыСИстекшимСрокомХранения(Субъекты, ДатаАктуальности = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.СубъектыСИстекшимСрокомХранения(Субъекты, ДатаАктуальности);
```
</details>

## УдалитьИнформациюОбУничтоженииПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет информацию о том, что персональные данные субъекта уничтожены.
//
// Параметры:
//  Субъект - ОпределяемыйТип.СубъектПерсональныхДанных
//
Процедура УдалитьИнформациюОбУничтоженииПерсональныхДанных(Субъект) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.УдалитьИнформациюОбУничтоженииПерсональныхДанных(Субъект) 
```
</details>

## СкрытьПерсональныеДанныеСубъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
//
// Скрывает персональные данные субъектов. Состав персональных данных определяется программно.
//
// Параметры:
//  Субъекты - Массив
//           - ОпределяемыйТип.СубъектПерсональныхДанных - ссылка или массив ссылок одного типа на субъекты.
//  СообщатьОбИсключениях - Булево - признак необходимости информирования пользователя о добавленных исключениях.
//
Процедура СкрытьПерсональныеДанныеСубъектов(Знач Субъекты, СообщатьОбИсключениях = Ложь) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.СкрытьПерсональныеДанныеСубъектов(Субъекты, СообщатьОбИсключениях);
```
</details>

## ЭтоОбъектСоСкрытымиПерсональнымиДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ЗащитаПерсональныхДанных.ЭтоОбъектСУничтоженнымиПерсональнымиДанными
//
// Определяет наличие уничтоженных персональных данных в объекте. В качестве объекта может быть передан и сам субъект.
//
// Параметры:
//  Объект - СправочникОбъект, СправочникСсылка, ДокументОбъект, ДокументСсылка, РегистрСведенийНаборЗаписей -
//  	проверяемый объект.
// 		Также в качестве значения параметра могут быть указаны наборы записей других регистров.
//
// Возвращаемое значение:
//  Булево - признак наличия уничтоженных персональных данных.
//
Функция ЭтоОбъектСоСкрытымиПерсональнымиДанными(Знач Объект) Экспорт
```

Пример вызова
```bsl
Результат = ЗащитаПерсональныхДанных.ЭтоОбъектСоСкрытымиПерсональнымиДанными(Объект) 
```
</details>

## ИзменитьНастройкиСкрытияПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ЗащитаПерсональныхДанных.ИзменитьНастройкиУничтоженияПерсональныхДанных
//
// Изменяет настройки уничтожения персональных данных субъектов в соответствии с новыми настройками системы.
//
// Параметры:
//  Параметры - Структура - параметры выполнения процедуры:
//   * ИспользоватьУничтожениеПерсональныхДанных - Булево - новое значение признака.
//  АдресРезультата - Строка - адрес временного хранилища, в которое нужно поместить результат работы процедуры.
//
Процедура ИзменитьНастройкиСкрытияПерсональныхДанных(Параметры, АдресРезультата = "") Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ИзменитьНастройкиСкрытияПерсональныхДанных(Параметры, АдресРезультата);
```
</details>

## ПослеЗагрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
//
// Параметры:
//  Объект - ПланОбменаОбъект - узел плана обмена, для которого выполнялось получение данных.
//
Процедура ПослеЗагрузкиДанных(Объект) Экспорт
```

Пример вызова
```bsl
ЗащитаПерсональныхДанных.ПослеЗагрузкиДанных(Объект) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
