---
title: Интернет поддержка пользователей
slug: bsp/интернет-поддержка-пользователей
---


## ИмяПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя, по которому программа идентифицируется в
// сервисах Интернет-поддержки.
//
// Возвращаемое значение:
//  Строка - имя программы. <Пустая строка>, если имя программы не заполнено.
//
Функция ИмяПрограммы() Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.ИмяПрограммы() 
```
</details>

## НастройкиСоединенияССерверами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки соединения с серверами Интернет-поддержки.
//
// Возвращаемое значение:
//  Структура - настройки соединения. Поля структуры:
//    * УстанавливатьПодключениеНаСервере - Булево - Истина, если подключение
//      устанавливается на сервере 1С:Предприятие;
//    * ТаймаутПодключения - Число - таймаут подключения к серверам в секундах;
//    * ДоменРасположенияСерверовИПП - Число - если 0, устанавливать подключение
//      к серверам ИПП в доменной зоне 1c.ru, если 1 - в доменной зоне 1c.eu.
//
Функция НастройкиСоединенияССерверами() Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.НастройкиСоединенияССерверами() 
```
</details>

## ДанныеАутентификацииПользователяИнтернетПоддержки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает логин и пароль пользователя Интернет-поддержки, сохраненные в информационной базе.
// Перед вызовом вызывающий код должен устанавливать привилегированный режим.
//
// Возвращаемое значение:
//  Структура - Структура - логин и пароль пользователя Интернет-поддержки:
//    * Логин - Строка - логин пользователя Интернет-поддержки;
//    * Пароль - Строка - пароль пользователя Интернет-поддержки.
//  Неопределено - при отсутствии сохраненных данных аутентификации.
//
Функция ДанныеАутентификацииПользователяИнтернетПоддержки() Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.ДанныеАутентификацииПользователяИнтернетПоддержки() 
```
</details>

## ТикетАутентификацииНаПорталеПоддержки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тикет аутентификации пользователя на портале поддержки.
// Возвращенный тикет может быть проверен вызовом операции check
// сервиса https://login.1c.ru или https://login.1c.eu
//
// Подробнее см. https://login.1c.ru/rest/public/swagger-ui.html.
//
// Получение тикета выполняется в соответствии с настройками
// библиотеки:
//  - доменная зона серверов (1c.ru или 1c.eu);
// Перед вызовом вызывающий код должен устанавливать привилегированный режим.
//
// Параметры:
//  ВладелецТикета - Строка - произвольное имя сервиса, для которого
//      выполняется аутентификация пользователя. Это же имя должно
//      использоваться при вызове операции checkTicket;
//      Не допускается незаполненное значение параметра.
//
// Возвращаемое значение:
//  Структура - результат получения тикета. Поля структуры:
//        * Тикет - Строка - полученный тикет аутентификации. Если при получении
//          тикета произошла ошибка (неверный логин или пароль или другая ошибка),
//          значение поля - пустая строка.
//        * КодОшибки - Строка - строковый код возникшей ошибки, который
//          может быть обработан вызывающим функционалом:
//              - <Пустая строка> - получение тикета выполнено успешно;
//              - "НеверныйЛогинИлиПароль" - неверный логин или пароль;
//              - "ПревышеноКоличествоПопыток" - превышено количество попыток
//                 получения тикета с некорректным логином и паролем;
//              - "ОшибкаПодключения" - ошибка при подключении к сервису;
//              - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//              - "НеизвестнаяОшибка" - при получении тикета возникла
//                 неизвестная (не обрабатываемая) ошибка;
//              - "ОперацияНеПоддерживается" - сервис не интегрирован с Порталом 1С:ИТС.
//                Ошибка может возникнуть при работе в модели сервиса.
//        * СообщениеОбОшибке - Строка - краткое описание ошибки, которое
//          может быть отображено пользователю;
//        * ИнформацияОбОшибке - Строка - подробное описание ошибки, которое
//          может быть записано в журнал регистрации.
//
Функция ТикетАутентификацииНаПорталеПоддержки(ВладелецТикета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.ТикетАутентификацииНаПорталеПоддержки(ВладелецТикета) 
```
</details>

## ЗаполненыДанныеАутентификацииПользователяИнтернетПоддержки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение данных аутентификации пользователя
// Интернет-поддержки.
//
// Возвращаемое значение:
//  Булево - признак заполнения данных аутентификации.
//      Истина - данные аутентификации заполнены,
//      Ложь - в противном случае.
//
Функция ЗаполненыДанныеАутентификацииПользователяИнтернетПоддержки() Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.ЗаполненыДанныеАутентификацииПользователяИнтернетПоддержки() 
```
</details>

## ПроверитьЛогинИПароль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет данные аутентификации пользователя
// Интернет-поддержки.
//
// Параметры:
//  Логин - Строка - логин пользователя Интернет-поддержки;
//  Пароль - Строка - пароль пользователя Интернет-поддержки.
//
// Возвращаемое значение:
//  Структура - результат проверки данных аутентификации:
//   *Результат - Булево - результат проверки, если Истина, логин и пароль ведены верно,
//   *КодОшибки - Строка - идентификатор ошибки в случае если логин и пароль ведены верно
//                или в процессе проверки возникли ошибки;
//   *СообщениеОбОшибке - Строка - описание ошибки проверки данных аутентификации.
//
Функция ПроверитьЛогинИПароль(Логин, Пароль) Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.ПроверитьЛогинИПароль(Логин, Пароль) 
```
</details>

## СохранитьДанныеАутентификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет логин и пароль пользователя в подсистеме Интернет-поддержки
// в безопасном хранилище. В вызывающем коде перед записью данных необходимо
// выполнить:
//   - Проверку доступности подключения Интернет-поддержки, вызвав
//     метод ИнтернетПоддержкаПользователей.ДоступноПодключениеИнтернетПоддержки;
//   - Вызвать метод ИнтернетПоддержкаПользователейКлиентСервер.ПроверитьДанныеАутентификации
//     или ИнтернетПоддержкаПользователей.ПроверитьЛогинИПароль для проверки наличия
//     не корректных символов в данных аутентификации;
//   - Установить привилегированный режим.
//
// В случае реализации собственной формы подключения Интернет-поддержки, необходимо
// после сохранения данных аутентификации, удалить значения введенные пользователем
// для того, чтобы минимизировать время хранения секретных данных на клиенте.
//
// Параметры:
//  ДанныеАутентификации - Структура, Неопределено - структура, содержащая логин
//  и пароль пользователя и пароль пользователя Интернет-поддержки.
//  Если передано значение Неопределено, данные аутентификации удаляются.
//   * Логин - Строка - логин пользователя Интернет-поддержки;
//   * Пароль - Строка - пароль пользователя Интернет-поддержки.
//
Процедура СохранитьДанныеАутентификации(ДанныеАутентификации) Экспорт
```

Пример вызова
```bsl
ИнтернетПоддержкаПользователей.СохранитьДанныеАутентификации(ДанныеАутентификации) 
```
</details>

## ДоступноПодключениеИнтернетПоддержки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, доступно ли текущему пользователю выполнение интерактивного
// подключения Интернет-поддержки в соответствии с текущим режимом работы
// и правами пользователя.
//
// Возвращаемое значение:
//  Булево - Истина - интерактивное подключение доступно,
//           Ложь - в противном случае.
//
Функция ДоступноПодключениеИнтернетПоддержки() Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.ДоступноПодключениеИнтернетПоддержки() 
```
</details>

## URLДляПереходаНаСтраницуИнтегрированногоСайта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает URL для перехода на страницу сайта, система аутентификации
// которого интегрирована с Порталом 1С:ИТС.
// В зависимости от текущего режима работы информационной базы и наличия у
// текущего пользователя информационной базы соответствующих прав
// переданный URL страницы сайта трансформируется таким образом, что открытие
// страницы происходит с учетными данными пользователя Портала 1С:ИТС.
// При отсутствии прав, несоответствии режима работы или возникновении ошибок
// переданный URL возвращается без изменений.
//
// Важно. Полученный URL необходимо использовать сразу после получения, т.к.
// URL действителен ограниченное время (исчисляется секундами).
//
// Параметры:
//  URLСтраницыСайта - Строка - URL страницы сайта;
//
// Возвращаемое значение:
//  Строка - URL для перехода на страницу сайта.
//
Функция URLДляПереходаНаСтраницуИнтегрированногоСайта(URLСтраницыСайта) Экспорт
```

Пример вызова
```bsl
Результат = ИнтернетПоддержкаПользователей.URLДляПереходаНаСтраницуИнтегрированногоСайта(URLСтраницыСайта) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
