---
title: Контроль ведения учета
slug: bsp/контроль-ведения-учета
---


## ВыполнитьПроверку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет указанную проверку ведения учета с заданными параметрами.
//
// Параметры:
//   Проверка                    - СправочникСсылка.ПравилаПроверкиУчета
//                               - Строка - правило проверки,
//                                 которая будет выполняться либо строковый идентификатор указанного правила.
//   ПараметрыВыполненияПроверки - Структура
//                               - Массив - произвольные дополнительные параметры проверки,
//                                 которые уточняют, что и как именно проверять.
//                                 См. КонтрольВеденияУчета.ПараметрыВыполненияПроверки.
//                               - Структура:
//       * Свойство1 - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - первое значение параметра.
//       * Свойство2 - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - второе значение параметра.
//       * Свойство3 - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - третье значение параметра.
//       ...
//     - Массив - несколько параметров проверки (элементы массива типа Структура, как описано выше).
//   ПроверяемыеОбъекты - ЛюбаяСсылка - если передано, то проверка будет выполнена только для данного объекта.
//                                     Проверка должна поддерживать выборочную проверку и у нее должно быть
//                                     установлено свойство ПоддерживаетВыборочнуюПроверку в значение Истина.
//                                     см. КонтрольВеденияУчетаПереопределяемый.ПриОпределенииПроверок.
//                      - Массив - ссылки на объекты, которые требуется проверить.
//
// Пример:
//   1. Проверка = КонтрольВеденияУчета.ПроверкаПоИдентификатору("ПроверитьСсылочнуюЦелостность");
//      КонтрольВеденияУчета.ВыполнитьПроверку(Проверка);
//   2. ПараметрыВыполненияПроверки = Новый Массив;
//      Параметр1 = КонтрольВеденияУчета.ПараметрыВыполненияПроверки("ЗакрытиеМесяца", Организация1, ЗакрываемыйМесяц);
//      ПараметрыВыполненияПроверки.Добавить(Параметр1);
//      Параметр2 = КонтрольВеденияУчета.ПараметрыВыполненияПроверки("ЗакрытиеМесяца", Организация2, ЗакрываемыйМесяц);
//      ПараметрыВыполненияПроверки.Добавить(Параметр2);
//      ВыполнитьПроверку("ПроверитьПроведениеДокументов", ПараметрыВыполненияПроверки);
//
Процедура ВыполнитьПроверку(Знач Проверка, Знач ПараметрыВыполненияПроверки = Неопределено, ПроверяемыеОбъекты = Неопределено) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ВыполнитьПроверку(Проверка, ПараметрыВыполненияПроверки, ПроверяемыеОбъекты);
```
</details>

## ВыполнитьПроверкиВКонтексте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверки по заданному контексту - общему признаку, связывающему воедино пакет проверок.
// Если указанный признак установлен у группы проверок, то выполняются все проверки этой группы.
// В этом случае наличие (или отсутствие) указанного признака у самой проверки значения не имеет.
// Проверки с флагом Использование, установленным в значение Ложь, пропускаются.
//
// Параметры:
//    КонтекстПроверокВеденияУчета - ОпределяемыйТип.КонтекстПроверокВеденияУчета - контекст выполняемых проверок.
//
// Пример:
//    КонтрольВеденияУчета.ВыполнитьПроверкиВКонтексте(Перечисления.ХозяйственныеОперации.ЗакрытиеМесяца);
//
Процедура ВыполнитьПроверкиВКонтексте(КонтекстПроверокВеденияУчета) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ВыполнитьПроверкиВКонтексте(КонтекстПроверокВеденияУчета) 
```
</details>

## СводнаяИнформацияПоВидамПроверок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сводку по количеству выявленных проблем указанного вида проверки.
//
// Параметры:
//   ВидПроверок                - СправочникСсылка.ВидыПроверок - ссылка на вид проверки.
//                              - Строка - строковый идентификатор вида проверки.
//                              - Массив из Строка - строковые идентификаторы вида проверки.
//   ПоискПоТочномуСоответствию - Булево - регулирует возможности точности. Если Истина, то поиск ведется
//                                по переданным свойствам на равенство, остальные свойства должны быть равны
//                                Неопределено (табличная часть дополнительных свойств должна быть пуста).
//                                Если Ложь, то значения остальных свойств могут быть произвольными, главное
//                                чтобы соответствующие свойства были равны свойствам структуры. По умолчанию Истина.
//   УчитыватьОтветственного    - Булево - если Истина, то учитываются только проблемы с незаполненным ответственным
//                                и те, за которые ответственный текущий пользователь.
//                                По умолчанию - Ложь.
//
// Возвращаемое значение:
//  Структура:
//    * Количество - Число - общее количество найденных проблем.
//    * ЕстьОшибки - Булево - признак того, имеются ли ошибки среди найденных проблем (с важностью "Ошибка").
//
// Пример:
//   1) Результат = СводнаяИнформацияПоВидамПроверок("СистемныеПроверки");
//   2) ВидПроверок = Новый Массив;
//      ВидПроверок.Добавить("ЗакрытиеМесяца");
//      ВидПроверок.Добавить(Организация);
//      ВидПроверок.Добавить(МесяцЗакрытия);
//      Результат = СводнаяИнформацияПоВидамПроверок(ВидПроверок);
//
Функция СводнаяИнформацияПоВидамПроверок(ВидПроверок = Неопределено, ПоискПоТочномуСоответствию = Истина, УчитыватьОтветственного = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.СводнаяИнформацияПоВидамПроверок(ВидПроверок, ПоискПоТочномуСоответствию, УчитыватьОтветственного);
```
</details>

## ПодробнаяИнформацияПоВидамПроверок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает подробные сведения о выявленных проблемах одного или нескольких интересующих видов проверки.
//
// Параметры:
//   ВидПроверок                - СправочникСсылка.ВидыПроверок - ссылка на вид проверки.
//                              - Строка - строковый идентификатор вида проверки.
//                              - Массив из Строка - строковые идентификаторы вида проверки.
//   ПоискПоТочномуСоответствию - Булево - если Истина, то вид проверки определяется по точному соответствию со
//                                всеми переданными значениям свойств в параметре ВидПроверок (см. пример № 2).
//                                Если Ложь, то вид проверки определяется по указанным значениям свойств
//                                ИС любыми значениями неуказанных свойств в параметре ВидПроверок (см. пример № 3).
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//     * ПроблемныйОбъект         - ЛюбаяСсылка - ссылка на объект, с которым связана проблема.
//     * ВажностьПроблемы         - ПеречислениеСсылка.ВажностьПроблемыУчета - важность проблемы учета
//                                  "Информация", "Предупреждение", "Ошибка", "ПолезныйСовет" и "ВажнаяИнформация".
//     * ПравилоПроверки          - СправочникСсылка.ПравилаПроверкиУчета - выполненная проверка с описанием проблемы.
//     * ВидПроверок              - СправочникСсылка.ВидыПроверок - вид проверки.
//     * УточнениеПроблемы        - Строка - текстовое уточнение найденной проблемы.
//     * Ответственный            - СправочникСсылка.Пользователи - заполнен, если по выявленной проблеме
//                                  алгоритм проверки определил конкретного ответственного.
//     * Выявлено                 - Дата - дата и время выявления проблемы.
//     * ДополнительнаяИнформация - ХранилищеЗначения - произвольные дополнительные сведения, связанные
//                                  с выявленной проблемой.
//
// Пример:
//   1) Результат = ПодробнаяИнформацияПоВидамПроверок("СистемныеПроверки");
//   2) ВидПроверок = Новый Массив;
//      ВидПроверок.Добавить("ЗакрытиеМесяца");
//      ВидПроверок.Добавить(Организация);
//      ВидПроверок.Добавить(МесяцЗакрытия);
//      Результат = ПодробнаяИнформацияПоВидамПроверок(ВидПроверок);
//   3) Выбрать все проблемы закрытия месяца по всем периодам для указанной организации:
//      ВидПроверок = Новый Массив;
//      ВидПроверок.Добавить("ЗакрытиеМесяца");
//      ВидПроверок.Добавить(Организация);
//      Результат = ПодробнаяИнформацияПоВидамПроверок(ВидПроверок, Ложь);
//
Функция ПодробнаяИнформацияПоВидамПроверок(ВидПроверок, ПоискПоТочномуСоответствию = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПодробнаяИнформацияПоВидамПроверок(ВидПроверок, ПоискПоТочномуСоответствию);
```
</details>

## ПроверкаПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает проверку по переданному идентификатору.
//
// Параметры:
//   Идентификатор - Строка - строковый идентификатор проверки. Например, "ПроверитьСсылочнуюЦелостность".
//
// Возвращаемое значение:
//   СправочникСсылка.ПравилаПроверкиУчета - ссылка на проверку или пустая ссылка,
//      если проверка с таким идентификатором не существует.
//
Функция ПроверкаПоИдентификатору(Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПроверкаПоИдентификатору(Идентификатор) 
```
</details>

## КоличествоПроблемПоОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает количество проблем, выявленных у переданного объекта.
//
// Параметры:
//   ПроблемныйОбъект - ЛюбаяСсылка - объект, для которого нужно вычислить количество проблем.
//
// Возвращаемое значение:
//   Число
//
Функция КоличествоПроблемПоОбъекту(ПроблемныйОбъект) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.КоличествоПроблемПоОбъекту(ПроблемныйОбъект) 
```
</details>

## КоличествоПроблемПоПравилуПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет количество проблем, выявленных переданным правилом проверки.
//
// Параметры:
//   ПравилоПроверки - СправочникСсылка.ПравилаПроверкиУчета - правило, для которого
//                     нужно вычислить количество проблем.
//
// Возвращаемое значение:
//   Число
//
Функция КоличествоПроблемПоПравилуПроверки(ПравилоПроверки) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.КоличествоПроблемПоПравилуПроверки(ПравилоПроверки) 
```
</details>

## ПроблемныеОбъекты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает проблемные объекты, выявленные указанным правилом проверки.
//
// Параметры:
//  ПравилоПроверки - СправочникСсылка.ПравилаПроверкиУчета
//  Параметры - см. ПараметрыВыборкиПроблемныхОбъектов
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//    * ПроблемныйОбъект - ЛюбаяСсылка
//    * ПравилоПроверки - СправочникСсылка.ПравилаПроверкиУчета
//    * ВидПроверки - СправочникСсылка.ВидыПроверок
//    * КлючУникальности - УникальныйИдентификатор
//
Функция ПроблемныеОбъекты(Знач ПравилоПроверки, Знач Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПроблемныеОбъекты(ПравилоПроверки, Параметры);
```
</details>

## ПараметрыВыборкиПроблемныхОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры выборки проблемных объектов для функции ПроблемныеОбъекты.
//
// Возвращаемое значение:
//  Структура:
//   * НачальныйПроблемныйОбъект - Неопределено
//   * РазмерПорции - Число - по умолчанию 1000.
//   * ДополнительныеУсловия - Строка
//   * ДополнительныеПараметры - Соответствие из КлючИЗначение:
//     ** Ключ - Строка - имя параметра запроса.
//     ** Значение - Произвольный - значение параметра запроса.
//
Функция ПараметрыВыборкиПроблемныхОбъектов() Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПараметрыВыборкиПроблемныхОбъектов() 
```
</details>

## ПараметрыВыполненияПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует параметры выполнения проверки для передачи в процедуры и функции ВыполнитьПроверку, ОписаниеПроблемы,
// ВидПроверки и другие.
// Параметры содержат уточнение, для чего именно требуется выполнить проверку,
// например, проверить закрытие месяца для конкретной организации по конкретному периоду.
// Порядок следования параметров учитывается.
//
// Параметры:
//     Параметр1     - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - первый параметр проверки.
//     Параметр2     - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - второй параметр проверки.
//     Параметр3     - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - третий параметр проверки.
//     Параметр4     - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - четвертый параметр проверки.
//     Параметр5     - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - пятый параметр проверки.
//     ДругиеПараметры - Массив - другие параметры проверки (элементы типов ЛюбаяСсылка, Булево, Число, Строка, Дата).
//
// Возвращаемое значение:
//    Структура:
//       * Наименование - Строка - представление вида проверки.
//       * Свойство1 - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - первый параметр проверки.
//       * Свойство2 - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - второй параметр проверки.
//       * Свойство3 - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - третий параметр проверки.
//       ...
//       * СвойствоН - ЛюбаяСсылка
//                   - Булево
//                   - Число
//                   - Строка
//                   - Дата - последний параметр вида проверки.
//
// Пример:
//     1. Параметры = ПараметрыВыполненияПроверки("СистемныеПроверки");
//     2. Параметры = ПараметрыВыполненияПроверки("ЗакрытиеМесяца", ОрганизацияСсылка, ЗакрываемыйМесяц);
//
Функция ПараметрыВыполненияПроверки(Знач Параметр1, Знач Параметр2 = Неопределено, Знач Параметр3 = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПараметрыВыполненияПроверки(Параметр1, Параметр2, Параметр3, );
```
</details>

## ОчиститьРезультатыПредыдущихПроверок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает результаты предыдущих проверок, оставляя только те проблемы, которые были проигнорированы ранее
// (признак ИгнорироватьПроблему = Истина).
// Для непараметрических проверок предыдущие результаты очищаются автоматически, а затем выполняется алгоритм проверки.
// Для проверок с параметрами предварительную очистку предыдущих результатов следует выполнять явно с помощью
// этой процедуры в самом алгоритме проверки. В противном случае, одна и та же проблема будет регистрироваться
// многократно при нескольких последовательных запусках проверки.
//
// Параметры:
//     Проверка                    - СправочникСсылка.ПравилаПроверкиУчета - проверка,
//                                   результаты которой необходимо очистить.
//     ПараметрыВыполненияПроверки - см. КонтрольВеденияУчета.ПараметрыВыполненияПроверки
//                                 - Массив    - несколько параметров проверки (элементы массива типа Структура,
//                                               как описано выше).
//
Процедура ОчиститьРезультатыПредыдущихПроверок(Знач Проверка, Знач ПараметрыВыполненияПроверки) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ОчиститьРезультатыПредыдущихПроверок(Проверка, ПараметрыВыполненияПроверки) 
```
</details>

## ОписаниеПроблемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание проблемы для последующей регистрации
// с помощью процедуры КонтрольВеденияУчета.ЗаписатьПроблему в процедуре-обработчике проверки.
//
// Параметры:
//   ПроблемныйОбъект  - ЛюбаяСсылка - объект, с которым связана выявленная проблема.
//   ПараметрыПроверки - Структура - параметры выполняемой проверки, значение которых следует взять из одноименного
//                                   параметра процедуры-обработчика проверки:
//     * Проверка         - СправочникСсылка.ПравилаПроверкиУчета - выполненная проверку.
//     * ВидПроверки      - СправочникСсылка.ВидыПроверок - вид проверки, к которому относится выполненная проверка.
//     * ВажностьПроблемы   - ПеречислениеСсылка.ВажностьПроблемыУчета - важность, с которой следует
//                            зарегистрировать выявленную проблемы учета:
//                            Информация, Предупреждение, Ошибка, ПолезныйСовет или ВажнаяИнформация.
//     * Идентификатор      - Строка - строковый идентификатор проверки.
//     * ДатаНачалаПроверки - Дата - пороговая дата, обозначающая границу проверяемых
//                            объектов (только для объектов с датой). Объекты, дата которых меньше
//                            указанной, не следует проверять. По умолчанию не заполнено (т.е. проверять все).
//     * ЛимитПроблем       - Число - количество проверяемых объектов.
//                            По умолчанию 1000. Если указано 0, то следует проверить все объекты.
//     * ВидПроверки        - СправочникСсылка.ВидыПроверок - ссылка на вид проверки, к
//                            которому относится выполненная проверка.
//
// Возвращаемое значение:
//   Структура:
//     * ПроблемныйОбъект         - ЛюбаяСсылка - ссылка на объект-источник проблемы.
//     * Проверка                 - СправочникСсылка.ПравилаПроверкиУчета - ссылка на выполненную проверку.
//                                  Взято из переданной структуры ПараметрыПроверки.
//     * ВидПроверки              - СправочникСсылка.ВидыПроверок - ссылка на вид проверки, к которому относится
//                                  выполненная проверка. Взято из переданной структуры ПараметрыПроверки
//     * ВажностьПроблемы         - СправочникСсылка.ВидыПроверок - ссылка на вид проверки, к которому относится
//                                  выполненная проверка. Взято из переданной структуры ПараметрыПроверки.
//     * УточнениеПроблемы        - Строка - строка уточнения проблемы. По умолчанию не заполнена.
//     * КлючУникальности         - УникальныйИдентификатор - ключ уникальности проблемы.
//     * Выявлено                 - Дата - момент обнаружения проблемы.
//     * ДополнительнаяИнформация - ХранилищеЗначения
//                                - Неопределено - произвольные дополнительные сведения, связанные
//                                  с выявленной проблемой. По умолчанию Неопределено.
//     * Ответственный            - СправочникСсылка.Пользователи
//                                - Неопределено - заполнен, если за проблемный объект
//                                  имеется конкретный ответственный. По умолчанию Неопределено.
//
// Пример:
//  Проблема = КонтрольВеденияУчета.ОписаниеПроблемы(ПроблемныйДокумент, ПараметрыПроверки);
//  Проблема.ВидПроверки = ВидПроверки;
//  Проблема.УточнениеПроблемы = СтроковыеФункцииКлиентСервер.ПодставитьПараметрыВСтроку(
//    НСтр("ru = 'По контрагенту ""%1"" имеется непроведенный документ ""%2""'"), Результат.Контрагент,
//      ПроблемныйДокумент);
//  КонтрольВеденияУчета.ЗаписатьПроблему(Проблема, ПараметрыПроверки);
//
Функция ОписаниеПроблемы(ПроблемныйОбъект, ПараметрыПроверки) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ОписаниеПроблемы(ПроблемныйОбъект, ПараметрыПроверки) 
```
</details>

## ЗаписатьПроблему
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает результат выполнения проверки.
//
// Параметры:
//   Проблема          - см. КонтрольВеденияУчета.ОписаниеПроблемы.
//   ПараметрыПроверки - см. КонтрольВеденияУчета.ОписаниеПроблемы.ПараметрыПроверки.
//
Процедура ЗаписатьПроблему(Проблема, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ЗаписатьПроблему(Проблема, ПараметрыПроверки);
```
</details>

## ИгнорироватьПроблему
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает или снимает признак игнорирования проблемы ведения учета.
// При установке параметра Игнорировать в Истина проблема перестает выводиться пользователям в формах объектов
// и отчете о результатах проверок. Например, это полезно, если пользователь решил, что
// обнаруженная проблема не существенна или ей не планируется заниматься.
// При сбросе в значение Ложь проблема вновь становится актуальной.
//
// Параметры:
//   ОписаниеПроблемы             - Структура:
//     * ПроблемныйОбъект         - ЛюбаяСсылка - ссылка на объект, с которым связана проблема.
//     * ПравилоПроверки          - СправочникСсылка.ПравилаПроверкиУчета - выполненная проверка с описанием проблемы.
//     * ВидПроверок              - СправочникСсылка.ВидыПроверок - вид проверки.
//     * УточнениеПроблемы        - Строка - текстовое уточнение найденной проблемы.
//     * ДополнительнаяИнформация - ХранилищеЗначения - дополнительная информация об игнорируемой проблеме.
//   Игнорировать - Булево - устанавливаемое значение для указанной проблемы.
//
Процедура ИгнорироватьПроблему(Знач ОписаниеПроблемы, Знач Игнорировать) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ИгнорироватьПроблему(ОписаниеПроблемы, Игнорировать) 
```
</details>

## ПриСозданииНаСервереФормыСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В форме списка выводит колонку с картинкой, сигнализирующей о наличии проблем с объектами в строках.
// Вызывается из события ПриСозданииНаСервере формы списка.
// У динамических списков должна быть определена основная таблица.
//
// Параметры:
//   Форма                  - ФормаКлиентскогоПриложения - форма списка.
//   ИменаСписков           - Строка - имена динамических списков через запятую.
//   ДополнительныеСвойства - Структура
//                          - Неопределено - дополнительные свойства:
//      * ИмяПоляИндикатораПроблем - Строка - имя поля динамического списка, которое
//                            будет использовано для вывода индикатора
//                            наличия проблем у объекта.
//
Процедура ПриСозданииНаСервереФормыСписка(Форма, ИменаСписков, ДополнительныеСвойства = Неопределено) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ПриСозданииНаСервереФормыСписка(Форма, ИменаСписков, ДополнительныеСвойства);
```
</details>

## ПриПолученииДанныхНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В форме списка выводит колонку с картинкой, сигнализирующей о наличии проблем с объектами в строках.
// Вызывается из события ПриПолученииДанныхНаСервере формы списка.
//
// Параметры:
//   Настройки              - НастройкиКомпоновкиДанных - содержит копию полных настроек динамического списка.
//   Строки                 - СтрокиДинамическогоСписка - коллекция содержит данные и оформление всех строк,
//                            получаемых в списке, кроме строк группировок.
//   ИмяКлючевогоПоля       - Строка - "Ссылка" или заданное имя колонки, содержащую ссылку объекта.
//   ДополнительныеСвойства - Структура
//                          - Неопределено - содержит дополнительные свойства в случае
//                            необходимости их использования.
//
Процедура ПриПолученииДанныхНаСервере(Настройки, Строки, ИмяКлючевогоПоля = "Ссылка", ДополнительныеСвойства = Неопределено) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ПриПолученииДанныхНаСервере(Настройки, Строки, ИмяКлючевогоПоля, ДополнительныеСвойства);
```
</details>

## ПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В форме объекта выводит группу с картинкой и надписью, сигнализирующими о наличии проблем с этим объектом.
// Вызывается из события ПриЧтенииНаСервере формы объекта.
//
// Параметры:
//   Форма         - ФормаКлиентскогоПриложения - форма объекта.
//   ТекущийОбъект - ДокументОбъект - объект, который будет прочитан.
//                 - СправочникОбъект
//                 - ПланОбменаОбъект
//                 - ПланВидовХарактеристикОбъект
//                 - ПланСчетовОбъект
//                 - ПланВидовРасчетаОбъект
//                 - ЗадачаОбъект
//
Процедура ПриЧтенииНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ПриЧтенииНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает фоновую проверку переданного объекта.
// Выполняются только те проверки, по которым ранее были найдены ошибки и у которых
// установлено свойство ПоддерживаетВыборочнуюПроверку в значение Истина.
//
// Параметры:
//   ТекущийОбъект - ДокументОбъект - <ВидОбъектаМетаданных>Объект.<ИмяОбъектаМетаданных>.
//                 - СправочникОбъект
//                 - ПланОбменаОбъект
//                 - ПланВидовХарактеристикОбъект
//                 - ПланСчетовОбъект
//                 - ПланВидовРасчетаОбъект
//                 - ЗадачаОбъект
//
Процедура ПослеЗаписиНаСервере(ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ПослеЗаписиНаСервере(ТекущийОбъект) 
```
</details>

## ПодсистемаДоступна
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина, если есть права на просмотр проблем ведения учета.
//
// Возвращаемое значение:
//   Булево
//
Функция ПодсистемаДоступна() Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПодсистемаДоступна() 
```
</details>

## ВидыПроверок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает виды проверки по переданным параметрам.
//
// Параметры:
//   ВидПроверок                - Строка
//                              - Массив из Строка
//                              - СправочникСсылка.ВидыПроверок - строковый идентификатор вида проверки,
//                                либо массив строковых идентификаторов, либо ссылка на вид проверки.
//   ПоискПоТочномуСоответствию - Булево - регулирует возможности точности. Если Истина, то поиск ведется
//                                по переданным свойствам на равенство, остальные свойства должны быть равны
//                                Неопределено (табличная часть дополнительных свойств должна быть пуста).
//                                Если Ложь, то значения остальных свойств могут быть произвольными, главное
//                                чтобы соответствующие свойства были равны свойствам структуры. По умолчанию Истина.
//
// Возвращаемое значение:
//   Массив - элементы СправочникСсылка.ВидыПроверок, либо пустой массив, если поиск не дал результата.
//            При поиска по точному соответствию массив содержит единственный элемент.
//
Функция ВидыПроверок(ВидПроверок, ПоискПоТочномуСоответствию = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ВидыПроверок(ВидПроверок, ПоискПоТочномуСоответствию);
```
</details>

## ВидПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает существующий или создает новый элемент справочника ВидыПроверок
// для регистрации или отбора результатов ведения учета.
//
// Параметры:
//     ПараметрыВыполненияПроверки - Строка - строковый идентификатор вида проверки (Свойство1)
//                                 - Структура - сведения, идентифицирующие вид проверки.
//     ТолькоПоиск - Булево - если Истина и вид проверки с заданными параметрами не существует,
//                   возвращается пустая ссылка; если Ложь, то создается элемент и возвращается ссылка на него.
//
// Возвращаемое значение:
//   СправочникСсылка.ВидыПроверок - найденный существующий или созданный элемент справочника.
//      В случае если осуществлялся только поиск (параметр ТолькоПоиск = Истина)
//      и элемент не был найден, возвращается пустая ссылка на справочник СправочникСсылка.ВидыПроверок.
//
// Пример:
//   ВидПроверки = КонтрольВеденияУчета.ВидПроверки("СистемныеПроверки");
//
Функция ВидПроверки(Знач ПараметрыВыполненияПроверки, Знач ТолькоПоиск = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ВидПроверки(ПараметрыВыполненияПроверки, ТолькоПоиск);
```
</details>

## ОбновитьПараметрыПроверокУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Принудительно обновляет состав проверок ведения учета при изменении метаданных
// или иных настроек.
//
Процедура ОбновитьПараметрыПроверокУчета() Экспорт
```

Пример вызова
```bsl
КонтрольВеденияУчета.ОбновитьПараметрыПроверокУчета() 
```
</details>

## ПодробнаяИнформацияПоВидамПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать функцию ПодробнаяИнформацияПоВидамПроверок.
// Возвращает подробные сведения о выявленных проблемах указанного вида проверки.
//
// Параметры:
//   ВидПроверок                - СправочникСсылка.ВидыПроверок - ссылка на вид проверки.
//                              - Строка - строковый идентификатор вида проверки.
//                              - Массив из Строка - строковые идентификаторы вида проверки.
//   ПоискПоТочномуСоответствию - Булево - регулирует возможности точности. Если Истина, то поиск ведется
//                                по переданным свойствам на равенство, остальные свойства должны быть равны
//                                Неопределено (табличная часть дополнительных свойств должна быть пуста).
//                                Если Ложь, то значения остальных свойств могут быть произвольными, главное
//                                чтобы соответствующие свойства были равны свойствам структуры. По умолчанию Истина.
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//     * ПроблемныйОбъект         - ЛюбаяСсылка - ссылка на объект "Источник" проблем.
//     * ПравилоПроверки          - СправочникСсылка.ПравилаПроверкиУчета - ссылка на выполненную проверку.
//     * УточнениеПроблемы        - Строка - строка-уточнение найденной проблемы.
//     * ВажностьПроблемы         - ПеречислениеСсылка.ВажностьПроблемыУчета - важность проблемы учета
//                                  "Информация", "Предупреждение", "Ошибка" и "ПолезныйСовет".
//     * Ответственный            - СправочникСсылка.Пользователи - заполнен если есть возможность
//                                  идентифицировать ответственного в проблемном объекте.
//     * ДополнительнаяИнформация - ХранилищеЗначения - служебное свойство с дополнительными
//                                  сведениями, связанными с выявленной проблемой.
//     * Выявлено                 - Дата - серверное время идентификации проблемы.
//
// Пример:
//   1) Результат = ПодробнаяИнформацияПоВидамПроверок("СистемныеПроверки");
//   2) ВидПроверок = Новый Массив;
//      ВидПроверок.Добавить("ЗакрытиеМесяца");
//      ВидПроверок.Добавить(Организация);
//      ВидПроверок.Добавить(МесяцЗакрытия);
//      Результат = ПодробнаяИнформацияПоВидамПроверок(ВидПроверок);
//
Функция ПодробнаяИнформацияПоВидамПроверки(ВидПроверок, ПоискПоТочномуСоответствию = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.ПодробнаяИнформацияПоВидамПроверки(ВидПроверок, ПоискПоТочномуСоответствию);
```
</details>

## СводнаяИнформацияПоВидамПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать функцию СводнаяИнформацияПоВидамПроверок.
// Возвращает сводку по количеству выявленных проблем указанного вида проверки.
//
// Параметры:
//   ВидПроверок                - СправочникСсылка.ВидыПроверок - ссылка на вид проверки.
//                              - Строка - строковый идентификатор вида проверки.
//                              - Массив из Строка - строковые идентификаторы вида проверки.
//   ПоискПоТочномуСоответствию - Булево - регулирует возможности точности. Если Истина, то поиск ведется
//                                по переданным свойствам на равенство, остальные свойства должны быть равны
//                                Неопределено (табличная часть дополнительных свойств должна быть пуста).
//                                Если Ложь, то значения остальных свойств могут быть произвольными, главное
//                                чтобы соответствующие свойства были равны свойствам структуры. По умолчанию Истина.
//
// Возвращаемое значение:
//  Структура:
//    * Количество - Число - общее количество найденных проблем.
//    * ЕстьОшибки - Булево - признак того, имеются ли ошибки среди найденных проблем (с важностью "Ошибка").
//
// Пример:
//   1) Результат = СводнаяИнформацияПоВидамПроверок("СистемныеПроверки");
//   2) ВидПроверок = Новый Массив;
//      ВидПроверок.Добавить("ЗакрытиеМесяца");
//      ВидПроверок.Добавить(Организация);
//      ВидПроверок.Добавить(МесяцЗакрытия);
//      Результат = СводнаяИнформацияПоВидамПроверок(ВидПроверок);
//
Функция СводнаяИнформацияПоВидамПроверки(ВидПроверок, ПоискПоТочномуСоответствию = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КонтрольВеденияУчета.СводнаяИнформацияПоВидамПроверки(ВидПроверок, ПоискПоТочномуСоответствию);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
