---
title: Машиночитаемые доверенности ФНС
slug: bsp/машиночитаемые-доверенности-фнс
---


## ФайлыДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает машиночитаемую доверенность в виде набора файлов.
// Если файлы доверенности еще не сформированы, то возвращается пустой набор файлов.
//
// Параметры:
//  Доверенность - СправочникСсылка.МашиночитаемыеДоверенности
//  ДляНалоговыхОрганов - Булево - если Истина, имя файла будет сформировано
//    в соответствии с требованиями налоговых органов.
//
// Возвращаемое значение:
//   Массив из Структура:
//    * ИмяФайла - Строка
//    * ТипФайла - Строка - принимает значения "Доверенность" или "Подпись".
//    * ДвоичныеДанные - ДвоичныеДанные
//    * ОписаниеОшибки - Строка
//
Функция ФайлыДоверенности(Знач Доверенность, Знач ДляНалоговыхОрганов) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.ФайлыДоверенности(Доверенность, ДляНалоговыхОрганов) 
```
</details>

## ФайлыДоверенностей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает машиночитаемые доверенности в виде набора файлов.
// Если файлы отдельно взятой доверенности еще не сформированы, то по ней возвращается пустой набор файлов.
//
// Параметры:
//  Доверенности - Массив из СправочникСсылка.МашиночитаемыеДоверенности
//  ДляНалоговыхОрганов - Булево - если Истина, имена файлов будут сформированы
//    в соответствии с требованиями налоговых органов.
//
// Возвращаемое значение:
//   Соответствие из КлючИЗначение:
//    * Ключ - СправочникСсылка.МашиночитаемыеДоверенности
//    * Значение - см. ФайлыДоверенности
//
Функция ФайлыДоверенностей(Знач Доверенности, Знач ДляНалоговыхОрганов) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.ФайлыДоверенностей(Доверенности, ДляНалоговыхОрганов) 
```
</details>

## ОтборДляДоверенностейПоСертификату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отбор для доверенностей по сертификату.
//
// Параметры:
//  Сертификат - СертификатКриптографии
//             - ДвоичныеДанные
//             - Строка - адрес двоичных данных сертификата во временном хранилище.
//             - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования.
//  Префикс    - Строка
//
// Возвращаемое значение:
//  Структура
//
Функция ОтборДляДоверенностейПоСертификату(Знач Сертификат, Префикс) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.ОтборДляДоверенностейПоСертификату(Сертификат, Префикс) 
```
</details>

## ДоверенностиСОтбором
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Доверенности с отбором. Если в отборе не передана доверенность, то отбор производится только по непомеченным на удаление.
//
// Параметры:
//  Отбор - Структура - содержит имя и значение поля, по которому надо отобрать доверенности:
//      "ПредставительИНН", "ПредставительОГРН", "ПредставительСНИЛС",
//      "ДоверительИНН", "ДоверительКПП" и т.п.
//       По умолчанию будут подобраны доверенности с признаками Верна, Подписана и статусом Действует.
//       Если значение отбора Неопределено, отбор по полю не производится.
//  ВыбранныеПоля - Массив из Строка, Строка - массив строк или строка через запятую: поля, которые нужно возвращать.
//  НаДату - Дата - по умолчанию - текущая дата сеанса: дата, на которую определяется действительность доверенности.
//       Если передана пустая дата, отбор по периоду действия не будет использоваться.
//
// Возвращаемое значение:
//  ТаблицаЗначений
//
Функция ДоверенностиСОтбором(Отбор, Знач ВыбранныеПоля, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.ДоверенностиСОтбором(Отбор, ВыбранныеПоля, НаДату);
```
</details>

## ДобавитьПодписьКФайлуДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет подпись к доверенности, устанавливает признак, что подписана, если есть все подписи доверенности.
//
// Параметры:
//  ФайлДоверенности - СправочникСсылка.МашиночитаемыеДоверенностиПрисоединенныеФайлы
//  Подпись - см. ЭлектроннаяПодписьКлиентСервер.НовыеСвойстваПодписи
//          - ДвоичныеДанные - данные подписи в формате DER
//          - Строка - адрес двоичных данных подписи во временном хранилище.
// Возвращаемое значение:
//  Булево - Истина, если удалось добавить подпись
//  Строка - текст ошибки, если подпись не соответствует доверенности
//
Функция ДобавитьПодписьКФайлуДоверенности(ФайлДоверенности, Знач Подпись) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.ДобавитьПодписьКФайлуДоверенности(ФайлДоверенности, Подпись) 
```
</details>

## РеквизитыПредставителяОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Реквизиты представителя организации.
//
// Параметры:
//  ФизическоеЛицо - ОпределяемыйТип.ФизическоеЛицо
//  ЭтоИндивидуальныйПредприниматель - Булево - это индивидуальный предприниматель
//  Должность - Строка - должность представителя организации
//
// Возвращаемое значение:
//  Структура - см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриЗаполненииРеквизитовФизическогоЛица.Реквизиты
//
Функция РеквизитыПредставителяОрганизации(ФизическоеЛицо, ЭтоИндивидуальныйПредприниматель = Ложь, Должность = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.РеквизитыПредставителяОрганизации(ФизическоеЛицо, ЭтоИндивидуальныйПредприниматель, Должность);
```
</details>

## РезультатПроверкиДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат проверки доверенности.
//
// Параметры:
//  Доверенность - СправочникСсылка.МашиночитаемыеДоверенности
//  ПроверятьВРеестреФНС - Булево, Неопределено - если Неопределено, то в зависимости от признака РегистрироватьВРеестре
//
// Возвращаемое значение:
//  Структура:
//   * Верна - Булево - подписи доверенности верны и соответствуют доверителям.
//   * ТребуетсяПроверка - Булево - если есть подписи, требующие проверки или не удалось получить статус в реестре ФНС.
//   * Статус - ПеречислениеСсылка.СтатусыМЧД
//   * ЕстьВРеестреФНС - Булево - доверенность удалось проверить в реестре ФНС
//   * ТекстОшибки - Строка
//   * ЕстьВсеПодписи - Булево - есть все подписи доверителей.
//   * РезультатыПроверкиПодписей - Массив из Структура:
//     ** Верна - Булево
//     ** КомуВыданСертификат - Строка
//     ** ДатаПодписи - Дата
//     ** ИдентификаторПодписи - УникальныйИдентификатор
//     ** ТребуетсяПроверка - Булево
//     ** Соответствует -  Булево - подпись соответствует доверителю.
//     ** ТекстОшибки - Строка
//     ** ТекстОшибкиСоответствия - Строка
//     ** РезультатПроверки - Неопределено - если подпись не требовалось проверять или не удалось ее проверить.
//                         - см. ЭлектроннаяПодписьКлиентСервер.РезультатПроверкиПодписи
//
Функция РезультатПроверкиДоверенности(Доверенность, ПроверятьВРеестреФНС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.РезультатПроверкиДоверенности(Доверенность, ПроверятьВРеестреФНС);
```
</details>

## РезультатПроверкиПодписиПоМЧД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет записанную в базу подпись на соответствие подписанту, документу, действие доверенности на дату подписи.
//
// Параметры:
//  ПодписанныйОбъект - ОпределяемыйТип.ПодписанныйОбъект - ссылка на подписанный объект.
//  ИдентификаторПодписи - УникальныйИдентификатор - см. ЭлектроннаяПодписьКлиентСервер.НовыеСвойстваПодписи.ИдентификаторПодписи
//  СертификатПодписи - СертификатКриптографии
//                    - ДвоичныеДанные
//                    - Строка - адрес двоичных данных во временном хранилище.
//  НаДату - Дата - дата подписи, если не заполнена, проверка будет выполнена на дату сеанса.
//
// Возвращаемое значение:
//  Массив из Структура:
//   * МашиночитаемаяДоверенность - СправочникСсылка.МашиночитаемыеДоверенности
//   * ТребуетсяПроверка - Булево - если Истина, не удалось проверить доверенность.
//   * ДатаПроверки - Дата
//   * Верна - Булево
//   * ПодписантСоответствуетПредставителю - Булево
//   * СовместныеПолномочия - Булево
//   * СовместныеПолномочияВерны - Булево
//   * ПротоколПроверки - Соответствие из КлючИЗначение:
//      ** Ключ - Строка - идентификатор проверки
//      ** Значение - см. РезультатПроверкиДляПротокола
//
Функция РезультатПроверкиПодписиПоМЧД(ПодписанныйОбъект, ИдентификаторПодписи, СертификатПодписи, НаДату) Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.РезультатПроверкиПодписиПоМЧД(ПодписанныйОбъект, ИдентификаторПодписи, СертификатПодписи, НаДату) 
```
</details>

## РезультатПроверкиДляПротокола
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Результат проверки для записи в протокол.
//
// Возвращаемое значение:
//  Структура:
//   * ЗаголовокПроверки - Строка - например, "Проверка документа".
///   * ТекстПроверки - Строка - например, "Организация не соответствует доверителю".
//   * Верна - Неопределено, Булево - если Неопределено - значит, требуется проверка.
//   * ДатаПроверки - Дата
//   * ДополнительныеДанные - Произвольный - дополнительные сведения о проверке, которые сохраняются в информационной базе.
//
Функция РезультатПроверкиДляПротокола() Экспорт
```

Пример вызова
```bsl
Результат = МашиночитаемыеДоверенностиФНС.РезультатПроверкиДляПротокола() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
