---
title: Напоминания пользователя
slug: bsp/напоминания-пользователя
---


## УстановитьНапоминание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает напоминание с произвольным временем или расписанием выполнения.
//
// Параметры:
//  Текст - Строка - текст напоминания;
//  ВремяСобытия - Дата - дата и время события, о котором надо напомнить.
//               - РасписаниеРегламентногоЗадания - расписание периодического события.
//               - Строка - имя реквизита Предмета, в котором содержится время наступления события.
//  ИнтервалДоСобытия - Число - время в секундах, за которое необходимо напомнить относительно времени события;
//  Предмет - ЛюбаяСсылка - предмет напоминания;
//  Идентификатор - Строка - уточняет предмет напоминания, например, "ДеньРождения".
//
Процедура УстановитьНапоминание(Текст, ВремяСобытия, ИнтервалДоСобытия = 0, Предмет = Неопределено, Идентификатор = Неопределено) Экспорт
```

Пример вызова
```bsl
НапоминанияПользователя.УстановитьНапоминание(Текст, ВремяСобытия, ИнтервалДоСобытия, Предмет, Идентификатор);
```
</details>

## НайтиНапоминания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список напоминаний текущего пользователя.
//
// Параметры:
//  Предмет - ЛюбаяСсылка
//          - Массив - предмет или предметы напоминания.
//  Идентификатор - Строка - уточняет предмет напоминания, например, "ДеньРождения".
//
// Возвращаемое значение:
//    Массив - коллекция напоминаний в виде структур с полями, соответствующими полям регистра сведений НапоминанияПользователя.
//
Функция НайтиНапоминания(Знач Предмет = Неопределено, Идентификатор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НапоминанияПользователя.НайтиНапоминания(Предмет, Идентификатор);
```
</details>

## УдалитьНапоминание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет напоминание пользователя.
//
// Параметры:
//  Напоминание - Структура - элемент коллекции, возвращаемый функцией НайтиНапоминания().
//
Процедура УдалитьНапоминание(Напоминание) Экспорт
```

Пример вызова
```bsl
НапоминанияПользователя.УдалитьНапоминание(Напоминание) 
```
</details>

## ОбновитьНапоминанияПоПредметам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет изменения реквизитов предметов, на которые есть пользовательская подписка,
// изменяет срок напоминания в случае необходимости.
//
// Параметры:
//  Предметы - Массив - предметы, по которым необходимо обновить сроки напоминаний.
//
Процедура ОбновитьНапоминанияПоПредметам(Предметы) Экспорт
```

Пример вызова
```bsl
НапоминанияПользователя.ОбновитьНапоминанияПоПредметам(Предметы) 
```
</details>

## ИспользуютсяНапоминанияПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность использования напоминаний пользователя.
//
// Возвращаемое значение:
//  Булево - используются напоминания пользователя
//
Функция ИспользуютсяНапоминанияПользователя() Экспорт
```

Пример вызова
```bsl
Результат = НапоминанияПользователя.ИспользуютсяНапоминанияПользователя() 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик одноименного события формы, размещает на форме элементы для настройки напоминания.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, в которой необходимо разместить элементы настройки напоминания.
//  ПараметрыРазмещения - см. ПараметрыРазмещения
//
Процедура ПриСозданииНаСервере(Форма, ПараметрыРазмещения) Экспорт
```

Пример вызова
```bsl
НапоминанияПользователя.ПриСозданииНаСервере(Форма, ПараметрыРазмещения) 
```
</details>

## ПараметрыРазмещения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет параметры размещения на форме элементов настройки напоминания.
//
// Возвращаемое значение:
//  Структура:
//   * Группа - ГруппаФормы - место размещения элементов настройки напоминания.
//   * ИмяРеквизитаСДатойСобытия - Строка - реквизит, относительно которого устанавливается время напоминания о событии.
//   * ИнтервалВремениНапоминания - Число - интервал времени напоминания по умолчанию, в секундах. По умолчанию - 0.
//   * ДобавлятьФлажок - Булево - если Истина, то рядом с полем ввода интервала времени будет добавлен флажок для
//                                быстрого включения/отключения напоминания. Если Ложь, то флажок выводиться не будет,
//                                отключение напоминания будет доступно в списке выбора интервалов времени. Значение по
//                                умолчанию - Ложь.
//
Функция ПараметрыРазмещения() Экспорт
```

Пример вызова
```bsl
Результат = НапоминанияПользователя.ПараметрыРазмещения() 
```
</details>

## ПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик одноименного события формы, обновляет на форме элементы, связанные с настройкой напоминания.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, в которой необходимо разместить элементы настройки напоминания.
//  ТекущийОбъект       - СправочникОбъект
//                      - ДокументОбъект
//                      - ПланВидовХарактеристикОбъект
//                      - ПланСчетовОбъект
//                      - ПланВидовРасчетаОбъект
//                      - БизнесПроцессОбъект
//                      - ЗадачаОбъект
//                      - ПланОбменаОбъект - предмет напоминания.
//
Процедура ПриЧтенииНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
НапоминанияПользователя.ПриЧтенииНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ПриЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик одноименного события формы, устанавливает напоминание по предмету при записи объекта в форме.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма, в которой размещены элементы настройки напоминания.
//   Отказ - Булево - признак отказа от записи.
//   ТекущийОбъект  - СправочникОбъект
//                  - ДокументОбъект
//                  - ПланВидовХарактеристикОбъект
//                  - ПланСчетовОбъект
//                  - ПланВидовРасчетаОбъект
//                  - БизнесПроцессОбъект
//                  - ЗадачаОбъект
//                  - ПланОбменаОбъект - предмет напоминания.
//   ПараметрыЗаписи - Структура
//   ТекстНапоминания - Строка - текст устанавливаемого напоминания. Если не заполнен, то используется представление
//                               предмета напоминания.
//
Процедура ПриЗаписиНаСервере(Форма, Отказ, ТекущийОбъект, ПараметрыЗаписи, ТекстНапоминания = "") Экспорт
```

Пример вызова
```bsl
НапоминанияПользователя.ПриЗаписиНаСервере(Форма, Отказ, ТекущийОбъект, ПараметрыЗаписи, ТекстНапоминания);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
