---
title: Обмен данными сервер
slug: bsp/обмен-данными-сервер
---


## ЗначениеНастройкиПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значение настройки плана обмена по ее имени.
// Для несуществующих настроек возвращается Неопределено.
//
// Параметры:
//   ИмяПланаОбмена         - Строка - имя плана обмена из метаданных.
//   ИмяПараметра           - Строка - имя параметра плана обмена или список параметров, разделенных запятыми.
//                                     Список допустимых значений см. в функциях НастройкиПланаОбменаПоУмолчанию,
//                                     ОписаниеВариантаНастройкиОбменаПоУмолчанию.
//   ИдентификаторНастройки - Строка - имя предопределенной настройки плана обмена.
//   ВерсияКорреспондента   - Строка - версия конфигурации корреспондента.
//
// Возвращаемое значение:
//   Произвольный, Структура - тип возвращаемого значения зависит от типа значения получаемой настройки.
//                             Произвольный, если в качестве ИмяПараметра был передан единичный параметр
//                             Структура, если в качестве параметра ИмяПараметра была передан список параметров через запятую.
//
Функция ЗначениеНастройкиПланаОбмена(ИмяПланаОбмена, ИмяПараметра, ИдентификаторНастройки = "", ВерсияКорреспондента = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ЗначениеНастройкиПланаОбмена(ИмяПланаОбмена, ИмяПараметра, ИдентификаторНастройки, ВерсияКорреспондента);
```
</details>

## ФормаУзлаПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура-обработчик события "ПриСозданииНаСервере" для формы узла плана обмена.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, из которой вызвана процедура:
//    * Объект - ДанныеФормыСтруктура:
//      ** Ссылка - ПланОбменаСсылка - узел плана обмена.
//  Отказ - Булево           - признак отказа от создания формы. Если установить в Истина, то форма создана не будет.
//
Процедура ФормаУзлаПриСозданииНаСервере(Форма, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ФормаУзлаПриСозданииНаСервере(Форма, Отказ) 
```
</details>

## ФормаУзлаПриЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура-обработчик события "ПриЗаписиНаСервере" для формы узла плана обмена.
//
// Параметры:
//  ТекущийОбъект - ПланОбменаОбъект - записываемый узел плана обмена.
//  Отказ         - Булево           - входящий, признак отказа от записи узла обмена.
//                                     Если установлен в Истина, то для узла не будет
//                                     зафиксировано завершение настройки синхронизации.
//
Процедура ФормаУзлаПриЗаписиНаСервере(ТекущийОбъект, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ФормаУзлаПриЗаписиНаСервере(ТекущийОбъект, Отказ) 
```
</details>

## ФормаНастройкиУзлаПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура-обработчик события "ПриСозданииНаСервере" для формы настройки узла.
//
// Параметры:
//  Форма          - ФормаКлиентскогоПриложения - форма, из которой вызвана процедура.
//  ИмяПланаОбмена - Строка           - имя плана обмена, для которого создана форма.
//
Процедура ФормаНастройкиУзлаПриСозданииНаСервере(Форма, ИмяПланаОбмена) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ФормаНастройкиУзлаПриСозданииНаСервере(Форма, ИмяПланаОбмена) 
```
</details>

## НадоВыполнитьОбработчикПослеВыгрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость выполнения обработчика события "ПослеВыгрузкиДанных" при обмене в РИБ.
//
// Параметры:
//  Объект - ПланОбменаОбъект - узел плана обмена, для которого выполняется обработчик.
//  Ссылка - ПланОбменаСсылка - ссылка на узел плана обмена, для которого выполняется обработчик.
//
// Возвращаемое значение:
//   Булево - если Истина, то необходимо выполнить обработчик "ПослеВыгрузкиДанных"; Ложь - нет.
//
Функция НадоВыполнитьОбработчикПослеВыгрузкиДанных(Объект, Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.НадоВыполнитьОбработчикПослеВыгрузкиДанных(Объект, Ссылка) 
```
</details>

## НадоВыполнитьОбработчикПослеЗагрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость выполнения обработчика события "ПослеЗагрузкиДанных" при обмене в РИБ.
//
// Параметры:
//  Объект - ПланОбменаОбъект - узел плана обмена, для которого выполняется обработчик.
//  Ссылка - ПланОбменаСсылка - ссылка на узел плана обмена, для которого выполняется обработчик.
//
// Возвращаемое значение:
//   Булево - если Истина, то необходимо выполнить обработчик "ПослеЗагрузкиДанных"; Ложь - нет.
//
Функция НадоВыполнитьОбработчикПослеЗагрузкиДанных(Объект, Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.НадоВыполнитьОбработчикПослеЗагрузкиДанных(Объект, Ссылка) 
```
</details>

## ПрефиксИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает префикс этой информационной базы.
//
// Возвращаемое значение:
//   Строка - префикс этой информационной базы.
//
Функция ПрефиксИнформационнойБазы() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПрефиксИнформационнойБазы() 
```
</details>

## ВерсияКорреспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает версию конфигурации корреспондента.
// Если версия конфигурации корреспондента не определена, то возвращает пустую версию - "0.0.0.0".
//
// Параметры:
//  Корреспондент - ПланОбменаСсылка - узел плана обмена, для которого необходимо получить версию конфигурации.
//
// Возвращаемое значение:
//  Строка - версия конфигурации корреспондента.
//
// Пример:
//  Если ОбщегоНазначенияКлиентСервер.СравнитьВерсии(ОбменДаннымиСервер.ВерсияКорреспондента(Корреспондент), "2.1.5.1")
//  >= 0 Тогда ...
//
Функция ВерсияКорреспондента(Знач Корреспондент) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ВерсияКорреспондента(Корреспондент) 
```
</details>

## УстановитьПрефиксИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает префикс этой информационной базы.
//
// Параметры:
//   Префикс - Строка - новое значение префикса информационной базы.
//
Процедура УстановитьПрефиксИнформационнойБазы(Знач Префикс) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.УстановитьПрефиксИнформационнойБазы(Префикс) 
```
</details>

## ПараметрыРезервнойКопии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет факт восстановления этой базы из резервной копии.
// Если база была восстановлена из резервной копии, то необходимо выполнить синхронизацию номеров отправленных и
// полученных сообщений для двух баз (номеру отправленного сообщения в этой базе присваивается значение номера
// принятого сообщения из базы-корреспондента).
// Если база была восстановлена из резервной копии, то рекомендуется не снимать с регистрации изменения данных на
// текущем узле, т.к. эти данные могли быть еще не отправлены.
//
// Параметры:
//   Отправитель    - ПланОбменаСсылка - узел, от имени которого было сформировано и отправлено сообщение обмена.
//   НомерПринятого - Число            - номер принятого сообщения в базе-корреспонденте.
//
// Возвращаемое значение:
//   ФиксированнаяСтруктура:
//     * Отправитель                 - ПланОбменаСсылка - см. выше параметр Отправитель.
//     * НомерПринятого              - Число            - см. выше параметр НомерПринятого.
//     * ВосстановленаРезервнаяКопия - Булево - Истина, если обнаружен факт восстановления этой базы из резервной копии.
//
Функция ПараметрыРезервнойКопии(Знач Отправитель, Знач НомерПринятого) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПараметрыРезервнойКопии(Отправитель, НомерПринятого) 
```
</details>

## ПриВосстановленииРезервнойКопии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет синхронизацию номеров отправленных и полученных сообщений
// для двух баз (номеру отправленного сообщения в этой базе присваивается значение номера принятого сообщения из
// базы-корреспондента).
//
// Параметры:
//   ПараметрыРезервнойКопии - ФиксированнаяСтруктура:
//     * Отправитель                 - ПланОбменаСсылка - узел, от имени которого было сформировано и отправлено
//                                                        сообщение обмена.
//     * НомерПринятого              - Число            - номер принятого сообщения в базе-корреспонденте.
//     * ВосстановленаРезервнаяКопия - Булево           - признак восстановления этой базы из резервной копии.
//
Процедура ПриВосстановленииРезервнойКопии(Знач ПараметрыРезервнойКопии) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ПриВосстановленииРезервнойКопии(ПараметрыРезервнойКопии) 
```
</details>

## СохраненныйВариантНастройкиУзлаПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор сохраненного варианта настройки плана обмена.
// Параметры:
//   УзелПланаОбмена         - ПланОбменаСсылка - узел плана обмена, для которого необходимо получить переопределяемое
//                                                имя.
//
// Возвращаемое значение:
//  Строка - идентификатор сохраненной настройки как он задан в конфигураторе.
//
Функция СохраненныйВариантНастройкиУзлаПланаОбмена(УзелПланаОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.СохраненныйВариантНастройкиУзлаПланаОбмена(УзелПланаОбмена) 
```
</details>

## ДанныеТаблицКорреспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные таблиц для реквизитов узла обмена.
//
// Параметры:
//   Таблицы        - Массив из Строка - имена реквизитов узла плана обмена.
//   ИмяПланаОбмена - Строка - имя плана обмена.
//
// Возвращаемое значение:
//   Соответствие - соответствие таблиц и их данных.
//
Функция ДанныеТаблицКорреспондента(Таблицы, Знач ИмяПланаОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ДанныеТаблицКорреспондента(Таблицы, ИмяПланаОбмена) 
```
</details>

## УстановитьКоличествоЭлементовВТранзакцииЗагрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет установку в константе количества элементов в транзакции загрузки данных.
//
// Параметры:
//  Количество - Число - количество элементов в транзакции.
//
Процедура УстановитьКоличествоЭлементовВТранзакцииЗагрузкиДанных(Количество) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.УстановитьКоличествоЭлементовВТранзакцииЗагрузкиДанных(Количество) 
```
</details>

## ПредставлениеДатыСинхронизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление даты синхронизации.
//
// Параметры:
//  ДатаСинхронизации - Дата - абсолютная дата синхронизации данных.
//
// Возвращаемое значение:
//  Строка - строковое представление даты.
//
Функция ПредставлениеДатыСинхронизации(Знач ДатаСинхронизации) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПредставлениеДатыСинхронизации(ДатаСинхронизации) 
```
</details>

## ОтносительнаяДатаСинхронизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление относительной даты синхронизации.
//
// Параметры:
//  ДатаСинхронизации - Дата - абсолютная дата синхронизации данных.
//
// Возвращаемое значение:
//  Строка - представление относительной даты синхронизации:
//    *Никогда             (Т = пустая дата).
//    *Сейчас              (Т < 5 мин)
//    *5 минут назад       (5 мин  < Т < 15 мин)
//    *15 минут назад      (15 мин  < Т < 30 мин)
//    *30 минут назад      (30 мин  < Т < 1 час)
//    *1 час назад         (1 час  < Т < 2 час)
//    *2 часа назад        (2 час  < Т < 3 час).
//    *Сегодня, 12:44:12   (3 час  < Т < вчера).
//    *Вчера, 22:30:45     (вчера  < Т < позавчера).
//    *Позавчера, 21:22:54 (позавчера  < Т < поза-позавчера).
//    *<12 Марта 2012г.>   (поза-позавчера < Т).
//
Функция ОтносительнаяДатаСинхронизации(Знач ДатаСинхронизации) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ОтносительнаяДатаСинхронизации(ДатаСинхронизации) 
```
</details>

## ПрофильДоступаСинхронизацияДанныхСДругимиПрограммами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор поставляемого профиля групп доступа "Синхронизация данных с другими программами".
//
// Возвращаемое значение:
//  Строка - идентификатор поставляемого профиля групп доступа.
//
Функция ПрофильДоступаСинхронизацияДанныхСДругимиПрограммами() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПрофильДоступаСинхронизацияДанныхСДругимиПрограммами() 
```
</details>

## ЕстьПраваНаАдминистрированиеОбменов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие возможности администрирования обменов у текущего пользователя.
//
// Возвращаемое значение:
//  Булево - если Истина - права есть, Ложь - прав нет.
//
Функция ЕстьПраваНаАдминистрированиеОбменов() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ЕстьПраваНаАдминистрированиеОбменов() 
```
</details>

## ПолучитьWSПрокси
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект WSПрокси веб-сервиса Exchange, созданный с переданными параметрами.
//
// Параметры:
//  СтруктураНастроек - Структура:
//    * WSURLВебСервиса - Строка - месторасположение wsdl.
//    * WSИмяСервиса - Строка - имя сервиса.
//    * WSURLПространстваИменСервиса - Строка - URI пространства имен web-сервиса.
//    * WSИмяПользователя - Строка - имя пользователя для входа на сервер.
//    * WSПароль - Строка - пароль пользователя.
//    * WSТаймаут - Число - таймаут на операции выполняемые через полученное прокси.
//  СтрокаСообщенияОбОшибке - Строка - содержит подробное описание ошибки в случае неуспешного подключения;
//  СообщениеПользователю - Строка - содержит краткое описание ошибки в случае неуспешного подключения.
//
// Возвращаемое значение:
//  WSПрокси - объект WSПрокси веб-сервиса Exchange.
//
Функция ПолучитьWSПрокси(СтруктураНастроек, СтрокаСообщенияОбОшибке = "", СообщениеПользователю = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПолучитьWSПрокси(СтруктураНастроек, СтрокаСообщенияОбОшибке, СообщениеПользователю);
```
</details>

## ПолучитьWSПрокси_2_0_1_6
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект WSПрокси веб-сервиса Exchange_2_0_1_6, созданный с переданными параметрами.
//
// Параметры:
//  СтруктураНастроек - Структура:
//    * WSURLВебСервиса - Строка - месторасположение wsdl.
//    * WSИмяСервиса - Строка - имя сервиса.
//    * WSURLПространстваИменСервиса - Строка - URI пространства имен web-сервиса.
//    * WSИмяПользователя - Строка - имя пользователя для входа на сервер.
//    * WSПароль - Строка - пароль пользователя.
//    * WSТаймаут - Число - таймаут на операции выполняемые через полученное прокси.
//  СтрокаСообщенияОбОшибке - Строка - содержит подробное описание ошибки в случае неуспешного подключения;
//  СообщениеПользователю - Строка - содержит краткое описание ошибки в случае неуспешного подключения.
//
// Возвращаемое значение:
//  WSПрокси - объект WSПрокси веб-сервиса Exchange_2_0_1_6.
//
Функция ПолучитьWSПрокси_2_0_1_6(СтруктураНастроек, СтрокаСообщенияОбОшибке = "", СообщениеПользователю = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПолучитьWSПрокси_2_0_1_6(СтруктураНастроек, СтрокаСообщенияОбОшибке, СообщениеПользователю);
```
</details>

## ПолучитьWSПрокси_2_1_1_7
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект WSПрокси веб-сервиса Exchange_2_0_1_7, созданный с переданными параметрами.
//
// Параметры:
//  СтруктураНастроек - Структура:
//    * WSURLВебСервиса - Строка - месторасположение wsdl.
//    * WSИмяСервиса - Строка - имя сервиса.
//    * WSURLПространстваИменСервиса - Строка - URI пространства имен web-сервиса.
//    * WSИмяПользователя - Строка - имя пользователя для входа на сервер.
//    * WSПароль - Строка - пароль пользователя.
//    * WSТаймаут - Число - таймаут на операции выполняемые через полученное прокси.
//  СтрокаСообщенияОбОшибке - Строка - содержит подробное описание ошибки в случае неуспешного подключения;
//  СообщениеПользователю - Строка - содержит краткое описание ошибки в случае неуспешного подключения.
//  Таймаут - Число - таймаут.
//
// Возвращаемое значение:
//  WSПрокси - объект WSПрокси веб-сервиса Exchange_2_0_1_7.
//
Функция ПолучитьWSПрокси_2_1_1_7(СтруктураНастроек, СтрокаСообщенияОбОшибке = "", СообщениеПользователю = "", Таймаут = 600) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПолучитьWSПрокси_2_1_1_7(СтруктураНастроек, СтрокаСообщенияОбОшибке, СообщениеПользователю, Таймаут);
```
</details>

## ПолучитьWSПрокси_3_0_1_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект WSПрокси веб-сервиса Exchange_3_0_1_1, созданный с переданными параметрами.
//
// Параметры:
//  СтруктураНастроек - Структура:
//    * WSURLВебСервиса - Строка - месторасположение wsdl.
//    * WSИмяСервиса - Строка - имя сервиса.
//    * WSURLПространстваИменСервиса - Строка - URI пространства имен web-сервиса.
//    * WSИмяПользователя - Строка - имя пользователя для входа на сервер.
//    * WSПароль - Строка - пароль пользователя.
//    * WSТаймаут - Число - таймаут на операции выполняемые через полученное прокси.
//  СтрокаСообщенияОбОшибке - Строка - содержит подробное описание ошибки в случае неуспешного подключения;
//  СообщениеПользователю - Строка - содержит краткое описание ошибки в случае неуспешного подключения.
//  Таймаут - Число - таймаут.
//
// Возвращаемое значение:
//  WSПрокси - объект WSПрокси веб-сервиса Exchange_3_0_1_1.
//
Функция ПолучитьWSПрокси_3_0_1_1(СтруктураНастроек, СтрокаСообщенияОбОшибке = "", СообщениеПользователю = "", Таймаут = 600) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПолучитьWSПрокси_3_0_1_1(СтруктураНастроек, СтрокаСообщенияОбОшибке, СообщениеПользователю, Таймаут);
```
</details>

## ПолучитьWSПрокси_3_0_2_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект WSПрокси веб-сервиса Exchange_3_0_1_1, созданный с переданными параметрами.
//
// Параметры:
//  СтруктураНастроек - Структура:
//    * WSURLВебСервиса - Строка - месторасположение wsdl.
//    * WSИмяСервиса - Строка - имя сервиса.
//    * WSURLПространстваИменСервиса - Строка - URI пространства имен web-сервиса.
//    * WSИмяПользователя - Строка - имя пользователя для входа на сервер.
//    * WSПароль - Строка - пароль пользователя.
//    * WSТаймаут - Число - таймаут на операции выполняемые через полученное прокси.
//  СтрокаСообщенияОбОшибке - Строка - содержит подробное описание ошибки в случае неуспешного подключения;
//  СообщениеПользователю - Строка - содержит краткое описание ошибки в случае неуспешного подключения.
//  Таймаут - Число - таймаут.
//
// Возвращаемое значение:
//  WSПрокси - объект WSПрокси веб-сервиса Exchange_3_0_2_1.
//
Функция ПолучитьWSПрокси_3_0_2_1(СтруктураНастроек, СтрокаСообщенияОбОшибке = "", СообщениеПользователю = "", Таймаут = 600) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПолучитьWSПрокси_3_0_2_1(СтруктураНастроек, СтрокаСообщенияОбОшибке, СообщениеПользователю, Таймаут);
```
</details>

## ПолучитьWSПрокси_3_0_2_2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект WSПрокси веб-сервиса Exchange_3_0_1_1, созданный с переданными параметрами.
//
// Параметры:
//  СтруктураНастроек - Структура:
//    * WSURLВебСервиса - Строка - месторасположение wsdl.
//    * WSИмяСервиса - Строка - имя сервиса.
//    * WSURLПространстваИменСервиса - Строка - URI пространства имен web-сервиса.
//    * WSИмяПользователя - Строка - имя пользователя для входа на сервер.
//    * WSПароль - Строка - пароль пользователя.
//    * WSТаймаут - Число - таймаут на операции выполняемые через полученное прокси.
//  СтрокаСообщенияОбОшибке - Строка - содержит подробное описание ошибки в случае неуспешного подключения;
//  СообщениеПользователю - Строка - содержит краткое описание ошибки в случае неуспешного подключения.
//  Таймаут - Число - таймаут.
//
// Возвращаемое значение:
//  WSПрокси - объект WSПрокси веб-сервиса Exchange_3_0_2_1.
//
Функция ПолучитьWSПрокси_3_0_2_2(СтруктураНастроек, СтрокаСообщенияОбОшибке = "", СообщениеПользователю = "", Таймаут = 600) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПолучитьWSПрокси_3_0_2_2(СтруктураНастроек, СтрокаСообщенияОбОшибке, СообщениеПользователю, Таймаут);
```
</details>

## КоличествоЭлементовВТранзакцииЗагрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает допустимое количество элементов, обрабатываемых в одной транзакции загрузки данных.
//
// Возвращаемое значение:
//   Число - допустимое количество элементов, обрабатываемых в одной транзакции загрузки данных.
//
Функция КоличествоЭлементовВТранзакцииЗагрузкиДанных() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.КоличествоЭлементовВТранзакцииЗагрузкиДанных() 
```
</details>

## КоличествоЭлементовВТранзакцииВыгрузкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает допустимое количество элементов, обрабатываемых в одной транзакции выгрузки данных.
//
// Возвращаемое значение:
//   Число - допустимое количество элементов, обрабатываемых в одной транзакции выгрузки данных.
//
Функция КоличествоЭлементовВТранзакцииВыгрузкиДанных() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.КоличествоЭлементовВТранзакцииВыгрузкиДанных() 
```
</details>

## УзлыОбменаБСП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с данными узлов всех настроенных обменов БСП.
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//     * УзелИнформационнойБазы - ПланОбменаСсылка - ссылка на узел плана обмена.
//     * Наименование - Строка - наименование узла плана обмена.
//     * ИмяПланаОбмена - Строка - имя плана обмена.
//
Функция УзлыОбменаБСП() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.УзлыОбменаБСП() 
```
</details>

## ИспользуютсяТиповыеПравила
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, используются ли типовых правила конвертации для плана обмена.
//
// Параметры:
//  ИмяПланаОбмена - Строка - имя плана обмена, для которого загружаются правила.
//
// Возвращаемое значение:
//   Булево - если Истина, то используются; Ложь - нет.
//
Функция ИспользуютсяТиповыеПравила(ИмяПланаОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ИспользуютсяТиповыеПравила(ИмяПланаОбмена) 
```
</details>

## ВнешнееСоединениеСБазой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает внешнее соединение с информационной базой и возвращает описание соединения.
//
// Параметры:
//  Параметры - Структура - параметры для установки внешнего соединения с информационной базой.
//                          Свойства см. в функции
//                          ОбщегоНазначенияКлиентСервер.СтруктураПараметровДляУстановкиВнешнегоСоединения:
//
//    * ВариантРаботыИнформационнойБазы             - Число  -  вариант работы информационной базы: 0 - файловый; 1 -
//	                                                           клиент-серверный;
//    * КаталогИнформационнойБазы                   - Строка - каталог информационной базы для файлового режима работы;
//    * ИмяСервера1СПредприятия                     - Строка - имя сервера1С:Предприятия;
//    * ИмяИнформационнойБазыНаСервере1СПредприятия - Строка - имя информационной базы на сервере1С:Предприятия;
//    * АутентификацияОперационнойСистемы           - Булево - признак аутентификации операционной системы при создании
//	                                                           внешнего подключения к информационной базе;
//    * ИмяПользователя                             - Строка - имя пользователя информационной базы;
//    * ПарольПользователя                          - Строка - пароль пользователя информационной базы.
//
// Возвращаемое значение:
//  Структура:
//    * Соединение                  - COMОбъект
//                                  - Неопределено - указатель на COM-объект соединения или Неопределено в
//                                    случае ошибки;
//    * КраткоеОписаниеОшибки       - Строка - краткое описание ошибки;
//    * ПодробноеОписаниеОшибки     - Строка - подробное описание ошибки;
//    * ОшибкаПодключенияКомпоненты - Булево - флаг ошибки подключения COM.
//
Функция ВнешнееСоединениеСБазой(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ВнешнееСоединениеСБазой(Параметры) 
```
</details>

## ВыполнитьОбменДаннымиСВнешнейСистемой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Точка входа для выполнения итерации обмена данными (загрузки и выгрузки) с внешней системой по узлу плана обмена.
//
// Параметры:
//  Корреспондент - ПланОбменаСсылка - узел плана обмена, соответствующий внешней системе.
//  ПараметрыОбмена - Структура - должна содержать следующие параметры:
//    * ВыполнятьЗагрузку - Булево - флаг необходимости выполнять загрузку данных.
//    * ВыполнятьОтправкуНастроек - Булево - флаг необходимости выполнять отправку настроек XDTO.
//  ФлагОшибка - Булево - Истина, в случае возникновения ошибки при выполнении обмена.
//                        Подробная информация об ошибке фиксируется в журнале регистрации.
//
Процедура ВыполнитьОбменДаннымиСВнешнейСистемой(Корреспондент, ПараметрыОбмена, ФлагОшибка) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ВыполнитьОбменДаннымиСВнешнейСистемой(Корреспондент, ПараметрыОбмена, ФлагОшибка) 
```
</details>

## НастройкиПланаОбменаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет настройки по умолчанию для плана обмена, которые затем могут быть переопределены
// в модуле менеджера плана обмена в процедуре ПриПолученииНастроек().
//
// Параметры:
//   ИмяПланаОбмена         - Строка - имя плана обмена из метаданных.
//
// Возвращаемое значение:
//   Структура:
//      * ВариантыНастроекОбмена                 - см. КоллекцияВариантовНастроекОбмена
//      * ВидГруппыДляВариантовНастроек          - ВидГруппыФормы - вариант вида группы для отображения в
//                                                 дереве команд создания обмена вариантов настроек.
//      * ИмяКонфигурацииИсточника               - Строка - имя конфигурации источника, выводимое в
//                                                 пользовательском интерфейсе.
//      * ИмяКонфигурацииПриемника               - Структура - перечень идентификаторов конфигураций-корреспондентов,
//                                                 обмен с которыми возможен через данный план обмена.
//      * ВерсииФорматаОбмена                    - Соответствие из КлючИЗначение - номеров поддерживаемых версий формата
//                                                 и ссылок на общие модули с логикой обмена через формат.
//                                                 Используется только для обменов через универсальный формат:
//         ** Ключ - Число - версия формата.
//         ** Значение - ОбщийМодуль - ссылка на общий модуль.
//      * ФорматОбмена                             - Строка - пространство имен XDTO пакета, в котором содержится
//                                                   универсальный формат, без указания версии формата.
//                                                   Используется только для обменов через универсальный формат.
//      * РасширенияФорматаОбмена                  - Соответствие из КлючИЗначение:
//        ** Ключ                                  - Строка - URI пространства имен схемы расширения формата.
//        ** Значение                              - Строка - номер расширяемой версии формата.
//      * ПланОбменаИспользуетсяВМоделиСервиса     - Булево - признак использования плана обмена для организации
//                                                   обмена в модели сервиса.
//      * ЭтоПланОбменаXDTO                        - Булево - признак того, что это план обмена через
//                                                   универсальный формат.
//      * ПредупреждатьОНесоответствииВерсийПравилОбмена - Булево - признак необходимости проверки на
//                                                                  расхождение версий в правилах конвертации.
//                                                                  Проверка выполняется при загрузке комплекта
//                                                                  правил, при отправке данных и при получении данных.
//      * ИмяПланаОбменаДляПереходаНаНовыйОбмен    - Строка - если для плана обмена свойство установлено, в
//                                                   рабочих местах управления настройками не будет
//                                                   предлагаться настроить этот вид обмена.
//                                                   Существующие обмены этого вида будут продолжать
//                                                   отображаться в списке настроенных обменов.
//                                                   Получении сообщения обмена в новом формате будет
//                                                   инициировать переход на новый вид обмена.
//      * НазначениеПланаОбмена                    - Строка - вариант назначения плана обмена.
//      * Алгоритмы                                - Структура - перечень экспортных процедур и функций, которые
//                                                   объявлены в модуле менеджера плана обмена
//                                                   и используются подсистемой обмена данными.
//      *ПравилаРегистрацииВМенеджере              - Булево - признак использования правил регистрации,
//                                                   расположенных в общем модуле (менеджере регистрации)
//      *ИмяМенеджераРегистрации                   - Строка - имя модуля с правилами регистрации
//      *ИспользоватьКешПубличныхИдентификаторов   - Булево - признак того, что при загрузке данных будет
//                                                   использован кеш для поиска ссылок
//      *Глобальный                                - Булево - если установлено Истина, то план обмена может быть
//                                                   использован для обмена с планами обмена с другими наименованиями.
//                                                   Только для обмена через EnterpriseData
//
Функция НастройкиПланаОбменаПоУмолчанию(ИмяПланаОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.НастройкиПланаОбменаПоУмолчанию(ИмяПланаОбмена) 
```
</details>

## ОписаниеВариантаНастройкиОбменаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет настройки по умолчанию варианта настройки обмена, которые затем могут быть переопределены
// в модуле менеджера плана обмена в процедуре ПриПолученииОписанияВариантаНастройки().
//
// Параметры:
//   ИмяПланаОбмена - Строка - содержит имя плана обмена.
//
// Возвращаемое значение:
//   Структура:
//      * Отборы                                    - Структура - отборы на узле плана обмена,
//                                                    подлежат заполнению значениями по умолчанию.
//      * ЗначенияПоУмолчанию                       - Структура - значения по умолчанию на узле плана обмена.
//      * ОбщиеДанныеУзлов                          - Строка - имена реквизитов и табличных частей плана обмена,
//                                                    через запятую, которые являются общими для пары
//                                                    обменивающихся конфигураций.
//      * ИспользоватьПомощникСозданияОбменаДанными - Булево - признак, будет ли использоваться помощник для
//                                                    создания новых узлов плана обмена.
//      * ИмяФормыСозданияНачальногоОбраза          - Строка - имя используемой формы создания начального
//                                                    образа распределенной ИБ.
//      * ИмяФормыПомощникаНастройкиСинхронизацииДанных - Строка - имя формы, которая будет использована для настройки
//                                                        правил отправки и получения данных вместо
//                                                        стандартной формы.
//      * ПояснениеДляНастройкиПараметровУчета      - Строка - пояснение о последовательности действий пользователя
//                                                    для настройки параметров учета в текущей
//                                                    информационной базе.
//      * ПутьКФайлуКомплектаПравилНаПользовательскомСайте - Строка - путь к файлу комплекта правил в виде архива
//                                                           на пользовательском сайте в разделе конфигурации.
//      * ПутьКФайлуКомплектаПравилВКаталогеШаблонов - Строка - относительный путь к файлу комплекта правил в
//                                                     каталоге шаблонов.
//      * ЗаголовокКомандыДляСозданияНовогоОбменаДанными - Строка - представление команды, выводимое в пользовательском
//                                                         интерфейсе при создании новой настройки
//                                                                         обмена данными.
//      * ЗаголовокПомощникаСозданияОбмена          - Строка - представление заголовка формы помощника
//                                                    создания обмена данными выводимое в
//                                                    пользовательском интерфейсе.
//      * ЗаголовокУзлаПланаОбмена                  - Строка - представление узла плана обмена
//                                                    выводимое в пользовательском интерфейсе.
//      * ИмяКонфигурацииКорреспондента             - Строка - идентификатор конфигурации корреспондента.
//      * НаименованиеКонфигурацииКорреспондента    - Строка - представление наименования конфигурации корреспондента
//                                                    выводимое в пользовательском интерфейсе.
//      * ИспользуемыеТранспортыСообщенийОбмена     - Массив из ПеречислениеСсылка.ВидыТранспортаСообщенийОбмена
//                                                    - Перечень используемых транспортов сообщений. Если не заполнен,
//                                                    будут доступны все возможные виды транспорта.
//      * КраткаяИнформацияПоОбмену                 - Строка - краткое описание обмена данными, которое
//                                                    выводится на первой странице помощника
//                                                    создания обмена.
//      * ПодробнаяИнформацияПоОбмену               - Строка - ссылка на веб-страницу или полный путь к
//                                                    форме внутри конфигурации строкой, для
//                                                    отображения в помощнике создания обмена.
//      * ИмяФайлаНастроекДляПриемника              - Строка - имя файла для сохранения настроек подключения
//                                                    при настройке обмена через OFFLINE-каналы.
//      * ПоддерживаетсяСопоставлениеДанных         - Булево - Истина, если для данного варианта настройки
//                                                    поддерживается
//                                                    интерактивное сопоставление данных. В
//                                                    противном случае полученные сообщения обмена
//                                                    будут сразу загружаться в информационную базу.
//      * РасширениеФормата                         - Строка - имя расширения формата, применимое для
//                                                    данного варианта настройки. Образуется из URI
//                                                    пространства имен схемы расширения формата,
//                                                    без учета версии. Напр., для пространства
//                                                    имен "HTTP://v8.1c.ru/EDI/edi_stnd/_DemoEnterpriseDataExt/1.1"
//                                                    имя расширение формата будет
//                                                    "HTTP://v8.1c.ru/EDI/edi_stnd/_DemoEnterpriseDataExt";
//      * ИмяПланаОбменаКорреспондента              - Строка - имя метаданных плана обмена корреспондирующей базы
//
Функция ОписаниеВариантаНастройкиОбменаПоУмолчанию(ИмяПланаОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ОписаниеВариантаНастройкиОбменаПоУмолчанию(ИмяПланаОбмена) 
```
</details>

## ПараметрыКонтекстаПолученияОписанияВариантаНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для подготовки структуры, для последующей передачи в обработчик получения описания варианта.
//
// Параметры:
//  ИмяКорреспондента - Строка - имя конфигурации-корреспондента.
//  ВерсияКорреспондента - Строка - версия конфигурации-корреспондента.
//
// Возвращаемое значение:
//   Структура:
//     * ИмяКорреспондента - Строка - имя конфигурации корреспондента.
//     * ВерсияКорреспондента - Строка - номер версии конфигурации корреспондента.
//
Функция ПараметрыКонтекстаПолученияОписанияВариантаНастройки(ИмяКорреспондента, ВерсияКорреспондента) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПараметрыКонтекстаПолученияОписанияВариантаНастройки(ИмяКорреспондента, ВерсияКорреспондента) 
```
</details>

## ПриСохраненииНастроекПодключенияВнешнейСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет настройки подключения для обмена с внешней системой через EnterpriseData.
//
// Параметры:
//  Контекст - Структура - контекст выполнения операции:
//    * Режим - Строка - режим, в котором вызывается обработчик.
//                       Возможные значения: "НовоеПодключение" | "РедактированиеПараметровПодключения".
//    * Корреспондент - ПланОбменаСсылка
//                    - Неопределено - узел обмена, соответствующий корреспонденту.
//                                     Для режима "НовоеПодключение" равен Неопределено;
//    * ИмяПланаОбмена - Строка
//                     - Неопределено - имя плана обмена, на котором создается узел.
//    * ИдентификаторНастройки - Строка
//                             - Неопределено - идентификатор варианта настройки,
//                                              как он указан в модуле менеджера плана обмена.
//  ПараметрыПодключения - Структура - структура параметров подключения:
//    * ИдентификаторКорреспондента - Строка - строка длиной 36 символов
//                                  - Неопределено - уникальный идентификатор корреспондента.
//    * НаименованиеКорреспондента - Строка
//                                 - Неопределено - название корреспондента, как он будет отображаться
//                                                  в списке настроенных синхронизаций.
//    * НастройкиТранспорта - Произвольный
//                          - Неопределено - произвольное значение, описывающее параметры подключения.
//    * РасписаниеСинхронизации - РасписаниеРегламентногоЗадания
//                              - Неопределено - расписание запуска синхронизации.
//    * НастройкиXDTO - Структура
//                    - Неопределено - структура настроек XDTO корреспондента:
//      ** ПоддерживаемыеВерсии - Массив - перечень поддерживаемых корреспондентом версий формата.
//      ** ПоддерживаемыеОбъекты - см. ОбменДаннымиXDTOСервер.ПоддерживаемыеОбъектыФормата
//  Результат - Структура:
//    * УзелОбмена - ПланОбменаСсылка - узел плана обмена, соответствующий корреспонденту.
//    * ИдентификаторКорреспондента - Строка - уникальный идентификатор корреспондента.
//
Процедура ПриСохраненииНастроекПодключенияВнешнейСистемы(Контекст, ПараметрыПодключения, Результат) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ПриСохраненииНастроекПодключенияВнешнейСистемы(Контекст, ПараметрыПодключения, Результат) 
```
</details>

## ПриПолученииНастроекПодключенияВнешнейСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет структуру сохраненных параметров подключения к внешней системе.
//
// Параметры:
//  Контекст - Структура - контекст выполнения операции:
//    * Корреспондент - ПланОбменаСсылка - узел обмена, соответствующий корреспонденту.
//  ПараметрыПодключения - Структура - структура параметров подключения:
//    * ИдентификаторКорреспондента - Строка - строка длиной 36 символов, уникальный идентификатор корреспондента.
//    * НаименованиеКорреспондента - Строка - название корреспондента, как он отображается
//                                            в списке настроенных синхронизаций.
//    * НастройкиТранспорта - Произвольный - сохраненные настройки транспорта сообщений обмена внешней системы.
//    * РасписаниеСинхронизации - РасписаниеРегламентногоЗадания - расписание автоматического запуска обмена.
//    * НастройкиXDTO - Структура
//                    - Неопределено - структура настроек XDTO корреспондента:
//      ** ПоддерживаемыеВерсии - Массив - перечень поддерживаемых корреспондентом версий формата.
//      ** ПоддерживаемыеОбъекты - см. ОбменДаннымиXDTOСервер.ПоддерживаемыеОбъектыФормата.
//
Процедура ПриПолученииНастроекПодключенияВнешнейСистемы(Контекст, ПараметрыПодключения) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ПриПолученииНастроекПодключенияВнешнейСистемы(Контекст, ПараметрыПодключения) 
```
</details>

## ВсеНастройкиТранспортаОбменаСВнешнимиСистемами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Таблица настроек транспорта обмена для всех настроенных обменов данными с внешними системами.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//    * Корреспондент - ПланОбменаСсылка - узел обмена, соответствующий корреспонденту.
//    * НастройкиТранспорта - Произвольный - сохраненные настройки транспорта сообщений обмена внешней системы.
//
Функция ВсеНастройкиТранспортаОбменаСВнешнимиСистемами() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ВсеНастройкиТранспортаОбменаСВнешнимиСистемами() 
```
</details>

## ПриНачалеСохраненияНастроекСинхронизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Начинает сохранение настроек синхронизации данных в длительной операции.
// При сохранении настроек выполняется перенос на узел обмена переданных данных заполнения,
// и устанавливается признак, что настройка синхронизации завершена.
// Рекомендуется использовать в помощнике настройки синхронизации данных.
//
// Параметры:
//  НастройкиСинхронизации - Структура - структура параметров для сохранения настроек:
//   * УзелОбмена - ПланОбменаСсылка - узел плана обмена, для которого выполняется сохранение настроек синхронизации.
//   * ДанныеЗаполнения - Структура - произвольная структура для заполнения настроек на узле.
//                                    Будет передана в алгоритм "ПриСохраненииНастроекСинхронизацииДанных" (при его наличии).
//  ПараметрыОбработчика   - Структура - исходящий служебный параметр. Зарезервирован для внутреннего использования.
//                                       Применяется для отслеживания состояния длительной операции.
//                                       На вход следует передавать реквизит формы типа "Произвольный",
//                                       не используемый ни в каких других операциях.
//  ПродолжитьОжидание     - Булево    - исходящий параметр. Истина, если сохранение настройки запущено в длительной операции.
//                                       Для отслеживания состояния в этом случае следует использовать процедуру
//                                       ОбменДаннымиСервер.ПриОжиданииСохраненияНастроекСинхронизации.
//
Процедура ПриНачалеСохраненияНастроекСинхронизации(НастройкиСинхронизации, ПараметрыОбработчика, ПродолжитьОжидание = Истина) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ПриНачалеСохраненияНастроекСинхронизации(НастройкиСинхронизации, ПараметрыОбработчика, ПродолжитьОжидание);
```
</details>

## ПриОжиданииСохраненияНастроекСинхронизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется при ожидании завершения настройки синхронизации данных.
// Проверяет статус выполнения длительной операции по сохранению настройки, и возвращает признак
// необходимости продолжения ожидания, либо сообщает, что операция сохранения настройки завершена.
//
// Параметры:
//  ПараметрыОбработчика   - Структура - входящий/исходящий служебный параметр. Зарезервирован для внутреннего использования.
//                                       Применяется для отслеживания состояния длительной операции.
//                                       На вход следует передавать реквизит формы типа "Произвольный",
//                                       который был использован при запуске настройки синхронизации
//                                       вызовом метода ОбменДаннымиСервер.ПриНачалеСохраненияНастроекСинхронизации.
//  ПродолжитьОжидание     - Булево    - исходящий параметр. Истина, если необходимо продолжить ожидание завершения
//                                       операции сохранения настройки синхронизации, Ложь - если настройка
//                                       синхронизации завершена.
//
Процедура ПриОжиданииСохраненияНастроекСинхронизации(ПараметрыОбработчика, ПродолжитьОжидание) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ПриОжиданииСохраненияНастроекСинхронизации(ПараметрыОбработчика, ПродолжитьОжидание) 
```
</details>

## ПриЗавершенииСохраненияНастроекСинхронизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статус завершения операции настройки синхронизации. Вызывается, когда процедуры
// ОбменДаннымиСервер.ПриНачалеСохраненияНастроекСинхронизации или ОбменДаннымиСервер.ПриОжиданииСохраненияНастроекСинхронизации
// устанавливают флаг ПродолжитьОжидание в значение Ложь.
//
// Параметры:
//  ПараметрыОбработчика   - Структура - входящий служебный параметр. Зарезервирован для внутреннего использования.
//                                       Применяется для получения состояния длительной операции.
//                                       На вход следует передавать реквизит формы типа "Произвольный",
//                                       который был использован при запуске настройки синхронизации
//                                       вызовом метода ОбменДаннымиСервер.ПриНачалеСохраненияНастроекСинхронизации.
//  СтатусЗавершения       - Структура - исходящий параметр, возвращает состояние завершения длительной операции:
//   * Отказ             - Булево - Истина, если при запуске, или в ходе выполнения длительной операции произошла ошибка.
//   * СообщениеОбОшибке - Строка - текст ошибки, произошедшей при выполнении длительной операции, если Отказ = Истина.
//   * Результат         - Структура - состояние сохранения настройки синхронизации:
//    ** НастройкиСохранены - Булево - Истина, если настройка синхронизации успешно завершена.
//    ** СообщениеОбОшибке  - Строка - текст ошибки, возникшей непосредственно в транзакции сохранения настройки синхронизации.
//
Процедура ПриЗавершенииСохраненияНастроекСинхронизации(ПараметрыОбработчика, СтатусЗавершения) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ПриЗавершенииСохраненияНастроекСинхронизации(ПараметрыОбработчика, СтатусЗавершения) 
```
</details>

## ЗавершитьНастройкуСинхронизацииДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак завершения настройки синхронизации данных.
//
// Параметры:
//   УзелОбмена - ПланОбменаСсылка - узел обмена, для которого необходимо установить признак.
//
Процедура ЗавершитьНастройкуСинхронизацииДанных(УзелОбмена) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ЗавершитьНастройкуСинхронизацииДанных(УзелОбмена) 
```
</details>

## НастройкаСинхронизацииЗавершена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак завершения настройки синхронизации для узла обмена.
//
// Параметры:
//   УзелОбмена - ПланОбменаСсылка - узел обмена, для которого необходимо получить признак.
//
// Возвращаемое значение:
//   Булево - Истина, если настройка синхронизации для переданного узла завершена.
//
Функция НастройкаСинхронизацииЗавершена(УзелОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.НастройкаСинхронизацииЗавершена(УзелОбмена) 
```
</details>

## ЗавершитьСозданиеНачальногоОбраза
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак успешного создания начального образа узла РИБ.
//
// Параметры:
//   УзелОбмена - ПланОбменаСсылка - узел обмена, для которого необходимо установить признак.
//
Процедура ЗавершитьСозданиеНачальногоОбраза(УзелОбмена) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ЗавершитьСозданиеНачальногоОбраза(УзелОбмена) 
```
</details>

## ДополнитьНастройкиТранспортаКоличествомЭлементовВТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Выполняет добавление информации об установленном в константе количестве элементов в транзакции
// в структуру, содержащую параметры транспорта сообщений обмена.
//
// Параметры:
//  Результат - Структура - содержит параметры транспорта сообщений обмена.
//
Процедура ДополнитьНастройкиТранспортаКоличествомЭлементовВТранзакции(Результат) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ДополнитьНастройкиТранспортаКоличествомЭлементовВТранзакции(Результат) 
```
</details>

## НомерОбластиИзКодаУзлаПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Возвращает номер области по коду узла плана обмена (обмен сообщениями).
//
// Параметры:
//  КодУзла - Строка - код узла плана обмена.
//
// Возвращаемое значение:
//  Число - номер области.
//
Функция НомерОбластиИзКодаУзлаПланаОбмена(Знач КодУзла) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.НомерОбластиИзКодаУзлаПланаОбмена(КодУзла) 
```
</details>

## РезультатЗапросаВСтруктуру
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Возвращает данные первой записи результата запроса в виде структуры.
//
// Параметры:
//  РезультатЗапроса - РезультатЗапроса - результат запроса, содержащий данные для обработки.
//
// Возвращаемое значение:
//  Структура - структура с результатом.
//
Функция РезультатЗапросаВСтруктуру(Знач РезультатЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.РезультатЗапросаВСтруктуру(РезультатЗапроса) 
```
</details>

## ПереопределяемоеИмяУзлаПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать функцию ЗначениеНастройкиПланаОбмена,
// установив параметру ИмяПараметра одно из следующих значений:
//  - ЗаголовокКомандыДляСозданияНовогоОбменаДанными;
//  - ЗаголовокПомощникаСозданияОбмена;
//  - ЗаголовокУзлаПланаОбмена;
//  - НаименованиеКонфигурацииКорреспондента.
//
// Возвращает, если оно задано, переопределяемое имя плана обмена,
// в зависимости от предопределенной настройки обмена.
// Параметры:
//   УзелПланаОбмена         - ПланОбменаСсылка - узел плана обмена, для которого необходимо получить переопределяемое
//                                                имя.
//   ИмяПараметраСИменемУзла - Строка - имя параметра, в настройках по умолчанию, из которого необходимо получить имя узла.
//   ВариантНастройки        - Строка - вариант настройки обмена.
//
// Возвращаемое значение:
//  Строка - переопределяемое имя плана обмена как оно заданно в конфигураторе.
//
Функция ПереопределяемоеИмяУзлаПланаОбмена(Знач УзелПланаОбмена, ИмяПараметраСИменемУзла, ВариантНастройки = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ПереопределяемоеИмяУзлаПланаОбмена(УзелПланаОбмена, ИмяПараметраСИменемУзла, ВариантНастройки);
```
</details>

## КоличествоНерассмотренныхПроблем
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Возвращает количество нерассмотренных проблем обмена данными. Используется для отображения
// количества проблем обмена в пользовательском интерфейсе. Например, для использования в заголовке
// гиперссылки для перехода к монитору проблем обмена.
//
// Параметры:
//   Узлы - Массив из ПланОбменаСсылка - узлы обмена.
//
// Возвращаемое значение:
//   Число - количество нерассмотренных проблем обмена данными.
//
Функция КоличествоНерассмотренныхПроблем(Узлы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.КоличествоНерассмотренныхПроблем(Узлы);
```
</details>

## СтруктураЗаголовкаГиперссылкиМонитораПроблем
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Возвращает структуру заголовка гиперссылки для перехода к монитору проблем обмена данными.
//
// Параметры:
//   Узлы - Массив из ПланОбменаСсылка - узлы обмена.
//
// Возвращаемое значение:
//   Структура:
//     * Заголовок - Строка   - заголовок гиперссылки.
//     * Картинка  - Картинка - картинка для гиперссылки.
//
Функция СтруктураЗаголовкаГиперссылкиМонитораПроблем(Узлы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.СтруктураЗаголовкаГиперссылкиМонитораПроблем(Узлы);
```
</details>

## ВыполнитьДействиеОбменаДляУзлаИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.Выполняет отправку или получение данных для узла информационной базы используя любой из
// доступных для плана обмена канал связи, кроме COM-соединения и web-сервиса.
//
// Параметры:
//  Отказ                        - Булево - флаг отказа, устанавливается в Истина в случае
//                                 не успешного выполнения процедуры.
//  УзелИнформационнойБазы       - УзелОбменаСсылка - ПланОбменаСсылка - узел плана обмена,
//                                 для которого выполняется действие обмена данными.
//  ДействиеПриОбмене            - ПеречислениеСсылка.ДействияПриОбмене - выполняемое действие обмена данными.
//  ВидТранспортаСообщенийОбмена - ПеречислениеСсылка.Перечисления.ВидыТранспортаСообщенийОбмена - вид транспорта,
//                                 который будет использоваться в процессе обмена данными. Если не указан,
//                                 определяется из параметров транспорта, заданных для узла плана обмена при
//                                 настройке обмена. Необязательный, значение по умолчанию Неопределено.
//  ТолькоПараметры              - Булево - содержит признак выборочной загрузки данных при обмене РИБ.
//  ДополнительныеПараметры      - Структура - зарезервировано для служебного использования.
//
Процедура ВыполнитьДействиеОбменаДляУзлаИнформационнойБазы( Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ВыполнитьДействиеОбменаДляУзлаИнформационнойБазы();
```
</details>

## FTPКаталогСуществует
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Определяет, существует ли каталог на FTP-сервере.
//
// Параметры:
//  Путь - Строка - путь к каталогу.
//  ИмяКаталога - Строка - имя каталога.
//  FTPСоединение - FTPСоединение - FTPСоединение, используемое для подключения к FTP-серверу.
//
// Возвращаемое значение:
//  Булево - если Истина, то каталог существует; Ложь - нет.
//
Функция FTPКаталогСуществует(Знач Путь, Знач ИмяКаталога, Знач FTPСоединение) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.FTPКаталогСуществует(Путь, ИмяКаталога, FTPСоединение) 
```
</details>

## ВсеТранспортыСообщенийОбменаКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Возвращает массив всех видов транспорта сообщений обмена, определенных в конфигурации.
//
// Возвращаемое значение:
//   Массив из ПеречислениеСсылка.ВидыТранспортаСообщенийОбмена - все виды транспорта сообщений обмена.
//
Функция ВсеТранспортыСообщенийОбменаКонфигурации() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиСервер.ВсеТранспортыСообщенийОбменаКонфигурации() 
```
</details>

## ВыполнитьДействиеОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку или получение данных для узла информационной базы используя любой из
// доступных для плана обмена канал связи, кроме COM-соединения и web-сервиса.
//
// Параметры:
//  Отказ                        - Булево - флаг отказа, устанавливается в Истина в случае
//                                 не успешного выполнения процедуры.
//  УзелИнформационнойБазы       - УзелОбменаСсылка - ПланОбменаСсылка - узел плана обмена,
//                                 для которого выполняется действие обмена данными.
//  ДействиеПриОбмене            - ПеречислениеСсылка.ДействияПриОбмене - выполняемое действие обмена данными.
//  ИдентификаторТранспорта      - Строка, Неопределено - тип транспорта, который будет использоваться в процессе обмена
//                                                        данными.
//  ДополнительныеПараметры      - Структура - зарезервировано для служебного использования.
//
Процедура ВыполнитьДействиеОбмена( Экспорт
```

Пример вызова
```bsl
ОбменДаннымиСервер.ВыполнитьДействиеОбмена();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
