---
title: Обмен сообщениями переопределяемый
slug: bsp/обмен-сообщениями-переопределяемый
---


## ПолучитьОбработчикиКаналовСообщений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает список обработчиков сообщений, которые обрабатывает данная информационная система.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//  Обработчики - ТаблицаЗначений - с колонками:
//    * Канал - Строка - Канал сообщения.
//    * Обработчик - ОбщийМодуль - Обработчик сообщения.
//
Процедура ПолучитьОбработчикиКаналовСообщений(Обработчики) Экспорт
```

Пример вызова
```bsl
ОбменСообщениямиПереопределяемый.ПолучитьОбработчикиКаналовСообщений(Обработчики) 
```
</details>

## ПолучателиСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик получения динамического списка конечных точек сообщений.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//  КаналСообщений - Строка - Идентификатор канала сообщений, для которого необходимо определить
//   конечные точки.
//  Получатели - Массив - Массив конечных точек, в которые следует адресовать сообщение,
//                            должен быть заполнен элементами типа ПланОбменаСсылка.ОбменСообщениями.
//                            Этот параметр необходимо определить в теле обработчика.
//
Процедура ПолучателиСообщения(Знач КаналСообщений, Получатели) Экспорт
```

Пример вызова
```bsl
ОбменСообщениямиПереопределяемый.ПолучателиСообщения(КаналСообщений, Получатели) 
```
</details>

## ПриОтправкеСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Обработчики событий отправки и получения сообщений.

// Обработчик события при отправке сообщения.
// Обработчик данного события вызывается перед помещением сообщения в XML-поток.
// Обработчик вызывается для каждого отправляемого сообщения.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//  КаналСообщений - Строка - Идентификатор канала сообщений, в который отправляется сообщение.
//  ТелоСообщения - Произвольный - Тело отправляемого сообщения. В обработчике события тело сообщения
//                                может быть изменено, например, дополнено информацией.
//
Процедура ПриОтправкеСообщения(КаналСообщений, ТелоСообщения) Экспорт
```

Пример вызова
```bsl
ОбменСообщениямиПереопределяемый.ПриОтправкеСообщения(КаналСообщений, ТелоСообщения) 
```
</details>

## ПриПолученииСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события при получении сообщения.
// Обработчик данного события вызывается при получении сообщения из XML-потока.
// Обработчик вызывается для каждого получаемого сообщения.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//  КаналСообщений - Строка - Идентификатор канала сообщений, из которого получено сообщение.
//  ТелоСообщения - Произвольный - Тело полученного сообщения. В обработчике события тело сообщения
//                                 может быть изменено, например, дополнено информацией.
//
Процедура ПриПолученииСообщения(КаналСообщений, ТелоСообщения) Экспорт
```

Пример вызова
```bsl
ОбменСообщениямиПереопределяемый.ПриПолученииСообщения(КаналСообщений, ТелоСообщения) 
```
</details>

## ПриИсчерпанииПопытокОбработкиСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ОбменСообщениямиВнутренний.ПриИсчерпанииПопытокОбработкиСообщения
// @skip-check module-empty-method - особенность реализации.
Процедура ПриИсчерпанииПопытокОбработкиСообщения(КаналСообщений, ТелоСообщения, Отправитель, ПодробноеПредставлениеОшибки) Экспорт
```

Пример вызова
```bsl
ОбменСообщениямиПереопределяемый.ПриИсчерпанииПопытокОбработкиСообщения(КаналСообщений, ТелоСообщения, Отправитель, ПодробноеПредставлениеОшибки) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
