---
title: Организации переопределяемый
slug: bsp/организации-переопределяемый
---


## ПриОпределенииРегистрационныхДанныхОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационной информации организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные - см. ОрганизацииСервер.РегистрационныеДанныеОрганизации
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
// Пример:
//       СведенияОбОрганизации = ОрганизацииСервер.СведенияОбОрганизации(Организация);
//
//	СвойстваОрганизации = СтрРазделить(Поля, ",", Ложь);
//
//	Запрос = Новый Запрос;
//	Запрос.УстановитьПараметр("Ссылка", Организация);
//	Запрос.Текст =
//		"ВЫБРАТЬ
//		|	Организации.Ссылка КАК Ссылка,
//		|	Организации.ВерсияДанных КАК ВерсияДанных,
//		|	Организации.ПометкаУдаления КАК ПометкаУдаления,
//		|	Организации.Код КАК Код,
//		|	Организации.Наименование КАК Наименование,
//		|	Организации.БИК КАК БИК,
//		|	Организации.ГлавныйБухгалтер КАК ГлавныйБухгалтер,
//		|	Организации.Директор КАК Директор,
//		|	Организации.ИндивидуальныйПредприниматель КАК ИндивидуальныйПредприниматель,
//		|	Организации.ИНН КАК ИНН,
//		|	Организации.ИнформационноеОбслуживание КАК ИнформационноеОбслуживание,
//		|	Организации.КорреспондентскийСчет КАК КорреспондентскийСчет,
//		|	Организации.КПП КАК КПП,
//		|	Организации.НаименованиеПолное КАК НаименованиеПолное,
//		|	Организации.НаименованиеСокращенное КАК НаименованиеСокращенное,
//		|	Организации.ОГРН КАК ОГРН,
//		|	Организации.Префикс КАК Префикс,
//		|	Организации.РасчетныйСчет КАК РасчетныйСчет,
//		|	Организации.ГоловнаяОрганизация КАК ГоловнаяОрганизация,
//		|	Организации.ПроизводственныйКалендарь КАК ПроизводственныйКалендарь,
//		|	Организации.Предопределенный КАК Предопределенный,
//		|	Организации.ИмяПредопределенныхДанных КАК ИмяПредопределенныхДанных,
//		|	Организации.ВАрхиве КАК ВАрхиве
//		|ИЗ
//		|	Справочник.Организации КАК Организации
//		|ГДЕ
//		|	Организации.Ссылка = &Ссылка";
//
//	РезультатЗапроса = Запрос.Выполнить();
//	ВыборкаДетальныеЗаписи = РезультатЗапроса.Выбрать();
//	Если ВыборкаДетальныеЗаписи.Следующий() Тогда
//		Для каждого Элемент Из СвойстваОрганизации Цикл
//			Если РезультатЗапроса.Колонки.Найти(Элемент) <> Неопределено Тогда
//				РегистрационныеДанные.Вставить(Элемент, ВыборкаДетальныеЗаписи[Элемент]);
//			КонецЕсли;
//		КонецЦикла;
//	КонецЕсли;
//
Процедура ПриОпределенииРегистрационныхДанныхОрганизации(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхОрганизации(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииДополнительныхСведенийОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую сведения о дополнительной информации организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  ДополнительныеСведения - см. ОрганизацииСервер.ДополнительныеСведенияОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииДополнительныхСведенийОрганизации(Организация, Поля, Дата, ДополнительныеСведения, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииДополнительныхСведенийОрганизации(Организация, Поля, Дата, ДополнительныеСведения, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииОрганизации(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииОрганизации(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

## ПриОпределенииБанковскогоСчетаОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о банковской информации организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  БанковскийСчет - см. ОрганизацииСервер.БанковскийСчетОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииБанковскогоСчетаОрганизации(Организация, Поля, Дата, БанковскийСчет, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииБанковскогоСчетаОрганизации(Организация, Поля, Дата, БанковскийСчет, КодЯзыка) 
```
</details>

## ПриОпределенииРегистрационныхДанныхОбособленногоПодразделения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационных данных обособленного подразделения.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные - см. ОрганизацииСервер.РегистрационныеДанныеОбособленногоПодразделения.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииРегистрационныхДанныхОбособленногоПодразделения(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхОбособленногоПодразделения(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииОбособленногоПодразделения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации обособленного подразделения.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияОбособленногоПодразделения.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииОбособленногоПодразделения(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииОбособленногоПодразделения(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

## ПриОпределенииРегистрационныхДанныхОтделенияИностраннойОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационной информации иностранной организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные -  см. ОрганизацииСервер.РегистрационныеДанныеОтделенияИностраннойОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииРегистрационныхДанныхОтделенияИностраннойОрганизации(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхОтделенияИностраннойОрганизации(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииИностраннойОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации иностранной организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияОтделенияИностраннойОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииИностраннойОрганизации(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииИностраннойОрганизации(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

## ПриОпределенииРегистрационныхДанныхИндивидуальногоПредпринимателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационной информации индивидуального предпринимателя.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные - см. ОрганизацииСервер.РегистрационныеДанныеИндивидуальногоПредпринимателя.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииРегистрационныхДанныхИндивидуальногоПредпринимателя(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхИндивидуальногоПредпринимателя(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииИндивидуальногоПредпринимателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации индивидуального предпринимателя.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияИндивидуальногоПредпринимателя.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииИндивидуальногоПредпринимателя(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииИндивидуальногоПредпринимателя(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

## ПриОпределенииРегистрационныхДанныхРуководителяОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационной информации руководителя организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные - см. ОрганизацииСервер.РегистрационныеДанныеРуководителяОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииРегистрационныхДанныхРуководителяОрганизации(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхРуководителяОрганизации(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииРуководителяОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации руководителя организации.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияРуководителяОрганизации.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииРуководителяОрганизации(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииРуководителяОрганизации(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

## ПриОпределенииРегистрационныхДанныхГлавногоБухгалтера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационной информации главного бухгалтера.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные - см. ОрганизацииСервер.РегистрационныеДанныеГлавногоБухгалтера.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииРегистрационныхДанныхГлавногоБухгалтера(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхГлавногоБухгалтера(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииГлавногоБухгалтера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации главного бухгалтера.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияГлавногоБухгалтера.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииГлавногоБухгалтера(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииГлавногоБухгалтера(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

## ПриОпределенииРегистрационныхДанныхУполномоченногоПредставителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о регистрационных данных уполномоченного представителя.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  РегистрационныеДанные - см. ОрганизацииСервер.РегистрационныеДанныеУполномоченногоПредставителя.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииРегистрационныхДанныхУполномоченногоПредставителя(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииРегистрационныхДанныхУполномоченногоПредставителя(Организация, Поля, Дата, РегистрационныеДанные, КодЯзыка) 
```
</details>

## ПриОпределенииКонтактнойИнформацииУполномоченногоПредставителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет структуру, содержащую сведения о контактной информации уполномоченного представителя.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, сведения по которой необходимо получить.
//  Поля - Строка - имена полей, перечисленные через запятую, в формате требований к свойствам структуры.
//                  Список допустимых имен полей см. в описании возвращаемого значения.
//                  Если указана пустая строка, то возвращаются значения всех полей.
//  Дата - Дата
//       - Неопределено - дата, на которую требуется получить данные. Если значение не указано,
//                  то возвращается значение на текущую дату.
//  КонтактнаяИнформация - см. ОрганизацииСервер.КонтактнаяИнформацияУполномоченногоПредставителя.
//  КодЯзыка - см. ОрганизацииСервер.СведенияОбОрганизации.КодЯзыка
//
Процедура ПриОпределенииКонтактнойИнформацииУполномоченногоПредставителя(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) Экспорт
```

Пример вызова
```bsl
ОрганизацииПереопределяемый.ПриОпределенииКонтактнойИнформацииУполномоченногоПредставителя(Организация, Поля, Дата, КонтактнаяИнформация, КодЯзыка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
