---
title: Отправка sms переопределяемый
slug: bsp/отправка-sms-переопределяемый
---


## ОтправитьSMS
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет SMS через настроенного поставщика услуги.
//
// Параметры:
//  ПараметрыОтправки - Структура:
//   * Провайдер          - ПеречислениеСсылка.ПровайдерыSMS - поставщик услуги по отправке SMS.
//   * НомераПолучателей  - Массив - массив строк номеров получателей в формате +7ХХХХХХХХХХ;
//   * Текст              - Строка - текст сообщения, максимальная длина у операторов может быть разной;
//   * ИмяОтправителя     - Строка - имя отправителя, которое будет отображаться вместо номера у получателей;
//   * Логин              - Строка - логин для доступа к услуге отправки SMS;
//   * Пароль             - Строка - пароль для доступа к услуге отправки SMS.
//
//  Результат - Структура - возвращаемое значение. Результат отправки:
//    * ОтправленныеСообщения - Массив из Структура:
//     ** НомерПолучателя - Строка - номер получателя из массива НомераПолучателей;
//     ** ИдентификаторСообщения - Строка - идентификатор SMS, по которому можно запросить статус отправки.
//    ОписаниеОшибки - Строка - пользовательское представление ошибки, если пустая строка, то ошибки нет.
//
Процедура ОтправитьSMS(ПараметрыОтправки, Результат) Экспорт
```

Пример вызова
```bsl
ОтправкаSMSПереопределяемый.ОтправитьSMS(ПараметрыОтправки, Результат) 
```
</details>

## СтатусДоставки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запрашивает статус доставки SMS у поставщика услуг.
//
// Параметры:
//  ИдентификаторСообщения - Строка - идентификатор, присвоенный SMS при отправке.
//  Провайдер - ПеречислениеСсылка.ПровайдерыSMS - провайдер услуги отправки SMS.
//  Логин              - Строка - логин для доступа к услуге отправки SMS.
//  Пароль             - Строка - пароль для доступа к услуге отправки SMS.
//  Результат          - см. ОтправкаSMS.СтатусДоставки.
//
Процедура СтатусДоставки(ИдентификаторСообщения, Провайдер, Логин, Пароль, Результат) Экспорт
```

Пример вызова
```bsl
ОтправкаSMSПереопределяемый.СтатусДоставки(ИдентификаторСообщения, Провайдер, Логин, Пароль, Результат) 
```
</details>

## ПриПроверкеНастроекОтправкиSMS
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет правильность сохраненных настроек отправки SMS.
//
// Параметры:
//  НастройкиОтправкиSMS - Структура - описание текущих настроек отправки SMS:
//   * Провайдер - ПеречислениеСсылка.ПровайдерыSMS
//   * Логин - Строка
//   * Пароль - Строка
//   * ИмяОтправителя - Строка
//  Отказ - Булево - установить этот параметр в Истина, если настройки не заполнены или заполнены неверно.
//
Процедура ПриПроверкеНастроекОтправкиSMS(НастройкиОтправкиSMS, Отказ) Экспорт
```

Пример вызова
```bsl
ОтправкаSMSПереопределяемый.ПриПроверкеНастроекОтправкиSMS(НастройкиОтправкиSMS, Отказ) 
```
</details>

## ПриПолученииРазрешений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет список разрешений для отправки SMS.
//
// Параметры:
//  Разрешения - Массив - массив объектов, возвращаемых одной из функций РаботаВБезопасномРежиме.Разрешение*().
//
Процедура ПриПолученииРазрешений(Разрешения) Экспорт
```

Пример вызова
```bsl
ОтправкаSMSПереопределяемый.ПриПолученииРазрешений(Разрешения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
