---
title: Отчеты клиент сервер
slug: bsp/отчеты-клиент-сервер
---


## НастройкиОтчетаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнительные настройки отчета по умолчанию, определяющие:
//  * Признак формирования отчета при открытии;
//  * Подключаемые обработчики событий;
//  * Настройки печати;
//  * Использование функции расчетных показателей;
//  * Права.
//
// Возвращаемое значение:
//   Структура - настройки (дополнительные свойства) отчета, хранящиеся в данных формы:
//
//       * ФормироватьСразу - Булево - значение по умолчанию для флажка "Формировать сразу".
//           Когда флажок включен, то отчет будет формироваться после открытия,
//           после выбора пользовательских настроек, после выбора другого варианта отчета.
//
//       * ВыводитьСуммуВыделенныхЯчеек - Булево - если Истина, то в отчете будет выводиться поле автосуммы.
//
//       * РазрешеноИзменятьСтруктуру - Булево - если Ложь, то в настройках отчета будет скрыта вкладка "Структура".
//           Если Истина, то вкладка "Структура" показывается для отчетов на СКД: в расширенном режиме,
//           а также в простом режиме, если в пользовательские настройки выведены флажки использования группировок.
//
//       * РазрешеноИзменятьВарианты - Булево - если Ложь, то блокируются кнопки изменения вариантов этого отчета.
//           Если у текущего пользователя нет прав "СохранениеДанныхПользователя" и "Добавление"
//           справочника ВариантыОтчетов, то принудительно устанавливается в Ложь.
//
//       * РазрешеноВыбиратьИНастраиватьВариантыБезСохранения - Булево - если Истина,
//           то есть возможность выбора и настройки предопределенных вариантов отчета, но без возможности сохранения
//           выполненных настроек. Например, может быть задано для контекстных отчетов (открываемых с параметрами),
//           у которых есть несколько вариантов.
//
//       * ПараметрыРасположенияЭлементовУправления - Структура
//                                                  - Неопределено - варианты:
//           - Неопределено - параметры элементов управления общей формы отчетов "по умолчанию".
//           - Структура - с именами настройки в коллекции НастройкиКомпоновкиДанных свойства Настройки
//                         типа КомпоновщикНастроекКомпоновкиДанных:
//               ** Отбор           - Массив - как у следующего свойства.
//               ** ПараметрыДанных - Структура - со свойствами поля формы:
//                    *** Поле                     - Строка - имя поля, отображение которого настраивается.
//                    *** РастягиватьПоГоризонтали - Булево - значение свойства поля формы.
//                    *** АвтоМаксимальнаяШирина   - Булево - значение свойства поля формы.
//                    *** Ширина                   - Число  - значение свойства поля формы.
//
//            Пример определения описываемого параметра:
//
//               МассивНастроек              = Новый Массив;
//               НастройкиЭлементаУправления = Новый Структура;
//               НастройкиЭлементаУправления.Вставить("Поле",                     "СписокРегистров");
//               НастройкиЭлементаУправления.Вставить("РастягиватьПоГоризонтали", Ложь);
//               НастройкиЭлементаУправления.Вставить("АвтоМаксимальнаяШирина",   Истина);
//               НастройкиЭлементаУправления.Вставить("Ширина",                   40);
//
//               МассивНастроек.Добавить(НастройкиЭлементаУправления);
//
//               НастройкиЭлементовУправления = Новый Структура();
//               НастройкиЭлементовУправления.Вставить("ПараметрыДанных", МассивНастроек);
//
//               Возврат НастройкиЭлементовУправления;
//
//       * ЗагрузитьНастройкиПриИзмененииПараметров - Массив - коллекция параметров компоновки данных,
//                                                    изменение которых, приводит к переформированию
//                                                    Схемы компоновки данных.
//
//               // Пример:
//               // 1. Инициализация:
//               //	Процедура ОпределитьНастройкиФормы(Форма, КлючВарианта, Настройки) Экспорт
//               //		Настройки.ЗагрузитьНастройкиПриИзмененииПараметров = Отчеты.УниверсальныйОтчет.ЗагрузитьНастройкиПриИзмененииПараметров();
//               //	КонецПроцедуры
//
//               //	Функция ЗагрузитьНастройкиПриИзмененииПараметров() Экспорт
//               //		Параметры = Новый Массив;
//               //		Параметры.Добавить(Новый ПараметрКомпоновкиДанных("ТипОбъектаМетаданных"));
//               //		Параметры.Добавить(Новый ПараметрКомпоновкиДанных("ИмяОбъектаМетаданных"));
//               //		Параметры.Добавить(Новый ПараметрКомпоновкиДанных("ИмяТаблицы"));
//               //
//               //		Возврат Параметры;
//               //	КонецФункции
//
//               // 2. Использование:
//               //	Процедура Подключаемый_ЭлементНастройки_ПриИзменении(Элемент)
//               //		...
//               //		Если ТипЗнч(ЭлементПользовательскойНастройки) = Тип("ЗначениеПараметраНастроекКомпоновкиДанных")
//               //			И НастройкиОтчета.ЗагрузитьНастройкиПриИзмененииПараметров.Найти(ЭлементПользовательскойНастройки.Параметр) <> Неопределено Тогда
//               //			// Вызов метода переформирования Схемы компоновки данных...
//               //		КонецЕсли;
//
//       * ПоляПоиска - Массив из Строка - коллекция имен полей компоновки данных, которые участвуют в универсальном поиске.
//       * ВариантПредставленияПериода - ПеречислениеСсылка.ВариантыПредставленияПериода - определяет вариант
//           представления периода на форме отчета.
//       * ВариантПериода - ПеречислениеСсылка.ВариантыПериода - определяет вариант формы выбора периода.
//       * ОтключитьСтандартноеКонтекстноеМеню - Булево - признак, позволяющий выключить использование
//           контекстного меню и настройки колонки отчета.
//       * СкрытьКомандыРассылки - Булево - флаг, позволяющий скрыть команды рассылок, у тех отчетов,
//           для которых рассылка не имеет смысла.
//       * Печать - Структура - параметры печати табличного документа "по умолчанию":
//           ** ПолеСверху - Число - отступ сверху при печати (в миллиметрах).
//           ** ПолеСлева  - Число - отступ слева  при печати (в миллиметрах).
//           ** ПолеСнизу  - Число - отступ снизу  при печати (в миллиметрах).
//           ** ПолеСправа - Число - отступ справа при печати (в миллиметрах).
//           ** ОриентацияСтраницы - ориентацияСтраницы - "Портрет" или "Ландшафт".
//           ** АвтоМасштаб - Булево - автоматически подгонять масштаб под размер страницы.
//           ** МасштабПечати - Число - масштаб изображения (в процентах).
//       * События - Структура - события, для которых определены обработчики в модуле объекта отчета:
//           ** ПриСозданииНаСервере - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // См. ОтчетыПереопределяемый.ПриСозданииНаСервере.
//               Процедура ПриСозданииНаСервере(Форма, Отказ, СтандартнаяОбработка) Экспорт
//
//               КонецПроцедуры
//
//           ** ПередЗагрузкойНастроекВКомпоновщик - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   Контекст - Произвольный
//               //   КлючСхемы - Строка
//               //   КлючВарианта - Строка, Неопределено
//               //   НовыеНастройкиКД - НастройкиКомпоновкиДанных, Неопределено
//               //   НовыеПользовательскиеНастройкиКД - ПользовательскиеНастройкиКомпоновкиДанных, Неопределено
//               //
//               Процедура ПередЗагрузкойНастроекВКомпоновщик(Контекст, КлючСхемы, КлючВарианта, НовыеНастройкиКД,
//               НовыеПользовательскиеНастройкиКД) Экспорт
//
//               КонецПроцедуры
//
//           ** ПослеЗагрузкиНастроекВКомпоновщик - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               //  Параметры:
//               //    ДополнительныеПараметры - Структура
//               //
//               Процедура ПослеЗагрузкиНастроекВКомпоновщик(ДополнительныеПараметры) Экспорт
//
//               КонецПроцедуры
//
//           ** ПередЗагрузкойВариантаНаСервере - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // См. ОтчетыПереопределяемый.ПередЗагрузкойВариантаНаСервере.
//               Процедура ПередЗагрузкойВариантаНаСервере(Форма, НовыеНастройкиКД) Экспорт
//
//               КонецПроцедуры
//
//           ** ПриЗагрузкеВариантаНаСервере - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   Форма - ФормаКлиентскогоПриложения
//               //         - РасширениеУправляемойФормыДляОтчета:
//               //            * Отчет - ДанныеФормыСтруктура
//               //                    - ОтчетОбъект
//               //   НовыеНастройкиКД - НастройкиКомпоновкиДанных
//               //
//               Процедура ПриЗагрузкеВариантаНаСервере(Форма, НовыеНастройкиКД) Экспорт
//
//               КонецПроцедуры
//
//           ** ПриЗагрузкеПользовательскихНастроекНаСервере - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   Форма - ФормаКлиентскогоПриложения
//               //   НовыеПользовательскиеНастройкиКД - ПользовательскиеНастройкиКомпоновкиДанных
//               //
//               Процедура ПриЗагрузкеПользовательскихНастроекНаСервере(Форма, НовыеПользовательскиеНастройкиКД) Экспорт
//
//               КонецПроцедуры
//
//           ** ПередЗаполнениемПанелиБыстрыхНастроек - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   Форма - ФормаКлиентскогоПриложения
//               //   ПараметрыЗаполнения - Структура
//               //
//               Процедура ПередЗаполнениемПанелиБыстрыхНастроек(Форма, ПараметрыЗаполнения) Экспорт
//
//               КонецПроцедуры
//
//           ** ПослеЗаполненияПанелиБыстрыхНастроек - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   Форма - ФормаКлиентскогоПриложения
//               //   ПараметрыЗаполнения - Структура
//               //
//               Процедура ПослеЗаполненияПанелиБыстрыхНастроек(Форма, ПараметрыЗаполнения) Экспорт
//
//               КонецПроцедуры
//
//           ** ПриОпределенииПараметровВыбора - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // См. ОтчетыПереопределяемый.ПриОпределенииПараметровВыбора.
//               Процедура ПриОпределенииПараметровВыбора(Форма, СвойстваНастройки) Экспорт
//
//               КонецПроцедуры
//
//           ** ПриОпределенииИспользуемыхТаблиц - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   КлючВарианта - Строка, Неопределено
//               //   ИспользуемыеТаблицы - Массив из Строка
//               //
//               Процедура ПриОпределенииИспользуемыхТаблиц(КлючВарианта, ИспользуемыеТаблицы) Экспорт
//
//               КонецПроцедуры
//
//           ** ПриОпределенииОсновныхПолей - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // См. ОтчетыПереопределяемый.ПриОпределенииОсновныхПолей.
//               Процедура ПриОпределенииОсновныхПолей(Форма, ОсновныеПоля) Экспорт
//
//               КонецПроцедуры
//
//           ** ПередФормированиемОтчета - Булево - если Истина, то в модуле объекта отчета
//               следует определить обработчик события по шаблону:
//
//               // Параметры:
//               //   ФормаОтчета - ФормаКлиентскогоПриложения
//               //   ДополнительныеПараметры - Структура:
//               //     * ТекстПредупреждения - Строка
//               //     * ИмяПараметраХраненияОтказаОтПредупреждения - Строка
//               //
//               Процедура Процедура ПередФормированиемОтчета(ФормаОтчета, ДополнительныеПараметры) Экспорт
//
//               КонецПроцедуры
//
Функция НастройкиОтчетаПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыКлиентСервер.НастройкиОтчетаПоУмолчанию() 
```
</details>

## ПолучитьНастройкиОтчетаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ОтчетыКлиентСервер.НастройкиОтчетаПоУмолчанию.
// Настройки формы отчета по умолчанию.
//
// Возвращаемое значение:
//   Структура:
//
Функция ПолучитьНастройкиОтчетаПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыКлиентСервер.ПолучитьНастройкиОтчетаПоУмолчанию() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
