---
title: Отчеты сервер
slug: bsp/отчеты-сервер
---


## ПодключитьСхему
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает отчету переданную схему и на основании нее, инициализирует компоновщик настроек.
// Если контекстом является форма отчета (настроек), то обновляет основной реквизит формы - Отчет.
// В результате, контекст объекта и формы отчета синхронизируются.
// Вызывается например, из обработчика ПередЗагрузкойНастроекВКомпоновщик объекта универсального отчета
// для установки схемы, программно сформированной на основании другого объекта метаданных.
//
// Параметры:
//  Отчет - ОтчетОбъект
//        - ВнешнийОтчет - СКД-отчет, которому необходимо установить схему.
//  Контекст - ФормаКлиентскогоПриложения - форма отчета или форма настройки отчета.
//             Передается "как есть" из одноименного параметра события ПередЗагрузкойНастроекВКомпоновщик.
//           - Структура:
//               * СсылкаОтчета - Произвольный     - ссылка отчета.
//               * ПолноеИмя - Строка           - полное имя отчета.
//               * Метаданные - ОбъектМетаданных - метаданные отчета.
//               * Объект - ОтчетОбъект
//                        - ВнешнийОтчет - объект отчета:
//                            ** КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета.
//                            ** СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема отчета.
//               * КлючВарианта - Строка - имя предопределенного или идентификатор пользовательского варианта отчета.
//               * АдресСхемы - Строка - адрес временного хранилища, по которому размещена схема отчета.
//               * Успех - Булево - Истина, если удалось подключить отчет.
//               * ТекстОшибки - Строка - текст ошибки.
//
//
//  Схема - СхемаКомпоновкиДанных - схема, которую необходимо установить отчету.
//  КлючСхемы - Строка - идентификатор новой схемы, который будет записан в дополнительные свойства
//                       пользовательских настроек.
//
// Пример:
//  // В обработчике объекта отчета ПередЗагрузкойНастроекВКомпоновщик компоновщик настроек
//  // инициализируется на основании схемы из общих макетов:
//  Если КлючСхемы <> "1" Тогда
//  	  КлючСхемы = "1";
//  	  Схема = ПолучитьОбщийМакет("МояОбщаяСхемаКомпоновки");
//  	  ОтчетыСервер.ПодключитьСхему(ЭтотОбъект, Контекст, Схема, КлючСхемы);
//  КонецЕсли;
//
Процедура ПодключитьСхему(Отчет, Контекст, Схема, КлючСхемы) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ПодключитьСхему(Отчет, Контекст, Схема, КлючСхемы) 
```
</details>

## ИнициализироватьКомпоновщикНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует компоновщик настроек компоновки данных, с обработкой исключения.
//
// Параметры:
//  КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - компоновщик настроек, который необходимо инициализировать.
//  Схема - СхемаКомпоновкиДанных
//        - Строка.
//  Отчет - ОтчетОбъект
//        - Неопределено - отчет, чей компоновщик инициализируется.
//  ВариантОтчета - СправочникСсылка.ВариантыОтчетов
//                - Неопределено - хранилище варианта отчета.
//
Процедура ИнициализироватьКомпоновщикНастроек(КомпоновщикНастроек, Схема, Отчет = Неопределено, ВариантОтчета = Неопределено) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ИнициализироватьКомпоновщикНастроек(КомпоновщикНастроек, Схема, Отчет, ВариантОтчета);
```
</details>

## ВывестиКоманду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит команду в форму отчета в виде кнопки в указанную группу.
// Также регистрирует команду, защищая ее от удаления при перерисовке формы.
// Для вызова из события ПриСозданииНаСервере формы отчета.
//
// Параметры:
//   ФормаОтчета - ФормаКлиентскогоПриложения
//               - РасширениеУправляемойФормыДляОтчета - форма, где:
//     * ПостоянныеРеквизиты - СписокЗначений
//     * ПостоянныеКоманды - СписокЗначений
//   КомандаИлиКоманды - КомандаФормы     - команда, с которой будут связаны выводимые кнопки.
//                       Если в свойстве Действие указана пустая строка,
//                       то при выполнении команды будет вызвана процедура ОтчетыКлиентПереопределяемый.ОбработчикКоманды.
//                       Если в свойстве Действие указана строка вида "<ИмяКлиентскогоОбщегоМодуля>.<ИмяЭкспортнойПроцедуры>",
//                       то при выполнении команды в указанном модуле будет вызвана указанная процедура с двумя параметрами,
//                       аналогичным двум первым параметрам процедуры ОтчетыКлиентПереопределяемый.ОбработчикКоманды.
//                     - Массив - набор команд (КомандаФормы), которые будут выведены в указанную группу.
//   ТипГруппы - Строка - условное имя группы, в которой требуется вывести кнопку.
//               "Главное"          - группа с кнопками "Сформировать" и "Формировать сразу".
//               "Настройки"        - группа с кнопками "Настройки", "Изменить вариант отчета" и т.п.
//               "РаботаСТабличнымДокументом" - группа с кнопками "Найти", "Развернуть все группы" и т.п.
//               "Интеграция"       - группа такими кнопками как "Печать, Сохранить, Отправить" и т.п.
//               "ПодменюОтправить" - подменю в группе "Интеграция" для отправки по почте.
//               "Прочее"           - группа с кнопками "Изменить форму", "Справка" и т.п.
//   ВНачалоГруппы - Булево - если Истина, то кнопка будет выведена в начале группы. Иначе в конце группы.
//   ТолькоВоВсехДействиях - Булево - если Истина, то кнопка будет выведена только в подменю "Еще".
//                           Иначе и в подменю "Еще", и в командной панели формы.
//   СуффиксПодгруппы - Строка - если заполнен, то команды будут объединены в подгруппу.
//                      СуффиксПодгруппы добавляется к имени группы справа.
//
Процедура ВывестиКоманду(ФормаОтчета, КомандаИлиКоманды, ТипГруппы, ВНачалоГруппы = Ложь, ТолькоВоВсехДействиях = Ложь, СуффиксПодгруппы = "") Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВывестиКоманду(ФормаОтчета, КомандаИлиКоманды, ТипГруппы, ВНачалоГруппы, ТолькоВоВсехДействиях, СуффиксПодгруппы);
```
</details>

## ВывестиГиперссылку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Оформляет ячейку в виде гиперссылки и заполняет поля адреса и представления ссылки.
//
// Параметры:
//   Ячейка      - ОбластьЯчеекТабличногоДокумента - область табличного документа.
//   АдресСсылки - Строка                          - адрес ссылки, которую необходимо вывести в указанной ячейке.
//			       В стандартной форме отчета автоматически открываются ссылки следующих форматов:
//			       "HTTP://<адрес>", "https://<адрес>", "e1cib/<адрес>", "e1c://<адрес>"
//			       Такие ссылки открываются при помощи процедуры ОбщегоНазначенияКлиент.ОткрытьНавигационнуюСсылку.
//			       См. также ПредставлениеНавигационнойСсылки.НавигационнаяСсылка в синтакс-помощнике.
//			       Для открытия ссылок других форматов следует написать код
//			       в процедуре ОтчетыКлиентПереопределяемый.ОбработкаВыбораТабличногоДокумента.
//   ПредставлениеСсылки - Строка
//                       - Неопределено - наименование, которую необходимо вывести в указанной ячейке.
//                                        Если Неопределено, то выводится как есть АдресСсылки.
//
Процедура ВывестиГиперссылку(Ячейка, АдресСсылки, ПредставлениеСсылки = Неопределено) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВывестиГиперссылку(Ячейка, АдресСсылки, ПредставлениеСсылки);
```
</details>

## ОтчетПустой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что отчет пустой.
//
// Параметры:
//   ОтчетОбъект - ОтчетОбъект
//               - ВнешнийОтчет - проверяемый отчет.
//   ПроцессорКД - ПроцессорКомпоновкиДанных - объект, выполняющий компоновку данных в отчете.
//
// Возвращаемое значение:
//   Булево - Истина, если отчет пустой. Ложь, если отчет содержит данные.
//
Функция ОтчетПустой(ОтчетОбъект, ПроцессорКД = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ОтчетПустой(ОтчетОбъект, ПроцессорКД);
```
</details>

## СвойстваЭлементовФормыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коллекцию свойств элементов формы отчета (настроек отчета), связанные с настройками,
// которые доступны для переопределения в модуле объекта отчета.
//
// Параметры:
//   ТипФормы - ТипФормыОтчета
//   КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных
//   ДополнительныеПараметры - см. ОтчетыКлиентСервер.НастройкиОтчетаПоУмолчанию
//
// Возвращаемое значение:
//   Структура:
//   * Группы - см. СвойстваГруппыЭлементовФормы
//   * Поля - ТаблицаЗначений:
//       ** ИндексНастройки - Число
//       ** ИдентификаторНастройки  - Строка
//       ** Настройки - НастройкиКомпоновкиДанных
//       ** ЭлементНастройки - ЭлементОтбораКомпоновкиДанных
//                           - ЗначениеПараметраНастроекКомпоновкиДанных
//                           - ВыбранноеПолеКомпоновкиДанных
//                           - ЭлементПорядкаКомпоновкиДанных
//                           - ЭлементУсловногоОформления
//       ** ОписаниеНастройки - ДоступноеПолеОтбораКомпоновкиДанных
//                            - ДоступныеПараметрыКомпоновкиДанных
//                            - ДоступноеПолеКомпоновкиДанных
//       ** Представление - Строка
//       ** ИдентификаторГруппы - Строка
//       ** ПоложениеЗаголовка - ПоложениеЗаголовкаЭлементаФормы
//       ** РастягиватьПоГоризонтали - Булево
//                                   - Неопределено
//       ** Ширина - Число
//
Функция СвойстваЭлементовФормыНастроек(ТипФормы, КомпоновщикНастроек, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.СвойстваЭлементовФормыНастроек(ТипФормы, КомпоновщикНастроек, ДополнительныеПараметры) 
```
</details>

## СвойстваГруппыЭлементовФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор свойств группы элементов формы пользовательских настроек.
//
// Возвращаемое значение:
//   Структура - содержит значения свойств группы:
//    * Отображение - ОтображениеОбычнойГруппы - см. Синтакс-помощник - ОтображениеОбычнойГруппы.
//    * Группировка - ГруппировкаПодчиненныхЭлементовФормы - количество групп-колонок элементов:
//       ** Вертикальная - ГруппировкаПодчиненныхЭлементовФормы - эквивалентно 1-ой колонке;
//       ** ГоризонтальнаяЕслиВозможно - ГруппировкаПодчиненныхЭлементовФормы - эквивалентно 2-м колонкам;
//       ** ГоризонтальнаяВсегда - ГруппировкаПодчиненныхЭлементовФормы - количество колонок равно количеству элементов
//                                                                        в группе.
//    * Заголовок - Строка - см. синтакс-помощник - ГруппаФормы.Заголовок
//    * ЦветФона - Цвет - см. синтакс-помощник - ГруппаФормы.ЦветФона
//    * Подсказка - Строка - см. синтакс-помощник - ГруппаФормы.Подсказка
//    * ОтображениеПодсказки - ОтображениеПодсказки - см. синтакс-помощник - ГруппаФормы.ОтображениеПодсказки
//    * Высота - Число - см. синтакс-помощник - ГруппаФормы.Высота
//    * Ширина - Число - см. синтакс-помощник - ГруппаФормы.Ширина
//    * РастягиватьПоВертикали - Неопределено, Булево - см. синтакс-помощник - ГруппаФормы.РастягиватьПоВертикали
//    * РастягиватьПоГоризонтали - Неопределено, Булево - см. синтакс-помощник - ГруппаФормы.РастягиватьПоГоризонтали
//
Функция СвойстваГруппыЭлементовФормы() Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.СвойстваГруппыЭлементовФормы() 
```
</details>

## УпорядочитьЭлементыФормыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УпорядочитьЭлементыФормыНастроек(ЭлементыНастроек, ДополнительныеСвойства) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.УпорядочитьЭлементыФормыНастроек(ЭлементыНастроек, ДополнительныеСвойства));
```
</details>

## РаспределитьСпискиПоКолонкамПропорционально
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РаспределитьСпискиПоКолонкамПропорционально(ЭлементыНастроек, КоличествоКолонок) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.РаспределитьСпискиПоКолонкамПропорционально(ЭлементыНастроек, КоличествоКолонок));
```
</details>

## РаспределитьЭлементыФормыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РаспределитьЭлементыФормыНастроек(Форма, Знач Группа, ЭлементыНастроек) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.РаспределитьЭлементыФормыНастроек(Форма, Группа, ЭлементыНастроек));
```
</details>

## РаспределитьЭлементыФормыНастроекПоСвойствам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РаспределитьЭлементыФормыНастроекПоСвойствам(Форма, Родитель, ЭлементыНастроек, НомерКолонки, НомерГруппы = Неопределено) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.РаспределитьЭлементыФормыНастроекПоСвойствам(Форма, Родитель, ЭлементыНастроек, НомерКолонки, НомерГруппы);
```
</details>

## ИерархияЭлементовФормыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИерархияЭлементовФормыНастроек(Форма, Родитель, Признаки, НомерСтроки, НомерКолонки) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ИерархияЭлементовФормыНастроек(Форма, Родитель, Признаки, НомерСтроки, НомерКолонки));
```
</details>

## ГруппаЭлементовФормыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ГруппаЭлементовФормыНастроек(Форма, Родитель, ИмяГруппы) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ГруппаЭлементовФормыНастроек(Форма, Родитель, ИмяГруппы));
```
</details>

## ЭтоОсновнаяФорма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоОсновнаяФорма(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЭтоОсновнаяФорма(Форма));
```
</details>

## ВывестиСтилизованныеЭлементыФормыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывод стилизованных элементов формы настроек.

Процедура ВывестиСтилизованныеЭлементыФормыНастроек(Форма, ЭлементыНастроек, ОписаниеНастроек, ИменаРеквизитов, ВидыЭлементов) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВывестиСтилизованныеЭлементыФормыНастроек(Форма, ЭлементыНастроек, ОписаниеНастроек, ИменаРеквизитов, ВидыЭлементов));
```
</details>

## РеквизитыЭлементовНастроекДобавляемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РеквизитыЭлементовНастроекДобавляемые(ЭлементыНастроек, ВидыЭлементов, ИменаРеквизитов, ПутьКДаннымЭлементов) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.РеквизитыЭлементовНастроекДобавляемые(ЭлементыНастроек, ВидыЭлементов, ИменаРеквизитов, ПутьКДаннымЭлементов));
```
</details>

## РеквизитыЭлементовНастроекУдаляемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РеквизитыЭлементовНастроекУдаляемые(ВидыЭлементов, ИменаРеквизитов, ПутьКДаннымЭлементов) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.РеквизитыЭлементовНастроекУдаляемые(ВидыЭлементов, ИменаРеквизитов, ПутьКДаннымЭлементов));
```
</details>

## УдалитьКомандыЭлементовНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьКомандыЭлементовНастроек(Форма, РеквизитыУдаляемые) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.УдалитьКомандыЭлементовНастроек(Форма, РеквизитыУдаляемые));
```
</details>

## ВывестиПериодыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывод периодов элементов формы настроек

Процедура ВывестиПериодыНастроек(Форма, ЭлементыНастроек, ИменаРеквизитов) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВывестиПериодыНастроек(Форма, ЭлементыНастроек, ИменаРеквизитов));
```
</details>

## ГруппаЭлементовПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ГруппаЭлементовПериода(Элементы, Родитель, СледующийЭлемент, ШаблонИмени, Заголовок) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ГруппаЭлементовПериода(Элементы, Родитель, СледующийЭлемент, ШаблонИмени, Заголовок));
```
</details>

## ДобавитьПолеПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьПолеПериода(Элементы, Группа, ШаблонИмени, Свойство, ЗаголовокЭлементаНастройки, ЭтоСтандартноеПредставление, ВыводитьЗаголовкиПериодов) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьПолеПериода(Элементы, Группа, ШаблонИмени, Свойство, ЗаголовокЭлементаНастройки, ЭтоСтандартноеПредставление, ВыводитьЗаголовкиПериодов));
```
</details>

## ЗаголовокЭлементаПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаголовокЭлементаПериода(Свойство, ЗаголовокЭлементаНастройки, ВыводитьЗаголовкиПериодов) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЗаголовокЭлементаПериода(Свойство, ЗаголовокЭлементаНастройки, ВыводитьЗаголовкиПериодов));
```
</details>

## ДобавитьКомандуСдвигаПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьКомандуСдвигаПериода(Форма, Группа, ШаблонИмени, ЭтоСтандартноеПредставление, НаправлениеСдвига = 1) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьКомандуСдвигаПериода(Форма, Группа, ШаблонИмени, ЭтоСтандартноеПредставление, НаправлениеСдвига);
```
</details>

## ДобавитьКомандуВыбораПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьКомандуВыбораПериода(Форма, Группа, ШаблонИмени, Период, ЭтоСтандартноеПредставление) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьКомандуВыбораПериода(Форма, Группа, ШаблонИмени, Период, ЭтоСтандартноеПредставление));
```
</details>

## УстановитьСвойстваКнопкиВыбораПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСвойстваКнопкиВыбораПериода(ЭлементПериода, Период, ЭтоСтандартноеПредставление) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.УстановитьСвойстваКнопкиВыбораПериода(ЭлементПериода, Период, ЭтоСтандартноеПредставление));
```
</details>

## ИнициализироватьПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значения свойствам стандартного периода: ДатаНачала, ДатаОкончания
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//         - РасширениеУправляемойФормыДляОтчета:
//     * Элементы - ВсеЭлементыФормы
//     * Отчет - ОтчетОбъект
//   Индекс - Число
//
// Возвращаемое значение:
//   СтандартныйПериод
//
Функция ИнициализироватьПериод(Форма, Индекс) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ИнициализироватьПериод(Форма, Индекс));
```
</details>

## ВывестиСпискиНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывод списков элементов формы настроек

Процедура ВывестиСпискиНастроек(Форма, ЭлементыНастроек, ОписаниеНастроек, ИменаРеквизитов) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВывестиСпискиНастроек(Форма, ЭлементыНастроек, ОписаниеНастроек, ИменаРеквизитов));
```
</details>

## ДобавитьЭлементыСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает элементы формы типа ТаблицаФормы, ссылающиеся на реквизит типа СписокЗначений
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//         - РасширениеУправляемойФормыДляОтчета:
//     * Отчет - ОтчетОбъект
//   ЭлементНастройки - СтрокаТаблицыЗначений
//   ОписаниеЭлементаНастройки - СтрокаТаблицыЗначений
//                             - Неопределено
//   ИмяСписка - Строка
//   ИменаРеквизитов - Структура:
//   * Сгенерированных - Структура
//   * Предопределенных - Структура
//
Процедура ДобавитьЭлементыСписка(Форма, ЭлементНастройки, ОписаниеЭлементаНастройки, ИмяСписка, ИменаРеквизитов) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьЭлементыСписка(Форма, ЭлементНастройки, ОписаниеЭлементаНастройки, ИмяСписка, ИменаРеквизитов));
```
</details>

## ДобавитьКомандыСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьКомандыСписка(Форма, ЭлементНастройки, ЭлементыНастроек, ИмяСписка) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьКомандыСписка(Форма, ЭлементНастройки, ЭлементыНастроек, ИмяСписка));
```
</details>

## ДобавитьКомандуСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьКомандуСписка(Форма, Родитель, ИмяКоманды, Заголовок, Действие, Картинка = Неопределено) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьКомандуСписка(Форма, Родитель, ИмяКоманды, Заголовок, Действие, Картинка);
```
</details>

## ИнициализироватьСписок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИнициализироватьСписок(Форма, Индекс, Поле, ЭлементНастройки) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ИнициализироватьСписок(Форма, Индекс, Поле, ЭлементНастройки));
```
</details>

## ВывестиЗначенияКакПоляФлажков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывод значений как поля флажков.

Процедура ВывестиЗначенияКакПоляФлажков(Форма, ЭлементыНастроек, ИменаРеквизитов) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВывестиЗначенияКакПоляФлажков(Форма, ЭлементыНастроек, ИменаРеквизитов));
```
</details>

## ИнициализироватьФлажок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значение флажка.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//         - РасширениеУправляемойФормыДляОтчета:
//     * Отчет - ОтчетОбъект
//   Индекс - Число
//
Процедура ИнициализироватьФлажок(Форма, Индекс) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ИнициализироватьФлажок(Форма, Индекс));
```
</details>

## ЗапомнитьВыделенныеСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запоминает состояние формы.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//   ИмяТаблицы - Строка
//   КлючевыеКолонки - Строка
//
// Возвращаемое значение:
//   Структура:
//   * Текущая - Неопределено
//   * Выделенные - Массив
//
Функция ЗапомнитьВыделенныеСтроки(Форма, ИмяТаблицы, КлючевыеКолонки) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЗапомнитьВыделенныеСтроки(Форма, ИмяТаблицы, КлючевыеКолонки) 
```
</details>

## ВосстановитьВыделенныеСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Восстанавливает состояние формы.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//   ИмяТаблицы - Строка
//   КлючевыеКолонки - Строка
//
Процедура ВосстановитьВыделенныеСтроки(Форма, ИмяТаблицы, СтрокиТаблицы) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ВосстановитьВыделенныеСтроки(Форма, ИмяТаблицы, СтрокиТаблицы) 
```
</details>

## ЕстьВнешнийНаборДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие внешних наборов данных.
//
// Параметры:
//   НаборыДанных - НаборыДанныхМакетаКомпоновкиДанных - коллекция проверяемых наборов данных.
//
// Возвращаемое значение:
//   Булево - Истина, если есть внешние наборы данных.
//
Функция ЕстьВнешнийНаборДанных(НаборыДанных) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЕстьВнешнийНаборДанных(НаборыДанных));
```
</details>

## ЗначенияДляВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗначенияДляВыбора(ПараметрыНастройки, ТипИлиТипы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЗначенияДляВыбора(ПараметрыНастройки, ТипИлиТипы);
```
</details>

## ДополнитьСтруктуруИзПараметровВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьСтруктуруИзПараметровВыбора(Структура, МассивПараметровВыбора) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДополнитьСтруктуруИзПараметровВыбора(Структура, МассивПараметровВыбора));
```
</details>

## ДобавитьВыбранноеПоле
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет выбранное поле компоновки данных.
//
// Параметры:
//   Куда - КомпоновщикНастроекКомпоновкиДанных
//        - НастройкиКомпоновкиДанных
//        - ВыбранныеПоляКомпоновкиДанных -
//       Коллекция в которую требуется добавить выбранное поле.
//   ИмяИлиПолеКД - Строка
//                - ПолеКомпоновкиДанных - имя поля.
//   Заголовок    - Строка - представление поля.
//
// Возвращаемое значение:
//   ВыбранноеПолеКомпоновкиДанных - добавленное выбранное поле.
//
Функция ДобавитьВыбранноеПоле(Куда, ИмяИлиПолеКД, Заголовок = "") Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ДобавитьВыбранноеПоле(Куда, ИмяИлиПолеКД, Заголовок);
```
</details>

## ДобавитьВариантыКонтекста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВариантыКонтекста(Отчет, Варианты, ВариантыКонтекста) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.ДобавитьВариантыКонтекста(Отчет, Варианты, ВариантыКонтекста) 
```
</details>

## РасширенноеОписаниеТипов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РасширенноеОписаниеТипов(ИсходноеОписаниеТипов, ПривестиКФорме, ПараметрыПодбора = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.РасширенноеОписаниеТипов(ИсходноеОписаниеТипов, ПривестиКФорме, ПараметрыПодбора);
```
</details>

## ЗначениеВМассив
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗначениеВМассив(Значение) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЗначениеВМассив(Значение) 
```
</details>

## ПривестиИдентификаторКИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПривестиИдентификаторКИмени(Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ПривестиИдентификаторКИмени(Идентификатор) 
```
</details>

## ЭлементНастроекПоПолномуПути
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит элемент компоновки данных по полному пути.
//
// Параметры:
//   НастройкиКД - НастройкиКомпоновкиДанных - корневой узел настроек, в который вложен искомый элемент.
//   ПолныйПутьКЭлементу - Строка - полный путь к элементу. Может быть получена в функции ПолныйПутьКЭлементу().
//
// Возвращаемое значение:
//   - НастройкиКомпоновкиДанных
//   - КоллекцияЭлементовСтруктурыНастроекКомпоновкиДанных
//   - ГруппировкаКомпоновкиДанных
//   - КоллекцияЭлементовСтруктурыТаблицыКомпоновкиДанных
//   - ГруппировкаТаблицыКомпоновкиДанных
//   - КоллекцияЭлементовСтруктурыДиаграммыКомпоновкиДанных
//   - ГруппировкаДиаграммыКомпоновкиДанных - найденный узел настроек.
//
Функция ЭлементНастроекПоПолномуПути(Знач Настройки, Знач ПолныйПутьКЭлементу) Экспорт
```

Пример вызова
```bsl
Результат = ОтчетыСервер.ЭлементНастроекПоПолномуПути(Настройки, ПолныйПутьКЭлементу) 
```
</details>

## УстановитьУсловияОтборов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//  ПараметрыЗагрузки - см. ОтчетыКлиентСервер.ПараметрыОбновленияФормыОтчета
//  КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных
//
Процедура УстановитьУсловияОтборов(ПараметрыЗагрузки, КомпоновщикНастроек) Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.УстановитьУсловияОтборов(ПараметрыЗагрузки, КомпоновщикНастроек) 
```
</details>

## УстановитьДоступныеЗначенияНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьДоступныеЗначенияНастроек(Форма, Отчет, КомпоновщикНастроек, ЭлементПользовательскойНастройки, Экспорт
```

Пример вызова
```bsl
ОтчетыСервер.УстановитьДоступныеЗначенияНастроек(Форма, Отчет, КомпоновщикНастроек, ЭлементПользовательскойНастройки, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
