---
title: Очередь заданий
slug: bsp/очередь-заданий
---


## ПолучитьЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Основные процедуры и функции.

// Все методы доступные в API оперирует параметрами заданий. Возможность использования
// конкретного параметра зависит от метода и, в некоторых случаях, значений других
// параметров. Подробнее об этом написано в описании конкретных методов.
// Описание параметров - см. НовыйПараметрыЗадания.

// Получает задания очереди по заданному отбору.
// Возможно получение неконсистентных данных.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  Отбор - Структура - значения, по которым требуется отбирать задания (объединяются по И). Возможные ключи структуры:
//            * ОбластьДанных - Число - область данных,
//            * ИмяМетода - Строка - имя метода,
//            * Идентификатор - УникальныйИдентификатор - идентификатор задания,
//            * СостояниеЗадания - ПеречислениеСсылка.СостоянияЗаданий - состояние задания,
//            * Ключ - Строка - ключ задания,
//            * Шаблон - СправочникСсылка.ШаблоныЗаданийОчереди - шаблон задания,
//            * Использование - Булево - использование задания.
//        - Массив Из Структура - описание:
//            * ВидСравнения - ВидСравнения - допустимыми значениями являются:
//                ВидСравнения.Равно, ВидСравнения.НеРавно - для сравнения со значением,
//                ВидСравнения.ВСписке, ВидСравнения.НеВСписке - для сравнения с массивом.
//            * Значение - Произвольный - значения сравнения  для видов сравнения Равно / НеРавно
//            			 - Массив -  для видов сравнения ВСписке и НеВСписке
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица найденных заданий. Колонки соответствуют параметрам заданий:
//	 * Идентификатор - СправочникСсылка.ОчередьЗаданий - ссылка на справочник.
//	 ...
//
Функция ПолучитьЗадания(Знач Отбор) Экспорт
```

Пример вызова
```bsl
Результат = ОчередьЗаданий.ПолучитьЗадания(Отбор) 
```
</details>

## ДобавитьЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет новое задание в очередь.
// В случае вызова в транзакции на задание устанавливается объектная блокировка.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ПараметрыЗадания - Структура - параметры добавляемого задания. Описание:
//  * ОбластьДанных - Число - номер области данных.
//  * Использование - Булево - признак использования.
//  * ЗапланированныйМоментЗапуска - Дата - момент запуска (ДатаВремя)
//  * ЭксклюзивноеВыполнение - Булево - признак эксклюзивного выполнения.
//  * ИмяМетода - Строка - имя метода для задания, обязательно для указания.
//  * Параметры - Массив - параметры метода.
//  * Ключ - Строка - ключ уникальности задания.
//  * ИнтервалПовтораПриАварийномЗавершении - Число - интервал повтора в секундах.
//  * Расписание - РасписаниеРегламентногоЗадания - расписания выполнения задания.
//  * КоличествоПовторовПриАварийномЗавершении - Число - количество повторов.
//
// Возвращаемое значение:
//  СправочникСсылка.ОчередьЗаданий - идентификатор добавленного задания.
//
Функция ДобавитьЗадание(ПараметрыЗадания) Экспорт
```

Пример вызова
```bsl
Результат = ОчередьЗаданий.ДобавитьЗадание(ПараметрыЗадания) 
```
</details>

## ИзменитьЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет задание с указанным идентификатором.
// В случае вызова в транзакции на задание устанавливается объектная блокировка.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//	Идентификатор - СправочникСсылка.ОчередьЗаданий - идентификатор задания.
//	ПараметрыЗадания - Структура - параметры, которые следует установить заданию, возможные ключи:
//						* Использование - Булево -
//						* ЗапланированныйМоментЗапуска - Дата -
//						* ЭксклюзивноеВыполнение - Булево -
//						* ИмяМетода - Строка -
//						* Параметры - Массив -
//  					* Ключ - Строка -
//						* ИнтервалПовтораПриАварийномЗавершении - Число -
//						* Расписание - РасписаниеРегламентногоЗадания -
//						* КоличествоПовторовПриАварийномЗавершении - Число -
//   				- Структура - в случае если задание создано на основе шаблона, могут быть указаны только следующие ключи:
//						* Использование - Булево -
//						* ЗапланированныйМоментЗапуска - Дата -
//						* ЭксклюзивноеВыполнение - Булево -
//						* ИнтервалПовтораПриАварийномЗавершении - Число -
//						* Расписание - РасписаниеРегламентногоЗадания -
//						* КоличествоПовторовПриАварийномЗавершении - Число -
//
Процедура ИзменитьЗадание(Идентификатор, ПараметрыЗадания) Экспорт
```

Пример вызова
```bsl
ОчередьЗаданий.ИзменитьЗадание(Идентификатор, ПараметрыЗадания) 
```
</details>

## УдалитьЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет задание из очереди заданий.
// Удаление заданий с установленным шаблоном запрещено.
// В случае вызова в транзакции на задание устанавливается объектная блокировка.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  Идентификатор - СправочникСсылка.ОчередьЗаданий - идентификатор задания.
//
Процедура УдалитьЗадание(Идентификатор) Экспорт
```

Пример вызова
```bsl
ОчередьЗаданий.УдалитьЗадание(Идентификатор) 
```
</details>

## ШаблонПоИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон задания очереди по имени предопределенного регламентного задания из которого он создан.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  Имя - Строка - имя предопределенного регламентного задания.
//
// Возвращаемое значение:
//  СправочникСсылка.ШаблоныЗаданийОчереди - шаблон задания.
//
Функция ШаблонПоИмени(Знач Имя) Экспорт
```

Пример вызова
```bsl
Результат = ОчередьЗаданий.ШаблонПоИмени(Имя) 
```
</details>

## ПолучитьТекстИсключенияДублированиеЗаданийСОдинаковымКлючом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст ошибки при попытке выполнить одновременно два задания с одним ключом.
// @skip-warning ПустойМетод - особенность реализации.
//
// Возвращаемое значение:
//   Строка - текст исключения.
//
Функция ПолучитьТекстИсключенияДублированиеЗаданийСОдинаковымКлючом() Экспорт
```

Пример вызова
```bsl
Результат = ОчередьЗаданий.ПолучитьТекстИсключенияДублированиеЗаданийСОдинаковымКлючом() 
```
</details>

## ШаблоныЗаданийОчереди
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список шаблонов заданий очереди.
// @skip-warning ПустойМетод - особенность реализации.
//
// Возвращаемое значение:
//  Массив Из Строка - имена предопределенных неразделенных регламентных заданий, которые используются
//           в качестве шаблонов для заданий очереди.
//
//
Функция ШаблоныЗаданийОчереди() Экспорт
```

Пример вызова
```bsl
Результат = ОчередьЗаданий.ШаблоныЗаданийОчереди() 
```
</details>

## СправочникОчередьЗаданий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер справочника ОчередьЗаданий.
// @skip-warning ПустойМетод - особенность реализации.
//
// Возвращаемое значение:
//	СправочникМенеджер.ОчередьЗаданий - менеджер справочника.
//
Функция СправочникОчередьЗаданий() Экспорт
```

Пример вызова
```bsl
Результат = ОчередьЗаданий.СправочникОчередьЗаданий() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
