---
title: Передача данных сервер
slug: bsp/передача-данных-сервер
---


## ВсеМенеджерыЛогическихХранилищ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджеры логических хранилищ.
//
// Возвращаемое значение:
//  ФиксированноеСоответствие из Строка - менеджеры логических хранилищ:
//    * Ключ - Строка - идентификатор логического хранилища;
//    * Значение - ОбщийМодуль - менеджер логического хранилища.
//
Функция ВсеМенеджерыЛогическихХранилищ() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ВсеМенеджерыЛогическихХранилищ() 
```
</details>

## ВсеМенеджерыФизическихХранилищ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджеры физических хранилищ.
//
// Возвращаемое значение:
//  ФиксированноеСоответствие из Строка - менеджеры физических хранилищ:
//    * Ключ - Строка - идентификатор физического хранилища;
//    * Значение - ОбщийМодуль - менеджер физического хранилища.
//
Функция ВсеМенеджерыФизическихХранилищ() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ВсеМенеджерыФизическихХранилищ() 
```
</details>

## ПолучитьИзЛогическогоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные из логического хранилища.
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//     * Кэш - Соответствие из Строка - необязательный, пустое соответствие, если указан, может использоваться для кеширования.
//   ИдентификаторХранилища - Строка - идентификатор логического хранилища.
//   Идентификатор - Строка - идентификатор данных в логическом хранилище.
//   Диапазон - Структура -
//     * Начало - Число - первый байт.
//     * Конец - Число - последний байт.
//   ИмяФайла - Строка, Неопределено - Имя файла для записи данных.
//
// Возвращаемое значение:
//  Неопределено, Структура - Получить из логического хранилища:
//   * Имя - Строка - имя файла
//   * ПолноеИмя - Строка - полное имя файла (включающее путь к файлу)
//
Функция ПолучитьИзЛогическогоХранилища(ПараметрыДоступа, ИдентификаторХранилища, Идентификатор, Диапазон = Неопределено, ИмяФайла = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ПолучитьИзЛогическогоХранилища(ПараметрыДоступа, ИдентификаторХранилища, Идентификатор, Диапазон, ИмяФайла);
```
</details>

## ПолучитьРазмерФайлаИзЛогическогоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает информацию о файле из логического хранилища.
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//   ИдентификаторХранилища - Строка - идентификатор логического хранилища.
//   Идентификатор - Строка - идентификатор данных в логическом хранилище.
//
// Возвращаемое значение:
//   Число - размер файла в байтах.
//
Функция ПолучитьРазмерФайлаИзЛогическогоХранилища(ПараметрыДоступа, ИдентификаторХранилища, Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ПолучитьРазмерФайлаИзЛогическогоХранилища(ПараметрыДоступа, ИдентификаторХранилища, Идентификатор) 
```
</details>

## ПолучитьИзФизическогоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные из физического хранилища.
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//   ИдентификаторХранилища - Строка - идентификатор физического хранилища.
//   Идентификатор - Строка - идентификатор данных в физическом хранилище.
//   ИмяФайла - Строка, Неопределено - Имя файла для записи данных.
//
// Возвращаемое значение:
//   Неопределено, Структура - описание файла:
//	   * Имя - Строка - имя файла;
//	   * ПолноеИмя - Строка - полное имя файла (включающее путь к файлу).
//
Функция ПолучитьИзФизическогоХранилища(ПараметрыДоступа, ИдентификаторХранилища, Идентификатор, ИмяФайла = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ПолучитьИзФизическогоХранилища(ПараметрыДоступа, ИдентификаторХранилища, Идентификатор, ИмяФайла);
```
</details>

## ОтправитьВЛогическоеХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет данные в логическое хранилище.
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//   ИдентификаторХранилища - Строка - идентификатор логического хранилища.
//   Данные - Строка - адрес данных во временном хранилище;
//          - Строка - полное имя файла (включающее путь к файлу);
//          - Файл - файловый объект;
//          - ДвоичныеДанные - значение в виде двоичных данных.
//   ИмяФайла - Строка - имя передаваемого файла.
//   ДополнительныеПараметры - Структура - структура со значениями сериализуемыми в json.
//
// Возвращаемое значение:
//  Число, Неопределено, Произвольный -
//
Функция ОтправитьВЛогическоеХранилище(ПараметрыДоступа, ИдентификаторХранилища, Данные, Знач ИмяФайла, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ОтправитьВЛогическоеХранилище(ПараметрыДоступа, ИдентификаторХранилища, Данные, ИмяФайла, ДополнительныеПараметры);
```
</details>

## НачатьОтправкуВЛогическоеХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Начинает отправку файла в логическое хранилище
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//   ИдентификаторХранилища - Строка - идентификатор логического хранилища.
//   Данные - Строка - адрес данных во временном хранилище;
//          - Строка - полное имя файла (включающее путь к файлу);
//          - Файл - файловый объект;
//          - ДвоичныеДанные - значение в виде двоичных данных.
//   ИмяФайла - Строка - имя передаваемого файла.
//   ДополнительныеПараметры - Структура - структура со значениями сериализуемыми в json.
//
// Возвращаемое значение:
//  Неопределено, Структура - поля:
//    * Location - Неопределено, Произвольный -
//    * SetCookie - Произвольный, Неопределено -
//    * АдресS3 - Произвольный, Неопределено -
//    * ИдентификаторФайлаS3 - Произвольный, Неопределено -
//    * ПередачаЧастями - Булево
//
Функция НачатьОтправкуВЛогическоеХранилище(ПараметрыДоступа, ИдентификаторХранилища, Данные, Знач ИмяФайла, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.НачатьОтправкуВЛогическоеХранилище(ПараметрыДоступа, ИдентификаторХранилища, Данные, ИмяФайла, ДополнительныеПараметры);
```
</details>

## ОтправитьЧастьФайлаВЛогическоеХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Отправляет очередную часть
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//   ПараметрыОтправки - Структура - поля:
//     Location - Строка -
//     SetCookie - Строка -
//     АдресS3 - Строка -
//     ИдентификаторФайлаS3 - Строка -
//     ПередачаЧастями - Булево -
//  Данные - Произвольный -
//  ПоследняяЧасть - Булево -
//  Смещение - Число -
//
// Возвращаемое значение:
//   Число, Неопределено - Количество байт в случае успешной отправки, или Неопределено, если не получилось отправить
//
Функция ОтправитьЧастьФайлаВЛогическоеХранилище(ПараметрыДоступа, ПараметрыОтправки, Данные, ПоследняяЧасть = Истина, Смещение = 0) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ОтправитьЧастьФайлаВЛогическоеХранилище(ПараметрыДоступа, ПараметрыОтправки, Данные, ПоследняяЧасть, Смещение);
```
</details>

## ОтправитьВФизическоеХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет данные в физическое хранилище.
//
// Параметры:
//   ПараметрыДоступа - Структура - поля:
//     * URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным;
//     * UserName - Строка - имя пользователя;
//     * Password - Строка - пароль пользователя.
//   ИдентификаторХранилища - Строка - идентификатор физического хранилища.
//   Данные - Строка - адрес данных во временном хранилище;
//          - Строка - полное имя файла (включающее путь к файлу);
//          - Файл - файловый объект;
//          - ДвоичныеДанные - значение в виде двоичных данных.
//   ИмяФайла - Строка - имя передаваемого файла.
//
//
// Возвращаемое значение:
//  Число, Неопределено, Произвольный -
//
Функция ОтправитьВФизическоеХранилище(ПараметрыДоступа, ИдентификаторХранилища, Данные, Знач ИмяФайла) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаДанныхСервер.ОтправитьВФизическоеХранилище(ПараметрыДоступа, ИдентификаторХранилища, Данные, ИмяФайла) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
