---
title: Подбор ФИО
slug: bsp/подбор-фио
---


## Подобрать
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат поиска по классификатору, пустой массив если данные не найдены.
//
// Параметры:
//  РежимПоиска - Строка - Режим поиска значения по классификатору, может принимать следующие значения:
//    "Фамилия", "Имя", "Отчество", "ФИО".
//  ДанныеФИО - Структура, Неопределено - описывает данные ФИО, по которым будет выполняться поиск.
//    В случае если значение параметра "Пол" пустое, будет использована для его определения по данным классификатора:
//    * Фамилия - Строка, Неопределено - описывает фамилию лица (ее часть когда РежимПоиска = "Фамилия").
//      Свойство может не передаваться.
//    * Имя - Строка, Неопределено - описывает имя лица (его часть когда РежимПоиска = "Имя").
//      Свойство может не передаваться.
//    * Отчество - Строка, Неопределено - описывает отчество лица (его часть когда РежимПоиска = "Отчество").
//      Свойство может не передаваться.
//    * Представление - Строка - описывает ФИО лица (в тех случаях когда РежимПоиска = "ФИО").
//      Свойство может не передаваться.
//  Пол - Число - задает значение пола для поиска значения в классификаторе, может принимать значения:
//    0 - не задан(будет определен по данным структуры ДанныеФИО), 1- мужской, 2 - женский, 3 - допустимы оба.
//  РазмерВыборки - Число - определяет размер выборки данных классификатора.
// Возвращаемое значение:
//   Массив из Строка - данные поиска по классификатору, отсортированные по популярности.
//
Функция Подобрать(РежимПоиска, ДанныеФИО = Неопределено, Пол = 0, РазмерВыборки = 10) Экспорт
```

Пример вызова
```bsl
Результат = ПодборФИО.Подобрать(РежимПоиска, ДанныеФИО, Пол, РазмерВыборки);
```
</details>

## ОпределитьПол
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат определения пола по данным классификатора.
//
// Параметры:
//  ДанныеФИО - Структура, Неопределено - описывает данные ФИО, по которым будет выполняться поиск.
//  Если передано свойство "Представление", поиск будет выполнятся по нему.
//    * Фамилия - Строка - описывает фамилию лица. Свойство может не передаваться.
//    * Имя - Строка - описывает имя лица. Свойство может не передаваться.
//    * Отчество - Строка - описывает отчество лица. Свойство может не передаваться.
//    * Представление - Строка - описывает ФИО лица. Свойство может не передаваться.
//  Возвращаемое значение:
//    Число - значение пола по данным классификатора, может принимать значения:
//      1- мужской, 2 - женский, 3 - допустимы оба.
//
Функция ОпределитьПол(ДанныеФИО) Экспорт
```

Пример вызова
```bsl
Результат = ПодборФИО.ОпределитьПол(ДанныеФИО) 
```
</details>

## НайтиФИО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск значений в классификатора по переданным частям ФИО.
//
// Параметры:
//  ЧастиФИО - Массив из Строка - данные для поиска в классификаторе.
//  ПолноеСовпадение - Булево - режим поиска. Если установлено Истина при поиске
//   будет проверяться равенство строки поиска с значением классификаторов,
//   если Ложь, для сравнения используется ПОДОБНО. Допускается указывать
//   параметры не точного поиска, например, Пет%.
//
//  Возвращаемое значение:
//    Структура - результат поиска:
//    * Фамилии - Массив из Структура - найденные фамилии:
//      ** Значение - Строка - найденное значение;
//      ** ПриоритетОтображения - Число - приоритет значения;
//      Свойство может не передаваться.
//    * Имена - Массив из Структура - найденные имена:
//      ** Значение - Строка - найденное значение;
//      ** ПриоритетОтображения - Число - приоритет значения;
//    * Отчества - Массив из Структура - найденные отчества:
//      ** Значение - Строка - найденное значение;
//
// Пример:
//	ЧастиФИО = Новый Массив;
//	ЧастиФИО.Добавить("Пет%");
//	Результат = ПодборФИО.НайтиФИО(ЧастиФИО, Ложь);
//
Функция НайтиФИО(ЧастиФИО, ПолноеСовпадение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ПодборФИО.НайтиФИО(ЧастиФИО, ПолноеСовпадение);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
