---
title: Получение обновлений программы
slug: bsp/получение-обновлений-программы
---


## ПараметрыПолученияОбновлений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры получения обновлений, определенные для текущей конфигурации.
//
// Возвращаемое значение:
//  Структура - содержит настройки обновления информационной базы:
//    * ПолучатьОбновленияКонфигурации - Булево - Истина, если для конфигурации задействовано получение обновлений
//        конфигурации.
//    * ПолучатьИсправления - Булево - Истина, если для конфигурации задействовано получение исправлений (патчей).
//    * ПолучатьОбновленияПлатформы - Булево - Истина, если разрешено загружать и устанавливать новые версии платформы.
//
Функция ПараметрыПолученияОбновлений() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ПараметрыПолученияОбновлений() 
```
</details>

## ДоступноИспользованиеОбновленияПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность использования автоматического обновления программы в
// текущем режиме работы.
//
// Параметры:
//	ПроверитьВозможностьПримененияОбновлений - Булево - проверить для текущего
//		пользователя наличие права применения обновления.
//		Если Истина - проверяется возможность использования в режиме применения
//		обновления, иначе проверить возможность просмотра информации о
//		доступных обновлениях;
//	ПроверитьОС - Булево - проверить возможность применения обновления
//		на текущей операционной системе.
//
// Возвращаемое значение:
//	Булево - признак возможности использования: Истина, если использование
//		возможно, Ложь - в противном случае.
//
Функция ДоступноИспользованиеОбновленияПрограммы( Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ДоступноИспользованиеОбновленияПрограммы();
```
</details>

## КаталогСохраненияПоследнегоПолученногоДистрибутива
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В файловом режиме работы возвращает каталог, в который был сохранен последний
// полученный дистрибутив Платформы 1С:Предприятие. В других режимах работы
// возвращает Неопределено.
//
// Возвращаемое значение:
//	Строка - каталог с дистрибутивом Платформы 1С:Предприятие в
//		файловом режиме работы;
//	Неопределено - в других режимах работы.
//
Функция КаталогСохраненияПоследнегоПолученногоДистрибутива() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.КаталогСохраненияПоследнегоПолученногоДистрибутива() 
```
</details>

## ИсправленияРодительскихКонфигураций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращается список доступных исправлений (патчей) для текущей версии конфигурации и библиотек, встроенных в
// конфигурацию.
// Вызов метода доступен только при работе под пользователем с административными правами или при установленном
// привилегированном режиме, в противном случае, в результате выполнения возвращается ошибка.
//
// Возвращаемое значение:
//  Структура - информация о доступных исправлениях (патчах):
//    * Исправления - Структура - описание исправлений:
//        ** Установить - Массив из Структура - описание доступных исправлений (патчей):
//             *** Идентификатор - Строка - идентификатор исправления (патча);
//             *** Наименование - Строка - наименование исправления (патча);
//             *** ИмяПрограммы - Строка - имя родительской конфигурации, для которой доступно исправление;
//             *** ВерсияПрограммы - Строка - версия родительской конфигурации, для которой доступно исправление;
//             *** Описание - Строка - описание исправления (патча);
//             *** ОписаниеИзмененныхМетаданных - Строка - список метаданных, в которые внесены изменения;
//             *** Размер - Число - размер исправления (патча);
//        ** Удалить - Массив из Строка - содержит элементы типа Строка, идентификаторы отозванных
//             исправлений, которые необходимо удалить;
//    * Ошибка - Булево - Истина, если при получении информации об исправлениях возникла ошибка;
//    * КраткоеОписаниеОшибки - Строка - краткое описание ошибки, которое может быть отображено пользователю;
//    * ПодробноеОписаниеОшибки - Строка - подробное описание ошибки, которое может быть записано в журнал регистрации.
//
Функция ИсправленияРодительскихКонфигураций() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ИсправленияРодительскихКонфигураций() 
```
</details>

## ЗагрузитьИсправления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает выбранные исправления (патчи) во временное хранилище.
// При возникновении ошибки загрузки файла одного из исправлений: загрузка файлов
// прерывается, вместе с описанием ошибки возвращаются файлы, которые удалось
// загрузить. На вызывающей стороне необходимо повторить вызов для незагруженных
// исправлений.
// Вызов метода доступен только при работе под пользователем с административными
// правами или при установленном привилегированном режиме, в противном случае,
// в результате выполнения возвращается ошибка.
// Работа метода в модели сервиса не поддерживается.
//
// Параметры:
//	ИдентификаторыИсправлений - Массив из Строка - идентификаторы загружаемых исправлений;
//	ИдентификаторФормы - УникальныйИдентификатор - уникальный идентификатор
//		формы, в хранилище которой необходимо поместить загруженные файлы.
//
// Возвращаемое значение:
//  Структура - информация о загруженных файлах исправлений:
//    * Исправления - Массив из Структура - описание файлов исправлений, которые удалось загрузить:
//      ** Идентификатор - УникальныйИдентификатор - идентификатор исправления;
//      ** АдресФайла - Строка - адрес полученного файла во временном хранилище;
//    * Ошибка - Булево - Истина, если при получении информации об исправлениях
//      возникла ошибка;
//    * КраткоеОписаниеОшибки - Строка - краткое описание ошибки,
//      которое может быть отображено пользователю;
//    * ПодробноеОписаниеОшибки - Строка - подробное описание ошибки,
//      которое может быть записано в журнал регистрации.
//
Функция ЗагрузитьИсправления(ИдентификаторыИсправлений, ИдентификаторФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ЗагрузитьИсправления(ИдентификаторыИсправлений, ИдентификаторФормы);
```
</details>

## ДоступнаАвтоматическаяЗагрузкаИсправлений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность автоматической загрузки и установки исправлений регламентным заданием.
//
// Возвращаемое значение:
//	Булево - признак возможности использования: Истина, если использование
//		возможно, Ложь - в противном случае.
//
Функция ДоступнаАвтоматическаяЗагрузкаИсправлений() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ДоступнаАвтоматическаяЗагрузкаИсправлений() 
```
</details>

## АвтоматическаяЗагрузкаИсправленийВключена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет значение настройки автоматической загрузки и установки исправлений.
// При работе в модели сервиса загрузка патчей выполняется через обработку поставляемых данных.
// Функция вернет значение "Истина", если работа с исправлениями в программе разрешена.
//
// Возвращаемое значение:
//	Булево - признак включенности автоматической загрузки: Истина, если загрузка
//		включена, Ложь - в противном случае.
//
Функция АвтоматическаяЗагрузкаИсправленийВключена() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.АвтоматическаяЗагрузкаИсправленийВключена() 
```
</details>

## ВключитьОтключитьАвтоматическуюУстановкуИсправлений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет значение настройки автоматической загрузки и установки исправлений.
// Перед вызовом метода необходимо проверить доступность загрузки исправлений
// см. ДоступнаАвтоматическаяЗагрузкаИсправлений. Если автоматическая
// загрузка исправлений не доступна, будет вызвано исключение.
//
// При работе в модели сервиса загрузка исправлений выполняется через обработку
// поставляемых данных. Вызов метода в модели сервиса не имеет смысла.
//
// Параметры:
//	ЗначениеНастройки - Булево - если Истина, автоматическая загрузка будет включена.
//
// Пример:
//	Если ПолучениеОбновленийПрограммы.ДоступнаАвтоматическаяЗагрузкаИсправлений() Тогда
//		ПолучениеОбновленийПрограммы.ВключитьОтключитьАвтоматическуюУстановкуИсправлений(Истина);
//	КонецЕсли;
//
Процедура ВключитьОтключитьАвтоматическуюУстановкуИсправлений(Знач ЗначениеНастройки) Экспорт
```

Пример вызова
```bsl
ПолучениеОбновленийПрограммы.ВключитьОтключитьАвтоматическуюУстановкуИсправлений(ЗначениеНастройки) 
```
</details>

## ИнформацияОДоступныхИсправлениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список доступных исправлений (патчей) для текущей версии конфигурации и библиотек, встроенных в
// конфигурацию.
// Вызов метода доступен только при работе под пользователем с административными правами или при установленном
// привилегированном режиме, в противном случае, в результате выполнения возвращается ошибка.
// Работа метода в модели сервиса не поддерживается.
//
// Возвращаемое значение:
//  Структура:
//    * Исправления - Неопределено - не удалось получить информацию о доступных исправлениях (патчах).
//                  - ТаблицаЗначений - список доступных исправлений с колонками:
//                      ** Идентификатор - Строка - идентификатор исправления (патча).
//                      ** Наименование - Строка - наименование исправления (патча).
//                      ** Описание - Строка - описание исправления (патча).
//                      ** ОписаниеИзмененныхМетаданных - Строка - список метаданных, в которые внесены изменения.
//                      ** Размер - Число - размер исправления (патча).
//    * Ошибка - Булево - Истина, если при получении информации об исправлениях возникла ошибка.
//    * КраткоеОписаниеОшибки - Строка - краткое описание ошибки, которое может быть отображено пользователю;
//    * ПодробноеОписаниеОшибки - Строка - подробное описание ошибки, которое может быть записано в журнал регистрации.
//
Функция ИнформацияОДоступныхИсправлениях() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ИнформацияОДоступныхИсправлениях() 
```
</details>

## ЗагрузитьИУстановитьИсправления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производить загрузку доступных исправлений, их установку и удаление отозванных исправлений для текущей версии
// конфигурации и библиотек, встроенных в конфигурацию.
// Вызов метода доступен только при работе под пользователем с административными правами или при установленном
// привилегированном режиме, в противном случае, в результате выполнения возвращается ошибка.
// Работа метода в модели сервиса не поддерживается.
//
// Возвращаемое значение:
//  Структура:
//    * НеУстановлено - Число - количество неустановленных исправлений.
//    * НеУдалено - Число - количество неудаленных исправлений.
//    * Ошибка - Булево - Истина, если ни один из доступных исправлений не применен.
//    * КраткоеОписаниеОшибки - Строка - краткое описание ошибки, которое может быть отображено пользователю. Может
//        быть заполнено даже если параметр Ошибка имеет значение Ложь.
//    * ПодробноеОписаниеОшибки - Строка - подробное описание ошибки, которое может быть записано в журнал регистрации.
//        Может быть заполнено даже если параметр Ошибка имеет значение Ложь.
//
Функция ЗагрузитьИУстановитьИсправления() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ЗагрузитьИУстановитьИсправления() 
```
</details>

## ИнформацияОВерсияхПлатформы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сохраненный ответ сервиса по получению информации о версиях платформы для текущей конфигурации.
//
// Возвращаемое значение:
//  Структура:
//    * МинимальнаяВерсияПлатформы - Строка - список минимальных версий платформы, перечисленные через ";".
//    * РекомендуемаяВерсияПлатформы - Строка - список рекомендуемых версий платформы, перечисленные через ";".
//
Функция ИнформацияОВерсияхПлатформы() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеОбновленийПрограммы.ИнформацияОВерсияхПлатформы() 
```
</details>

## УдалитьИнформациюОВерсияхПлатформы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет ранее сохраненный ответ сервиса по получению информации о версиях платформы для текущей конфигурации.
//
Процедура УдалитьИнформациюОВерсияхПлатформы() Экспорт
```

Пример вызова
```bsl
ПолучениеОбновленийПрограммы.УдалитьИнформациюОВерсияхПлатформы() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
