---
title: Получение файлов из интернета клиент сервер
slug: bsp/получение-файлов-из-интернета-клиент-сервер
---


## ПараметрыПолученияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для получения файла из Интернета.
//
// Возвращаемое значение:
//  Структура:
//     * ПутьДляСохранения            - Строка       - путь на сервере (включая имя файла) для сохранения скачанного файла.
//                                                     Не заполняется при сохранении файла во временное хранилище.
//     * Пользователь                 - Строка       - пользователь, от имени которого установлено соединение.
//     * Пароль                       - Строка       - пароль, пользователя от которого установлено соединение.
//     * Порт                         - Число        - порт сервера, с которым установлено соединение.
//     * Таймаут                      - Число        - таймаут на получение файла в секундах.
//     * ЗащищенноеСоединение         - Булево       - признак использования защищенного соединения ftps или https.
//                                    - ЗащищенноеСоединениеOpenSSL
//                                    - Неопределено - в случае, если защищенное соединение не используется.
//     * ПроверятьДоставкуПакетовПриОшибке - Булево - при ошибке обращения к URL включать в диагностику команду PING.
//     * ПроверятьДоступКИнтернетСервисам - Булево - необязательный параметр, по умолчанию Истина - выполняется проверка
//                                             разрешения доступа к Интернет-сервисам из приложения.
//
//    Параметры только для HTTP (https) соединения:
//     * Заголовки                    - Соответствие - см. в синтакс-помощнике описание параметра Заголовки объекта HTTPЗапрос.
//     * ИспользоватьАутентификациюОС - Булево       - см. в синтакс-помощнике описание параметра
//                                                     ИспользоватьАутентификациюОС объекта HTTPСоединение.
//
//    Параметры только для ftp (ftps) соединения:
//     * ПассивноеСоединение          - Булево       - флаг указывает, что соединение должно пассивным (или активным).
//     * УровеньИспользованияЗащищенногоСоединения - УровеньИспользованияЗащищенногоСоединенияFTP - см. описание
//         одноименного свойства в синтакс-помощнике платформы. Значение по умолчанию - Авто.
//
Функция ПараметрыПолученияФайла() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеФайловИзИнтернетаКлиентСервер.ПараметрыПолученияФайла() 
```
</details>

## ПолучитьПрокси
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ПолучениеФайловИзИнтернета.ПолучитьПрокси.
// Возвращает объект ИнтернетПрокси для доступа в Интернет.
// Допустимые протоколы для создания ИнтернетПрокси HTTP, https, ftp и ftps.
//
// Параметры:
//    URLИлиПротокол - Строка - url в формате [Протокол://]<Сервер>/<Путь к файлу на сервере>,
//                              либо идентификатор протокола (HTTP, ftp, ...).
//
// Возвращаемое значение:
//    ИнтернетПрокси - описывает параметры прокси-серверов для различных протоколов.
//                     Если не удалось распознать схему сетевой протокол,
//                     то будет создать прокси на основании протокола HTTP.
//
Функция ПолучитьПрокси(Знач URLИлиПротокол) Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеФайловИзИнтернетаКлиентСервер.ПолучитьПрокси(URLИлиПротокол) 
```
</details>

## РазделитьURL
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ОбщегоНазначенияКлиентСервер.СтруктураURI.
// Разделяет URL по составным частям: протокол, сервер, путь к ресурсу.
//
// Параметры:
//    URL - Строка - ссылка на ресурс в сети Интернет.
//
// Возвращаемое значение:
//    Структура:
//        * Протокол            - Строка - протокол доступа к ресурсу.
//        * ИмяСервера          - Строка - сервер, на котором располагается ресурс.
//        * ПутьКФайлуНаСервере - Строка - путь к ресурсу на сервере.
//
Функция РазделитьURL(Знач URL) Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеФайловИзИнтернетаКлиентСервер.РазделитьURL(URL) 
```
</details>

## СтруктураURI
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ОбщегоНазначенияКлиентСервер.СтруктураURI.
// Разбирает строку URI на составные части и возвращает в виде структуры.
// На основе RFC 3986.
//
// Параметры:
//     СтрокаURI - Строка - ссылка на ресурс в формате:
//                          <схема>://<логин>:<пароль>@<хост>:<порт>/<путь>?<параметры>#<якорь>.
//
// Возвращаемое значение:
//    Структура - составные части URI согласно формату:
//        * Схема         - Строка - схема URI.
//        * Логин         - Строка - имя пользователя.
//        * Пароль        - Строка - пароль пользователя.
//        * ИмяСервера    - Строка - часть <хост>:<порт> входного параметра.
//        * Хост          - Строка - имя сервера.
//        * Порт          - Строка - порт сервера.
//        * ПутьНаСервере - Строка - часть <путь>?<параметры>#<якорь> входного параметра.
//
Функция СтруктураURI(Знач СтрокаURI) Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеФайловИзИнтернетаКлиентСервер.СтруктураURI(СтрокаURI) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
