---
title: Поставляемые данные
slug: bsp/поставляемые-данные
---


## ДескрипторыПоставляемыхДанныхИзМенеджера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить дескрипторы данных по заданным условиям.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ВидДанных - Строка - имя вида поставляемых данных.
//  Фильтр - Массив - элементы должны содержать поля Код (строка) и Значение (строка).
//
// Возвращаемое значение:
//    ОбъектXDTO - типа ArrayOfDescriptor.
//
Функция ДескрипторыПоставляемыхДанныхИзМенеджера(Знач ВидДанных, Знач Фильтр = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ДескрипторыПоставляемыхДанныхИзМенеджера(ВидДанных, Фильтр);
```
</details>

## ЗагрузитьИОбработатьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициирует обработку данных.
//
// Может использоваться в связке с ДескрипторыПоставляемыхДанныхИзМенеджера для
// ручной инициации процесса обработки данных. После вызова метода система поведет
// себя так, как будто она только что получила уведомление о доступности новых данных,
// с указанным дескриптором - будет вызван ДоступныНовыеДанные, а затем, при необходимости,
// ОбработатьНовыеДанные для соответствующих обработчиков.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Descriptor.
//
Процедура ЗагрузитьИОбработатьДанные(Знач Дескриптор) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.ЗагрузитьИОбработатьДанные(Дескриптор) 
```
</details>

## СохранитьПоставляемыеДанныеВКэш
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные в справочник ПоставляемыеДанные.
//
// Данные сохраняются либо в том на диске, либо в поле таблицы ПоставляемыеДанные в
// зависимости от константы ХранитьФайлыВТомахНаДиске и наличия свободных томов. Данные
// могут быть позднее извлечены при помощи поиска по реквизитам, либо путем указания
// уникального идентификатора, который передавался в поле Дескриптор.FileGUID. Если в базе
// уже есть данные с тем же видом данных и набором ключевых характеристик - новые данные
// замещают старые. При это используется обновление существующего элемента справочника, а
// не удаление и создание нового.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Descriptor или структура с полями.
//	 	"ВидДанных, ДатаДобавления, ИдентификаторФайла, Характеристики",
//    	где Характеристики - массив структур с полями "Код, Значение, Ключевая".
//   ПутьКФайлу - Строка - полное имя извлеченного файла.
//
Процедура СохранитьПоставляемыеДанныеВКэш(Знач Дескриптор, Знач ПутьКФайлу) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.СохранитьПоставляемыеДанныеВКэш(Дескриптор, ПутьКФайлу) 
```
</details>

## УдалитьПоставляемыеДанныеИзКэша
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет файл из кэша.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  СсылкаИлиИдентификатор - СправочникСсылка.ПоставляемыеДанные - ссылка на поставляемые данные,
//                         - УникальныйИдентификатор - уникальный идентификатор.
//
Процедура УдалитьПоставляемыеДанныеИзКэша(Знач СсылкаИлиИдентификатор) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.УдалитьПоставляемыеДанныеИзКэша(СсылкаИлиИдентификатор) 
```
</details>

## ДескрипторПоставляемыхДанныхИзКэша
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает дескриптор данных из кэша.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  СсылкаИлиИдентификатор - СправочникСсылка.ПоставляемыеДанные - ссылка на поставляемые данные,
//                         - УникальныйИдентификатор - уникальный идентификатор,
//  ВВидеXDTO - Булево - в каком виде возвращать значения.
//
// Возвращаемое значение:
//    ОбъектXDTO - типа ArrayOfDescriptor.
//
Функция ДескрипторПоставляемыхДанныхИзКэша(Знач СсылкаИлиИдентификатор, Знач ВВидеXDTO = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ДескрипторПоставляемыхДанныхИзКэша(СсылкаИлиИдентификатор, ВВидеXDTO);
```
</details>

## ПоставляемыеДанныеИзКэша
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает двоичные данные присоединенного файла.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  СсылкаИлиИдентификатор - СправочникСсылка.ПоставляемыеДанные - ссылка на поставляемые данные,
//                         - УникальныйИдентификатор - уникальный идентификатор.
//
// Возвращаемое значение:
//  ДвоичныеДанные - двоичные данные поставляемых данных.
//
Функция ПоставляемыеДанныеИзКэша(Знач СсылкаИлиИдентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ПоставляемыеДанныеИзКэша(СсылкаИлиИдентификатор) 
```
</details>

## ЕстьВКеше
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие данных с указанными ключевыми характеристиками в кэше.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Descriptor.
//
// Возвращаемое значение:
//  Булево - наличие дескриптора в кэше.
//
Функция ЕстьВКеше(Знач Дескриптор) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ЕстьВКеше(Дескриптор) 
```
</details>

## СсылкиПоставляемыхДанныхИзКэша
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив ссылок на данные, удовлетворяющие заданным условиям.
//
// Параметры:
//  ВидДанных - Строка - имя вида поставляемых данных.
//  Фильтр - Массив - элементы должны содержать поля Код (строка) и Значение (строка).
//
// Возвращаемое значение:
//    Массив из ЛюбаяСсылка - массив ссылок на данные.
//
Функция СсылкиПоставляемыхДанныхИзКэша(Знач ВидДанных, Знач Фильтр = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.СсылкиПоставляемыхДанныхИзКэша(ВидДанных, Фильтр);
```
</details>

## ДескрипторыПоставляемыхДанныхИзКэша
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные по заданным условиям.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ВидДанных - Строка - имя вида поставляемых данных.
//  Фильтр - Массив - элементы должны содержать поля Код (строка) и Значение (строка).
//  ВВидеXDTO - Булево - в каком виде возвращать значения.
//
// Возвращаемое значение:
//    ОбъектXDTO - типа ArrayOfDescriptor или
//    Массив структур с полями "ВидДанных, ДатаДобавления, ИдентификаторФайла, Характеристики",
//    где Характеристики - массив структур с полями "Код, Значение, Ключевая".
//	  Для получения самого файла необходимо вызвать ПолучитьПоставляемыеДанныеИзКэша.
//
//
Функция ДескрипторыПоставляемыхДанныхИзКэша(Знач ВидДанных, Знач Фильтр = Неопределено, Знач ВВидеXDTO = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ДескрипторыПоставляемыхДанныхИзКэша(ВидДанных, Фильтр, ВВидеXDTO);
```
</details>

## ПолучитьОписаниеДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пользовательское представление дескриптора поставляемых данных.
// Может быть использовано при выводе сообщений в журнал регистрации.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  Дескриптор - ОбъектXDTO - типа Descriptor или  структура с полями.
//	 	"ВидДанных, ДатаДобавления, ИдентификаторФайла, Характеристики",
//    	где Характеристики - массив структур с полями "Код, Значение".
//	ДескрипторJSON - Булево - признак того, что дескриптор в формате JSON
//
// Возвращаемое значение:
//  Строка - пользовательское представление дескриптора.
//
Функция ПолучитьОписаниеДанных(Знач Дескриптор, Знач ДескрипторJSON = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ПолучитьОписаниеДанных(Дескриптор, ДескрипторJSON);
```
</details>

## ПолучитьОбработчики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает зарегистрированные обработчики поставляемых данных.
// Используется для запуска процедур проверки и загрузки новых поставляемых данных. Так же может
// быть использована для получения списка поддерживаемых видов поставляемых данных.
//
// Возвращаемое значение:
//	ТаблицаЗначений - таблица с колонками:
//		* ВидДанных - Строка - код вида данных, обрабатываемый обработчиком.
//		* КодОбработчика - Строка - используется при восстановлении обработки данных после сбоя.
//		* Обработчик - ОбщийМодуль - модуль, содержащий следующие экспортные процедуры:
//			ДоступныНовыеДанные(Дескриптор, Загружать)
//			ОбработатьНовыеДанные(Дескриптор, ПутьКФайлу)
//			ОбработкаДанныхОтменена(Дескриптор)
//
Функция ПолучитьОбработчики() Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ПолучитьОбработчики() 
```
</details>

## ОбластиТребующиеОбработки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

///////////////////////////////////////////////////////////////////////////////////
// Обновление информации в областях данных.

// Возвращает список областей данных, в которые еще не были скопированы поставляемые данные.
// @skip-warning ПустойМетод - особенность реализации.
//
// В случае первого вызова функции возвращается полный набор доступных областей.
// При последующем вызове, при восстановлении после сбоя, будут возвращены только
// необработанные области. После копирования данных в область следует вызвать ОбластьОбработана.
//
// Параметры:
//  ИдентификаторФайла - УникальныйИдентификатор - идентификатор файла поставляемых данных,
//  КодОбработчика - Строка - код обработчика,
//  ВключаяНеразделенную - Булево - если Истина, ко всем имеющимся областям добавится область с кодом -1.
//
// Возвращаемое значение:
//  Массив из Число - области требующие обработки.
//
Функция ОбластиТребующиеОбработки(Знач ИдентификаторФайла, Знач КодОбработчика, Знач ВключаяНеразделенную = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПоставляемыеДанные.ОбластиТребующиеОбработки(ИдентификаторФайла, КодОбработчика, ВключаяНеразделенную);
```
</details>

## ОбластьОбработана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет область из списка необработанных. Выключает разделение сеанса (если оно было включено),
// поскольку при включенном разделении запись в неразделенный регистр запрещена.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторФайла - УникальныйИдентификатор - файла поставляемых данных,
//  КодОбработчика - Строка - код обработчика,
//  ОбластьДанных - Число - идентификатор обработанной области.
//
Процедура ОбластьОбработана(Знач ИдентификаторФайла, Знач КодОбработчика, Знач ОбластьДанных) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.ОбластьОбработана(ИдентификаторФайла, КодОбработчика, ОбластьДанных) 
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Обработчики событий подсистем конфигурации.

// См. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков.
// @skip-warning ПустойМетод - особенность реализации.
//
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

## ПриОпределенииОбработчиковКаналовСообщений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбменСообщениямиПереопределяемый.ПолучитьОбработчикиКаналовСообщений.
// @skip-warning ПустойМетод - особенность реализации.
//
Процедура ПриОпределенииОбработчиковКаналовСообщений(Обработчики) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.ПриОпределенииОбработчиковКаналовСообщений(Обработчики) 
```
</details>

## ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки.
//
// Параметры:
// 	Типы - См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки.Типы
//
Процедура ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки(Типы) Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки(Типы) 
```
</details>

## ЗапроситьВсеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ПоставляемыеДанные.ЗапроситьДанные
// Инициировать уведомление о всех имеющихся в МС поставляемых данных (за исключением тех,
// у которых стоит пометка "Запрет уведомления".
// @skip-warning ПустойМетод - особенность реализации.
//
Процедура ЗапроситьВсеДанные() Экспорт
```

Пример вызова
```bsl
ПоставляемыеДанные.ЗапроситьВсеДанные() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
