---
title: Проверка и корректировка данных
slug: bsp/проверка-и-корректировка-данных
---


## Проверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу модулей проверки.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   ВосстанавливатьНастройки - Булево - требуется или нет восстанавливать сохраненные настройки обработок.
//   ПолучатьПрошлыйРезультат - Булево - требуется или нет получать сохраненный результат.
//
// Возвращаемое значение:
//   ТаблицаЗначений - таблица с колонками:
//     * Идентификатор - УникальныйИдентификатор - идентификатор проверки.
//     * Пометка - Булево - для выбора проверки значение этого поля должно быть Истина.
//     * Имя - Строка - имя модуля.
//     * Наименование - Строка - краткое наименование проверки для пользователя.
//     * Описание - Строка - описание проверки для пользователя.
//     * ФормаНастроек - Строка - имя формы настроек, описание:
//          см. ПроверкаИКорректировкаДанныхПереопределяемый.ПриЗаполненииПроверок.
//     * Настройки - Структура - структура, содержащая любой сериализуемый тип, описание:
//       ** Поля - Произвольный - произвольный набор полей.
//          см. ПроверкаИКорректировкаДанныхПереопределяемый.ПриЗаполненииПроверок.
//     * ВременныеДанные - Структура - структура, содержащая любой сериализуемый тип, описание:
//       ** Поля - Произвольный - произвольный набор полей.
//          см. ПроверкаИКорректировкаДанныхПереопределяемый.ПриЗаполненииПроверок.
//     * ТребуетсяЗаполнитьНастройки - Булево - в строках, где требуется заполнить настройки,
//          значение этого поля будет Истина.
//     * Дата - Дата - дата последней проверки.
//     * Исправлять - Булево - флаг последней проверки.
//     * ОбнаруженыПроблемы - Булево - результат последней проверки.
//     * ПредставлениеРезультата - Строка - результат последней проверки.
//     * ТабличныйДокумент - Произвольный - файл с результатом последней проверки.
//
Функция Проверки(ВосстанавливатьНастройки = Ложь, Знач ПолучатьПрошлыйРезультат = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИКорректировкаДанных.Проверки(ВосстанавливатьНастройки, ПолучатьПрошлыйРезультат);
```
</details>

## ПроверитьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск проблем для выбранных строк и заполняет колонку Результат.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   Проверки - ТаблицаЗначений - таблица полученная с помощью функции Проверки().
//   Исправлять - Булево - Истина, если требуется исправление.
//   СохранятьРезультат - Булево - если Истина, тогда результат будет сохранен в присоединенный файл.
//
// Возвращаемое значение:
//   Булево - Истина - проверка выполнена, Ложь - требуется заполнить настройки.
//
Функция ПроверитьДанные(Проверки, Исправлять = Ложь, СохранятьРезультат = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИКорректировкаДанных.ПроверитьДанные(Проверки, Исправлять, СохранятьРезультат);
```
</details>

## ТабличныйДокументИзПрисоединенногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет извлечение табличного документа из zip-архива присоединенного файла.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   ПрисоединенныйФайл - СправочникСсылка.ИсторияПроверкиИКорректировкиДанныхПрисоединенныеФайлы - файл из которого
//      требуется извлечь табличный документ.
//
// Возвращаемое значение:
//   ТабличныйДокумент - табличный документ извлеченный из архива. Если табличный документ не
//      найден, то будет вызвано исключение.
//
Функция ТабличныйДокументИзПрисоединенногоФайла(ПрисоединенныйФайл) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИКорректировкаДанных.ТабличныйДокументИзПрисоединенногоФайла(ПрисоединенныйФайл) 
```
</details>

## ВнедренаБСП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак внедрения БСП.
// @skip-warning ПустойМетод - особенность реализации.
//
// Возвращаемое значение:
//   Булево - Истина - внедрена, Ложь - нет.
//
Функция ВнедренаБСП() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИКорректировкаДанных.ВнедренаБСП() 
```
</details>

## Модуль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает модуль по имени.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//   Имя - Строка - имя общего модуля.
//
// Возвращаемое значение:
//   ОбщийМодуль - ОбщийМодуль.
//
Функция Модуль(Имя) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИКорректировкаДанных.Модуль(Имя) 
```
</details>

## ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки.
//
// Параметры:
// 	Типы - См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки.Типы
//
Процедура ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки(Типы) Экспорт
```

Пример вызова
```bsl
ПроверкаИКорректировкаДанных.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки(Типы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
