---
title: Программный интерфейс сервиса
slug: bsp/программный-интерфейс-сервиса
---


## СвойстваВерсииИнтерфейса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства версии программного интерфейса менеджера сервиса.
//
// Возвращаемое значение:
//  Структура - свойства версии внешнего программного интерфейса:
//   * Версия - Число - номер версии внешнего программного интерфейса.
//   * ВерсияМенеджераСервиса - Строка - номер версии менеджера сервиса.
//   * ЧасовойПоясМенеджераСервиса - Строка - часовой пояс менеджера сервиса.
//
Функция СвойстваВерсииИнтерфейса() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваВерсииИнтерфейса() 
```
</details>

## ДействующийТокенДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает действующий токен доступа пользователя.
//
// Параметры:
//  Пользователь - СправочникСсылка.Пользователи - если не указан, используется текущий пользователь.
//  ВызыватьИсключениеПриОшибке - Булево - по умолчанию = Истина
//  СвойстваОтвета - Структура - возвращаемый параметр:
//   * Ошибка - Булево - ошибка при получении токена
//   * Сообщение - Строка - сообщение об ошибке.
//
// Возвращаемое значение:
//  Строка - токен доступа.
//
Функция ДействующийТокенДоступа(Пользователь = Неопределено, ВызыватьИсключениеПриОшибке = Истина, СвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ДействующийТокенДоступа(Пользователь, ВызыватьИсключениеПриОшибке, СвойстваОтвета);
```
</details>

## НовыйТокенДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает новый токен доступа пользователя.
//
// Параметры:
//  Пользователь - СправочникСсылка.Пользователи - если не указан, используется текущий пользователь.
//  ВызыватьИсключениеПриОшибке - Булево
//
// Возвращаемое значение:
//  Структура - данные нового токена доступа:
//   * ТокенДоступа - Строка - если токен получен успешно
//                  - Неопределено - если при получении токена произошла ошибка
//   * ВремяЖизни - Дата - время жизни токена доступа
//   * Ошибка - Булево - ошибка при получении токена
//   * Сообщение - Строка - сообщение об ошибке
Функция НовыйТокенДоступа(Пользователь = Неопределено, ВызыватьИсключениеПриОшибке = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйТокенДоступа(Пользователь, ВызыватьИсключениеПриОшибке);
```
</details>

## Абоненты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список абонентов текущего пользователя.
//
// Возвращаемое значение:
//  ТаблицаЗначений - список абонентов:
//    * Наименование - Строка - наименование абонента
//    * Код - Число - код абонента
//    * РольПользователя - ПеречислениеСсылка.РолиПользователейАбонентов - роль текущего пользователя абонента.
//
Функция Абоненты() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.Абоненты() 
```
</details>

## ДополнительныеСведенияАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дополнительные сведения (реквизиты и свойства) абонента этого приложения.
// Реализует метод внешнего программного интерфейса - account/attached_info.
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - дополнительные реквизиты и свойства абонента:
//   * ПубличныйИдентификатор - Строка - публичный идентификатор абонента
//   * Реквизиты - ТаблицаЗначений - дополнительные реквизиты абонента:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//   * Свойства - ТаблицаЗначений - дополнительные свойства абонента:
//     ** Ключ - Строка - имя дополнительного свойства
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного свойства
//
Функция ДополнительныеСведенияАбонента(ВызыватьИсключениеПриОшибке = Истина, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ДополнительныеСведенияАбонента(ВызыватьИсключениеПриОшибке, );
```
</details>

## ОбновитьДопСведенияАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет дополнительные сведения (реквизиты и свойства) абонента.
// Реализует метод внешнего программного интерфейса - account/update_attached_info.
//
// Параметры:
//  ДопСведения - см. НовыйДопСведенияАбонента
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - установка доп. сведений: Истина - установлено, Ложь - произошла ошибка.
//
Функция ОбновитьДопСведенияАбонента(ДопСведения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ОбновитьДопСведенияАбонента(ДопСведения, );
```
</details>

## ОбязательныеСведенияДляОформленияПодписки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дополнительные сведения (реквизиты и свойства) указанного абонента,
// необходимые для оформления платной подписки.
// Реализует метод внешнего программного интерфейса - account/attached_info_for_subscribing
//
// Параметры:
//  КодАбонента - Число - код абонента, для которого нужно получить доп. сведения.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - дополнительные реквизиты и свойства абонента:
//   * ЕстьОшибки - Булево - признак наличия ошибок заполнения.
//   * Реквизиты - ТаблицаЗначений - дополнительные реквизиты абонента:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Заголовок - Строка - заголовок дополнительного реквизита
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//     ** ЗаполнятьОбязательно - Булево - признак обяз
//     ** Подсказка - Строка - подсказка заполнения
//     ** Ошибка - Булево - признак ошибки заполнения
//     ** Сообщение - Строка - сообщение об ошибке.
//   * Свойства - ТаблицаЗначений - дополнительные свойства абонента:
//     ** Ключ - Строка - имя дополнительного свойства
//     ** Заголовок - Строка - заголовок дополнительного реквизита
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного свойства
//     ** ЗаполнятьОбязательно - Булево - признак обяз
//     ** Подсказка - Строка - подсказка заполнения
//     ** Ошибка - Булево - признак ошибки заполнения
//     ** Сообщение - Строка - сообщение об ошибке.
//
Функция ОбязательныеСведенияДляОформленияПодписки(КодАбонента, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ОбязательныеСведенияДляОформленияПодписки(КодАбонента, );
```
</details>

## ЗначенияДополнительногоСведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значения дополнительного сведения.
//
// Параметры:
//  ИмяСведения - Строка - имя сведения, для которого нужно получить значения.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - значения дополнительного сведения:
//   * Наименование - Строка - длина 100
//   * Вес - Число - точность 10,2
Функция ЗначенияДополнительногоСведения(ИмяСведения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ЗначенияДополнительногоСведения(ИмяСведения, );
```
</details>

## ПользователиАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список пользователей абонента этого приложения.
// Реализует метод внешнего программного интерфейса - account/users/list.
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
//  Возвращаемое значение:
//  ТаблицаЗначений - пользователи абонента:
//   * Логин - Строка - логин (имя) пользователя
//   * ПолноеИмя - Строка - полное имя пользователя
//   * Почта - Строка - электронная почта пользователя
//   * РольПользователя - ПеречислениеСсылка.РолиПользователейАбонентов - роль пользователя
//   * РазрешенноеКоличествоСеансов - Число - разрешенное количество сеансов
//   * ВременныйДоступ - Булево - временный доступ
//
Функция ПользователиАбонента(ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПользователиАбонента(ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## СвойстваПользователяАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства пользователя абонента по логину.
// Реализует метод внешнего программного интерфейса - account/users/info.
// Параметры:
//  Логин - Строка - Логин (Имя) пользователя.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - свойства пользователя абонента:
//   * Логин - Строка - логин (имя) пользователя
//   * ПолноеИмя - Строка - полное имя пользователя
//   * Почта - Строка - электронная почта пользователя
//   * РольПользователя - ПеречислениеСсылка.РолиПользователейАбонентов - роли пользователя
//   * РазрешенноеКоличествоСеансов - Число - разрешенное количество сеансов
//   * ВременныйДоступ - Булево - временный доступ
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты пользователя абонента:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
Функция СвойстваПользователяАбонента(Логин, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваПользователяАбонента(Логин, );
```
</details>

## СоздатьПользователяАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую учетную запись пользователя сервиса и подключает созданного пользователя к абоненту этого приложения.
//
// Параметры:
//  ПараметрыСоздания - см. НовыйПараметрыСозданияПользователя
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - признак добавления пользователя Истина - пользователь добавлен, Ложь - произошла ошибка.
//
Функция СоздатьПользователяАбонента(ПараметрыСоздания, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьПользователяАбонента(ПараметрыСоздания, );
```
</details>

## ДобавитьПользователяАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет существующего пользователя сервиса к абоненту этого приложения.
//
// Параметры:
//  ПараметрыДобавления - см. НовыйПараметрыДобавленияПользователя
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - признак создания учетной записи Истина - создана, Ложь - произошла ошибка.
//
Функция ДобавитьПользователяАбонента(ПараметрыДобавления, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ДобавитьПользователяАбонента(ПараметрыДобавления, );
```
</details>

## УстановитьРольПользователяАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает указанному пользователю абонента этого приложения указанную роль.
// Реализует метод внешнего программного интерфейса - account/users/set_role.
//
// Параметры:
//  Логин - Строка - логин (имя) пользователя.
//  Роль - ПеречислениеСсылка.РолиПользователейАбонентов - устанавливаемая роль пользователя.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - установки роли Истина - установлено, Ложь - произошла ошибка.
//
Функция УстановитьРольПользователяАбонента(Логин, Роль, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.УстановитьРольПользователяАбонента(Логин, Роль, );
```
</details>

## ОбновитьДопРеквизитыПользователяАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет дополнительные реквизиты пользователя абонента
// Реализует метод внешнего программного интерфейса - account/users/update_attached_info.
//
// Параметры:
//  Логин - Строка - логин (имя) пользователя.
//  ДопРеквизиты - ТаблицаЗначений - дополнительные реквизиты пользователя абонента:
//     * Ключ - Строка - имя дополнительного реквизита
//     * Тип - Строка - тип значения
//     * Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - установка доп. реквизитов: Истина - установлено, Ложь - произошла ошибка.
Функция ОбновитьДопРеквизитыПользователяАбонента(Логин, ДопРеквизиты, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ОбновитьДопРеквизитыПользователяАбонента(Логин, ДопРеквизиты, );
```
</details>

## НовыйПараметрыСозданияПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров создания пользователя для метода ПрограммныйИнтерфейсСервиса.СоздатьПользователяАбонента.
//
// Возвращаемое значение:
//  Структура - шаблон параметров создания пользователя:
//	 * Логин - Строка - логин (имя пользователя)
//	 * Пароль - Строка - пароль пользователя
//   * ПочтаОбязательна - Булево - признак обязательной установки почты (по умолчанию = Истина)
//   * Почта - Строка - электронная почта
//   * РольПользователя - ПеречислениеСсылка.РолиПользователейАбонентов - роль (по умолчанию = ПользовательАбонента)
//   * ПолноеИмя - Строка - полное имя (наименование) пользователя
//   * Телефон - Строка - телефон пользователя
//   * ЧасовойПояс - Строка - рабочий часовой пояс пользователя
//   * Описание - Строка - описание пользователя
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты пользователя абонента:
//     ** Ключ - Строка - имя реквизита
//     ** Тип - Строка - тип реквизита.
//              Простые: string, decimal, date, boolean
//              Ссылочные: user, subscriber, tariff, service_provider_tariff, tariff_period,
//                         subscription, service, additional_value, additional_value_group.
//     ** Значение - Строка, Число, Дата, Булево - значение реквизита.
//
Функция НовыйПараметрыСозданияПользователя() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыСозданияПользователя() 
```
</details>

## НовыйПараметрыДобавленияПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров добавления существующего пользователя для метода ПрограммныйИнтерфейсСервиса.СоздатьПользователяАбонента.
//
// Возвращаемое значение:
//  Структура - шаблон параметров создания пользователя:
//	 * Логин - Строка - логин (имя пользователя)
//   * РольПользователя - ПеречислениеСсылка.РолиПользователейАбонентов - роль (по умолчанию = ПользовательАбонента)
//   * Описание - Строка - описание пользователя
//   * Принудительно - Булево - выполнить даже при наличии предупреждений
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты пользователя абонента:
//     ** Ключ - Строка - имя реквизита
//     ** Тип - Строка - тип реквизита.
//              Простые: string, decimal, date, boolean
//              Ссылочные: user, subscriber, tariff, service_provider_tariff, tariff_period,
//                         subscription, service, additional_value, additional_value_group.
//     ** Значение - Строка, Число, Дата, Булево - значение реквизита.
//
Функция НовыйПараметрыДобавленияПользователя() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыДобавленияПользователя() 
```
</details>

## ОбслуживающиеОрганизацииАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список обслуживающих организаций абонента этого приложения.
// Реализует метод внешнего программного интерфейса - account/servants/list
//
// Возвращаемое значение:
//  ТаблицаЗначений - обслуживающие организации абонента:
//   * Код - Число - код (номер) обслуживающей организации
//   * Наименование - Строка - наименование обслуживающей организации
//   * Идентификатор - Строка - идентификатор абонента
//   * Город - Строка - город
//   * Сайт - Строка - сайт
//   * Почта - Строка - электронная почта
//   * Телефон - Строка - телефон
//   * РазрешеноПодписыватьНаТарифы - Булево - разрешено подписывать на тарифы
//   * РазрешеноАвтоматическоеВыставлениеСчетов - Булево - разрешено автоматическое выставление счетов
//   * РазрешеноПереопределениеТарифов - Булево - разрешено переопределение тарифов
//   * ТолькоСтраницаВыбораТарифа - Булево - отображать только страницу выбора тарифа в форме оплаты
//
Функция ОбслуживающиеОрганизацииАбонента() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ОбслуживающиеОрганизацииАбонента() 
```
</details>

## СтраницаВыбораТарифаОбслуживающейОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает HTML-страницу выбора тарифа обслуживающей организации абонента этого приложения.
// Реализует метод внешнего программного интерфейса -  account/servants/tariff_selection_page
// Параметры:
//  КодОО - Число - код обслуживающей организации.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Строка - HTML-страница выбора тарифа обслуживающей организации.
//
Функция СтраницаВыбораТарифаОбслуживающейОрганизации(КодОО, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СтраницаВыбораТарифаОбслуживающейОрганизации(КодОО, );
```
</details>

## РекомендуемыеТарифы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список рекомендуемых тарифов, определенных обслуживающей организацией.
// Реализует метод внешнего программного интерфейса - account/servants/recommended_tariffs
//
// Параметры:
//  КодОО - Число - код обслуживающей организации.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - список тарифов:
//   * КодТарифаПровайдера - Строка - код тарифа провайдера
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации.
Функция РекомендуемыеТарифы(КодОО, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.РекомендуемыеТарифы(КодОО, );
```
</details>

## ТарифыОбслуживающейОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список тарифов обслуживающей организации.
// Реализует метод внешнего программного интерфейса - account/servant_tariffs/list
//
// Параметры:
//  Отбор - см. НовыйОтборСпискаТарифовОбслуживающейОрганизации
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - список тарифов:
//   * Код - Строка - код тарифа
//   * Наименование - Строка - наименование тарифа
//   * КодТарифаПровайдера - Строка - код базового тарифа
//   * КраткоеОписание - Строка - краткое описание тарифа
//   * ПериодыДействия - ТаблицаЗначений - периоды действия. Заполняется если передан параметр получения ПараметрПолученияПериодыДействия:
//     ** Код - Строка - код периода действия
//     ** Наименование - Строка - наименование периода действия
//     ** Сумма - Число - стоимость тарифа с этим периодом действия
//     ** Рекомендуемый - Булево - признак, что период действия является рекомендуемым
//     ** Комментарий - Строка - комментарий к периоду действия.
//
Функция ТарифыОбслуживающейОрганизации(Отбор, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ТарифыОбслуживающейОрганизации(Отбор, );
```
</details>

## ТарифОбслуживающейОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о тарифе обслуживающей организаций.
//
// Параметры:
//  КодОО - Число - код обслуживающей организации.
//  КодТарифа - Строка - код тарифа обслуживающей организации.
//
// Возвращаемое значение:
//  Структура - информация о тарифе:
//   * Код - Строка - код тарифа
//   * Наименование - Строка - наименование тарифа
//   * КодТарифаПровайдера - Строка - код тарифа провайдера
//   * КраткоеОписание - Строка - краткое описание тарифа
//   * ОписаниеДляАбонентов - ФорматированныйДокумент - описание тарифа для абонентов.
//   * ПериодыДействия - ТаблицаЗначений - периоды действия тарифа:
//     ** Код - Строка - код периода действия
//     ** Наименование - Строка - наименование периода действия
//     ** Сумма - Число - стоимость
//     ** Рекомендуемый - Булево - признак того, что период является рекомендуемым к покупке
//     ** Комментарий - Строка - комментарий к периоду действия
//
Функция ТарифОбслуживающейОрганизации(КодОО, КодТарифа) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ТарифОбслуживающейОрганизации(КодОО, КодТарифа) 
```
</details>

## ОбслуживаемыеАбоненты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список обслуживаемых абонентов.
// Реализует метод внешнего программного интерфейса - account/customers/list
//
// Параметры:
//  КодОО - Число - код (номер) ведущего абонента (если не указан, используется абонент текущего приложения).
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//   * Наименование - Строка - наименование абонента (длина - 64)
//   * Код - Строка - код (номер) обслуживаемого абонента (длина - 12).
Функция ОбслуживаемыеАбоненты(КодОО = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ОбслуживаемыеАбоненты(КодОО, );
```
</details>

## СвойстваОбслуживаемогоАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства обслуживаемого абонента.
// Реализует метод внешнего программного интерфейса - account/customers/info
//
// Параметры:
//  КодАбонента - Число - код (номер) обслуживаемого абонента.
//  КодОО - Число - код (номер) ведущего абонента (если не указан, используется абонент текущего приложения).
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура:
//   * Наименование - Строка - наименование абонента (длина - 64)
//   * Код - Строка - код (номер) обслуживаемого абонента (длина - 12)
//   * Сайт - Строка - сайт из КИ (длина - 500)
//   * Город - Строка - город из КИ (длина - 500)
//   * Почта - Строка - почта из КИ (длина - 500)
//   * Телефон - Строка - телефон из КИ (длина - 500)
//
Функция СвойстваОбслуживаемогоАбонента(КодАбонента, КодОО = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваОбслуживаемогоАбонента(КодАбонента, КодОО, );
```
</details>

## ДопСведенияОбслуживаемогоАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дополнительные сведения (реквизиты и свойства) обслуживаемого абонента.
// Реализует метод внешнего программного интерфейса - account/customers/attached_info
//
// Параметры:
//  КодАбонента - Число - код (номер) обслуживаемого абонента.
//  КодОО - Число - код (номер) ведущего абонента (если не указан, используется абонент текущего приложения).
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - дополнительные реквизиты и свойства абонента:
//   * ПубличныйИдентификатор - Строка - публичный идентификатор абонента
//   * Реквизиты - ТаблицаЗначений - дополнительные реквизиты абонента:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//   * Свойства - ТаблицаЗначений - дополнительные свойства абонента:
//     ** Ключ - Строка - имя дополнительного свойства
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного свойства
Функция ДопСведенияОбслуживаемогоАбонента(КодАбонента, КодОО = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ДопСведенияОбслуживаемогоАбонента(КодАбонента, КодОО, );
```
</details>

## ОбновитьДопСведенияОбслуживаемогоАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет дополнительные сведения (реквизиты и свойства) обслуживаемого абонента.
// Реализует метод внешнего программного интерфейса - account/customers/update_attached_info.
//
// Параметры:
//  ДопСведения - см. НовыйДопСведенияАбонента
//  КодОО - Число - код (номер) ведущего абонента (если не указан, используется абонент текущего приложения).
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - установка доп. сведений: Истина - установлено, Ложь - произошла ошибка.
//
Функция ОбновитьДопСведенияОбслуживаемогоАбонента(ДопСведения, КодОО = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ОбновитьДопСведенияОбслуживаемогоАбонента(ДопСведения, КодОО, );
```
</details>

## НовыйДопСведенияАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон дополнительных сведений абонента.
//
// Возвращаемое значение:
//  Структура:
//   * КодАбонента - Число - код абонента
//   * ПубличныйИдентификатор - Строка - публичный идентификатор абонента (длина - 36), может отсутствовать.
//   * Реквизиты - ТаблицаЗначений - дополнительные реквизиты абонента:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения (не обязательно, если у доп. реквизита один тип значения)
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//   * Свойства - ТаблицаЗначений - дополнительные свойства абонента:
//     ** Ключ - Строка - имя дополнительного свойства
//     ** Тип - Строка - тип значения (не обязательно, если у доп. свойства один тип значения)
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного свойства
//
Функция НовыйДопСведенияАбонента() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйДопСведенияАбонента() 
```
</details>

## ПодпискиНаТарифы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список подписок на тарифы обслуживаемых абонентов.
// Реализует метод внешнего программного интерфейса - account/customer_subscriptions/list
//
// Параметры:
//  Отбор - см. НовыйОтборПодписокНаТарифы
//  КодОО - Число - код (номер) ведущего абонента (если не указан, используется абонент текущего приложения).
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - существующие подписки на тарифы:
//   * Номер - Строка - номер подписки
//   * Дата - Дата - дата регистрации подписки
//   * ДатаПодключения - Дата - дата подключения тарифа по подписке
//   * ДатаОтключения - Дата - дата отключения тарифа
//   * КодОбслуживаемогоАбонента - Число - код (номер) обслуживаемого абонента
//   * КодВедущегоАбонента - Число - код (номер) ведущего абонента
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//   * КодТарифаПровайдера - Строка - код тарифа в подписке
//   * КодПериодаДействия - Строка - код периода действия
//   * Количество - Число - количество тарифов в подписке
//   * НомерОсновнойПодписки - Строка - номер основной подписки, если текущая подписка на тариф-расширение.
//   * ТипПодписки - ПеречислениеСсылка.ТипыПодписокСервиса - тип подписки
//   * НомерСчетаНаОплату - Строка - номер счета на оплату
//   * ИдентификаторСчетаНаОплату - УникальныйИдентификатор - идентификатор счета на оплату
//
Функция ПодпискиНаТарифы(Отбор, КодОО = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПодпискиНаТарифы(Отбор, КодОО, );
```
</details>

## СвойстваПодпискиНаТариф
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства подписки на тариф обслуживаемого абонента.
// Реализует метод внешнего программного интерфейса - account/customer_subscriptions/info
//
// Параметры:
//  НомерПодписки - Строка - номер подписки.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - свойства подписки на тариф:
//   * Номер - Строка - номер подписки
//   * Дата - Дата - дата регистрации подписки
//   * ДатаПодключения - Дата - дата подключения тарифа по подписке
//   * ДатаОтключения - Дата - дата отключения тарифа
//   * КодОбслуживаемогоАбонента - Число - код (номер) обслуживаемого абонента
//   * КодВедущегоАбонента - Число - код (номер) ведущего абонента
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//   * КодТарифаПровайдера - Строка - код тарифа в подписке
//   * КодПериодаДействия - Строка - код периода действия
//   * Количество - Число - количество тарифов в подписке
//   * НомерОсновнойПодписки - Строка - номер основной подписки, если текущая подписка на тариф-расширение.
//   * ТипПодписки - ПеречислениеСсылка.ТипыПодписокСервиса - тип подписки
//   * НомерСчетаНаОплату - Строка - номер счета на оплату
//   * ИдентификаторСчетаНаОплату - УникальныйИдентификатор - идентификатор счета на оплату
Функция СвойстваПодпискиНаТариф(НомерПодписки, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваПодпискиНаТариф(НомерПодписки, );
```
</details>

## СвойстваПодпискиНаТарифАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства подписки на тариф абонента.
// Реализует метод внешнего программного интерфейса - subscription/info
//
// Параметры:
//  НомерПодписки - Строка - номер подписки.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - свойства подписки на тариф:
//   * Номер - Строка - номер подписки
//   * Дата - Дата - дата регистрации подписки
//   * ДатаПодключения - Дата - дата подключения тарифа по подписке
//   * ДатаОтключения - Дата - дата отключения тарифа
//   * КодОбслуживаемогоАбонента - Число - код (номер) обслуживаемого абонента
//   * КодВедущегоАбонента - Число - код (номер) ведущего абонента
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//   * КодТарифаПровайдера - Строка - код тарифа в подписке
//   * КодПериодаДействия - Строка - код периода действия
//   * Количество - Число - количество тарифов в подписке
//   * НомерОсновнойПодписки - Строка - номер основной подписки, если текущая подписка на тариф-расширение.
//   * ТипПодписки - ПеречислениеСсылка.ТипыПодписокСервиса - тип подписки
//   * НомерСчетаНаОплату - Строка - номер счета на оплату
//   * ИдентификаторСчетаНаОплату - УникальныйИдентификатор - идентификатор счета на оплату
Функция СвойстваПодпискиНаТарифАбонента(НомерПодписки, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваПодпискиНаТарифАбонента(НомерПодписки, );
```
</details>

## СоздатьПодпискуНаОсновнойТариф
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую подписку на основной тариф обслуживаемого абонента
// Реализует метод внешнего программного интерфейса - account/customer_subscriptions/create
//
// Параметры:
//  ДанныеПодписки - см. НовыйШаблонПодпискиНаОсновнойТариф
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Неопределено, Структура - если оформление подписки успешно выполнено:
//   * Номер - Строка - номер созданной подписки.
//   * ДатаОтключения - Дата - дата отключения созданной подписки.
Функция СоздатьПодпискуНаОсновнойТариф(ДанныеПодписки, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьПодпискуНаОсновнойТариф(ДанныеПодписки, );
```
</details>

## СоздатьПодпискуНаРасширениеТарифа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод создает новую подписку или несколько подписок на расширение тарифа обслуживаемого абонента.
// Реализует метод внешнего программного интерфейса - account/customer_subscriptions/create_enhanced
//
// Параметры:
//  ДанныеРасширенияТарифа - см. НовыйШаблонПодпискиНаРасширениеТарифа
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Неопределено, ТаблицаЗначений - если оформление подписки успешно выполнено:
//   * Номер - Строка - номер созданной подписки.
//   * ДатаОтключения - Дата - дата отключения созданной подписки.
Функция СоздатьПодпискуНаРасширениеТарифа(ДанныеРасширенияТарифа, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьПодпискуНаРасширениеТарифа(ДанныеРасширенияТарифа, );
```
</details>

## НовыйШаблонПодпискиНаОсновнойТариф
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон новой подписки на основной тариф обслуживаемого абонента.
//
// Возвращаемое значение:
//  Структура:
//   * КодВедущегоАбонента - Число - код (номер) ведущего абонента
//   * КодОбслуживаемогоАбонента - Число - код (номер) обслуживаемого абонента
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//   * КодТарифаПровайдера - Строка - код тарифа в подписке
//   * КодПериодаДействия - Строка - код периода действия подписки
//   * ДатаПодключения - Дата - дата подключения тарифа по подписке
//   * ДатаОтключения - Дата - дата отключения тарифа
Функция НовыйШаблонПодпискиНаОсновнойТариф() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйШаблонПодпискиНаОсновнойТариф() 
```
</details>

## НовыйШаблонПодпискиНаРасширениеТарифа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон новой подписки на расширение тарифа обслуживаемого абонента.
//
// Возвращаемое значение:
//  Структура:
//   * КодВедущегоАбонента - Число - код (номер) ведущего абонента
//   * КодОбслуживаемогоАбонента - Число - код (номер) обслуживаемого абонента
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//   * КодТарифаПровайдера - Строка - код тарифа в подписке
//   * КодПериодаДействия - Строка - код периода действия подписки
//   * ДатаПодключения - Дата - дата подключения тарифа по подписке
//   * ДатаОтключения - Дата - дата отключения тарифа
//   * НомерОсновнойПодписки - Строка - номер подписки на основной тариф
//   * Количество - Число - количество тарифов в подписке.
Функция НовыйШаблонПодпискиНаРасширениеТарифа() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйШаблонПодпискиНаРасширениеТарифа() 
```
</details>

## СписокУчетныхСистем
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список учетных систем, доступных абоненту.
// Реализует метод внешнего программного интерфейса - accounting_system/list
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - список учетных систем абонента:
//   * Код - Число - код учетной системы
//   * Наименование - Строка - наименование учетной системы
//   * КодВладельца - Число - код абонента-владельца учетной системы
//   * ЗагружатьДанные - Булево - признак загрузки данных
//   * ЛогинПользовательДляЗагрузки - Строка - логин пользователя для загрузки данных
//   * ВыгружатьДанные - Булево - признак выгрузки данных
//   * АдресДляВыгрузки - Строка - URL-адрес учетной системы для выгрузки данных
//   * ЛогинПользователяДляВыгрузки - Строка - логин пользователя для выгрузки данных
//
Функция СписокУчетныхСистем(ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СписокУчетныхСистем(ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## СвойстваУчетнойСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства учетной системы абонента по коду учетной системы.
// Реализует метод внешнего программного интерфейса - accounting_system/info
//
// Параметры:
//  Код - Число - код учетной системы абонента.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - свойства учетной системы:
//   * Код - Число - код учетной системы абонента
//   * Наименование - Строка - наименование учетной системы
//   * Описание - Строка - описание учетной системы
//   * КодВладельца - Число - код абонента-владельца учетной системы
//   * ЗагружатьДанные - Булево - признак загрузки данных
//   * ЛогинПользователяДляЗагрузки - Строка - логин пользователя для загрузки данных в менеджер сервиса
//   * ПравилаЗагрузки - ТаблицаЗначений - правила загрузки данных:
//     ** КодПравила - Строка - код правила загрузки данных
//     ** Адрес - Строка - адрес объекта для загрузки данных
//   * ВыгружатьДанные - Булево - признак выгрузки данных
//   * АдресДляВыгрузки - Строка - URL-адрес учетной системы для выгрузки данных в учетную систему
//   * ЛогинПользователяДляВыгрузки - Строка - логин пользователя для выгрузки данных
//   * ПравилаВыгрузки - ТаблицаЗначений - правила выгрузки данных:
//     ** КодПравила - Строка - код правила выгрузки данных
//     ** ИдентификаторСтроки - УникальныйИдентификатор - идентификатор строки правила выгрузки
//     ** КодУсловия - Строка - код условия использования правила выгрузки
//     ** Адрес - Строка - адрес объекта для выгрузки данных
//     ** БыстраяОтправка - Булево - признак быстрой отправки
//     ** ВыгрузкаПоРасписанию - Булево - признак выгрузки по расписанию
//     ** ОтборПоПоставщику - Булево - признак отбора по поставщику
//   * ПравилаОбработкиОтветов - ТаблицаЗначений:
//     ** ИдентификаторСтрокиПравилаВыгрузки - УникальныйИдентификатор - идентификатор строки правила выгрузки
//     ** КодПравила - Строка - код правила обработки ответа
//     ** КодыОтветов - Массив Из Число - коды ответов для вызова правила обработки.
//
Функция СвойстваУчетнойСистемы(Код, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваУчетнойСистемы(Код, );
```
</details>

## СоздатьОбновитьУчетнуюСистемуБиллинга
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую или обновляет существующую учетную систему биллинга.
// Реализует метод внешнего программного интерфейса - accounting_system/create_update_billing
//
// Параметры:
//  ПараметрыСозданияОбновления - см. НовыйПараметрыСозданияОбновленияУчетнойСистемыБиллинга
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - свойства учетной системы:
//   * Код - Число - код учетной системы абонента
//   * Наименование - Строка - наименование учетной системы
//
Функция СоздатьОбновитьУчетнуюСистемуБиллинга(ПараметрыСозданияОбновления, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьОбновитьУчетнуюСистемуБиллинга(ПараметрыСозданияОбновления, );
```
</details>

## НовыйПараметрыСозданияОбновленияУчетнойСистемыБиллинга
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров создания\обновления учетной системы биллинга.
//
// Возвращаемое значение:
//  Структура - шаблон параметров:
//   * ЛогинПользователяДляЗагрузки - Строка - логин пользователя для загрузки данных в менеджер сервиса
//   * ЛогинПользователяДляВыгрузки - Строка - логин пользователя для выгрузки данных в учетную систему
//   * АдресДляВыгрузки - Строка - URL-адрес учетной системы для выгрузки данных в учетную систему
//   * ПарольДляВыгрузки - Строка - пароль пользователя для выгрузки данных в учетную систему
//   * КодУчетнойСистемы - Число - код обновляемой учетной системы абонента.
//   								Если не указан, создается новая учетная система.
Функция НовыйПараметрыСозданияОбновленияУчетнойСистемыБиллинга() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыСозданияОбновленияУчетнойСистемыБиллинга() 
```
</details>

## Конфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список прикладных конфигураций, доступных абоненту этого приложения.
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - доступные конфигурации:
//    * Код - Строка - код конфигурации
//    * Наименование - Строка - синоним конфигурации
//    * Имя - Строка - имя конфигурации (как оно задано в конфигураторе).
//    * Описание - Строка - описание конфигурации
//    * КодАбонента - Число - код абонента.
//
Функция Конфигурации(ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.Конфигурации(ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## СписокВариантовПереходаВидовПриложений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список вариантов перехода видов приложений
// Реализует метод внешнего программного интерфейса - apptype/transition_options/list
//
// Параметры:
//  Отбор - см. НовыйОтборВариантовПерехода
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Неопределено, ТаблицаЗначений - список обработчиков перехода видов приложения:
//   * НомерВерсииКонфигурации - Строка - номер версии конфигурации
//   * КодПредыдущегоВидаПриложения - Строка - код предыдущего вида приложения
//   * КодВидаПриложения - Строка - код целевого вида приложения
//   * ИмяВидаПриложения - Строка - имя целевого вида приложения
//   * НаименованиеВидаПриложения - Строка - наименование целевого вида приложения
//
Функция СписокВариантовПереходаВидовПриложений(Отбор = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СписокВариантовПереходаВидовПриложений(Отбор, );
```
</details>

## НовыйОтборВариантовПерехода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон отбора обработчиков перехода.
//
// Возвращаемое значение:
//  Структура:
//   * КодКонфигурации - Строка - код конфигурации
//   * ВерсияКонфигурации - Строка - версия конфигурации
//   * КодВидаПриложения - Строка - код вида приложения
Функция НовыйОтборВариантовПерехода() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйОтборВариантовПерехода() 
```
</details>

## СписокСчетовНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список счетов на оплату
// Реализует метод внешнего программного интерфейса - bill/list
//
// Параметры:
//  Отбор - см. НовыйОтборСчетовНаОплату
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - список счетов на оплату:
//	 * Номер - Строка - номер счета
//	 * Дата - Дата - дата создания счета
//	 * ДатаИзменения - Дата - дата изменения счета
//	 * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета
//	 * КодПродавца - Число - код (номер) абонента-продавца
//	 * КодПокупателя - Число - код (номер) абонента-покупателя
//	 * Сумма - Число - сумма счета
//	 * Продление - Булево - признак продления
//	 * ПлатежнаяСсылка - Строка - платежная ссылка
//	 * Оплачен - Булево - признак оплаты счета
//	 * ДополнительнаяИнформация - Строка - дополнительная информация по счету
//	 * Комментарий - Строка - комментарий счета
Функция СписокСчетовНаОплату(Отбор = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СписокСчетовНаОплату(Отбор, );
```
</details>

## ДанныеСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные счета на оплату по номеру или идентификатору счета.
// Реализует метод внешнего программного интерфейса - bill/info
//
// Параметры:
//  ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета (не указывается, если передан номер счета)
//  НомерСчета - Строка - номер счета (не указывается, если передан идентификатор счета)
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - данные счета:
//	 * Номер - Строка - номер счета
//	 * Дата - Дата - дата создания счета
//	 * ДатаИзменения - Дата - дата изменения счета
//	 * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета
//	 * КодПродавца - Число - код (номер) абонента-продавца
//	 * КодПокупателя - Число - код (номер) абонента-покупателя
//	 * Сумма - Число - сумма счета
//	 * Продление - Булево - признак продления
//	 * ПлатежнаяСсылка - Строка - платежная ссылка
//	 * Оплачен - Булево - признак оплаты счета
//	 * ДополнительнаяИнформация - Строка - дополнительная информация по счету
//	 * Комментарий - Строка - комментарий счета
//   * Тарифы - ТаблицаЗначений - тарифы:
//     ** КодТарифаПровайдера - Строка - код тарифа провайдера
//     ** КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//     ** КодПериодаДействия - Строка - код периода действия тарифа
//     ** Количество - Число - количество тарифов в подписке
//     ** Сумма - Число - стоимость тарифа с учетом периода действия
//     ** НомерОснования - Строка - номер подписки-основания
//   * Услуги - ТаблицаЗначений - услуги:
//     ** Услуга - Строка - наименование услуги
//     ** Сумма - Число - стоимость услуги
//   * Файлы - ТаблицаЗначений - файлы представления текущего счета на оплату:
//     ** Идентификатор - УникальныйИдентификатор - идентификатор файла
//     ** Описание - Строка - имя файла представления счета
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты счета:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//	 * Состояние - Структура - данные состояния счета:
//     ** Ошибка - Булево - признак ошибки
//     ** Описание - Строка - описание состояния
//     ** Имя - Строка - имя состояния:
//         "created" - создан
//         "wait_sending" - ожидание отправки
//         "wait_registration" - ожидание оформления
//         "wait_payment" - ожидание оплаты
//         "paid" - оплачен
//         "billing_error" - ошибка выставления счета.
Функция ДанныеСчетаНаОплату(ИдентификаторСчета = Неопределено, НомерСчета = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ДанныеСчетаНаОплату(ИдентификаторСчета, НомерСчета, );
```
</details>

## СоздатьСчетНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новый счет на оплату.
// Реализует метод внешнего программного интерфейса - bill/create
//
// Параметры:
//  ДанныеСчета - Структура:
//	 * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета
//	 * КодПродавца - Число - код (номер) абонента-продавца
//	 * КодПокупателя - Число - код (номер) абонента-покупателя
//	 * Сумма - Число - сумма счета
//	 * Продление - Булево - признак продления
//	 * ПлатежнаяСсылка - Строка - платежная ссылка
//	 * Оплачен - Булево - признак оплаты счета
//	 * ДополнительнаяИнформация - Строка - дополнительная информация по счету
//	 * Комментарий - Строка - комментарий счета
//   * Тарифы - ТаблицаЗначений - тарифы:
//     ** КодТарифаПровайдера - Строка - код тарифа провайдера
//     ** КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//     ** КодПериодаДействия - Строка - код периода действия тарифа
//     ** Количество - Число - количество тарифов в подписке
//     ** Сумма - Число - стоимость тарифа с учетом периода действия
//     ** НомерОснования - Строка - номер подписки-основания
//   * Услуги - ТаблицаЗначений - услуги:
//     ** Услуга - Строка - наименование услуги
//     ** Сумма - Число - стоимость услуги
//   * Файлы - ТаблицаЗначений - файлы представления текущего счета на оплату:
//     ** Идентификатор - УникальныйИдентификатор - идентификатор файла
//     ** Описание - Строка - имя файла представления счета
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты счета:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения (не обязательно, если у доп. реквизита один тип значения)
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура:
//   * Номер - Строка - номер созданного счета на оплату
//   * ИдентификаторСчета - УникальныйИдентификатор - идентификатор созданного счета на оплату.
Функция СоздатьСчетНаОплату(ДанныеСчета, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьСчетНаОплату(ДанныеСчета, );
```
</details>

## ИзменитьСчетНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет существующий счет на оплату.
// Реализует метод внешнего программного интерфейса - bill/update
//
// Параметры:
//  ДанныеСчета - Структура:
//   * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета
//   * КодПродавца - Число - код (номер) абонента-продавца
//	 * КодПокупателя - Число - код (номер) абонента-покупателя
//	 * Сумма - Число - сумма счета
//	 * Продление - Булево - признак продления
//	 * ПлатежнаяСсылка - Строка - платежная ссылка
//	 * Оплачен - Булево - признак оплаты счета
//	 * ДополнительнаяИнформация - Строка - дополнительная информация по счету
//	 * Комментарий - Строка - комментарий счета
//   * Тарифы - ТаблицаЗначений - тарифы:
//     ** КодТарифаПровайдера - Строка - код тарифа провайдера
//     ** КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//     ** КодПериодаДействия - Строка - код периода действия тарифа
//     ** Количество - Число - количество тарифов в подписке
//     ** Сумма - Число - стоимость тарифа с учетом периода действия
//     ** НомерОснования - Строка - номер подписки-основания
//   * Услуги - ТаблицаЗначений - услуги:
//     ** Услуга - Строка - наименование услуги
//     ** Сумма - Число - стоимость услуги
//   * Файлы - ТаблицаЗначений - файлы представления текущего счета на оплату:
//     ** Идентификатор - УникальныйИдентификатор - идентификатор файла
//     ** Описание - Строка - имя файла представления счета
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты счета:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения (не обязательно, если у доп. реквизита один тип значения)
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура:
//   * Номер - Строка - номер измененного счета на оплату
//   * ИдентификаторСчета - УникальныйИдентификатор - идентификатор измененного счета на оплату.
Функция ИзменитьСчетНаОплату(ДанныеСчета, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ИзменитьСчетНаОплату(ДанныеСчета, );
```
</details>

## СчетНаОплатуФайлыТалонНаЗагрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает талон на загрузку файла в существующий счет на оплату
// Реализует метод внешнего программного интерфейса - bill/file_token/upload
//
// Параметры:
//  ПараметрыПолучения - см. НовыйПараметрыПолученияТалонаНаЗагрузкуФайла
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура:
//  * НомерСчета - Строка - номер счета
//  * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета
//  * НаправлениеПередачиДанных - Строка - направление передачи файла = "upload"
//  * ТалонНаЗагрузкуФайла - Строка - талон на загрузку файла
//  * АдресДляЗагрузки - Строка - URL для загрузки файла методом PUT
Функция СчетНаОплатуФайлыТалонНаЗагрузку(ПараметрыПолучения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СчетНаОплатуФайлыТалонНаЗагрузку(ПараметрыПолучения, );
```
</details>

## СоздатьПодпискиНаТарифыНаОснованииСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создать подписки на тарифы на основании счета на оплату.
//
// Параметры:
//  ПараметрыСоздания - см. НовыйПараметрыСозданияПодписокНаТарифыНаОснованииСчетаНаОплату
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Массив из Строка - номера созданных подписок
Функция СоздатьПодпискиНаТарифыНаОснованииСчетаНаОплату(ПараметрыСоздания, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьПодпискиНаТарифыНаОснованииСчетаНаОплату(ПараметрыСоздания, );
```
</details>

## НовыйОтборСчетовНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон отбора счетов на оплату.
//
// Возвращаемое значение:
//  Структура:
//   * КодПородавца - Число - код абонента-продавца
//   * КодПокупателя - Число - код абонента-покупателя
//   * НачалоПериода - Дата - дата начала периода
//   * КонецПериода - Дата - дата конца периода
//
Функция НовыйОтборСчетовНаОплату() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйОтборСчетовНаОплату() 
```
</details>

## НовыйШаблонСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон нового счета на оплату.
//
// Возвращаемое значение:
//  Структура:
//   * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета
//	 * КодПродавца - Число - код (номер) абонента-продавца
//	 * КодПокупателя - Число - код (номер) абонента-покупателя
//	 * Сумма - Число - сумма счета
//	 * Продление - Булево - признак продления
//	 * ПлатежнаяСсылка - Строка - платежная ссылка
//	 * Оплачен - Булево - признак оплаты счета
//	 * ДополнительнаяИнформация - Строка - дополнительная информация по счету
//	 * Комментарий - Строка - комментарий счета
//   * Тарифы - ТаблицаЗначений - тарифы:
//     ** КодТарифаПровайдера - Строка - код тарифа провайдера
//     ** КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//     ** КодПериодаДействия - Строка - код периода действия тарифа
//     ** НомерОснования - Строка - номер подписки-основания
//     ** Сумма - Число - стоимость тарифа с учетом периода действия
//   * Услуги - ТаблицаЗначений - услуги:
//     ** Услуга - Строка - наименование услуги
//     ** Сумма - Число - стоимость услуги
//   * Файлы - ТаблицаЗначений - файлы представления текущего счета на оплату:
//     ** Идентификатор - УникальныйИдентификатор - идентификатор файла
//     ** Описание - Строка - имя файла представления счета
//   * ДополнительныеРеквизиты - ТаблицаЗначений - дополнительные реквизиты счета:
//     ** Ключ - Строка - имя дополнительного реквизита
//     ** Тип - Строка - тип значения (не обязательно, если у доп. реквизита один тип значения)
//     ** Значение - Строка, Число, Дата, Булево - значение дополнительного реквизита
Функция НовыйШаблонСчетаНаОплату() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйШаблонСчетаНаОплату() 
```
</details>

## НовыйПараметрыПолученияТалонаНаЗагрузкуФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров получения талона на загрузку файла.
//
// Возвращаемое значение:
//  Структура:
//   * НомерСчета - Строка - номер счета (не указывается, если передан идентификатор счета)
//   * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета (не указывается, если передан номер счета)
//   * ИмяФайла - Строка - имя файла с расширением
//   * Размер - Строка - размер файла в байтах.
Функция НовыйПараметрыПолученияТалонаНаЗагрузкуФайла() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыПолученияТалонаНаЗагрузкуФайла() 
```
</details>

## НовыйПараметрыСозданияПодписокНаТарифыНаОснованииСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров создания подписок на тарифы на основании счета на оплату.
//
// Возвращаемое значение:
//  Структура:
//   * НомерСчета - Строка - номер счета (не указывается, если передан идентификатор счета)
//   * ИдентификаторСчета - УникальныйИдентификатор - идентификатор счета (не указывается, если передан номер счета)
//   * ДатаПодключения - Дата - дата подключения создаваемых подписок на тарифы.
Функция НовыйПараметрыСозданияПодписокНаТарифыНаОснованииСчетаНаОплату() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыСозданияПодписокНаТарифыНаОснованииСчетаНаОплату() 
```
</details>

## НовыйТарифыСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон табличной части "Тарифы" счета на оплату.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Новый тарифы счета на оплату:
// * КодТарифаПровайдера - Строка - длина 9
// * КодТарифаОбслуживающейОрганизации - Строка - длина 9
// * КодПериодаДействия - Строка - длина 10
// * Количество - Число - разрядность 10,0
// * Сумма  - Число - разрядность 31,2
// * НомерОснования - Строка - разрядность 9.
Функция НовыйТарифыСчетаНаОплату() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйТарифыСчетаНаОплату() 
```
</details>

## НовыйУслугиСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон табличной части "Услуги" счета на оплату.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Новый услуги счета на оплату:
// * Услуга - Строка - длина 1000
// * Сумма - Число - разрядность 31,2.
Функция НовыйУслугиСчетаНаОплату() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйУслугиСчетаНаОплату() 
```
</details>

## НовыйФайлыСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон табличной части "Файлы" счета на оплату.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Новый файлы счета на оплату:
// * Идентификатор - УникальныйИдентификатор
// * Описание - Строка -длина 150.
Функция НовыйФайлыСчетаНаОплату() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйФайлыСчетаНаОплату() 
```
</details>

## АбонентЭтогоПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные абонента этого приложения.
//
// Параметры:
//	Пользователь - СправочникСсылка.Пользователи - пользователь абонента, которого требуется определить. Если не указан, используется текущий.
//	Токен - Строка - ключ, выданный администратору ИБ для осуществления операции.
//
// Возвращаемое значение:
//  Структура - данные абонента:
//    * Наименование - Строка - наименование абонента
//    * Код - Число - код абонента
//    * РольПользователя - ПеречислениеСсылка.РолиПользователейАбонентов - роль текущего пользователя абонента.
//
Функция АбонентЭтогоПриложения(Знач Пользователь = Неопределено, Знач Токен = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.АбонентЭтогоПриложения(Пользователь, Токен);
```
</details>

## Приложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список приложений, доступных пользователю абонента этого приложения.
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - доступные приложения:
//   * Код - Число - код (номер) приложения
//   * Наименование - Строка - наименование
//   * КодАбонентаВладельца - Число - код абонента, владельца приложения
//   * КодКонфигурации - Строка - код конфигурации
//   * ВерсияКонфигурации - Строка - версия конфигурации
//   * НаименованиеКонфигурации - Строка - наименование конфигурации
//   * КодВидаПриложения - Строка - код вида приложения
//   * ИмяВидаПриложения - Строка - имя вида приложения
//   * НаименованиеВидаПриложения - Строка - наименование вида приложения
//   * СостояниеПриложения - ПеречислениеСсылка.СостоянияПриложений - состояние приложения
//   * АдресПриложения - Строка - URL-адрес приложения
//   * ЧасовойПояс - Строка - часовой пояс приложения
//
Функция Приложения(ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.Приложения(ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## ПриложенияАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список приложений, доступных пользователю абонента этого приложения.
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - доступные приложения:
//   * Код - Число - код (номер) приложения
//   * Наименование - Строка - наименование
//   * КодАбонентаВладельца - Число - код абонента, владельца приложения
//   * КодКонфигурации - Строка - код конфигурации
//   * ВерсияКонфигурации - Строка - версия конфигурации
//   * НаименованиеКонфигурации - Строка - наименование конфигурации
//   * КодВидаПриложения - Строка - код вида приложения
//   * ИмяВидаПриложения - Строка - имя вида приложения
//   * НаименованиеВидаПриложения - Строка - наименование вида приложения
//   * СостояниеПриложения - ПеречислениеСсылка.СостоянияПриложений - состояние приложения
//   * АдресПриложения - Строка - URL-адрес приложения
//   * ЧасовойПояс - Строка - часовой пояс приложения
//
Функция ПриложенияАбонента(КодАбонента, ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПриложенияАбонента(КодАбонента, ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## СвойстваПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию об указанном приложении.
//
// Параметры:
//  КодПриложения - Строка - код приложения (номер области).
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - свойства приложения:
//   * Код - Число - код (номер) приложения
//   * Наименование - Строка- наименование
//   * КодАбонентаВладельца - Число - код абонента, владельца приложения
//   * КодКонфигурации - Строка - код конфигурации
//   * ВерсияКонфигурации - Строка - версия конфигурации
//   * НаименованиеКонфигурации - Строка - наименование конфигурации
//   * КодВидаПриложения - Строка - код вида приложения
//   * ИмяВидаПриложения - Строка - имя вида приложения
//   * НаименованиеВидаПриложения - Строка - наименование вида приложения
//   * СостояниеПриложения - ПеречислениеСсылка.СостоянияПриложений - состояние приложения
//   * АдресПриложения - Строка - URL-адрес приложения
//   * ЧасовойПояс - Строка - часовой пояс приложения
//
Функция СвойстваПриложения(КодПриложения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваПриложения(КодПриложения, );
```
</details>

## ПользователиПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список пользователей, которым разрешен доступ к указанному приложению.
//
// Параметры:
//  КодПриложения - Число - код приложения (номер области)
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
//
// Возвращаемое значение:
//  ТаблицаЗначений - пользователи, которым разрешен доступ:
//   * Логин - Строка - логин (имя) пользователя
//   * Роль - ПеречислениеСсылка.ПраваПользователяПриложения - право пользователя на текущее приложение в менеджере сервиса.
//
Функция ПользователиПриложения(КодПриложения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПользователиПриложения(КодПриложения, );
```
</details>

## ДобавитьПользователяВПриложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает пользователю с указанным логином доступ к указанному приложению
// и назначает указанную роль для работы в приложении.
//
// Параметры:
//  ПараметрыДобавления - см. НовыйПараметрыДобавленияПользователяВПриложение
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - результат установки права доступа к приложению: Истина - право установлено, Ложь - произошла ошибка.
//
Функция ДобавитьПользователяВПриложение(ПараметрыДобавления, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ДобавитьПользователяВПриложение(ПараметрыДобавления, );
```
</details>

## УдалитьПользователяИзПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет пользователю с указанным логином доступ к указанному приложению.
//
// Параметры:
//  Логин - Строка - Логин (Имя) пользователя.
//  КодПриложения - Число - код приложения (номер области)
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - результат отмены права доступа к приложению: Истина - право отменено, Ложь - произошла ошибка.
//
Функция УдалитьПользователяИзПриложения(Логин, КодПриложения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.УдалитьПользователяИзПриложения(Логин, КодПриложения, );
```
</details>

## СоздатьПриложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новое приложение с указанной прикладной конфигурацией.
//
// Параметры:
//  ПараметрыСоздания - см. НовыйПараметрыСозданияПриложения
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - результат создания приложения:
//  * Код - Число - код созданного приложения (номер области)
//  * СостояниеПриложения - ПеречислениеСсылка.СостоянияПриложений - состояние приложения после создания.
//  * АдресПриложения - Строка - адрес созданного приложения.
//
Функция СоздатьПриложение(ПараметрыСоздания, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СоздатьПриложение(ПараметрыСоздания, );
```
</details>

## УстановитьНаименованиеПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает новое наименование приложению.
//
// Параметры:
//  ПараметрыИзменения - см. НовыйПараметрыУстановкиНаименованияПриложение
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - результат установки наименования приложению: Истина - наименование установлено, Ложь - произошла ошибка.
//
Функция УстановитьНаименованиеПриложения(ПараметрыИзменения, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.УстановитьНаименованиеПриложения(ПараметрыИзменения, );
```
</details>

## СписокРезервныхКопийПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список резервных копий приложения.
// Реализует метод внешнего программного интерфейса - tenant/backup/list.
//
// Возвращаемое значение:
//  ТаблицаЗначений - список резервных копий:
//   * ИдентификаторРК - Строка - идентификатор резервной копии, длина - 36
//   * МоментСозданияРК - Дата - момент создания резервной копии, ДатаВремя
//   * ДляТехПоддержки - Булево - признак создания резервной копии для тех. поддержки
//
Функция СписокРезервныхКопийПриложения() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СписокРезервныхКопийПриложения() 
```
</details>

## НовыйПараметрыСозданияПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров создания приложения для метода ПрограммныйИнтерфейсСервиса.СоздатьПриложение.
//
// Возвращаемое значение:
//  Структура - шаблон параметров создания приложения:
//   * Наименование - Строка - наименование создаваемого приложения.
//   * КодКонфигурации - Строка - код конфигурации (вид приложения)
//   * ЧасовойПояс - Строка - рабочий часовой пояс приложения
Функция НовыйПараметрыСозданияПриложения() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыСозданияПриложения() 
```
</details>

## НовыйПараметрыДобавленияПользователяВПриложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров добавления пользователя в приложение для метода
// ПрограммныйИнтерфейсСервиса.ДобавитьПользователяВПриложение.
//
// Возвращаемое значение:
//  Структура - шаблон параметров добавления пользователя в приложение:
//	 * КодПриложения - Число - номер приложения.
//	 * Логин - Строка - логин (имя пользователя)
//   * Право - ПеречислениеСсылка.ПраваПользователяПриложения - право пользователя на приложение в менеджере сервиса
//
Функция НовыйПараметрыДобавленияПользователяВПриложение() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыДобавленияПользователяВПриложение() 
```
</details>

## НовыйПараметрыУстановкиНаименованияПриложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров изменения наименования приложения для метода
// ПрограммныйИнтерфейсСервиса.УстановитьНаименованиеПриложения.
//
// Возвращаемое значение:
//  Структура - шаблон параметров добавления пользователя в приложение:
//   * КодПриложения - Число - код приложения (номер области)
//   * НазваниеПриложения - Строка - новое наименование приложения
//
Функция НовыйПараметрыУстановкиНаименованияПриложение() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыУстановкиНаименованияПриложение() 
```
</details>

## ТарифСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о тарифе сервиса по коду тарифа.
//
// Параметры:
//  КодТарифа - Строка - код тарифа.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура - информация о тарифе:
//   * Код - Строка - код тарифа
//   * Наименование - Строка - наименование тарифа
//   * ОписаниеДляОбслуживающихОрганизаций - Строка - описание тарифа для обслуживающей организации.
//   * ОписаниеДляАбонентов - ФорматированныйДокумент - описание тарифа для абонентов.
//   * ДатаНачалаДействия - Дата - дата начала действия тарифа.
//   * ДатаОкончанияДействия - Дата - дата окончания действия тарифа.
//   * ПериодДействияПродлевающейПодписки - Число - период (в днях), в течение которого действует продлевающая подписка (если разрешено продление).
//   * ПериодДействияРасширяющейПодписки - Число - период (в днях), в течение которого действует расширяющая подписка.
//   * ПериодДобавленияПродлевающейПодписки - Число - период (в днях) после завершения действия подписки, в течение которого можно создать продлевающую подписку.
//   * РасширениеТарифа - Булево - признак, что тариф является расширением
//   * Платный - Булево - признак, что тариф является платным (содержит платные периоды действия)
//   * Тестовый - Булево - признак, что тариф является тестовым
//   * ЕстьУсловие - Булево - признак, что для использования тарифа требуется соблюдение условия использования.
//   * ПериодическаяОплата - Булево - признак, что тариф использует периодическую оплату
//   * ПериодичностьОплаты - Строка - код периода периодичности оплаты
//   * Услуги - ТаблицаЗначений - услуги тарифа:
//     ** Код - Строка - код услуги
//     ** Наименование - Строка - Наименование услуги
//     ** ТипУслуги - ПеречислениеСсылка.ТипыУслуг - тип услуги
//     ** Описание - Строка - Описание услуги
//     ** КоличествоЛицензий - Число - количество лицензий на услугу, включенное в тариф
//     ** КоличествоДопЛицензийРасширяющейПодписки - Число - количество лицензий на услугу, которое может быть предоставлено расширяющей подпиской
//     ** ИдентификаторПоставщика - Строка - идентификатор поставщика услуги
//     ** НаименованиеПоставщика - Строка - наименование поставщика услуги
//   * Расширения - ТаблицаЗначений - расширения тарифа:
//     ** Код - Строка - код тарифа-расширения
//     ** Наименование - Строка - наименование тарифа-расширения
//   * Конфигурации - ТаблицаЗначений - конфигурации тарифа:
//     ** Код - Строка - код конфигурации
//     ** Наименование - Строка - имя конфигурации
//     ** Описание - Строка - описание конфигурации
//   * ПериодыДействия - ТаблицаЗначений - периоды действия тарифа:
//     ** Код - Строка - код периода действия
//     ** Наименование - Строка - наименование периода действия
//     ** Сумма - Число - стоимость
//     ** Комментарий - Строка - комментарий к периоду действия
//   * ПериодыОповещенийОбОкончанииПодписки - ТаблицаЗначений - периоды оповещений об окончании подписки на тариф:
//     ** КоличествоДней - Число - количество дней, когда оповещать пользователя.
//
Функция ТарифСервиса(КодТарифа, ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ТарифСервиса(КодТарифа, ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## ТарифыСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список тарифов сервиса, доступных абоненту этого приложения.
// Параметры:
//  Отбор - см. НовыйОтборСпискаТарифов
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - список тарифов сервиса:
//   * Код - Строка - код тарифа
//   * Наименование - Строка - наименование тарифа
//   * ОписаниеДляОбслуживающихОрганизаций - Строка - описание тарифа для обслуживающей организации.
//   * ОписаниеДляАбонентов - ФорматированныйДокумент - описание тарифа для абонентов.
//   * ДатаНачалаДействия - Дата - дата начала действия тарифа.
//   * ДатаОкончанияДействия - Дата - дата окончания действия тарифа.
//   * ПериодДействияПродлевающейПодписки - Число - период (в днях), в течение которого действует продлевающая подписка (если разрешено продление).
//   * ПериодДействияРасширяющейПодписки - Число - период (в днях), в течение которого действует расширяющая подписка.
//   * ПериодДобавленияПродлевающейПодписки - Число - период (в днях) после завершения действия подписки, в течение которого можно создать продлевающую подписку.
//   * РасширениеТарифа - Булево - признак, что тариф является расширением
//   * Платный - Булево - признак, что тариф является платным (содержит платные периоды действия)
//   * Тестовый - Булево - признак, что тариф является тестовым
//   * ЕстьУсловие - Булево - признак, что для использования тарифа требуется соблюдение условия использования.
//   * ПериодическаяОплата - Булево - признак, что тариф использует периодическую оплату
//   * ПериодичностьОплаты - Строка - код периода периодичности оплаты
//   * ПериодыДействия - ТаблицаЗначений - периоды действия. Заполняется если передан параметр получения ПараметрПолученияПериодыДействия:
//     ** Код - Строка - код периода действия
//     ** Наименование - Строка - наименование периода действия
//     ** Сумма - Число - стоимость
//     ** Комментарий - Строка - комментарий к периоду действия
//
Функция ТарифыСервиса(Отбор = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ТарифыСервиса(Отбор, );
```
</details>

## НовыйОтборСпискаТарифов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон отбора списка тарифов провайдера.
//
// Возвращаемое значение:
//  Структура:
//    * Наименование - Строка - отбор по части наименования
//    * ДоступныеТарифы - Массив из Строка - отбор тарифов по кодам доступных тарифов
//    * ПараметрыПолучения - Массив из Строка - может содержать параметры получения данных, возвращаемые методами
//     - см. ПараметрПолученияПериодыДействия
//     - см. ПараметрПолученияТолькоПлатные
//     - см. ПараметрПолученияТолькоРасширения
Функция НовыйОтборСпискаТарифов() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйОтборСпискаТарифов() 
```
</details>

## НовыйОтборСпискаТарифовОбслуживающейОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон отбора списка тарифов обслуживающей организации.
//
// Возвращаемое значение:
//  Структура:
//    * КодОбслуживающейОрганизации - Строка - код обслуживающей организации
//    * ДоступныеТарифы - Массив из Строка - отбор тарифов по кодам доступных тарифов
//    * ПараметрыПолучения - Массив из Строка - может содержать параметры получения данных, возвращаемые методами
//     - см. ПараметрПолученияПериодыДействия
//     - см. ПараметрПолученияТолькоРасширения
Функция НовыйОтборСпискаТарифовОбслуживающейОрганизации() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйОтборСпискаТарифовОбслуживающейОрганизации() 
```
</details>

## ПараметрПолученияПериодыДействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметр получения тарифов "Периоды действия"
//
// Возвращаемое значение:
//  Строка
//
Функция ПараметрПолученияПериодыДействия() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПараметрПолученияПериодыДействия() 
```
</details>

## ПараметрПолученияТолькоПлатные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметр получения тарифов "Только платные"
//
// Возвращаемое значение:
//  Строка
Функция ПараметрПолученияТолькоПлатные() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПараметрПолученияТолькоПлатные() 
```
</details>

## ПараметрПолученияТолькоРасширения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметр получения тарифов "Только расширения"
//
// Возвращаемое значение:
//  Строка
Функция ПараметрПолученияТолькоРасширения() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПараметрПолученияТолькоРасширения() 
```
</details>

## ПодпискиАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список существующих подписок абонента текущего приложения.
//
// Параметры:
//  Отбор - см. НовыйОтборПодписокНаТарифы
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений - существующие подписки абонента:
//   * КодАбонента - Число - код (номер) абонента
//   * Номер - Строка - номер подписки
//   * Дата - Дата - дата регистрации подписки
//   * ТипПодписки - ПеречислениеСсылка.ТипыПодписокСервиса - тип подписки
//   * КодОбслуживающейОрганизации - Число - код (номер) абонента обслуживающей организации
//   * ДатаПодключения - Дата - дата подключения тарифа по подписке
//   * ДатаОтключения - Дата - дата отключения тарифа
//   * КодТарифа - Строка - код тарифа в подписке
//   * КодТарифаОбслуживающейОрганизации - Строка - код тарифа обслуживающей организации
//   * КодПериодаДействия - Строка - код периода действия
//   * Количество - Число - количество тарифов в подписке
//   * НомерОсновнойПодписки - Строка - номер основной подписки, если текущая подписка на тариф-расширение.
//   * НомерСчетаНаОплату - Строка - номер счета на оплату
//   * ИдентификаторСчетаНаОплату - УникальныйИдентификатор - идентификатор счета на оплату
//
Функция ПодпискиАбонента(Отбор = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ПодпискиАбонента(Отбор, );
```
</details>

## НовыйОтборПодписокНаТарифы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон отбора подписок на тарифы обслуживаемых абонентов.
//
// Возвращаемое значение:
//  Структура:
//   * КодОбслуживаемогоАбонента - Число - код (номер) обслуживаемого абонента
//										   (не используется, если вызывается для метода ПодпискиАбонента)
//   * ТолькоАктивные - Булево - получение только активных подписок
//   * ТолькоОсновные - Булево - получение только основных подписок
//   * НачалоПериода - Дата - дата начала периода
//   * КонецПериода - Дата - дата конца периода
Функция НовыйОтборПодписокНаТарифы() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйОтборПодписокНаТарифы() 
```
</details>

## ИспользоватьПромокод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет активацию указанного промо-кода для абонента текущего приложения.
//
// Параметры:
//  Промокод - Строка - используемый промокод.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - результат использования: Истина - промокод активирован, Ложь - произошла ошибка.
//
Функция ИспользоватьПромокод(Промокод, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ИспользоватьПромокод(Промокод, );
```
</details>

## ИспользоватьПромокодСМеткой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет активацию указанного промо-кода для абонента текущего приложения.
//
// Параметры:
//  Промокод - Строка - используемый промокод.
//  Метка - Строка - дополнительная информация о промо-коде
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - результат использования: Истина - промокод активирован, Ложь - произошла ошибка.
//
Функция ИспользоватьПромокодСМеткой(Промокод, Метка, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ИспользоватьПромокодСМеткой(Промокод, Метка, );
```
</details>

## ЗавершитьСеансы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет завершение сеансов пользователей.
//
// Параметры:
// 	НомераСеансов - Массив Из Число - номера сеансов, которые требуется завершить.
// 	Пользователь - СправочникСсылка.Пользователи - пользователь абонента,
// 	от имени которого выполняется операция или идентификатор администратора ИБ.
// 	Токен - Строка - секретный ключ, использующийся для выполнения операции от имени администратора ИБ
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
Процедура ЗавершитьСеансы(Знач НомераСеансов, Знач Пользователь = Неопределено, Знач Токен = Неопределено, Экспорт
```

Пример вызова
```bsl
ПрограммныйИнтерфейсСервиса.ЗавершитьСеансы(НомераСеансов, Пользователь, Токен, );
```
</details>

## Задачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список активных задач плользователя из МС, относящихся к текущей области пользователя
//
// Параметры:
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//	* НомерЗадачи - Строка - номер задачи
//	* НаименованиеЗадачи - Строка - номер задачи
Функция Задачи(ВызыватьИсключениеПриОшибке = Истина, ОсновныеСвойстваОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.Задачи(ВызыватьИсключениеПриОшибке, ОсновныеСвойстваОтвета);
```
</details>

## СвойстваЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание задачи пользователя.
//
// Параметры:
//  НомерЗадачи - Строка - номер задачи, для которой требуется получить данные.
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Структура:
//   * type - Строка - тип задачи
//   * author - Строка - автор задачи
//   * description - Строка - описание задачи
//   * tenant - Строка - Наименование приложения
//   * subscriber - Строка - Наименование ведущего абонента (Абонент ОО или ЛК)
//   * backup_type - Строка - вид запрашиваемой резервной копии (Для тех.поддержки или нет)
Функция СвойстваЗадачи(НомерЗадачи, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.СвойстваЗадачи(НомерЗадачи, );
```
</details>

## ВыполнитьЗадачу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнение задачи пользователя, отказ или согласование.
//
// Параметры:
//  ПараметрыЗапроса - см. НовыйПараметрыПодтвержденияЗадачи
//  ВызыватьИсключениеПриОшибке - Булево - признак вызова исключения при ошибке получения данных.
//  ОсновныеСвойстваОтвета - Структура - возвращаемый параметр:
//   * КодСостояния - Число - код состояния ответа HTTP-сервиса.
//   * КодОтвета - Число - заполняется из ответа значением свойства "general.response".
//   * Сообщение - Строка - заполняется из ответа значением свойства "general.message".
//
// Возвращаемое значение:
//  Булево - результат выполнения задачи: Истина - задача выполнена, Ложь - произошла ошибка.
Функция ВыполнитьЗадачу(ПараметрыЗапроса, Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.ВыполнитьЗадачу(ПараметрыЗапроса, );
```
</details>

## НовыйПараметрыПодтвержденияЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон параметров подтвержения задачи.
//
// Возвращаемое значение:
//  Структура:
//   * ПолученоСогласие - Булево - признак получения согласия на предоставление доступа.
//   * НомерЗадачи - Строка - номер подтверждаемой задачи.
//   * ДатаИстеченияДоступа - Дата - дата прекращения доступа к копии.
//   * ИдентификаторКопии - Строка - идентификатор существующей копии
//   * СуществующаяКопия - Булево - признак использования существующей копии.
Функция НовыйПараметрыПодтвержденияЗадачи() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйПараметрыПодтвержденияЗадачи() 
```
</details>

## НачатьСоставнуюЗагрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает параметры для составной загрузки.
//
// Параметры:
//  ИмяФайла - Строка
//  РазмерФайла - Число
//  ТипФайла - Строка
//  Владелец - Произвольный
//
// Возвращаемое значение:
//  Структура:
//    * ИдентификаторФайла - Строка
//    * Тип - Строка
//    * Адрес - Строка
//    * Заголовки - Соответствие из КлючИЗначение:
//      ** Ключ - Строка
//      ** Значение - Строка
Функция НачатьСоставнуюЗагрузку(ИмяФайла, РазмерФайла, ТипФайла, Владелец) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НачатьСоставнуюЗагрузку(ИмяФайла, РазмерФайла, ТипФайла, Владелец) 
```
</details>

## НоваяЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает параметры для новой части
//
// Параметры:
//  ИдентификаторФайла - Строка
//  НомерЧасти - Строка
//
// Возвращаемое значение:
//  Структура:
//    * Тип - Строка
//    * Адрес - Строка
//    * Заголовки - Соответствие из КлючИЗначение:
//      ** Ключ - Строка
//      ** Значение - Строка
Функция НоваяЧасть(ИдентификаторФайла, НомерЧасти) Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НоваяЧасть(ИдентификаторФайла, НомерЧасти) 
```
</details>

## ЗавершитьСоставнуюЗагрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Завершает составную загрузку
//
// Параметры:
//  ИдентификаторФайла - Строка
//  Части - Массив из Строка
Процедура ЗавершитьСоставнуюЗагрузку(ИдентификаторФайла, Части) Экспорт
```

Пример вызова
```bsl
ПрограммныйИнтерфейсСервиса.ЗавершитьСоставнуюЗагрузку(ИдентификаторФайла, Части) 
```
</details>

## ОтменитьСоставнуюЗагрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет составную загрузку
//
// Параметры:
//  ИдентификаторФайла - Строка
Процедура ОтменитьСоставнуюЗагрузку(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
ПрограммныйИнтерфейсСервиса.ОтменитьСоставнуюЗагрузку(ИдентификаторФайла) 
```
</details>

## НовыйОсновныеСвойстваОтвета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает шаблон основных свойств ответа на запрос программного интерфейса.
//
// Возвращаемое значение:
// 	Структура:
// * КодСостояния - Число - код состояния ответа вызова HTTP-сервиса.
// * КодОтвета - Число - код ответа программного интерфейса.
// * Сообщение - Строка - сообщение программного интерфейса.
Функция НовыйОсновныеСвойстваОтвета() Экспорт
```

Пример вызова
```bsl
Результат = ПрограммныйИнтерфейсСервиса.НовыйОсновныеСвойстваОтвета() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
