---
title: Работа в безопасном режиме переопределяемый
slug: bsp/работа-в-безопасном-режиме-переопределяемый
---


## ПриПроверкеВозможностиИспользованияПрофилейБезопасности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при проверке возможности использования профилей безопасности.
//
// Параметры:
//  Отказ - Булево - если конфигурация не адаптирована к использованию
//   профилей безопасности, значение параметра в данной процедуры необходимо
//   установить равным Истина.
//
Процедура ПриПроверкеВозможностиИспользованияПрофилейБезопасности(Отказ) Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриПроверкеВозможностиИспользованияПрофилейБезопасности(Отказ) 
```
</details>

## ПриПроверкеВозможностиНастройкиПрофилейБезопасности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при проверке возможности настройки профилей безопасности.
//
// Параметры:
//  Отказ - Булево - если для информационной базы недоступно использование профилей безопасности
//    значение данного параметра нужно установить равным Истина.
//
Процедура ПриПроверкеВозможностиНастройкиПрофилейБезопасности(Отказ) Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриПроверкеВозможностиНастройкиПрофилейБезопасности(Отказ) 
```
</details>

## ПриВключенииИспользованияПрофилейБезопасности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при включении использования для информационной базы профилей безопасности.
//
Процедура ПриВключенииИспользованияПрофилейБезопасности() Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриВключенииИспользованияПрофилейБезопасности() 
```
</details>

## ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет перечень запросов внешних разрешений, которые обязательно должны быть предоставлены
// при создании информационной базы или обновлении программы.
//
// Параметры:
//  ЗапросыРазрешений - Массив из см. РаботаВБезопасномРежиме.ЗапросНаИспользованиеВнешнихРесурсов
//
Процедура ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) 
```
</details>

## ПриЗапросеРазрешенийНаИспользованиеВнешнихРесурсов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании запроса разрешений на использование внешних ресурсов.
//
// Параметры:
//  ПрограммныйМодуль - ЛюбаяСсылка - ссылка на объект информационной базы, представляющий программный
//    модуль, для которого выполняется запрос разрешений,
//  Владелец - ЛюбаяСсылка - ссылка на объект информационной базы, представляющий объект-владелец запрашиваемых
//    разрешений на использование внешних ресурсов,
//  РежимЗамещения - Булево - флаг замещения ранее предоставленных разрешений по владельцу,
//  ДобавляемыеРазрешения - Массив - массив ОбъектXDTO добавляемых разрешений,
//  УдаляемыеРазрешения - Массив - массив ОбъектXDTO удаляемых разрешений,
//  СтандартнаяОбработка - Булево - флаг выполнения стандартной обработки создания запроса на использование
//    внешних ресурсов.
//  Результат - УникальныйИдентификатор - идентификатор запроса (в том случае, если внутри обработчика
//    значение параметра СтандартнаяОбработка установлено в значение Ложь).
//
Процедура ПриЗапросеРазрешенийНаИспользованиеВнешнихРесурсов(Знач ПрограммныйМодуль, Знач Владелец, Знач РежимЗамещения, Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриЗапросеРазрешенийНаИспользованиеВнешнихРесурсов(ПрограммныйМодуль, Владелец, РежимЗамещения, );
```
</details>

## ПриЗапросеСозданияПрофиляБезопасности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при запросе создания профиля безопасности.
//
// Параметры:
//  ПрограммныйМодуль - ЛюбаяСсылка - ссылка на объект информационной базы, представляющий программный
//    модуль, для которого выполняется запрос разрешений,
//  СтандартнаяОбработка - Булево - флаг выполнения стандартной обработки,
//  Результат - УникальныйИдентификатор - идентификатор запроса (в том случае, если внутри обработчика
//    значение параметра СтандартнаяОбработка установлено в значение Ложь).
//
Процедура ПриЗапросеСозданияПрофиляБезопасности(Знач ПрограммныйМодуль, СтандартнаяОбработка, Результат) Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриЗапросеСозданияПрофиляБезопасности(ПрограммныйМодуль, СтандартнаяОбработка, Результат) 
```
</details>

## ПриЗапросеУдаленияПрофиляБезопасности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при запросе удаления профиля безопасности.
//
// Параметры:
//  ПрограммныйМодуль - ЛюбаяСсылка - ссылка на объект информационной базы, представляющий программный
//    модуль, для которого выполняется запрос разрешений,
//  СтандартнаяОбработка - Булево - флаг выполнения стандартной обработки,
//  Результат - УникальныйИдентификатор - идентификатор запроса (в том случае, если внутри обработчика
//    значение параметра СтандартнаяОбработка установлено в значение Ложь).
//
Процедура ПриЗапросеУдаленияПрофиляБезопасности(Знач ПрограммныйМодуль, СтандартнаяОбработка, Результат) Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриЗапросеУдаленияПрофиляБезопасности(ПрограммныйМодуль, СтандартнаяОбработка, Результат) 
```
</details>

## ПриПодключенииВнешнегоМодуля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при подключении внешнего модуля. В теле процедуры-обработчика может быть изменен
// безопасный режим, в котором будет выполняться подключение.
//
// Параметры:
//  ВнешнийМодуль - ЛюбаяСсылка - ссылка на объект информационной базы, представляющий подключаемый
//    внешний модуль,
//  БезопасныйРежим - ОпределяемыйТип.БезопасныйРежим - безопасный режим, в котором внешний
//    модуль будет подключен к информационной базе. Может быть изменен внутри данной процедуры.
//
Процедура ПриПодключенииВнешнегоМодуля(Знач ВнешнийМодуль, БезопасныйРежим) Экспорт
```

Пример вызова
```bsl
РаботаВБезопасномРежимеПереопределяемый.ПриПодключенииВнешнегоМодуля(ВнешнийМодуль, БезопасныйРежим) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
