---
title: Работа в модели сервиса
slug: bsp/работа-в-модели-сервиса
---


## РазделительОсновныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя общего реквизита, который является разделителем основных данных.
//
// Возвращаемое значение:
//   Строка - имя общего реквизита, который является разделителем основных данных.
//
Функция РазделительОсновныхДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.РазделительОсновныхДанных() 
```
</details>

## РазделительВспомогательныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя общего реквизита, который является разделителем вспомогательных данных.
//
// Возвращаемое значение:
//   Строка - имя общего реквизита, который является разделителем вспомогательных данных.
//
Функция РазделительВспомогательныхДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.РазделительВспомогательныхДанных() 
```
</details>

## РазделениеВключено
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак работы в режиме разделения данных по областям
// (технически это признак условного разделения).
//
// Возвращает Ложь, если конфигурация не может работать в режиме разделения данных
// (не содержит общих реквизитов, предназначенных для разделения данных).
//
// Возвращаемое значение:
//  Булево - Истина, если разделение включено.
//  Булево - Ложь,   если разделение выключено или не поддерживается.
//
Функция РазделениеВключено() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.РазделениеВключено() 
```
</details>

## ДоступноИспользованиеРазделенныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак возможности обращения к разделенным данным (которые входят в состав разделителей).
// Признак относится к сеансу, но может меняться во время работы сеанса, если разделение было включено
// в самом сеансе, поэтому проверку следует делать непосредственно перед обращением к разделенным данным.
//
// Возвращает Истина, если конфигурация не может работать в режиме разделения данных
// (не содержит общих реквизитов, предназначенных для разделения данных).
//
// Возвращаемое значение:
//   Булево - Истина, если разделение не поддерживается, либо разделение выключено,
//                    либо разделение включено и разделители    установлены.
//   Булево - Ложь,   если разделение включено и разделители не установлены.
//
Функция ДоступноИспользованиеРазделенныхДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ДоступноИспользованиеРазделенныхДанных() 
```
</details>

## ОчиститьВсеПараметрыСеансаКромеРазделителей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает все параметры сеанса, кроме связанных с общим
// реквизитом ОбластьДанных.
//
Процедура ОчиститьВсеПараметрыСеансаКромеРазделителей() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ОчиститьВсеПараметрыСеансаКромеРазделителей() 
```
</details>

## ОбластьДанныхЗаблокирована
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет блокировку области данных.
//
// Параметры:
//  ОбластьДанных -  Число - значение разделителя области данных,
//   блокировку которой требуется проверить.
//
// Возвращаемое значение:
//  Булево - если Истина, область данных заблокирована, иначе нет.
//
Функция ОбластьДанныхЗаблокирована(Знач ОбластьДанных) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ОбластьДанныхЗаблокирована(ОбластьДанных) 
```
</details>

## ПодготовитьОбластьДанныхКИспользованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает область данных к использованию. Запускает процедура обновления ИБ,
// при необходимости заполняет демонстрационными данными, устанавливает новый статус в регистре ОбластиДанных.
//
// Параметры:
//   ОбластьДанных - Число - значение разделителя области данных, которую необходимо подготовить к использованию.
//   ИДФайлаВыгрузки - УникальныйИдентификатор - идентификатор файла.
//   Вариант - Строка - вариант начальных данных.
//
Процедура ПодготовитьОбластьДанныхКИспользованию(Знач ОбластьДанных, Знач ИДФайлаВыгрузки, Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ПодготовитьОбластьДанныхКИспользованию(ОбластьДанных, ИДФайлаВыгрузки, );
```
</details>

## СкопироватьДанныеОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует данные области данных в другую область данных.
//
// Параметры:
//   ОбластьИсточник - Число - значение разделителя области данных источника данных.
//   ОбластьПриемник - Число - значение разделителя области данных приемника данных.
//
Процедура СкопироватьДанныеОбласти(Знач ОбластьИсточник, Знач ОбластьПриемник) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.СкопироватьДанныеОбласти(ОбластьИсточник, ОбластьПриемник) 
```
</details>

## ОбслуживаниеОбластейДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура одноименного регламентного задания.
// Находит все области данных со статусами, требующими обработки
// прикладным приложением, и при необходимости планирует запуск ФЗ
// по их обслуживанию.
//
Процедура ОбслуживаниеОбластейДанных() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ОбслуживаниеОбластейДанных() 
```
</details>

## ПолучитьПроксиМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает прокси web-сервиса для синхронизации административных действий в сервисе.
// Вызывающий код должен самостоятельно устанавливать привилегированный режим.
//
// Параметры:
//  ПарольПользователя - Строка - пароль для подключения.
//
// Возвращаемое значение:
//   WSПрокси - прокси менеджера сервиса.
//
Функция ПолучитьПроксиМенеджераСервиса(Знач ПарольПользователя = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьПроксиМенеджераСервиса(ПарольПользователя);
```
</details>

## УстановитьРазделениеСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. В зависимости от потребности следует использовать одну из следующих процедур:
// см. РаботаВМоделиСервиса.ВойтиВОбластьДанных
// см. РаботаВМоделиСервиса.ВыйтиИзОбластиДанных
//
// Параметры:
//  Использование - Булево - использование разделителя ОбластьДанных в сеансе.
//  ОбластьДанных - Число - значение разделителя ОбластьДанных.
//
Процедура УстановитьРазделениеСеанса(Знач Использование = Неопределено, Знач ОбластьДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.УстановитьРазделениеСеанса(Использование, ОбластьДанных);
```
</details>

## ВойтиВОбластьДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет вход в область данных. Входить в область можно только из неразделенного сеанса.
//
// Параметры:
// 	ОбластьДанных - Число -
Процедура ВойтиВОбластьДанных(Знач ОбластьДанных) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ВойтиВОбластьДанных(ОбластьДанных) 
```
</details>

## ВыйтиИзОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет выход из области данных.
//
Процедура ВыйтиИзОбластиДанных() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ВыйтиИзОбластиДанных() 
```
</details>

## ЗначениеРазделителяСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение разделителя текущей области данных.
// В случае если значение не установлено, выдается ошибка.
//
// Возвращаемое значение:
//   Число - значение разделителя текущей области данных.
//
Функция ЗначениеРазделителяСеанса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЗначениеРазделителяСеанса() 
```
</details>

## ИспользованиеРазделителяСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает флаг использования разделителя ОбластьДанных для текущего сеанса.
//
// Возвращаемое значение:
//  Булево - если Истина, разделение используется, иначе нет.
//
Функция ИспользованиеРазделителяСеанса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ИспользованиеРазделителяСеанса() 
```
</details>

## ДобавитьКонстантуВТаблицуПараметровИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет описание параметра по имени константы в таблицу параметров.
// Возвращает добавленный параметр.
//
// Параметры:
//   ТаблицаПараметров - см. ПараметрыИБ
//   ИмяКонстанты - Строка - имя константы, которую необходимо добавить в параметры ИБ.
//
// Возвращаемое значение:
//   СтрокаТаблицыЗначений - описание добавленного параметра:
//    * Имя - Строка
//    * Описание - Строка
//    * Тип - ОписаниеТипов
//
Функция ДобавитьКонстантуВТаблицуПараметровИБ(Знач ТаблицаПараметров, Знач ИмяКонстанты) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ДобавитьКонстантуВТаблицуПараметровИБ(ТаблицаПараметров, ИмяКонстанты) 
```
</details>

## ПолучитьИмяПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает имя приложения - так, как его задал абонент.
//
// Возвращаемое значение:
//   Строка - имя приложения.
//
Функция ПолучитьИмяПриложения() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьИмяПриложения() 
```
</details>

## ПолучитьРазмерБлокаПередачиФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает размер блоков в Мб для передачи больших файлов частями.
//
// Возвращаемое значение:
//   Число - размер блока передачи файлов в мегабайтах.
//
Функция ПолучитьРазмерБлокаПередачиФайла() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьРазмерБлокаПередачиФайла() 
```
</details>

## ЗаписатьСтруктурныйОбъектXDTOВСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сериализует объект структурного типа.
//
// Параметры:
//   ЗначениеСтруктурногоТипа - Массив, Структура, Соответствие - сериализуемый объект.
//
// Возвращаемое значение:
//   Строка - сериализованное значение объекта структурного типа.
//
Функция ЗаписатьСтруктурныйОбъектXDTOВСтроку(Знач ЗначениеСтруктурногоТипа) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЗаписатьСтруктурныйОбъектXDTOВСтроку(ЗначениеСтруктурногоТипа) 
```
</details>

## СтрокаВBase64
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Кодирует строковое значение по алгоритму base64.
//
// Параметры:
//   Строка - Строка - исходная строка, которую необходимо закодировать.
//
// Возвращаемое значение:
//   Строка - закодированная строка.
//
Функция СтрокаВBase64(Знач Строка) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СтрокаВBase64(Строка) 
```
</details>

## Base64ВСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Декодирует base64-представление строки в исходное значение.
//
// Параметры:
//   СтрокаBase64 - Строка - исходная строка, которую необходимо декодировать.
//
// Возвращаемое значение:
//   Строка - декодированная строка.
//
Функция Base64ВСтроку(Знач СтрокаBase64) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.Base64ВСтроку(СтрокаBase64) 
```
</details>

## ПолучитьЧасовойПоясОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает часовой пояс области данных.
// Предназначена для вызова из сеансов с неустановленным использованием
// разделителей. В сеансах с установленным использованием разделителей
// следует использовать ПолучитьЧасовойПоясИнформационнойБазы().
//
// Параметры:
//  ОбластьДанных - Число - значение разделителя области данных, часовой
//   пояс которой требуется получить.
//
// Возвращаемое значение:
//  Строка, Неопределено - часовой пояс области данных, Неопределено,
//   если часовой пояс не задан.
//
Функция ПолучитьЧасовойПоясОбластиДанных(Знач ОбластьДанных) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьЧасовойПоясОбластиДанных(ОбластьДанных) 
```
</details>

## КонечнаяТочкаМенеджераСервисаНастроена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия настройки конечной точки менеджера сервиса
//
// Возвращаемое значение:
//  Булево - Истина, если конечная точка менеджера сервиса установлена и в настройках транспорта заполнено имя пользователя.
//
Функция КонечнаяТочкаМенеджераСервисаНастроена() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.КонечнаяТочкаМенеджераСервисаНастроена() 
```
</details>

## ВнутреннийАдресМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает внутренний адрес менеджера сервиса.
//
// Возвращаемое значение:
//  Строка - внутренний адрес менеджера сервиса.
//
Функция ВнутреннийАдресМенеджераСервиса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ВнутреннийАдресМенеджераСервиса() 
```
</details>

## АдресПровайдераАутентификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает адрес провайдера аутентификации.
//
// Возвращаемое значение:
//  Строка - адрес провайдера аутентификации.
//
Функция АдресПровайдераАутентификации() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.АдресПровайдераАутентификации() 
```
</details>

## АутентификацияТокеномДоступаВнутреннихВызововПрограммногоИнтерфейса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак аутентификации токеном доступа внутренних вызовов программного интерфейса.
//
// Возвращаемое значение:
//  Булево
Функция АутентификацияТокеномДоступаВнутреннихВызововПрограммногоИнтерфейса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.АутентификацияТокеномДоступаВнутреннихВызововПрограммногоИнтерфейса() 
```
</details>

## ИмяСлужебногоПользователяМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя служебного пользователя менеджера сервиса.
// Вызывающий код должен самостоятельно устанавливать привилегированный режим.
//
// Возвращаемое значение:
//  Строка - имя служебного пользователя менеджера сервиса.
//
Функция ИмяСлужебногоПользователяМенеджераСервиса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ИмяСлужебногоПользователяМенеджераСервиса() 
```
</details>

## ПарольСлужебногоПользователяМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пароль служебного пользователя менеджера сервиса.
// Вызывающий код должен самостоятельно устанавливать привилегированный режим.
//
// Возвращаемое значение:
//  Строка - пароль служебного пользователя менеджера сервиса.
//
Функция ПарольСлужебногоПользователяМенеджераСервиса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПарольСлужебногоПользователяМенеджераСервиса() 
```
</details>

## ОбработатьИнформациюОбОшибкеWebСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает информацию об ошибке, полученную из web-сервиса.
// В случае если передана не пустая информация об ошибке, записывает
// подробное представление ошибки в журнал регистрации и вызывает
// исключение с текстом краткого представления об ошибке.
//
// Параметры:
//   ИнформацияОбОшибке - ИнформацияОбОшибке - информация об ошибке,
//   ИмяПодсистемы - Строка - имя подсистемы,
//   ИмяВебСервиса - Строка - имя web-сервиса,
//   ИмяОперации - Строка - имя операции.
//
Процедура ОбработатьИнформациюОбОшибкеWebСервиса(Знач ИнформацияОбОшибке, Знач ИмяПодсистемы = "", Знач ИмяВебСервиса = "", Знач ИмяОперации = "") Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ОбработатьИнформациюОбОшибкеWebСервиса(ИнформацияОбОшибке, ИмяПодсистемы, ИмяВебСервиса, ИмяОперации);
```
</details>

## ПсевдонимПользователяИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает псевдоним пользователя, который должен использоваться в интерфейсе.
//
// Параметры:
//   ИдентификаторПользователя - УникальныйИдентификатор - идентификатор пользователя.
//
// Возвращаемое значение:
//   Строка - псевдоним пользователя информационной базы для отображения в интерфейсе.
//
Функция ПсевдонимПользователяИнформационнойБазы(Знач ИдентификаторПользователя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПсевдонимПользователяИнформационнойБазы(ИдентификаторПользователя) 
```
</details>

## ПолучитьМенеджерЗаписиОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает в транзакции менеджер записи для регистра ОбластиДанных.
//
// Параметры:
//  ОбластьДанных - Число - номер области данных.
//  Статус - ПеречислениеСсылка.СтатусыОбластейДанных - ожидаемый статус области.
//
// Возвращаемое значение:
//  РегистрСведенийМенеджерЗаписи.ОбластиДанных - менеджер записи области данных.
//
Функция ПолучитьМенеджерЗаписиОбластиДанных(Знач ОбластьДанных, Знач Статус) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьМенеджерЗаписиОбластиДанных(ОбластьДанных, Статус) 
```
</details>

## ПодготовитьОбластьДанныхКИспользованиюИзЭталонной
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные в "типовую" область.
//
// Параметры:
//   ОбластьДанных - Число - номер заполняемой области.
//   ИДФайлаВыгрузки - УникальныйИдентификатор - ид файла начальных данных.
//   Вариант - Строка - вариант начальных данных.
//   СообщениеОбОшибке - Строка - возвращаемая, описание ошибки.
//
// Возвращаемое значение:
//  Строка - один из вариантов "Успех", "ФатальнаяОшибка".
//
Функция ПодготовитьОбластьДанныхКИспользованиюИзЭталонной(Знач ОбластьДанных, Знач ИДФайлаВыгрузки, Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПодготовитьОбластьДанныхКИспользованиюИзЭталонной(ОбластьДанных, ИДФайлаВыгрузки, );
```
</details>

## КонтрольНеразделенныхОбъектовПриЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Контроль неразделенных данных.

// Обработчик подписки на событие КонтрольНеразделенныхОбъектовПриЗаписи.
//
Процедура КонтрольНеразделенныхОбъектовПриЗаписи(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.КонтрольНеразделенныхОбъектовПриЗаписи(Источник, Отказ) 
```
</details>

## КонтрольНеразделенныхНаборовЗаписейПриЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие КонтрольНеразделенныхНаборовЗаписейПриЗаписи.
//
Процедура КонтрольНеразделенныхНаборовЗаписейПриЗаписи(Источник, Отказ, Замещение) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.КонтрольНеразделенныхНаборовЗаписейПриЗаписи(Источник, Отказ, Замещение) 
```
</details>

## ПолучитьФайлИзХранилищаМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Работа с файлами

// Возвращает полное имя файла, полученного из файлового хранилища МС по его идентификатору.
//
// Параметры:
//   ИДФайла - УникальныйИдентификатор - идентификатор файла в файловом хранилище МС.
//
// Возвращаемое значение:
//   Строка - полное имя извлеченного файла.
//
Функция ПолучитьФайлИзХранилищаМенеджераСервиса(Знач ИДФайла) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьФайлИзХранилищаМенеджераСервиса(ИДФайла) 
```
</details>

## ПоместитьФайлВХранилищеМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет файл в хранилище менеджера сервиса.
//
// Параметры:
//   АдресДанныеФайл - Строка - адрес файла во временном хранилище,
//                   - ДвоичныеДанные - двоичные данные файла,
//                   - Файл - файл.
//   ИмяФайла - Строка - хранимое имя файла.
//   ДополнительныеПараметры - Структура - сериализуемыt в json данные.
//
// Возвращаемое значение:
//   УникальныйИдентификатор - Идентификатор файла в хранилище.
//
Функция ПоместитьФайлВХранилищеМенеджераСервиса(Знач АдресДанныеФайл, Знач ИмяФайла = "", Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПоместитьФайлВХранилищеМенеджераСервиса(АдресДанныеФайл, ИмяФайла, );
```
</details>

## ЭтоПолноеИмяДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Функции определения типов объектов метаданных по полному имени объекта
// метаданных.

// Ссылочные типы данных

// Определяет принадлежность объекта метаданных к общему типу "Документ" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если документ.
//
Функция ЭтоПолноеИмяДокумента(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяДокумента(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Справочник" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если справочник.
//
Функция ЭтоПолноеИмяСправочника(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяСправочника(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПеречисления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Перечисление" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если перечисление.
//
Функция ЭтоПолноеИмяПеречисления(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПеречисления(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "План обмена" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если план обмена.
//
Функция ЭтоПолноеИмяПланаОбмена(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПланаОбмена(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПланаВидовХарактеристик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "План видов характеристик" по
//  полному имени объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина если план видов характеристик.
//
Функция ЭтоПолноеИмяПланаВидовХарактеристик(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПланаВидовХарактеристик(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяБизнесПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Бизнес-процесс" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если бизнес-процесс.
//
Функция ЭтоПолноеИмяБизнесПроцесса(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяБизнесПроцесса(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Задача" по полному имени объекта
//  метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если задача.
//
Функция ЭтоПолноеИмяЗадачи(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяЗадачи(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПланаСчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "План счетов" по полному имени объекта
//  метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если план счетов.
//
Функция ЭтоПолноеИмяПланаСчетов(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПланаСчетов(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПланаВидовРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "План видов расчета" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если план видов расчета.
//
Функция ЭтоПолноеИмяПланаВидовРасчета(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПланаВидовРасчета(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяРегистраСведений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистры

// Определяет принадлежность объекта метаданных к общему типу "Регистр сведений" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина если регистр сведений.
//
Функция ЭтоПолноеИмяРегистраСведений(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяРегистраСведений(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяРегистраНакопления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Регистр накопления" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если регистр накопления.
//
Функция ЭтоПолноеИмяРегистраНакопления(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяРегистраНакопления(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяРегистраБухгалтерии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Регистр бухгалтерии" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если регистр бухгалтерии.
//
Функция ЭтоПолноеИмяРегистраБухгалтерии(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяРегистраБухгалтерии(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяРегистраРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к общему типу "Регистр расчета" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если регистр расчета.
//
Функция ЭтоПолноеИмяРегистраРасчета(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяРегистраРасчета(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПерерасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перерасчеты

// Определяет принадлежность объекта метаданных к типу "Перерасчет" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина если перерасчет.
//
Функция ЭтоПолноеИмяПерерасчета(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПерерасчета(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяКонстанты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Константы

// Определяет принадлежность объекта метаданных к общему типу "Константа" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если константа.
//
Функция ЭтоПолноеИмяКонстанты(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяКонстанты(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяЖурналаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Журналы документов

// Определяет принадлежность объекта метаданных к общему типу "Журнал документов" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если журнал документов.
//
Функция ЭтоПолноеИмяЖурналаДокументов(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяЖурналаДокументов(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяПоследовательности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Последовательности

// Определяет принадлежность объекта метаданных к общему типу "Последовательности" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если последовательность.
//
Функция ЭтоПолноеИмяПоследовательности(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяПоследовательности(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяРегламентногоЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// РегламентныеЗадания

// Определяет принадлежность объекта метаданных к общему типу "Регламентные задания" по полному имени
//  объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если регламентное задание.
//
Функция ЭтоПолноеИмяРегламентногоЗадания(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяРегламентногоЗадания(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Общие

// Определяет принадлежность объекта метаданных к типу регистр по полному имени объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если регистр.
//
Функция ЭтоПолноеИмяРегистра(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяРегистра(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяОбъектаСсылочногоТипа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет принадлежность объекта метаданных к ссылочному типу по полному имени объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   принадлежность к заданному типу.
//
// Возвращаемое значение:
//  Булево - Истина, если ссылочный тип.
//
Функция ЭтоПолноеИмяОбъектаСсылочногоТипа(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяОбъектаСсылочногоТипа(ПолноеИмя) 
```
</details>

## ЭтоПолноеИмяОбъектаСПредопределеннымиДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет поддержку предопределенных данных объектом метаданных по полному имени объекта метаданных.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя объекта метаданных, для которого необходимо определить
//   поддержку предопределенных данных.
//
// Возвращаемое значение:
//  Булево - Истина, если объект метаданных поддерживает предопределенные данные.
//
Функция ЭтоПолноеИмяОбъектаСПредопределеннымиДанными(Знач ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоПолноеИмяОбъектаСПредопределеннымиДанными(ПолноеИмя) 
```
</details>

## ПараметрыВыборки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры выборки по полному имени объекта метаданных.
//
// Параметры:
//  ПолноеИмяОбъектаМетаданных - Строка - полное имя объекта метаданных.
//
// Возвращаемое значение:
//	Структура - параметры выборки:
//	 * Таблица - Строка - имя объекта метаданных.
//	 * ИмяПоляРегистратор - Строка - имя поля регистратора.
Функция ПараметрыВыборки(Знач ПолноеИмяОбъектаМетаданных) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПараметрыВыборки(ПолноеИмяОбъектаМетаданных) 
```
</details>

## СобытиеЖурналаРегистрацииКопированиеОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок копирования области данных.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииКопированиеОбластиДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииКопированиеОбластиДанных() 
```
</details>

## СобытиеЖурналаРегистрацииБлокировкаОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок блокировки области данных.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииБлокировкаОбластиДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииБлокировкаОбластиДанных() 
```
</details>

## СобытиеЖурналаРегистрацииПодготовкаОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок подготовки области данных.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииПодготовкаОбластиДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииПодготовкаОбластиДанных() 
```
</details>

## СобытиеЖурналаРегистрацииПолучениеФайлаИзХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок получения файла из хранилища.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииПолучениеФайлаИзХранилища() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииПолучениеФайлаИзХранилища() 
```
</details>

## СобытиеЖурналаРегистрацииДобавлениеФайлаОбменЧерезФС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок добавления файла при обмене через файловую систему.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииДобавлениеФайлаОбменЧерезФС() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииДобавлениеФайлаОбменЧерезФС() 
```
</details>

## СобытиеЖурналаРегистрацииДобавлениеФайлаОбменНеЧерезФС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок добавления файла при обмене не через файловую систему.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииДобавлениеФайлаОбменНеЧерезФС() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииДобавлениеФайлаОбменНеЧерезФС() 
```
</details>

## СобытиеЖурналаРегистрацииУдалениеВременногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события журнала регистрации для записи ошибок удаления временного файла.
//
// Возвращаемое значение:
//	Строка - имя события ошибки.
//
Функция СобытиеЖурналаРегистрацииУдалениеВременногоФайла() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СобытиеЖурналаРегистрацииУдалениеВременногоФайла() 
```
</details>

## ПриЗаполненииТаблицыПараметровИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Прочее

// См. РаботаВМоделиСервисаПереопределяемый.ПриЗаполненииТаблицыПараметровИБ.
// Параметры:
// 	ТаблицаПараметров - см. ПараметрыИБ
Процедура ПриЗаполненииТаблицыПараметровИБ(Знач ТаблицаПараметров) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ПриЗаполненииТаблицыПараметровИБ(ТаблицаПараметров) 
```
</details>

## ПриЗаполненииТиповИсключаемыхИзПроверкиУстраненияПроблемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбменДаннымиПереопределяемый.ПриЗаполненииТиповИсключаемыхИзПроверкиУстраненияПроблемы.
//
// Параметры:
// 	Типы - См. ОбменДаннымиПереопределяемый.ПриЗаполненииТиповИсключаемыхИзПроверкиУстраненияПроблемы.Типы
//
Процедура ПриЗаполненииТиповИсключаемыхИзПроверкиУстраненияПроблемы(Типы) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ПриЗаполненииТиповИсключаемыхИзПроверкиУстраненияПроблемы(Типы) 
```
</details>

## ЗаписатьПробныйФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает тестовый файл на диск, возвращая его имя и размер.
// Файл должна удалять вызывающая сторона.
//
// Возвращаемое значение:
//   Строка - имя пробного файла без пути.
//
Функция ЗаписатьПробныйФайл() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЗаписатьПробныйФайл() 
```
</details>

## ПриИзмененииОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнительные действия, выполняемые при изменении разделения сеанса.
//
Процедура ПриИзмененииОбластиДанных() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ПриИзмененииОбластиДанных() 
```
</details>

## ЗарегистрироватьОбработчикиПоставляемыхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует обработчики поставляемых данных за день и за все время.
//
// Параметры:
//   Обработчики - ТаблицаЗначений - таблица обработчиков.
//
Процедура ЗарегистрироватьОбработчикиПоставляемыхДанных(Знач Обработчики) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ЗарегистрироватьОбработчикиПоставляемыхДанных(Обработчики) 
```
</details>

## ДоступныНовыеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении уведомления о новых данных.
// В теле следует проверить, необходимы ли эти данные приложению,
// и если да - установить флажок Загружать.
//
// Параметры:
//   Дескриптор - ОбъектXDTO, Структура - Дескриптор.
//   Загружать - Булево - Истина, если загружать, Ложь - иначе.
//	 ДескрипторJSON - Булево - флаг обозначающий что дескриптор пришел в формате JSON
//
Процедура ДоступныНовыеДанные(Знач Дескриптор, Загружать, Знач ДескрипторJSON = Ложь) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ДоступныНовыеДанные(Дескриптор, Загружать, ДескрипторJSON);
```
</details>

## ДоступныНовыеДанныеJSON
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении уведомления о новых данных.
// В теле следует проверить, необходимы ли эти данные приложению,
// и если да - установить флажок Загружать.
//
// Параметры:
//   Дескриптор - Структура - Дескриптор.
//   Загружать - Булево - Истина, если загружать, Ложь - иначе.
//
Процедура ДоступныНовыеДанныеJSON(Знач Дескриптор, Загружать) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ДоступныНовыеДанныеJSON(Дескриптор, Загружать) 
```
</details>

## ОбработатьНовыеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после вызова ДоступныНовыеДанные, позволяет разобрать данные.
//
// Параметры:
//   Дескриптор - ОбъектXDTO, Структура - Дескриптор.
//   ПутьКФайлу - Строка - полное имя извлеченного файла. Файл будет автоматически удален
//                  после завершения процедуры. Если в менеджере сервиса не был
//                  указан файл - значение аргумента равно Неопределено.
//	 ДескрипторJSON - Булево - флаг обозначающий что дескриптор пришел в формате JSON
//
Процедура ОбработатьНовыеДанные(Знач Дескриптор, Знач ПутьКФайлу, Знач ДескрипторJSON = Ложь) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ОбработатьНовыеДанные(Дескриптор, ПутьКФайлу, ДескрипторJSON);
```
</details>

## ОбработатьНовыеДанныеJSON
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после вызова ДоступныНовыеДанные, позволяет разобрать данные.
//
// Параметры:
//   Дескриптор - Структура - Дескриптор.
//   ПутьКФайлу - Строка - полное имя извлеченного файла. Файл будет автоматически удален
//                  после завершения процедуры. Если в менеджере сервиса не был
//                  указан файл - значение аргумента равно Неопределено.
//
Процедура ОбработатьНовыеДанныеJSON(Знач Дескриптор, Знач ПутьКФайлу) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ОбработатьНовыеДанныеJSON(Дескриптор, ПутьКФайлу) 
```
</details>

## ОбработкаДанныхОтменена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при отмене обработки данных в случае сбоя.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Дескриптор.
//
Процедура ОбработкаДанныхОтменена(Знач Дескриптор) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ОбработкаДанныхОтменена(Дескриптор) 
```
</details>

## СеансЗапущенБезРазделителей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для общего модуля РаботаВМоделиСервисаПовтИсп.

// Определяет, запущен сеанс с разделителями или без.
//
// Возвращаемое значение:
//   Булево - Истина, если сеанс запущен без разделителей.
//
Функция СеансЗапущенБезРазделителей() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СеансЗапущенБезРазделителей() 
```
</details>

## ЭтоРазделеннаяКонфигурация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия в конфигурации общих реквизитов-разделителей.
//
// Возвращаемое значение:
//   Булево - Истина, если это разделенная конфигурация.
//
Функция ЭтоРазделеннаяКонфигурация() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоРазделеннаяКонфигурация() 
```
</details>

## ЭтоРазделенныйОбъектМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что объект метаданных используется в общих реквизитах-разделителях.
//
// Параметры:
//   ОбъектМетаданных - Строка - имя объекта метаданных.
//   Разделитель - Строка - имя общего реквизита-разделителя, на разделение которыми проверяется объект метаданных.
//
// Возвращаемое значение:
//   Булево - Истина, если это разделенный объект.
//
Функция ЭтоРазделенныйОбъектМетаданных(Знач ОбъектМетаданных, Знач Разделитель = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ЭтоРазделенныйОбъектМетаданных(ОбъектМетаданных, Разделитель);
```
</details>

## СериализуемыеСтруктурныеТипы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив сериализуемых структурных типов, поддерживаемых в настоящее время.
//
// Возвращаемое значение:
//   ФиксированныйМассив из Тип - массив из типа Тип.
//
Функция СериализуемыеСтруктурныеТипы() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СериализуемыеСтруктурныеТипы() 
```
</details>

## КонечнаяТочкаМенеджераСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает конечную точку для отправки сообщений в менеджер сервиса.
//
// Возвращаемое значение:
//  ПланОбменаСсылка.ОбменСообщениями - узел соответствующий менеджеру сервиса.
//
Функция КонечнаяТочкаМенеджераСервиса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.КонечнаяТочкаМенеджераСервиса() 
```
</details>

## СоответствиеВидовКИПользователяXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие видов контактной информации пользователя видам.
// КИ используемой в XDTO модели сервиса.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение- соответствие видов КИ:
//  * Ключ - СправочникСсылка.ВидыКонтактнойИнформации
//  * Значение - Строка
//
Функция СоответствиеВидовКИПользователяXDTO() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СоответствиеВидовКИПользователяXDTO() 
```
</details>

## СоответствиеВидовКИXDTOВидамКИПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие видов контактной информации XDTO видам КИ пользователя.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение -- соответствие видов КИ:
//  * Ключ - Строка
//  * Значение - СправочникСсылка.ВидыКонтактнойИнформации
Функция СоответствиеВидовКИXDTOВидамКИПользователя() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СоответствиеВидовКИXDTOВидамКИПользователя() 
```
</details>

## СоответствиеПравXDTOДействиямСПользователемСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие прав XDTO используемым в модели сервиса возможным
// действиям с пользователем сервиса.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение - соответствие прав действиям:
//  * Ключ - Строка
//  * Значение - Строка
//
Функция СоответствиеПравXDTOДействиямСПользователемСервиса() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СоответствиеПравXDTOДействиямСПользователемСервиса() 
```
</details>

## ПолучитьМодельДанныхОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание модели данных, относящихся к области данных.
//
// Возвращаемое значение:
//  ФиксированноеСоответствие из КлючИЗначение - модель данных области:
//    * Ключ - ОбъектМетаданных - объект метаданных,
//    * Значение - Строка - имя общего реквизита-разделителя.
//
Функция ПолучитьМодельДанныхОбласти() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьМодельДанныхОбласти() 
```
</details>

## РазделителиКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив существующих в конфигурации разделителей.
//
// Возвращаемое значение:
//   ФиксированныйМассив из Строка - массив имен общих реквизитов, которые
//     являются разделителями.
//
Функция РазделителиКонфигурации() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.РазделителиКонфигурации() 
```
</details>

## СоставОбщегоРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает состав общего реквизита с заданным именем.
//
// Параметры:
//   Имя - Строка - имя общего реквизита.
//
// Возвращаемое значение:
//   СоставОбщегоРеквизита - список объектов метаданных, в которые входит общий реквизит.
//
Функция СоставОбщегоРеквизита(Знач Имя) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СоставОбщегоРеквизита(Имя) 
```
</details>

## СтатусОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает статус области данных.
//
// Параметры:
//  ОбластьДанных -  Число - значение разделителя области данных,
//   статус которой требуется получить.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.СтатусыОбластейДанных - статус области данных.
//
Функция СтатусОбластиДанных(ОбластьДанных) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СтатусОбластиДанных(ОбластьДанных) 
```
</details>

## ПараметрыИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу описания параметров ИБ.
//
// Возвращаемое значение:
// ТаблицаЗначений - параметры ИБ. Содержит колонки:
//  * Имя - Строка - имя параметра.
//  * Описание - Строка - описание параметра для отображения в пользовательском интерфейсе.
//  * ЗапретЧтения - Булево - признак невозможности считывания параметра ИБ. Может быть установлен, например, для
//                            паролей.
//  * ЗапретЗаписи - Булево - признак невозможности изменения параметра ИБ.
//  * Тип - ОписаниеТипов - тип значения параметра. Допускается использовать только примитивные типы и
//                          перечисления, присутствующие в управляющем приложении.
//
Функция ПараметрыИБ() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПараметрыИБ() 
```
</details>

## ДоступноИзменениеПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает флаг доступности действий изменения пользователей.
//
// Возвращаемое значение:
// 	Булево - Истина, если изменение пользователей доступно, иначе Ложь.
//
Функция ДоступноИзменениеПользователей() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ДоступноИзменениеПользователей() 
```
</details>

## ИспользуемыеОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коллекцию используемых областей данных.
//
// Возвращаемое значение:
//   РезультатЗапроса - результат запроса, содержащего список областей данных.
//
Функция ИспользуемыеОбластиДанных() Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ИспользуемыеОбластиДанных() 
```
</details>

## СоздатьКлючЗаписиРегистраСведенийВспомогательныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает ключ записи для регистра сведений, включенного в состав разделителя ОбластьДанныхВспомогательныеДанные.
//
// Параметры:
//  Менеджер - РегистрСведенийМенеджер - менеджер регистра сведений, для которого требуется получить ключ записи,
//  ЗначенияКлюча - Структура - содержащая значения для заполнения свойств ключа записи.
//                              Имена элементов структуры должны соответствовать именам ключевых полей.
//
// Возвращаемое значение:
//  РегистрСведенийКлючЗаписиИмяРегистраСведений - ключ записи.
//
Функция СоздатьКлючЗаписиРегистраСведенийВспомогательныхДанных(Знач Менеджер, Знач ЗначенияКлюча) Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.СоздатьКлючЗаписиРегистраСведенийВспомогательныхДанных(Менеджер, ЗначенияКлюча) 
```
</details>

## УстановитьФлагАктивностиПользователяВОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак активности пользователя в текущей области.
// Признаком является значение совместно разделенной константы ДатаПоследнегоСтартаКлиентскогоСеанса.
// @skip-warning ПустойМетод - особенность реализации.
//
Процедура УстановитьФлагАктивностиПользователяВОбласти() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.УстановитьФлагАктивностиПользователяВОбласти() 
```
</details>

## ЗаблокироватьТекущуюОбластьДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать метод платформы УстановитьМонопольныйРежим(Истина).
//
// Параметры:
//  ПроверитьОтсутствиеДругихСеансов - Булево - проверять отсутствие других сеансов или нет.
//  РазделяемаяБлокировка - Булево - это разделяемая блокировка.
//
Процедура ЗаблокироватьТекущуюОбластьДанных(Знач ПроверитьОтсутствиеДругихСеансов = Ложь, Знач РазделяемаяБлокировка = Ложь) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ЗаблокироватьТекущуюОбластьДанных(ПроверитьОтсутствиеДругихСеансов, РазделяемаяБлокировка);
```
</details>

## РазблокироватьТекущуюОбластьДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать метод платформы УстановитьМонопольныйРежим(Ложь).
Процедура РазблокироватьТекущуюОбластьДанных() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.РазблокироватьТекущуюОбластьДанных() 
```
</details>

## ЗаписатьВспомогательныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Выполняет запись значения ссылочного типа, разделенных разделителем РазделительВспомогательныхДанных
// с переключением разделения сеанса на время записи.
//
// Параметры:
//  ОбъектВспомогательныхДанных - СправочникОбъект
//  							- ПланВидовХарактеристикОбъект
//  							- ДокументОбъект - объект ссылочного типа или УдалениеОбъекта.
//
Процедура ЗаписатьВспомогательныеДанные(ОбъектВспомогательныхДанных) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ЗаписатьВспомогательныеДанные(ОбъектВспомогательныхДанных) 
```
</details>

## УдалитьВспомогательныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Выполняет удаление значения ссылочного типа, разделенных разделителем РазделительВспомогательныхДанных
// с переключением разделения сеанса на время записи.
//
// Параметры:
//  ОбъектВспомогательныхДанных - СправочникОбъект
//  							- ПланВидовХарактеристикОбъект
//  							- ДокументОбъект - объект ссылочного типа.
//
Процедура УдалитьВспомогательныеДанные(ОбъектВспомогательныхДанных) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.УдалитьВспомогательныеДанные(ОбъектВспомогательныхДанных) 
```
</details>

## ПолучитьФайлИзХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать РаботаВМоделиСервиса.ПолучитьФайлИзХранилищаМенеджераСервиса
// Получает описание файла по его идентификатору в регистре Файлы.
// Если хранение на диске и ПутьВместоДанных = Истина,
// в выходной структуре Данные = Неопределено, ПолноеИмя = Полное имя файла,
// иначе Данные - двоичные данные файла, ПолноеИмя - Неопределено.
// Значение ключа Имя всегда содержит имя в хранилище.
//
// Параметры:
//   ИдентификаторФайла - УникальныйИдентификатор - уникальный идентификатор файла,
//   ПараметрыПодключения - Структура - поля:
//							* URL - Строка - URL сервиса, обязательно должно присутствовать и быть заполненным,
//							* UserName - Строка - имя пользователя сервиса,
//							* Password - Строка - пароль пользователя сервиса,
//   ПутьВместоДанных - Булево - что возвращать,
//   ПроверятьСуществование - Булево - проверять ли существование файла в случае ошибки его получения.
//
// Возвращаемое значение:
//   Структура - описание файла:
//	   * Имя - Строка - имя файла в хранилище.
//	   * Данные - ДвоичныеДанные - данные файла.
//	   * ПолноеИмя - Строка - полное имя файла (файл будет удален автоматически по истечении срока хранения временных файлов).
//
Функция ПолучитьФайлИзХранилища(Знач ИдентификаторФайла, Знач ПараметрыПодключения, Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПолучитьФайлИзХранилища(ИдентификаторФайла, ПараметрыПодключения, );
```
</details>

## ПоместитьФайлВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать РаботаВМоделиСервиса.ПоместитьФайлВХранилищеМенеджераСервиса
// Добавляет файл в хранилище менеджера сервиса.
//
// Параметры:
//  АдресДанныеФайл - Строка, ДвоичныеДанные, Файл - Строка/ДвоичныеДанные/Файл - Адрес временного хранилища/Данные файла/Файл.
//  ПараметрыПодключения - Структура - с полями:
//   * URL - Строка - URL сервиса. Обязательно должно присутствовать и быть заполненным.
//	 * UserName - Строка - Имя пользователя сервиса.
//	 * Password - Строка - Пароль пользователя сервиса.
//  ИмяФайла - Строка - Хранимое имя файла.
//
// Возвращаемое значение:
// УникальныйИдентификатор - идентификатор файла в хранилище.
//
Функция ПоместитьФайлВХранилище(Знач АдресДанныеФайл, Знач ПараметрыПодключения, Знач ИмяФайла = "") Экспорт
```

Пример вызова
```bsl
Результат = РаботаВМоделиСервиса.ПоместитьФайлВХранилище(АдресДанныеФайл, ПараметрыПодключения, ИмяФайла);
```
</details>

## ПриПроверкеБлокировкиОбластиДанныхПриЗапуске
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка заблокированности области данных при запуске.
// Только для вызова из СтандартныеПодсистемыСервер.ДобавитьПараметрыРаботыКлиентаПриЗапуске().
//
// Параметры:
//  ОписаниеОшибки - Строка - Текст с описанием ошибки
Процедура ПриПроверкеБлокировкиОбластиДанныхПриЗапуске(ОписаниеОшибки) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервиса.ПриПроверкеБлокировкиОбластиДанныхПриЗапуске(ОписаниеОшибки) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
