---
title: Работа в модели сервиса переопределяемый
slug: bsp/работа-в-модели-сервиса-переопределяемый
---


## ПриУдаленииОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при удалении области данных.
// В процедуре необходимо удалить данные области данных, которые не могут быть удалены стандартным механизмом.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//   ОбластьДанных - Число - значение разделителя удаляемой области данных.
//
Процедура ПриУдаленииОбластиДанных(Знач ОбластьДанных) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервисаПереопределяемый.ПриУдаленииОбластиДанных(ОбластьДанных) 
```
</details>

## ПриЗаполненииТаблицыПараметровИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список параметров ИБ.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//   ТаблицаПараметров - см. РаботаВМоделиСервиса.ПараметрыИБ
//
Процедура ПриЗаполненииТаблицыПараметровИБ(Знач ТаблицаПараметров) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервисаПереопределяемый.ПриЗаполненииТаблицыПараметровИБ(ТаблицаПараметров) 
```
</details>

## ПриПолученииЗначенийПараметровИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед попыткой получения значений параметров ИБ из одноименных констант.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//   ИменаПараметров - Массив - имена параметров, значения которых необходимо получить.
//     							В случае если значение параметра получается в данной процедуре,
//     							необходимо удалить имя обработанного параметра из массива.
//   ЗначенияПараметров - Структура - значения параметров.
//
Процедура ПриПолученииЗначенийПараметровИБ(Знач ИменаПараметров, Знач ЗначенияПараметров) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервисаПереопределяемый.ПриПолученииЗначенийПараметровИБ(ИменаПараметров, ЗначенияПараметров) 
```
</details>

## ПриУстановкеЗначенийПараметровИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед попыткой записи значений параметров ИБ в одноименные константы.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//   ЗначенияПараметров - Структура - значения параметров которые требуется установить.
//     В случае если значение параметра устанавливается в данной процедуре из структуры необходимо удалить соответствующую
//     пару КлючИЗначение.
//
Процедура ПриУстановкеЗначенийПараметровИБ(Знач ЗначенияПараметров) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервисаПереопределяемый.ПриУстановкеЗначенийПараметровИБ(ЗначенияПараметров) 
```
</details>

## ПриВключенииРазделенияПоОбластямДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при включении разделения данных по областям данных,
// при первом запуске конфигурации с параметром "ИнициализироватьРазделеннуюИБ" ("InitializeSeparatedIB").
// В частности, здесь следует размещать код по включению регламентных заданий, используемых только при включенном
// разделении данных, и соответственно, по выключению заданий, используемых только при выключенном разделении данных.
// @skip-warning ПустойМетод - переопределяемый метод.
//
Процедура ПриВключенииРазделенияПоОбластямДанных() Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервисаПереопределяемый.ПриВключенииРазделенияПоОбластямДанных() 
```
</details>

## УстановитьПраваПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает пользователю права по умолчанию.
// Вызывается при работе в модели сервиса, в случае обновления в менеджере
// сервиса прав пользователя без прав администрирования.
// @skip-warning ПустойМетод - переопределяемый метод.
//
// Параметры:
//  Пользователь - СправочникСсылка.Пользователи - пользователь, которому
//   требуется установить права по умолчанию.
//
Процедура УстановитьПраваПоУмолчанию(Пользователь) Экспорт
```

Пример вызова
```bsl
РаботаВМоделиСервисаПереопределяемый.УстановитьПраваПоУмолчанию(Пользователь) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
