---
title: Работа с почтовыми сообщениями
slug: bsp/работа-с-почтовыми-сообщениями
---


## ОтправитьПисьмо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку одного письма.
// Функция может вызвать исключение, которое требуется обработать.
//
// Параметры:
//  УчетнаяЗаписьИлиСоединение - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - почтовый ящик, с которого необходимо
//                                                                   выполнить  отправку.
//                             - ИнтернетПочта - установленное соединение с почтовым сервером.
//
//  Письмо - ИнтернетПочтовоеСообщение - отправляемое письмо.
//
// Возвращаемое значение:
//  Структура - результат отправки письма:
//   * ОшибочныеПолучатели - Соответствие из КлючИЗначение - адреса получателей с ошибками:
//    ** Ключ     - Строка - адрес получателя;
//    ** Значение - Строка - текст ошибки.
//   * ИдентификаторПисьмаSMTP - Строка - уникальный идентификатор письма, присвоенный при отправке по протоколу SMTP.
//   * ИдентификаторПисьмаIMAP - Строка - уникальный идентификатор письма, присвоенный при отправке по протоколу IMAP.
//
Функция ОтправитьПисьмо(УчетнаяЗаписьИлиСоединение, Письмо) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ОтправитьПисьмо(УчетнаяЗаписьИлиСоединение, Письмо) 
```
</details>

## ОтправитьПисьма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку нескольких писем.
// Функция может вызвать исключение, которое требуется обработать.
// Если до наступления ошибки отправки было успешно отправлено хотя бы одно письмо, исключение не вызывается,
// поэтому при обработке результата функции необходимо проверять какие письма не были отправлены.
//
// Параметры:
//  УчетнаяЗаписьИлиСоединение - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - почтовый ящик, с которого необходимо
//                                                                   выполнить  отправку.
//                             - ИнтернетПочта - установленное соединение с почтовым сервером.
//
//  Письма - Массив из ИнтернетПочтовоеСообщение - коллекция почтовых сообщений. Элемент коллекции - ИнтернетПочтовоеСообщение.
//  ТекстОшибки - Строка - сообщение об ошибке в случае, когда удалось отправить не все письма.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//   * Ключ     - ИнтернетПочтовоеСообщение - отправляемое письмо;
//   * Значение - Структура - результат отправки письма:
//    ** ОшибочныеПолучатели - Соответствие из КлючИЗначение - адреса получателей с ошибками:
//     *** Ключ     - Строка - адрес получателя;
//     *** Значение - Строка - текст ошибки.
//    ** ИдентификаторПисьмаSMTP - Строка - уникальный идентификатор письма, присвоенный при отправке по протоколу SMTP.
//    ** ИдентификаторПисьмаIMAP - Строка - уникальный идентификатор письма, присвоенный при отправке по протоколу IMAP.
//
Функция ОтправитьПисьма(УчетнаяЗаписьИлиСоединение, Письма, ТекстОшибки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ОтправитьПисьма(УчетнаяЗаписьИлиСоединение, Письма, ТекстОшибки);
```
</details>

## ЗагрузитьПочтовыеСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает сообщения с сервера для указанной почты.
// Предварительно проверяется корректность заполнения настроек почты.
// Функция может вызвать исключение, которое требуется обработать.
//
// Параметры:
//   УчетнаяЗаписьИлиСоединение - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - электронная почта, с которой
//                              загружаются письма.
//                              - ИнтернетПочта - установленное соединение с почтовым сервером
//   ПараметрыЗагрузки - Структура:
//     * Колонки - Массив - массив строк названий колонок
//                          названия колонок должны соответствовать полям объекта
//                          ИнтернетПочтовоеСообщение.
//     * РежимТестирования - Булево - используется для проверки подключения к серверу.
//     * ПолучениеЗаголовков - Булево - если Истина, то в возвращаемом наборе есть только
//                                       заголовки писем.
//     * Отбор - Структура - соответствует параметру ПараметрыОтбора встроенной функции ИнтернетПочта.ПолучитьЗаголовки.
//     * ЗаголовкиИдентификаторы - Массив - заголовки или идентификаторы сообщений, полные
//                                    сообщения по которым требуется получить.
//     * ПриводитьСообщенияКТипу - Булево - возвращать набор полученных почтовых сообщений
//                                    в виде таблицы значений с простыми типами. По умолчанию Истина.
//
// Возвращаемое значение:
//  ТаблицаЗначений - список почтовых сообщений с колонками:
//   * Важность - ВажностьИнтернетПочтовогоСообщения
//   * Вложения - ИнтернетПочтовыеВложения - в случае если вложениями являются другие почтовые сообщения,
//                 они сами не возвращаются, но возвращаются их вложения - двоичные
//                 данные и их тексты в виде двоичных данных, рекурсивно.
//   * ДатаОтправления - Дата
//   * ДатаПолучения - Дата
//   * Заголовок - Строка
//   * ИмяОтправителя - Строка
//   * Идентификатор - Массив из Строка
//   * Копии - ИнтернетПочтовыеАдреса
//   * ОбратныйАдрес - ИнтернетПочтовыеАдреса
//   * Отправитель - Строка
//                 - ИнтернетПочтовыйАдрес
//   * Получатели - ИнтернетПочтовыеАдреса
//   * Размер - Число
//   * Тексты - ИнтернетТекстыПочтовогоСообщения
//   * Кодировка - Строка
//   * СпособКодированияНеASCIIСимволов - СпособКодированияНеASCIIСимволовИнтернетПочтовогоСообщения
//   * Частичное - Булево - заполняется если статус Истина. В режиме тестирования возвращается Истина.
//  Булево - если передан параметр РежимТестирования = Истина. Истина - подключение выполнено успешно.
//
Функция ЗагрузитьПочтовыеСообщения(Знач УчетнаяЗаписьИлиСоединение, Знач ПараметрыЗагрузки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ЗагрузитьПочтовыеСообщения(УчетнаяЗаписьИлиСоединение, ПараметрыЗагрузки);
```
</details>

## ДоступныеУчетныеЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить доступные учетные записи электронной почты.
//
//  Параметры:
//   ДляОтправки  - Булево - выбирать только учетные записи, настроенные для отправки почты.
//   ДляПолучения - Булево - выбирать только учетные записи, настроенные на получение почты.
//   ВключатьСистемнуюУчетнуюЗапись - Булево - включать системную учетную запись, если настроена для отправки/получения.
//
// Возвращаемое значение:
//  ТаблицаЗначений - описание учетных записей:
//   * Ссылка       - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - учетная запись;
//   * Наименование - Строка - наименование почты;
//   * Адрес        - Строка - адрес электронной почты.
//
Функция ДоступныеУчетныеЗаписи(Знач ДляОтправки = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ДоступныеУчетныеЗаписи(ДляОтправки, );
```
</details>

## СистемнаяУчетнаяЗапись
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает настройки почты для рассылки различных уведомлений из программы.
//
// Возвращаемое значение:
//  СправочникСсылка.УчетныеЗаписиЭлектроннойПочты
//
Функция СистемнаяУчетнаяЗапись() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.СистемнаяУчетнаяЗапись() 
```
</details>

## ПроверитьСистемнаяУчетнаяЗаписьДоступна
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что почта для рассылки различных уведомлений доступна (может быть использована).
//
// Возвращаемое значение:
//  Булево
//
Функция ПроверитьСистемнаяУчетнаяЗаписьДоступна() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ПроверитьСистемнаяУчетнаяЗаписьДоступна() 
```
</details>

## ДоступнаОтправкаПисем
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина, если доступна по меньшей мере одна настроенная учетная запись для отправки почты
// либо достаточно прав на настройку почты.
//
// Возвращаемое значение:
//  Булево
//
Функция ДоступнаОтправкаПисем() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ДоступнаОтправкаПисем() 
```
</details>

## УчетнаяЗаписьНастроена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, настроена ли учетная запись для отправки и/или получения почты.
//
// Параметры:
//  УчетнаяЗапись - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - проверяемая учетная запись;
//  ДляОтправки  - Булево - проверять параметры, необходимые для отправки почты;
//  ДляПолучения - Булево - проверять параметры, необходимые для получения почты.
//
// Возвращаемое значение:
//  Булево - Истина, если настроена.
//
Функция УчетнаяЗаписьНастроена(УчетнаяЗапись, Знач ДляОтправки = Неопределено, Знач ДляПолучения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.УчетнаяЗаписьНастроена(УчетнаяЗапись, ДляОтправки, ДляПолучения);
```
</details>

## ПроверитьВозможностьОтправкиИПолученияЭлектроннойПочты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку настроек электронной почты.
//
// Параметры:
//  УчетнаяЗапись     - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - проверяемая почта.
//  СообщениеОбОшибке - Строка - текст сообщения об ошибке либо пустая строка, если ошибок не было.
//  ДополнительноеСообщение - Строка - сообщения о том, какие проверки были выполнены для почты.
//
Процедура ПроверитьВозможностьОтправкиИПолученияЭлектроннойПочты(УчетнаяЗапись, СообщениеОбОшибке, ДополнительноеСообщение) Экспорт
```

Пример вызова
```bsl
РаботаСПочтовымиСообщениями.ПроверитьВозможностьОтправкиИПолученияЭлектроннойПочты(УчетнаяЗапись, СообщениеОбОшибке, ДополнительноеСообщение) 
```
</details>

## ЕстьВнешниеРесурсы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие в документе HTML ссылок на ресурсы, загружаемые по HTTP(s).
//
// Параметры:
//  ДокументHTML - ДокументHTML - документ HTML, в котором необходимо выполнить проверку.
//
// Возвращаемое значение:
//  Булево - Истина, если в документе HTML есть внешние ресурсы.
//
Функция ЕстьВнешниеРесурсы(ДокументHTML) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ЕстьВнешниеРесурсы(ДокументHTML) 
```
</details>

## ОтключитьНебезопасноеСодержимое
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет из документа HTML скрипты, обработчики событий, а также очищает ссылки на ресурсы, загружаемые по HTTP(s).
//
// Параметры:
//  ДокументHTML - ДокументHTML - документ HTML, в котором необходимо очистить небезопасное содержимое.
//  ОтключитьВнешниеРесурсы - Булево - признак необходимости очистки ссылок на ресурсы, загружаемые по HTTP(s).
//
Процедура ОтключитьНебезопасноеСодержимое(ДокументHTML, ОтключитьВнешниеРесурсы = Истина) Экспорт
```

Пример вызова
```bsl
РаботаСПочтовымиСообщениями.ОтключитьНебезопасноеСодержимое(ДокументHTML, ОтключитьВнешниеРесурсы);
```
</details>

## ПоясненияПоОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает с сайта ИТС рекомендации по устранению ошибки подключения к почтовому серверу.
//
// Параметры:
//   ТекстОшибки - Строка - исходный текст ошибки.
//
// Возвращаемое значение:
//  Структура:
//   * ВозможныеПричины - Массив из ФорматированнаяСтрока
//   * СпособыУстранения - Массив из ФорматированнаяСтрока
//
Функция ПоясненияПоОшибке(ТекстОшибки) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ПоясненияПоОшибке(ТекстОшибки) 
```
</details>

## РасширенноеПредставлениеОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает расширенное описание ошибки подключения к почтовому серверу.
//
// Параметры:
//  ИнформацияОбОшибке - ИнформацияОбОшибке
//  КодЯзыка - Строка - код языка реквизита. Например, "ru".
//  ВключитьПодробноеПредставлениеОшибки - Булево - добавляет в текст ошибки стек.
//
// Возвращаемое значение:
//  Строка
//
Функция РасширенноеПредставлениеОшибки(ИнформацияОбОшибке, КодЯзыка, ВключитьПодробноеПредставлениеОшибки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.РасширенноеПредставлениеОшибки(ИнформацияОбОшибке, КодЯзыка, ВключитьПодробноеПредставлениеОшибки);
```
</details>

## ПоляИнтернетПочтовогоСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список имен полей объекта ИнтернетПочтовоеСообщение.
//
// Возвращаемое значение:
//  Структура:
//    * АдресаУведомленияОДоставке - Строка
//    * АдресаУведомленияОПрочтении - Строка
//    * Важность - Строка
//    * Вложения - Строка
//    * ДатаОтправления - Строка
//    * ДатаПолучения - Строка
//    * Заголовок - Строка
//    * Идентификатор - Строка
//    * ИдентификаторСообщения - Строка
//    * ИмяОтправителя - Строка
//    * Категории - Строка
//    * Кодировка - Строка
//    * Копии - Строка
//    * ОбратныйАдрес - Строка
//    * Отправитель - Строка
//    * Получатели - Строка
//    * Размер - Строка
//    * СлепыеКопии - Строка
//    * СмещениеДатыОтправления - Строка
//    * СтатусРазбора - Строка
//    * Тема - Строка
//    * Тексты - Строка
//    * СпособКодированияНеASCIIСимволов - Строка
//    * УведомитьОДоставке - Строка
//    * УведомитьОПрочтении - Строка
//    * Частичное - Строка
//
Функция ПоляИнтернетПочтовогоСообщения() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ПоляИнтернетПочтовогоСообщения() 
```
</details>

## ПодготовитьПисьмо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует письмо по переданным параметрам.
//
// Параметры:
//  УчетнаяЗапись - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - ссылка на
//                 учетную запись электронной почты.
//  ПараметрыПисьма - Структура - содержит всю необходимую информацию о письме:
//
//   * Кому - Массив
//          - Строка - интернет адреса получателей письма.
//          - Массив - коллекция структур адресов:
//              * Адрес         - Строка - почтовый адрес (должно быть обязательно заполнено).
//              * Представление - Строка - имя адресата.
//          - Строка - интернет-адреса получателей письма, разделитель - ";".
//
//   * ПолучателиСообщения - Массив - массив структур, описывающий получателей:
//      ** Адрес - Строка - почтовый адрес получателя сообщения.
//      ** Представление - Строка - представление адресата.
//
//   * Копии        - Массив
//                  - Строка - адреса получателей копий письма. См. описание поля Кому.
//
//   * СкрытыеКопии - Массив
//                  - Строка - адреса получателей скрытых копий письма. См. описание поля Кому.
//
//   * Тема       - Строка - (обязательный) тема почтового сообщения.
//   * Тело       - Строка - (обязательный) текст почтового сообщения (простой текст в кодировке win-1251).
//   * Важность   - ВажностьИнтернетПочтовогоСообщения
//
//   * Вложения - Массив - файлы, которые необходимо приложить к письму (описания в виде структур):
//     ** Представление - Строка - имя файла вложения;
//     ** АдресВоВременномХранилище - Строка - адрес двоичных данных вложения во временном хранилище.
//     ** Кодировка - Строка - кодировка вложения (используется, если отличается от кодировки письма).
//     ** Идентификатор - Строка - (необязательный) используется для отметки картинок, отображаемых в теле письма.
//
//   * АдресОтвета - Соответствие
//                 - Строка - см. описание поля Кому.
//   * ИдентификаторыОснований - Строка - идентификаторы оснований данного письма.
//   * ОбрабатыватьТексты  - Булево - необходимость обрабатывать тексты письма при отправке.
//   * УведомитьОДоставке  - Булево - необходимость запроса уведомления о доставке.
//   * УведомитьОПрочтении - Булево - необходимость запроса уведомления о прочтении.
//   * ТипТекста   - Строка
//                 - ПеречислениеСсылка.ТипыТекстовЭлектронныхПисем
//                 - ТипТекстаПочтовогоСообщения - определяет тип
//                  переданного теста допустимые значения:
//                  HTML/ТипыТекстовЭлектронныхПисем.HTML - текст почтового сообщения в формате HTML.
//                  ПростойТекст/ТипыТекстовЭлектронныхПисем.ПростойТекст - простой текст почтового сообщения.
//                                                 Отображается "как есть" (значение по
//                                                 умолчанию).
//                  РазмеченныйТекст/ТипыТекстовЭлектронныхПисем.РазмеченныйТекст - текст почтового сообщения в формате
//                                                 Rich Text.
//
// Возвращаемое значение:
//  ИнтернетПочтовоеСообщение - подготовленное письмо.
//
Функция ПодготовитьПисьмо(УчетнаяЗапись, ПараметрыПисьма) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ПодготовитьПисьмо(УчетнаяЗапись, ПараметрыПисьма) 
```
</details>

## ПодключениеКПочте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает открытое подключение к почтовому серверу. Может вызывать исключение, которое необходимо обработать.
//
// Параметры:
//  УчетнаяЗапись - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - настройки подключения к почте;
//  ДляПолучения - Булево - если Истина, то подключение будет выполняться к серверу входящей почты,
//                          если Ложь, то к серверу исходящей почты.
//
// Возвращаемое значение:
//   ИнтернетПочта
//
Функция ПодключениеКПочте(Знач УчетнаяЗапись, Знач ДляПолучения = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ПодключениеКПочте(УчетнаяЗапись, ДляПолучения);
```
</details>

## ОтправитьПочтовоеСообщение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку почтовых сообщений.
// Функция может вызвать исключение, которое требуется обработать.
//
// Параметры:
//  УчетнаяЗапись - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - ссылка на
//                 учетную запись электронной почты.
//  ПараметрыОтправки - Структура - содержит всю необходимую информацию о письме:
//
//   * Кому - Массив
//          - Строка - интернет адреса получателей письма.
//          - Массив - коллекция структур адресов:
//              * Адрес         - Строка - почтовый адрес (должно быть обязательно заполнено).
//              * Представление - Строка - имя адресата.
//          - Строка - интернет-адреса получателей письма, разделитель - ";".
//
//   * ПолучателиСообщения - Массив - массив структур, описывающий получателей:
//      ** Адрес - Строка - почтовый адрес получателя сообщения.
//      ** Представление - Строка - представление адресата.
//
//   * Копии        - Массив
//                  - Строка - адреса получателей копий письма. См. описание поля Кому.
//
//   * СкрытыеКопии - Массив
//                  - Строка - адреса получателей скрытых копий письма. См. описание поля Кому.
//
//   * Тема       - Строка - (обязательный) тема почтового сообщения.
//   * Тело       - Строка - (обязательный) текст почтового сообщения (простой текст в кодировке win-1251).
//   * Важность   - ВажностьИнтернетПочтовогоСообщения
//
//   * Вложения - Массив - файлы, которые необходимо приложить к письму (описания в виде структур):
//     ** Представление - Строка - имя файла вложения;
//     ** АдресВоВременномХранилище - Строка - адрес двоичных данных вложения во временном хранилище.
//     ** Кодировка - Строка - кодировка вложения (используется, если отличается от кодировки письма).
//     ** Идентификатор - Строка - (необязательный) используется для отметки картинок, отображаемых в теле письма.
//
//   * АдресОтвета - Соответствие
//                 - Строка - см. описание поля Кому.
//   * ИдентификаторОснования  - Строка - идентификатор основания данного письма.
//   * ИдентификаторыОснований - Строка - идентификаторы оснований данного письма.
//   * ОбрабатыватьТексты  - Булево - необходимость обрабатывать тексты письма при отправке.
//   * УведомитьОДоставке  - Булево - необходимость запроса уведомления о доставке.
//   * УведомитьОПрочтении - Булево - необходимость запроса уведомления о прочтении.
//   * ТипТекста   - Строка
//                 - ПеречислениеСсылка.ТипыТекстовЭлектронныхПисем
//                 - ТипТекстаПочтовогоСообщения - определяет тип
//                  переданного теста допустимые значения:
//                  HTML/ТипыТекстовЭлектронныхПисем.HTML - текст почтового сообщения в формате HTML.
//                  ПростойТекст/ТипыТекстовЭлектронныхПисем.ПростойТекст - простой текст почтового сообщения.
//                                                 Отображается "как есть" (значение по
//                                                 умолчанию).
//                  РазмеченныйТекст/ТипыТекстовЭлектронныхПисем.РазмеченныйТекст - текст почтового сообщения в формате
//                                                 Rich Text.
//   * Соединение - ИнтернетПочта - существующее соединение с почтовым сервером. Если не указано, то создается новое.
//   * ПротоколПочты - Строка - если указано значение "IMAP", то письмо будет передано по протоколу IMAP, если по
//                              указано значение "Все", то по протоколу SMTP и по протоколу IMAP, если ничего не указано
//                              то по протоколу SMTP. Параметр имеет смысл, только наличии действующего соединения,
//                              указанного в параметр Соединение. В противном случае протокол будет определен
//                              автоматически при установке соединения.
//   * ИдентификаторСообщения - Строка - (возвращаемый параметр) идентификатор отправленного почтового сообщения на SMTP-сервере;
//   * ИдентификаторСообщенияОтправкаIMAP - Строка - (возвращаемый параметр) идентификатор отправленного почтового
//                                         сообщения на IMAP сервере;
//   * ОшибочныеПолучатели - Соответствие - (возвращаемый параметр) список адресов, по которым отправка не выполнена.
//                                          См. возвращаемое значение метода ИнтернетПочта.Послать() в синтакс-помощнике.
//
//  УдалитьСоединение - ИнтернетПочта - параметр устарел, см. параметр ПараметрыОтправки.Соединение.
//  УдалитьПротоколПочты - Строка     - параметр устарел, см. параметр ПараметрыОтправки.ПротоколПочты.
//
// Возвращаемое значение:
//  Строка - идентификатор отправленного сообщения.
//
Функция ОтправитьПочтовоеСообщение(Знач УчетнаяЗапись, Знач ПараметрыОтправки, Экспорт
```

Пример вызова
```bsl
Результат = РаботаСПочтовымиСообщениями.ОтправитьПочтовоеСообщение(УчетнаяЗапись, ПараметрыОтправки, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
