---
title: Работа с файлами
slug: bsp/работа-с-файлами
---


## ДвоичныеДанныеФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает двоичные данные файла.
//
// Параметры:
//  ПрисоединенныйФайл - ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с файлом.
//
//  ВызыватьИсключение - Булево - если указать Ложь, то функция будет возвращать Неопределено
//                     			  вместо вызова исключений, уровень записи журнала регистрации будет понижен до "Предупреждение".
//                                Значение по умолчанию - Истина.
//
// Возвращаемое значение:
//  ДвоичныеДанные, Неопределено - двоичные данные присоединенного файла. Если двоичные данные файла не найдены
//                               в информационной базе или в томах, вызывает исключение. Если двоичные данные не
//                               найдены и параметр ВызыватьИсключение принимает значение Ложь, тогда
//                               возвращаемое значение - Неопределено.
//
// Пример:
//  Сохранение данных файла на сервере:
//	ДанныеФайла = РаботаСФайлами.ДвоичныеДанныеФайла(Файл, Ложь);
//	Если ДанныеФайла <> Неопределено Тогда
//		ДанныеФайла.Записать(ПутьКФайлу);
//	КонецЕсли;
//
Функция ДвоичныеДанныеФайла(Знач ПрисоединенныйФайл, Знач ВызыватьИсключение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ДвоичныеДанныеФайла(ПрисоединенныйФайл, ВызыватьИсключение);
```
</details>

## ДвоичныеДанныеФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает двоичные данные файла.
//
// Параметры:
//  ПрисоединенныеФайлы - Массив из ОпределяемыйТип.ПрисоединенныйФайл - массив элементов справочника с файлом, все
//                                                                       элементы должны быть одного типа.
//
//  ВызыватьИсключение - Булево - если указать Ложь, то функция будет возвращать Неопределено
//                     			  вместо вызова исключений, уровень записи журнала регистрации будет понижен до "Предупреждение".
//                                Значение по умолчанию - Истина.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//   * Ключ - ОпределяемыйТип.ПрисоединенныйФайл - файл из параметра ПрисоединенныеФайлы.
//   * Значение - ДвоичныеДанные - двоичные данные присоединенного файла. Если двоичные данные файла не существуют
//                               в информационной базе или в томах, вызывает исключение. Если двоичные данные не
//                               существуют и параметр ВызыватьИсключение принимает значение Ложь, тогда
//                               запись для такого файла будет отсутствовать.
//
Функция ДвоичныеДанныеФайлов(Знач ПрисоединенныеФайлы, Знач ВызыватьИсключение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ДвоичныеДанныеФайлов(ПрисоединенныеФайлы, ВызыватьИсключение);
```
</details>

## ДанныеФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о файле. Используется в различных командах работы с файлами
// и как значение параметра ДанныеФайла в других процедурах и функциях.
//
// Параметры:
//  ПрисоединенныйФайл                    - ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с файлом.
//  ДополнительныеПараметры               - см. РаботаСФайламиКлиентСервер.ПараметрыДанныхФайла.
//  УдалитьПолучатьСсылкуНаДвоичныеДанные - Булево - устарел, следует использовать ДополнительныеПараметры.
//  УдалитьДляРедактирования              - Булево - устарел, следует использовать ДополнительныеПараметры.
//
// Возвращаемое значение:
//  Структура, Неопределено - информация о присоединенном файле. Если файл не найден или
//    отсутствует часть обязательной информации о файле и свойство ВызыватьИсключение параметра
//    ДополнительныеПараметры принимает значение Ложь, возвращаемое значение - Неопределено. Если файл
//    не найден или отсутствует часть обязательной информации о файле и ВызыватьИсключение отсутствует
//    или принимает значение Истина, вызывает исключение. Свойства структуры:
//    * Ссылка                             - ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с файлом.
//    * СсылкаНаДвоичныеДанныеФайла        - Строка - адрес во временном хранилище, по которому помещены данные файла.
//    * Владелец                           - ОпределяемыйТип.ВладелецФайлов - ссылка объект-владелец файла.
//    * ОтносительныйПуть                  - Строка - относительный путь файла.
//    * ДатаМодификацииУниверсальная       - Дата   - дата изменения файла в UTC.
//    * ИмяФайла                           - Строка - имя файла, например, "документ.txt".
//    * Наименование                       - Строка - наименование файла (в справочнике хранения файлов).
//    * Расширение                         - Строка - расширение файла без точки.
//    * Размер                             - Число  - размер файла в байтах.
//    * Редактирует                        - СправочникСсылка.Пользователи
//                                         - СправочникСсылка.ВнешниеПользователи
//                                         - Неопределено - пользователь, занявший файл для редактирования.
//    * ДатаЗаема                          - Дата   - дата и время, когда файл был открыт для редактирования.
//    * ПодписанЭП                         - Булево - признак того, что файл подписан.
//    * Зашифрован                         - Булево - признак того, что файл зашифрован.
//    * МассивСертификатовШифрования       - см. ЭлектроннаяПодпись.СертификатыШифрования
//    * ПометкаУдаления                    - Булево - признак того, что файл помечен на удаление.
//    * НавигационнаяСсылка                - Строка - навигационная ссылка на файл.
//    * ХранитьВерсии                      - Булево - признак того, что у файла хранятся версии.
//    * ТекущаяВерсия                      - ОпределяемыйТип.ПрисоединенныйФайл - если справочник файлов поддерживает создание
//                                              версий, содержит ссылку на текущую версию файла. В ином случае содержит
//                                              ссылку на файл.
//    * Версия                             - ОпределяемыйТип.ПрисоединенныйФайл - аналогично выше.
//    * НомерВерсии                        - Число - если справочник файлов поддерживает создание версий, содержит номер
//                                                   текущей версии файла, иначе - 0.
//    * АвторТекущейВерсии                 - СправочникСсылка.УчетныеЗаписиСинхронизацииФайлов
//                                         - СправочникСсылка.Пользователи
//                                         - СправочникСсылка.ВнешниеПользователи - пользователь, отредактировавший файл.
//    * Том                                - СправочникСсылка.ТомаХраненияФайлов - том хранения файла.
//    * Автор                              - СправочникСсылка.УчетныеЗаписиСинхронизацииФайлов
//                                         - СправочникСсылка.Пользователи
//                                         - СправочникСсылка.ВнешниеПользователи - автор файла.
//    * СтатусИзвлеченияТекста             - Строка - статус извлечения текста из файла.
//    * ПолноеНаименованиеВерсии           - Строка - если справочник файлов поддерживает создание версий, содержит полное
//                                              наименование текущей версии файла. В ином случае содержит полное
//                                              наименование файла.
//    * КодировкаТекущейВерсии             - Строка - кодировка текстового файла.
//    * НаЧтение                           - Булево - признак того, что файл редактируется пользователем, отличным от текущего.
//    * ПолноеИмяФайлаВРабочемКаталоге     - Строка - путь к файлу в рабочем каталоге.
//    * ВРабочемКаталогеНаЧтение           - Булево - файл в рабочем каталоге помечен только для чтения.
//    * РабочийКаталогВладельца            - Строка - путь к рабочему каталогу владельца.
//    * ПапкаДляСохранитьКак               - Строка - путь к каталогу сохранения.
//    * ФайлРедактируется                  - Булево - признак того, что файл занят для редактирования.
//    * ФайлРедактируетТекущийПользователь - Булево - признак того, что файл занят для редактирования текущим пользователем.
//    * Кодировка                          - Строка - кодировка текстового файла.
//    * Служебный                          - Булево - признак того, что файл является служебным.
//
// Пример:
//
// // В этом примере установка идентификатора формы в параметре ДополнительныеПараметры предотвращает преждевременную
// // очистку временного хранилища из-за возможных серверных вызовов при открытии файлов (например,
// // если файл зашифрован или когда открывается форма текстового или табличного редактора).
//
// // Открытие нескольких файлов.
//	ПараметрыДанныхФайла = РаботаСФайламиКлиентСервер.ПараметрыДанныхФайла();
//	ПараметрыДанныхФайла.ИдентификаторФормы = УникальныйИдентификатор;
//	Пока Выборка.Следующий() Цикл
//		МассивДанныхФайлов.Добавить(РаботаСФайлами.ДанныеФайла(Выборка.Файл, ПараметрыДанныхФайла));
//	КонецЦикла;
//
Функция ДанныеФайла(Знач ПрисоединенныйФайл, Знач ДополнительныеПараметры = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ДанныеФайла(ПрисоединенныйФайл, ДополнительныеПараметры, );
```
</details>

## ЗаполнитьПрисоединенныеФайлыКОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит все присоединенные к объекту файлы и добавляет ссылки на них в параметр Файлы.
//
// Параметры:
//  ВладелецФайла - ОпределяемыйТип.ВладелецПрисоединенныхФайлов
//  Файлы         - Массив из ОпределяемыйТип.ПрисоединенныйФайл - массив, в который будут добавлены ссылки на файлы объекта.
//
Процедура ЗаполнитьПрисоединенныеФайлыКОбъекту(Знач ВладелецФайла, Знач Файлы) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ЗаполнитьПрисоединенныеФайлыКОбъекту(ВладелецФайла, Файлы) 
```
</details>

## НоваяСсылкаНаФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую ссылку на файл для указанного владельца файла.
// В частности, ссылка используется при добавлении файла в функции ДобавитьФайл.
//
// Параметры:
//  ВладелецФайлов - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект, к которому
//                   требуется прикрепить добавляемый файл.
//
//  ИмяСправочника - Неопределено - вычислить справочник по владельцу (допустимо,
//                   когда справочник только один, иначе будет вызвано исключение).
//
//                 - Строка - имя справочника *ПрисоединенныеФайлы, отличное
//                            от стандартного <ИмяВладельца>ПрисоединенныеФайлы.
//
// Возвращаемое значение:
//  ОпределяемыйТип.ПрисоединенныйФайл - ссылка на новый еще не записанный элемент справочника с файлом.
//
Функция НоваяСсылкаНаФайл(ВладелецФайлов, ИмяСправочника = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.НоваяСсылкаНаФайл(ВладелецФайлов, ИмяСправочника);
```
</details>

## ОбновитьФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет свойства файла без учета версий: двоичные данные, текст, дату изменения,
// а также другие необязательные свойства. Использовать только для файлов, которые не хранят версии.
//
// Параметры:
//  ПрисоединенныйФайл - ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с файлом.
//  ИнформацияОФайле - Структура:
//     * АдресФайлаВоВременномХранилище - Строка - адрес новых двоичных данных файла.
//     * АдресВременногоХранилищаТекста - Строка - адрес новых двоичных данных текста,
//                                                 извлеченного из файла.
//     * ИмяБезРасширения               - Строка - необязательное, если свойство не указано или не заполнено,
//                                                 тогда не будет изменено.
//     * ДатаМодификацииУниверсальная   - Дата   - необязательное, дата последнего изменения файла, если
//                                                 свойство не указано или не заполнено, тогда будет
//                                                 установлена текущая дата сеанса.
//     * Расширение                     - Строка - необязательное, новое расширение файла.
//     * Редактирует                    - ЛюбаяСсылка - необязательное, новый пользователь, редактирующий файл.
//     * Кодировка                      - Строка - необязательное, кодировка, в которой сохранен файл.
//                                                 Список поддерживаемых кодировок см. в справке к методу
//                                                 глобального контекста "ПолучитьДвоичныеДанныеИзСтроки".
//
Процедура ОбновитьФайл(Знач ПрисоединенныйФайл, Знач ИнформацияОФайле) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ОбновитьФайл(ПрисоединенныйФайл, ИнформацияОФайле) 
```
</details>

## ИмяФормыОбъектаФайловПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя формы объекта присоединенных файлов по владельцу.
//
// Параметры:
//  ВладелецФайлов - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект, к которому
//                   требуется прикрепить добавляемый файл.
//
// Возвращаемое значение:
//  Строка - полное имя формы объекта присоединенных файлов по владельцу.
//
Функция ИмяФормыОбъектаФайловПоВладельцу(Знач ВладелецФайлов) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ИмяФормыОбъектаФайловПоВладельцу(ВладелецФайлов) 
```
</details>

## КОбъектуМожноПрисоединятьФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность прикрепления добавляемого файла к владельцу файлов.
//
// Параметры:
//  ВладелецФайлов - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект, к которому
//                       требуется прикрепить добавляемый файл.
//  ИмяСправочника - Строка - если указано, то выполняется проверка добавления в определенное хранилище файлов.
//                            Иначе имя справочника будет определено по владельцу.
//
// Возвращаемое значение:
//  Булево - если Истина, тогда к объекту можно присоединять файлы.
//
Функция КОбъектуМожноПрисоединятьФайлы(ВладелецФайлов, ИмяСправочника = "") Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.КОбъектуМожноПрисоединятьФайлы(ВладелецФайлов, ИмяСправочника);
```
</details>

## ДобавитьФайлСДиска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет новый файл из файловой системы.
// Если справочник файлов поддерживает хранение версий, то будет создана первая версия файла.
//
// Параметры:
//   ВладелецФайлов    - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект, к которому
//                       требуется прикрепить добавляемый файл.
//   ПутьКФайлуНаДиске - Строка - полный путь к файлу, включающий имя и расширение файла.
//                       Файл должен находиться на сервере.
//
// Возвращаемое значение:
//  ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с созданным файлом.
//
Функция ДобавитьФайлСДиска(ВладелецФайлов, ПутьКФайлуНаДиске) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ДобавитьФайлСДиска(ВладелецФайлов, ПутьКФайлуНаДиске) 
```
</details>

## УстановитьПометкуУдаленияФайловДокументовПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПередЗаписью объектов-владельцев файлов,
// помечает присоединенные файлы на удаление при пометке объекта-владельца.
// Подходит только для документов.
//
// Параметры:
//  Источник        - ДокументОбъект - документ с присоединенными файлами.
//  Отказ           - Булево - стандартный параметр обработчика ПередЗаписью.
//  РежимЗаписи     - РежимЗаписиДокумента - стандартный параметр обработчика ПередЗаписью.
//  РежимПроведения - РежимПроведенияДокумента - стандартный параметр обработчика ПередЗаписью.
//
Процедура УстановитьПометкуУдаленияФайловДокументовПередЗаписью(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.УстановитьПометкуУдаленияФайловДокументовПередЗаписью(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## УстановитьПометкуУдаленияФайловПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПередЗаписью объектов-владельцев файлов,
// помечает присоединенные файлы на удаление при пометке объекта-владельца.
// Подходит для ссылочных объектов, кроме документов.
//
// Параметры:
//  Источник - ОпределяемыйТип.ВладелецПрисоединенныхФайловОбъект - объект с присоединенными файлами.
//  Отказ    - Булево - стандартный параметр обработчика ПередЗаписью.
//
Процедура УстановитьПометкуУдаленияФайловПередЗаписью(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.УстановитьПометкуУдаленияФайловПередЗаписью(Источник, Отказ) 
```
</details>

## ПараметрыДобавленияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для добавления файла.
// Для использования в РаботаСФайлами.ДобавитьФайл.
//
// Параметры:
//   ДополнительныеРеквизиты - Строка
//                           - Массив - имена реквизитов присоединенного файла, перечисленные через
//                           запятую, или массив имен реквизитов.
//                           - Структура - коллекция дополнительных реквизитов. Стандартные свойства будут
//                           вставлены в коллекцию в случае отсутствия.
//
// Возвращаемое значение:
//   Структура:
//      * Автор                       - СправочникСсылка.Пользователи
//                                    - СправочникСсылка.ВнешниеПользователи
//                                    - СправочникСсылка.УчетныеЗаписиСинхронизацииФайлов - пользователь или
//                                    учетная запись синхронизации файлов, от имени которого создается файл.
//                                    Значение по умолчанию - Неопределено.
//      * ВладелецФайлов              - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект, к которому
//                                    требуется прикрепить добавляемый файл.
//                                    Значение по умолчанию - Неопределено.
//      * ИмяБезРасширения            - Строка - имя файла без расширения.
//                                    Значение по умолчанию - "".
//      * РасширениеБезТочки          - Строка - расширение файла (без точки вначале).
//                                    Значение по умолчанию - "".
//      * ВремяИзмененияУниверсальное - Дата - дата и время изменения файла (UTC+0:00). Если параметр принимает значение
//                                    Неопределено, при добавлении файла время изменения будет установлено равным
//                                    результату выполнения функции ТекущаяУниверсальнаяДата().
//                                    Значение по умолчанию - Неопределено.
//      * ГруппаФайлов                - ОпределяемыйТип.ПрисоединенныйФайл - группа справочника с файлами, в которую
//                                    будет добавлен новый файл.
//                                    Значение по умолчанию - Неопределено.
//      * Служебный                   - Булево - если Истина, тогда файл будет скрыт от пользователей.
//                                    Значение по умолчанию - Ложь.
//
Функция ПараметрыДобавленияФайла(ДополнительныеРеквизиты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ПараметрыДобавленияФайла(ДополнительныеРеквизиты);
```
</details>

## ДобавитьФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект в справочнике для хранения файла и заполняет его реквизиты переданными свойствами.
//
// Параметры:
//   ПараметрыФайла                 - см. РаботаСФайлами.ПараметрыДобавленияФайла.
//   АдресФайлаВоВременномХранилище - Строка - адрес, указывающий на двоичные данные во временном хранилище.
//   АдресВременногоХранилищаТекста - Строка - адрес, указывающий на извлеченный текст из файла во временном хранилище.
//   Описание                       - Строка - текстовое описание файла.
//   НоваяСсылкаНаФайл              - Неопределено - если у владельца файла только один справочник хранения файлов.
//                                  - ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника хранения файлов,
//                                    которую следует использовать для добавляемого файла.
//                                    Должна соответствовать одному из типов справочников хранения файлов владельца
//                                    файлов. Ссылка может быть получена функцией НоваяСсылкаНаФайл.
//
// Возвращаемое значение:
//   ОпределяемыйТип.ПрисоединенныйФайл - ссылка на созданный присоединенный файл.
//
Функция ДобавитьФайл(ПараметрыФайла, Знач АдресФайлаВоВременномХранилище, Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ДобавитьФайл(ПараметрыФайла, АдресФайлаВоВременномХранилище, );
```
</details>

## НастройкиРаботыСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает персональные настройки работы с файлами.
//
// Возвращаемое значение:
//  Структура:
//    * ПоказыватьЗанятыеФайлыПриЗавершенииРаботы        - Булево - существует, только если внедрена подсистема Работа с
//                                                                  файлами.
//    * СпрашиватьРежимРедактированияПриОткрытииФайла    - Булево - существует, только если внедрена подсистема Работа с
//                                                                  файлами.
//    * ПоказыватьКолонкуРазмер                          - Булево - существует, только если внедрена подсистема Работа с
//                                                                  файлами.
//    * ДействиеПоДвойномуЩелчкуМыши                     - Строка - существует, только если внедрена подсистема Работа с
//                                                                  файлами.
//    * СпособСравненияВерсийФайлов                      - Строка - существует, только если внедрена подсистема Работа с
//                                                                  файлами.
//    * ГрафическиеСхемыРасширение                       - Строка - список расширений для графических схем.
//    * ГрафическиеСхемыСпособОткрытия                   - ПеречислениеСсылка.СпособыОткрытияФайлаНаПросмотр - способ
//                                                       открытия графических схем.
//    * ТекстовыеФайлыРасширение                         - Строка - расширения файлов открытого формата документов.
//    * ТекстовыеФайлыСпособОткрытия                     - ПеречислениеСсылка.СпособыОткрытияФайлаНаПросмотр - способ
//                                                       открытия текстовых файлов.
//    * МаксимальныйРазмерЛокальногоКэшаФайлов           - Число - определяет максимальный размер локального кэша файлов.
//    * ПоказыватьИнформациюЧтоФайлНеБылИзменен          - Булево - показывать файлы при завершении работы.
//    * ПоказыватьПодсказкиПриРедактированииФайлов       - Булево - а веб-клиенте показывать подсказки при
//                                                                  редактировании файлов.
//    * ПутьКЛокальномуКэшуФайлов                        - Строка - путь к локальному кэшу файлов.
//    * ЭтоПолноправныйПользователь                      - Булево - устарел, следует использовать
//                                                           ПользователиКлиент.ЭтоПолноправныйПользователь.
//    * УдалятьФайлИзЛокальногоКэшаФайловПриЗавершенииРедактирования - Булево - удаление файлов из локального кэша при
//                                                                              завершении редактирования.
//
Функция НастройкиРаботыСФайлами() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.НастройкиРаботыСФайлами() 
```
</details>

## МаксимальныйРазмерФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает максимальный размер файла.
//
// Возвращаемое значение:
//  Число - целое число байтов.
//
Функция МаксимальныйРазмерФайла() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.МаксимальныйРазмерФайла() 
```
</details>

## МаксимальныйРазмерФайлаОбщий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает максимальный размер файла провайдера.
//
// Возвращаемое значение:
//  Число - целое число байтов.
//
Функция МаксимальныйРазмерФайлаОбщий() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.МаксимальныйРазмерФайлаОбщий() 
```
</details>

## СохранитьНастройкиРаботыСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет настройки работы с файлами.
//
// Параметры:
//  НастройкиРаботыСФайлами - Структура - настройки работы с файлами с их значениями:
//     * ПоказыватьИнформациюЧтоФайлНеБылИзменен        - Булево - необязательный. Показывать сообщение, если файл не
//                                                      был изменен.
//     * ПоказыватьЗанятыеФайлыПриЗавершенииРаботы      - Булево - необязательный. Показывать файлы при завершении работы.
//     * ПоказыватьКолонкуРазмер                        - Булево - необязательный. Если принимает значение Истина, на формах
//                                                      списках файлов будет отображаться колонка Размер.
//     * ТекстовыеФайлыРасширение                       - Строка - расширения файлов открытого формата документов.
//     * ТекстовыеФайлыСпособОткрытия                   - ПеречислениеСсылка.СпособыОткрытияФайлаНаПросмотр - способ
//                                                      открытия текстовых файлов.
//     * ГрафическиеСхемыРасширение                     - Строка - список расширений графических файлов.
//     * ПоказыватьПодсказкиПриРедактированииФайлов     - Булево - необязательный. В веб-клиенте показывать подсказки
//                                                      при редактировании файлов.
//     * СпрашиватьРежимРедактированияПриОткрытииФайла  - Булево - необязательный. Выбирать режим редактирования при
//                                                      открытии файла.
//     * СпособСравненияВерсийФайлов                    - ПеречислениеСсылка.СпособыСравненияВерсийФайлов -
//                                                        необязательный. Способ сравнения версий и файлов.
//     * ДействиеПоДвойномуЩелчкуМыши                   - ПеречислениеСсылка.ДействияСФайламиПоДвойномуЩелчку - необязательный.
//     * ГрафическиеСхемыСпособОткрытия                 - ПеречислениеСсылка.СпособыОткрытияФайлаНаПросмотр -
//                                                        необязательный. Способ открытия файла на просмотр.
//
Процедура СохранитьНастройкиРаботыСФайлами(НастройкиРаботыСФайлами) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.СохранитьНастройкиРаботыСФайлами(НастройкиРаботыСФайлами) 
```
</details>

## РеквизитыРедактируемыеВГрупповойОбработке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реквизиты объекта, которые разрешается редактировать
// с помощью обработки группового изменения реквизитов.
//
// Возвращаемое значение:
//  Массив из Строка
//
Функция РеквизитыРедактируемыеВГрупповойОбработке() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.РеквизитыРедактируемыеВГрупповойОбработке() 
```
</details>

## ПеренестиФайлыМеждуСправочникамиХранения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переносит файлы между справочниками хранения при объекте-владельце файлов и помечает
// перенесенные файлы к удалению.
//
// Для использования в процедурах обновления ИБ, когда выполняется перенос присоединенных файлов
// объекта-владельца между таблиц хранения файлов. Например, для справочника владельца присоединенных
// можно осуществить перенос файлов из справочника
// Справочник.<Имя справочника владельца>ПрисоединенныеФайлы в справочник Справочник.Файлы
// или в обратную сторону.
// Выполняется последовательно для каждого элемента объекта-владельца файлов
// (элемента справочника, ПВХ, документа и т.п.).
//
// Параметры:
//   ВладелецФайлов - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект-владелец - приемник файлов.
//   Источник - Строка - если требуется конвертация из указанного хранилища.
//                       Если не заполнен, то используется первый неосновной справочник хранения.
//   Приемник - Строка - если требуется конвертация в указанное хранилище.
//                       Если не заполнен, то используется основной справочник хранения файлов.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//   * Ключ     - ОпределяемыйТип.ПрисоединенныйФайл - перенесенный файл, который помечен на удаление
//                                                     после переноса.
//   * Значение - ОпределяемыйТип.ПрисоединенныйФайл - созданный файл.
//
Функция ПеренестиФайлыМеждуСправочникамиХранения(Знач ВладелецФайлов, Знач Источник = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ПеренестиФайлыМеждуСправочникамиХранения(ВладелецФайлов, Источник, );
```
</details>

## ПриЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПриЗаписиНаСервере формы владельца файла.
//
// Параметры:
//  Отказ           - Булево  - стандартный параметр события формы.
//  ТекущийОбъект   - ОпределяемыйТип.ВладелецПрисоединенныхФайловОбъект - стандартный параметр события формы.
//  ПараметрыЗаписи - Структура - стандартный параметр события формы.
//  Форма           - ФормаКлиентскогоПриложения - форма записываемого объекта.
//
Процедура ПриЗаписиНаСервере(Отказ, ТекущийОбъект, ПараметрыЗаписи, Форма) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ПриЗаписиНаСервере(Отказ, ТекущийОбъект, ПараметрыЗаписи, Форма) 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Размещает на форме гиперссылки и поля присоединенных файлов.
//
// Параметры:
//  Форма               - ФормаКлиентскогоПриложения - форма для подключения.
//  ДобавляемыеЭлементы - Структура
//                      - Массив - параметры элементов управления
//                      присоединенными файлами для размещения на форме или массив
//                      таких структур. Свойства: см. РаботаСФайлами.ГиперссылкаФайлов
//                      и РаботаСФайлами.ПолеФайла.
//  НастройкиРаботыСФайламиВФорме - см. РаботаСФайлами.НастройкиРаботыСФайламиВФорме.
//
//
// Пример:
//  1. Добавление гиперссылки присоединенных файлов:
//   ПараметрыГиперссылки = РаботаСФайлами.ГиперссылкаФайлов();
//   ПараметрыГиперссылки.Размещение = "КоманднаяПанель";
//   РаботаСФайлами.ПриСозданииНаСервере(ЭтотОбъект, ПараметрыГиперссылки);
//
//  2. Добавление поля изображения:
//   ПараметрыПоля = РаботаСФайлами.ПолеФайла();
//   ПараметрыПоля.ПутьКДанным = "Объект.ФайлКартинки";
//   ПараметрыПоля.ПутьКДаннымИзображения = "АдресКартинки";
//   РаботаСФайлами.ПриСозданииНаСервере(ЭтотОбъект, ПараметрыПоля);
//
//  3. Добавление нескольких элементов управления:
//   ДобавляемыеЭлементы = Новый Массив;
//   ДобавляемыеЭлементы.Добавить(ПараметрыГиперссылки);
//   ДобавляемыеЭлементы.Добавить(ПараметрыПоля);
//   РаботаСФайлами.ПриСозданииНаСервере(ЭтотОбъект, ДобавляемыеЭлементы);
//
Процедура ПриСозданииНаСервере(Форма, ДобавляемыеЭлементы = Неопределено, НастройкиРаботыСФайламиВФорме = Неопределено) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ПриСозданииНаСервере(Форма, ДобавляемыеЭлементы, НастройкиРаботыСФайламиВФорме);
```
</details>

## ГиперссылкаФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для размещения гиперссылки присоединенных файлов на форме.
//
// Возвращаемое значение:
//  Структура - параметры размещения гиперссылки. Свойства:
//    * Владелец                   - Строка - имя реквизита, содержащего ссылку на владельца присоединенных файлов.
//                                 Значение по умолчанию - "Объект.Ссылка".
//    * Размещение                 - Строка
//                                 - Неопределено - если указано имя группы формы или командная панель,
//                                 гиперссылка будет помещена в указанную группу или панель. Если указано имя элемента
//                                 формы, гиперссылка будет вставлена перед указанным элементом. Если значение
//                                 параметра - Неопределено или элемент не найден, гиперссылка будет добавлена на форму
//                                 после всех существующих элементов.
//                                 Значение по умолчанию - "УправлениеПрисоединеннымиФайлами".
//    * Заголовок                  - Строка - заголовок гиперссылки. Значение по умолчанию - "Файлы".
//    * ОтображатьЗаголовокСправа  - Булево - если параметр принимает значение Истина, заголовок
//                                 будет отображаться после команд добавления, иначе - перед командами добавления.
//                                 Значение по умолчанию - Истина;
//    * ОтображатьКоличество       - Булево - если параметр принимает значение Истина, отображает
//                                 количество присоединенных файлов в заголовке. Значение по умолчанию - Истина.
//    * ДобавлятьФайлы             - Булево - если указать Ложь, команды добавления файлов будут отсутствовать.
//                                 Значение по умолчанию - Истина.
//    * ОтображениеФигуры          - Строка - строковое представление свойства "ОтображениеФигуры" для
//                                 команд добавления присоединенных файлов. Значение по умолчанию - "Авто".
//    * Видимость                  - Булево - если параметр принимает значение Ложь, гиперссылка на форме размещаться
//                                 не будет. Параметр имеет смысл только для глобального отключения видимости
//                                 в процедуре РаботаСФайламиПереопределяемый.ПриОпределенииГиперссылкиФайлов.
//
Функция ГиперссылкаФайлов() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ГиперссылкаФайлов() 
```
</details>

## ПолеФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для размещения поля присоединенного файла на форме.
//
// Возвращаемое значение:
//  Структура - параметры размещения гиперссылки. Свойства:
//    * Владелец                  - Строка - имя реквизита, содержащего ссылку на владельца присоединенных файлов.
//                                Значение по умолчанию - "Объект.Ссылка".
//    * Размещение                - Строка
//                                - Неопределено - если указано имя группы формы, поле будет
//                                размещено в указанной группе. Если указано имя элемента формы, поле будет
//                                вставлено перед указанным элементом. Если значение параметра - Неопределено
//                                или элемент не найден, поле будет добавлено на форму после всех существующих
//                                элементов. Значение по умолчанию - "УправлениеПрисоединеннымиФайлами".
//    * ПутьКДанным               - Строка
//                                - Неопределено - имя реквизита формы, содержащего ссылку на файл для
//                                отображения. Если параметр принимает значение Неопределено или реквизит не найден,
//                                добавляет реквизит формы с именем "ПолеПрисоединенногоФайла" и типом
//                                "ОпределяемыйТип.ПрисоединенныйФайл". Значение по умолчанию - "ПолеПрисоединенногоФайла".
//    * ПутьКДаннымИзображения    - Строка
//                                - Неопределено - имя реквизита формы, содержащего изображение, которое будет
//                                выведено в поле предпросмотра. Если параметр принимает значение Неопределено или реквизит
//                                не найден, добавляет реквизит формы с именем "ПолеКартинкиПрисоединенногоФайла" и типом
//                                "Строка". Значение по умолчанию - Неопределено.
//    * ТолькоОдинФайл            - Булево - если указать Истина, с помощью команд добавления можно будет
//                                присоединить только один файл. После добавления первого файла, команда "Добавить"
//                                будет заменять существующий файл на файл, выбранный пользователем, а нажатие на
//                                заголовок приведет к открытию файла для просмотра. Значение по умолчанию - Ложь.
//    * ПоказыватьПредпросмотр    - Булево - если параметр принимает значение Истина, добавляет на форму
//                                область предпросмотра присоединенного файла. Значение по умолчанию - Истина.
//    * ТекстНевыбраннойКартинки  - Строка - выводится в поле предпросмотра изображения, если
//                                изображение отсутствует. Значение по умолчанию - "Добавить изображение".
//    * Заголовок                 - Строка - если заголовок отличается от пустой строки, добавляет на форму заголовок
//                                поля присоединенного файла. Значение по умолчанию - "".
//    * ВыводитьЗаголовокФайла    - Булево - если параметр принимает значение Истина, добавляет гиперссылку
//                                заголовок которой соответствует краткому имени файла. Если значение параметра
//                                "Заголовок" отличается от "", заголовок файла будет добавлен после общего заголовка
//                                элемента управления. Значение по умолчанию - Ложь.
//    * ПоказыватьКоманднуюПанель - Булево - если параметр принимает значение Истина, команды будут размещены в
//                                командной панели на форме и в контекстном меню элемента предпросмотра, иначе -
//                                только в контекстном меню элемента предпросмотра. Значение по умолчанию - Истина.
//    * ДобавлятьФайлы            - Булево - если указать Ложь, команды добавления файлов будут отсутствовать.
//                                Значение по умолчанию - Истина.
//    * ВыбиратьФайл              - Булево - если параметр принимает значение Истина, добавляет команду выбора файла
//                                из присоединенных. Значение по умолчанию - Истина.
//    * ПросматриватьФайл         - Булево - если параметр принимает значение Истина, добавляет команду открытия
//                                файла для просмотра. Значение по умолчанию - Истина.
//    * РедактироватьФайл         - Строка - если параметр принимает значение "ВФорме", добавляет команду
//                                открытия формы присоединенного файла. Если параметр принимает значение
//                                "Непосредственно", добавляет команды редактирования файла, сохранения и отмены
//                                изменений. Если принимает значение "НеРедактировать", команды редактирования добавлены
//                                не будут. Значение по умолчанию - "ВФорме".
//    * ОчищатьФайл               - Булево - если параметр принимает значение Истина, добавляет команду очистки
//                                реквизита-владельца. Значение по умолчанию - Истина.
//    * МаксимальныйРазмер        - Число - ограничение на размер файла (в мегабайтах), загружаемого из файловой системы.
//                                Если принимает значение 0, проверка размера не проводится. Свойство игнорируется,
//                                если принимает значение больше, чем указано в константе МаксимальныйРазмерФайла.
//                                Значение по умолчанию - 0.
//    * ФильтрДиалогаВыбора       - Строка - фильтр, устанавливаемый в диалог выбора при добавлении файла.
//                                Формат см. в свойстве Фильтр объекта ДиалогВыбораФайла в синтакс-помощнике.
//                                Значение по умолчанию - "Все файлы (*.*)|*.*"
//
Функция ПолеФайла() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ПолеФайла() 
```
</details>

## ЕстьТомаХраненияФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет наличие активных томов хранения файлов.
// Если есть хоть один том хранения файлов, то будет возвращена Истина.
//
// Возвращаемое значение:
//  Булево - если Истина, тогда существует хотя бы один работающий том.
//
Функция ЕстьТомаХраненияФайлов() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ЕстьТомаХраненияФайлов() 
```
</details>

## ДобавитьПодписьКФайлу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет электронную подпись к файлу.
//
// Параметры:
//  ПрисоединенныйФайл - ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с файлом.
//
//  СвойстваПодписи    - см. ЭлектроннаяПодписьКлиентСервер.НовыеСвойстваПодписи
//                     - Массив - массив описанных выше структур.
//
//  ИдентификаторФормы - УникальныйИдентификатор - если указан, то используется при блокировке объекта.
//
Процедура ДобавитьПодписьКФайлу(ПрисоединенныйФайл, СвойстваПодписи, ИдентификаторФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ДобавитьПодписьКФайлу(ПрисоединенныйФайл, СвойстваПодписи, ИдентификаторФормы);
```
</details>

## СкопироватьПрисоединенныеФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При программном копировании Источника создает у Получателя копии всех
// присоединенных файлов. Для интерактивного копирования необходимо использовать
// процедуру РаботаСФайлами.ПриЗаписиНаСервере.
// Источник и Получатель должны быть объектами одного типа.
//
// Параметры:
//  Источник   - ЛюбаяСсылка - объект, имеющий присоединенные файлы для копирования.
//  Получатель - ЛюбаяСсылка - объект, к которому копируются присоединенные файлы.
//
Процедура СкопироватьПрисоединенныеФайлы(Знач Источник, Знач Получатель) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.СкопироватьПрисоединенныеФайлы(Источник, Получатель) 
```
</details>

## НастройкиРаботыСФайламиВФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для настройки работы с файлами в форме.
//
// Возвращаемое значение:
//  Структура - параметры копирования файлов. Свойства:
//    * КопироватьПрисоединенныеФайлы - Булево - признак копирования присоединенных файлов при копировании объекта-владельца
//                                   Значение по умолчанию - Ложь.
//
Функция НастройкиРаботыСФайламиВФорме() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.НастройкиРаботыСФайламиВФорме() 
```
</details>

## ПолучитьНастройкиСканированияПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает настройки сканирования пользователя.
//
// Параметры:
//  ИдентификаторКлиента - УникальныйИдентификатор - идентификатор клиента
//
// Возвращаемое значение:
//   см. РаботаСФайламиКлиентСервер.НастройкиСканированияПользователя
//
Функция ПолучитьНастройкиСканированияПользователя(ИдентификаторКлиента) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.ПолучитьНастройкиСканированияПользователя(ИдентификаторКлиента) 
```
</details>

## СохранитьНастройкиСканированияПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет настройки сканирования пользователя.
//
// Параметры:
//  НастройкиСканированияПользователя - см. РаботаСФайламиКлиентСервер.НастройкиСканированияПользователя
//  ИдентификаторКлиента - УникальныйИдентификатор
//
Процедура СохранитьНастройкиСканированияПользователя(НастройкиСканированияПользователя, ИдентификаторКлиента) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.СохранитьНастройкиСканированияПользователя(НастройкиСканированияПользователя, ИдентификаторКлиента) 
```
</details>

## СоздатьФайлНаОсновеФайлаНаДиске
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать РаботаСФайлами.ДобавитьФайлСДиска
// Добавляет к указанному владельцу файлов новый файл на основании файла из файловой системы.
// Если владелец файлов поддерживает хранение версий, то будет создана первая версия файла.
//
// Параметры:
//   ВладелецФайлов    - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - папка файлов или объект, к которому
//                       требуется прикрепить добавляемый файл.
//   ПутьКФайлуНаДиске - Строка - полный путь к файлу, включающий имя и расширение файла.
//                       Файл должен находиться на сервере.
//
// Возвращаемое значение:
//  ОпределяемыйТип.ПрисоединенныйФайл - ссылка на элемент справочника с созданным файлом.
//
Функция СоздатьФайлНаОсновеФайлаНаДиске(ВладелецФайлов, ПутьКФайлуНаДиске) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.СоздатьФайлНаОсновеФайлаНаДиске(ВладелецФайлов, ПутьКФайлуНаДиске) 
```
</details>

## ОпределитьФормуПрисоединенногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать РаботаСФайламиКлиентСервер.ОпределитьФормуПрисоединенногоФайла.
// Обработчик подписки на событие ОбработкаПолученияФормы для переопределения формы файла.
//
// Параметры:
//  Источник                 - СправочникМенеджер - менеджер справочника с именем "*ПрисоединенныеФайлы".
//  ВидФормы                 - Строка - имя стандартной формы.
//  Параметры                - Структура - параметры формы.
//  ВыбраннаяФорма           - Строка - имя или объект метаданных открываемой формы.
//  ДополнительнаяИнформация - Структура - дополнительная информация открытия формы.
//  СтандартнаяОбработка     - Булево - признак выполнения стандартной (системной) обработки события.
//
Процедура ОпределитьФормуПрисоединенногоФайла(Источник, ВидФормы, Параметры, Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ОпределитьФормуПрисоединенногоФайла(Источник, ВидФормы, Параметры, );
```
</details>

## ИзменитьСправочникХраненияФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать СконвертироватьФайлыВПрисоединенные.
//
// Переносит файлы из справочника Файлы в присоединенные файлы при объекте-владельце файлов и помечает
// перенесенные файлы к удалению.
//
// Для использования в процедурах обновления ИБ.
// Выполняется последовательно для каждого элемента объекта-владельца файлов
// (элемента справочника, ПВХ, документа и т.п.).
//
// Параметры:
//   ВладелецФайлов - ЛюбаяСсылка - ссылка на объект, для которого выполняется конвертация.
//   ИмяСправочника - Строка - если требуется конвертация в указанное хранилище.
//
Процедура ИзменитьСправочникХраненияФайлов(Знач ВладелецФайлов, ИмяСправочника = Неопределено) Экспорт
```

Пример вызова
```bsl
РаботаСФайлами.ИзменитьСправочникХраненияФайлов(ВладелецФайлов, ИмяСправочника);
```
</details>

## СконвертироватьФайлыВПрисоединенные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать РаботаСФайлами.ПеренестиФайлыМеждуСправочникамиХранения.
// Переносит файлы из справочника Файлы в присоединенные файлы при объекте-владельце файлов и помечает
// перенесенные файлы к удалению.
//
// Для использования в процедурах обновления ИБ, если выполняется переход от использования
// хранения файлов в справочнике Файлы на хранение файлов как присоединенных при объекте-владельце файлов.
// Выполняется последовательно для каждого элемента объекта-владельца файлов
// (элемента справочника, ПВХ, документа и т.п.).
//
// Параметры:
//   ВладелецФайлов - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект-владелец - приемник файлов.
//   ИмяСправочника - Строка - если требуется конвертация в указанное хранилище.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//   * Ключ     - СправочникСсылка.Файлы - перенесенный файл, который помечен на удаление после переноса.
//   * Значение - ОпределяемыйТип.ПрисоединенныйФайл - созданный файл.
//
Функция СконвертироватьФайлыВПрисоединенные(Знач ВладелецФайлов, ИмяСправочника = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайлами.СконвертироватьФайлыВПрисоединенные(ВладелецФайлов, ИмяСправочника);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
