---
title: Работа с файлами клиент сервер
slug: bsp/работа-с-файлами-клиент-сервер
---


## ПараметрыДанныхФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для получения данных файла. См. РаботаСФайлами.ДанныеФайла.
//
// Возвращаемое значение:
//  Структура:
//    * ИдентификаторФормы             - УникальныйИдентификатор - уникальный идентификатор формы, во временное хранилище
//                                     которой надо поместить файл и вернуть адрес в свойстве СсылкаНаДвоичныеДанныеФайла.
//                                     Значение по умолчанию - Неопределено.
//    * ПолучатьСсылкуНаДвоичныеДанные - Булево - если передать Ложь, то ссылка на двоичные данные в СсылкаНаДвоичныеДанныеФайла
//                                     не будет получена, что существенно ускорит выполнение для больших двоичных данных.
//                                     Значение по умолчанию - Истина.
//    * ДляРедактирования              - Булево - если указать Истина, то файл будет захвачен для редактирования.
//                                     Значение по умолчанию - Ложь.
//    * ВызыватьИсключение             - Булево - если указать Ложь, то функция в исключительных ситуациях не будет вызывать
//                                     исключений и вернет Неопределено. Значение по умолчанию - Истина.
//
Функция ПараметрыДанныхФайла() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайламиКлиентСервер.ПараметрыДанныхФайла() 
```
</details>

## ОпределитьФормуПрисоединенногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ОбработкаПолученияФормы для переопределения формы файла.
//
// Параметры:
//  Источник                 - СправочникМенеджер - менеджер справочника с именем "*ПрисоединенныеФайлы".
//  ВидФормы                 - Строка - имя стандартной формы.
//  Параметры                - Структура - параметры формы.
//  ВыбраннаяФорма           - Строка - имя или объект метаданных открываемой формы.
//  ДополнительнаяИнформация - Структура - дополнительная информация открытия формы.
//  СтандартнаяОбработка     - Булево - признак выполнения стандартной (системной) обработки события.
//
Процедура ОпределитьФормуПрисоединенногоФайла(Источник, ВидФормы, Параметры, Экспорт
```

Пример вызова
```bsl
РаботаСФайламиКлиентСервер.ОпределитьФормуПрисоединенногоФайла(Источник, ВидФормы, Параметры, );
```
</details>

## НастройкиСканированияПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки сканирования пользователя.
//
// Возвращаемое значение:
//  Структура:
//   * ПоказыватьДиалогСканера - Булево
//   * ИмяУстройства - Строка - НаименованиеСканера
//   * ФорматСканированногоИзображения - ПеречислениеСсылка.ФорматыСканированногоИзображения
//   * СохранятьВPDF - Булево
//   * ФорматХраненияМногостраничный - ПеречислениеСсылка.ФорматыХраненияМногостраничныхФайлов
//   * Разрешение - ПеречислениеСсылка.РазрешенияСканированногоИзображения
//   * Цветность - ПеречислениеСсылка.ЦветностиИзображения
//   * Поворот - ПеречислениеСсылка.СпособыПоворотаИзображения
//   * РазмерБумаги - ПеречислениеСсылка.РазмерыБумаги
//   * ДвустороннееСканирование - Булево
//   * АвтоматическаяПодачаДокументов - Булево
//   * ИспользоватьImageMagickДляПреобразованияВPDF - Булево
//   * КачествоJPG - Число
//   * СжатиеTIFF - ПеречислениеСсылка.ВариантыСжатияTIFF
//   * ПутьКПрограммеКонвертации - Строка
//
Функция НастройкиСканированияПользователя() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФайламиКлиентСервер.НастройкиСканированияПользователя() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
