---
title: Распределенное выполнение команд
slug: bsp/распределенное-выполнение-команд
---


## ВыполнитьКомандуДополнительнойОбработки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает команду указанной дополнительной обработки и передает в нее параметры,
// регистрирует сообщение для МС с результатами выполнения.
// Важно! Вызывается как фоновое задание.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//	ИдентификаторОбработки - Строка - указывает на обработку, команду которой нужно выполнить.
//	ИдентификаторКоманды - Строка - имя команды (как оно задано в обработке), которую нужно выполнить.
//	ИдентификаторОперации - Строка - позволяет идентифицировать отдельные вызовы (например, для логирования).
//	СообщитьМенеджеру - Булево - указывает на необходимость сообщить Менеджеру сервиса о результате выполнения команды.
//
Процедура ВыполнитьКомандуДополнительнойОбработки(ИдентификаторОбработки, ИдентификаторКоманды, ИдентификаторОперации, СообщитьМенеджеру = Ложь) Экспорт
```

Пример вызова
```bsl
РаспределенноеВыполнениеКоманд.ВыполнитьКомандуДополнительнойОбработки(ИдентификаторОбработки, ИдентификаторКоманды, ИдентификаторОперации, СообщитьМенеджеру);
```
</details>

## ВыполнитьПередачуФайлаПриложению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает команду передачи файла из текущей области данных в любую другую область
// данных сервиса.
// Важно! Если какой-либо из параметров передан некорректно, вызывается исключение.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//	ИмяФайла - Строка - полное имя к передаваемому файлу.
//	КодПолучателя - Число - код области данных, куда нужно передать файл.
//	БыстраяПередача - Булево - указывает, что необходимо использовать быстрые сообщения для передачи файла.
//	ПараметрыВызова - Структура - дополнительные параметры вызова:
//		* Код - Число - код ответа,
//		* Тело - Строка - тело ответа.
//
// Возвращаемое значение:
//   УникальныйИдентификатор - идентификатор вызова.
//
Функция ВыполнитьПередачуФайлаПриложению(ИмяФайла, КодПолучателя, БыстраяПередача = Ложь, ПараметрыВызова = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспределенноеВыполнениеКоманд.ВыполнитьПередачуФайлаПриложению(ИмяФайла, КодПолучателя, БыстраяПередача, ПараметрыВызова);
```
</details>

## ВыслатьКвитанциюПередачиФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет области-получателю сообщение-квитанцию о получении (завершении обработки,
// и так далее) ранее полученного файла.
// Важно! Если какой-либо из параметров передан некорректно, вызывается исключение.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//	ИдентификаторВызова - УникальныйИдентификатор - ранее выданный функцией ВыполнитьПередачуФайлаПриложению
//	КодПолучателя - Число - код области данных, куда нужно передать квитанцию.
//	БыстраяПередача - Булево - указывает, что необходимо использовать быстрые сообщения для передачи файла.
//	ПараметрыВызова - Структура - дополнительные параметры вызова:
//	  * Код - Число - код ответа,
//	  * Тело - Строка - тело ответа.
//
Процедура ВыслатьКвитанциюПередачиФайла(ИдентификаторВызова, КодПолучателя, БыстраяПередача = Ложь, ПараметрыВызова = Неопределено) Экспорт
```

Пример вызова
```bsl
РаспределенноеВыполнениеКоманд.ВыслатьКвитанциюПередачиФайла(ИдентификаторВызова, КодПолучателя, БыстраяПередача, ПараметрыВызова);
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//	СоответствиеИменПсевдонимам - см. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков.СоответствиеИменПсевдонимам
//
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
РаспределенноеВыполнениеКоманд.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
