---
title: Склонение представлений объектов клиент
slug: bsp/склонение-представлений-объектов-клиент
---


## ПросклонятьПредставление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Склоняет переданную фразу по всем падежам.
// Результат фиксируется в данных формы.
//
// Параметры:
//  Форма				 - ФормаКлиентскогоПриложения	 - форма объекта склонения.
//  Представление		 - Строка			 - строка для склонения.
//  ПараметрыСклонения	 - Структура		 - параметры склонения, созданные методом СклонениеПредставленийОбъектовКлиентСервер.ПараметрыСклонения().
//  ПоказыватьСообщения	 - Булево			 - признак, определяющий нужно ли показывать пользователю сообщения об ошибках.
//
Процедура ПросклонятьПредставление(Форма, Представление, ПараметрыСклонения = Неопределено, ПоказыватьСообщения = Ложь) Экспорт
```

Пример вызова
```bsl
СклонениеПредставленийОбъектовКлиент.ПросклонятьПредставление(Форма, Представление, ПараметрыСклонения, ПоказыватьСообщения);
```
</details>

## ПоказатьСклонение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик команды "Склонения" формы объекта склонения.
// Открывает форму редактирования склонений представления по всем падежам.
//
// Параметры:
//  Форма				 - ФормаКлиентскогоПриложения	 - форма объекта склонения.
//  Представление		 - Строка			 - строка для склонения.
//  ПараметрыСклонения	 - Структура		 - параметры склонения, созданные методом СклонениеПредставленийОбъектовКлиентСервер.ПараметрыСклонения().
//
Процедура ПоказатьСклонение(Форма, Представление, ПараметрыСклонения = Неопределено) Экспорт
```

Пример вызова
```bsl
СклонениеПредставленийОбъектовКлиент.ПоказатьСклонение(Форма, Представление, ПараметрыСклонения);
```
</details>

## ПриИзмененииПредставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. См. СклонениеПредставленийОбъектовКлиент.ПросклонятьПредставление.
Процедура ПриИзмененииПредставления(Форма) Экспорт
```

Пример вызова
```bsl
СклонениеПредставленийОбъектовКлиент.ПриИзмененииПредставления(Форма) 
```
</details>

## ПросклонятьПредставлениеПоВсемПадежам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. См. СклонениеПредставленийОбъектовКлиент.ПросклонятьПредставление.
// Склоняет переданную фразу по всем падежам.
//
// Параметры:
//  Форма 			- ФормаКлиентскогоПриложения - форма объекта склонения.
//  Представление   - Строка - строка для склонения.
//  ЭтоФИО       	- Булево - признак склонения ФИО.
//  Пол				- Число	- пол физического лица (в случае склонения ФИО)
//							1 - мужской
//							2 - женский.
//  ПоказыватьСообщения - Булево - признак, определяющий нужно ли показывать пользователю сообщения об ошибках.
//
Процедура ПросклонятьПредставлениеПоВсемПадежам(Форма, Представление, ЭтоФИО = Ложь, Пол = Неопределено, ПоказыватьСообщения = Ложь) Экспорт
```

Пример вызова
```bsl
СклонениеПредставленийОбъектовКлиент.ПросклонятьПредставлениеПоВсемПадежам(Форма, Представление, ЭтоФИО, Пол, ПоказыватьСообщения);
```
</details>

## ОбработатьКомандуСклонения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. См. СклонениеПредставленийОбъектовКлиент.ПоказатьСклонение.
// Обработчик команды "Склонения" формы объекта склонения.
//
// Параметры:
//  Форма 			- ФормаКлиентскогоПриложения - форма объекта склонения.
//  Представление   - Строка - строка для склонения.
//  ЭтоФИО       	- Булево - признак склонения ФИО.
//  Пол				- Число	- пол физического лица (в случае склонения ФИО)
//							1 - мужской
//							2 - женский.
//
Процедура ОбработатьКомандуСклонения(Форма, Представление, ЭтоФИО = Ложь, Пол = Неопределено) Экспорт
```

Пример вызова
```bsl
СклонениеПредставленийОбъектовКлиент.ОбработатьКомандуСклонения(Форма, Представление, ЭтоФИО, Пол);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
