---
title: Соединения ИБ
slug: bsp/соединения-иб
---


## УстановитьБлокировкуСоединений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает блокировку соединений ИБ.
// Если вызывается из сеанса с установленными значениями разделителей,
// то устанавливает блокировку сеансов области данных.
//
// Параметры:
//  ТекстСообщения           - Строка - текст, который будет частью сообщения об ошибке
//                                      при попытке установки соединения с заблокированной
//                                      информационной базой.
//
//  КодРазрешения            - Строка - строка, которая должна быть добавлена к параметру
//                                      командной строки "/uc" или к параметру строки
//                                      соединения "uc", чтобы установить соединение с
//                                      информационной базой несмотря на блокировку.
//                                      Не применимо для блокировки сеансов области данных.
//  ОжиданиеНачалаБлокировки - Число -  время отсрочки начала блокировки в минутах.
//  ДлительностьБлокировки   - Число -  время длительности блокировки в минутах.
//
// Возвращаемое значение:
//   Булево   - Истина, если блокировка установлена успешно.
//              Ложь, если для выполнения блокировки недостаточно прав.
//
Функция УстановитьБлокировкуСоединений(Знач ТекстСообщения = "", Знач КодРазрешения = "КодРазрешения", // АПК:142 Для сохранения обратной совместимости. Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.УстановитьБлокировкуСоединений(ТекстСообщения, КодРазрешения, // АПК:142 Для сохранения обратной совместимости.);
```
</details>

## УстановленаБлокировкаСоединений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определить, установлена ли блокировка соединений при пакетном
// обновлении конфигурации информационной базы.
//
// Возвращаемое значение:
//    Булево - Истина, если установлена, Ложь - иначе.
//
Функция УстановленаБлокировкаСоединений() Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.УстановленаБлокировкаСоединений() 
```
</details>

## ПараметрыБлокировкиСеансов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить параметры блокировки соединений ИБ для использования на стороне клиента.
//
// Параметры:
//    ПолучитьКоличествоСеансов - Булево - если Истина, то в возвращаемой структуре
//                                         заполняется поле КоличествоСеансов.
//
// Возвращаемое значение:
//   Структура:
//     * Установлена       - Булево - Истина, если установлена блокировка, Ложь - иначе.
//     * Начало            - Дата   - дата начала блокировки.
//     * Конец             - Дата   - дата окончания блокировки.
//     * Сообщение         - Строка - сообщение пользователю.
//     * ИнтервалОжиданияЗавершенияРаботыПользователей - Число - интервал в секундах.
//     * КоличествоСеансов - Число  - 0, если параметр ПолучитьКоличествоСеансов = Ложь.
//     * ТекущаяДатаСеанса - Дата   - текущая дата сеанса.
//
Функция ПараметрыБлокировкиСеансов(Знач ПолучитьКоличествоСеансов = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.ПараметрыБлокировкиСеансов(ПолучитьКоличествоСеансов);
```
</details>

## РазрешитьРаботуПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Снять блокировку информационной базы.
//
// Возвращаемое значение:
//   Булево   - Истина, если операция выполнена успешно.
//              Ложь, если для выполнения операции недостаточно прав.
//
Функция РазрешитьРаботуПользователей() Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.РазрешитьРаботуПользователей() 
```
</details>

## ИнформацияОСоединениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о текущих соединениях с информационной базой.
// При необходимости записывает сообщение в журнал регистрации.
//
// Параметры:
//    ПолучатьСтрокуСоединения - Булево - признак необходимости добавления в возвращаемое значение строки соединения.
//    СообщенияДляЖурналаРегистрации - СписокЗначений - если параметр не пустой, то будет выполнена запись событий
//                                                      из списка в журнал регистрации.
//    ПортКластера - Число - нестандартный порт кластера серверов.
//
// Возвращаемое значение:
//    Структура:
//        * НаличиеАктивныхСоединений - Булево - признак наличия активных соединений.
//        * НаличиеCOMСоединений - Булево - признак наличия com соединений.
//        * НаличиеСоединенияКонфигуратором - Булево - признак наличия соединения конфигуратора.
//        * ЕстьАктивныеПользователи - Булево - признак наличия активных пользователей.
//        * СтрокаСоединенияИнформационнойБазы - Строка - строка соединения информационной базы. Свойство будет,
//                                                            только если параметр ПолучатьСтрокуСоединения был
//                                                            установлен в значение Истина.
//
Функция ИнформацияОСоединениях(ПолучатьСтрокуСоединения = Ложь, Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.ИнформацияОСоединениях(ПолучатьСтрокуСоединения, );
```
</details>

## НовыеПараметрыБлокировкиСоединений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить пустую структуру с параметрами блокировки сеансов области данных.
//
// Возвращаемое значение:
//   Структура:
//     * Начало         - Дата   - время начала действия блокировки.
//     * Конец          - Дата   - время завершения действия блокировки.
//     * Сообщение      - Строка - сообщения для пользователей, выполняющих вход в заблокированную область данных.
//     * Установлена    - Булево - признак того, что блокировка установлена.
//     * Эксклюзивная   - Булево - блокировка не может быть изменена администратором приложения.
//
Функция НовыеПараметрыБлокировкиСоединений() Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.НовыеПараметрыБлокировкиСоединений() 
```
</details>

## УстановитьБлокировкуСеансовОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить блокировку сеансов области данных.
//
// Параметры:
//   Параметры         - см. НовыеПараметрыБлокировкиСоединений
//   ПоМестномуВремени - Булево - время начала и окончания блокировки указаны в местном времени сеанса.
//                                Если Ложь, то в универсальном времени.
//   ОбластьДанных - Число - номер области данных, для которой устанавливается блокировка.
//     При вызове из сеанса, в котором заданы значения разделителей, может быть передано только значение,
//       совпадающее со значением разделителя в сеансе (или опущено).
//     При вызове из сеанса, в котором не заданы значения разделителей, значение параметра не может быть опущено.
//
Процедура УстановитьБлокировкуСеансовОбластиДанных(Знач Параметры, Знач ПоМестномуВремени = Истина, Знач ОбластьДанных = -1) Экспорт
```

Пример вызова
```bsl
СоединенияИБ.УстановитьБлокировкуСеансовОбластиДанных(Параметры, ПоМестномуВремени, ОбластьДанных);
```
</details>

## ПолучитьБлокировкуСеансовОбластиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить информацию о блокировке сеансов области данных.
//
// Параметры:
//   ПоМестномуВремени - Булево - время начала и окончания блокировки необходимо вернуть
//                                в местном времени сеанса. Если Ложь, то
//                                возвращается в универсальном времени.
//
// Возвращаемое значение:
//   см. НовыеПараметрыБлокировкиСоединений.
//
Функция ПолучитьБлокировкуСеансовОбластиДанных(Знач ПоМестномуВремени = Истина) Экспорт
```

Пример вызова
```bsl
Результат = СоединенияИБ.ПолучитьБлокировкуСеансовОбластиДанных(ПоМестномуВремени);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
