---
title: Сообщения в службу технической поддержки
slug: bsp/сообщения-в-службу-технической-поддержки
---


## ПодготовитьСообщение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует сообщение для отправки сообщения в службу технической
// поддержки. В параметрах передаются данные заполнения, вложения
// и параметры выгрузки журнала регистрации.
//
// Параметры:
//  ДанныеСообщения - Структура - данные для формирования сообщения,
//                    См. СообщенияВСлужбуТехническойПоддержкиКлиентСервер.ДанныеСообщения;
//  Вложения - Массив Из Структура, Неопределено - файлы вложений. Важно: допускаются только
//              текстовые вложения (*.txt, *.json, *.xml). Поля структуры элемента вложения:
//   * Представление - Строка - представление вложения. Например, "Вложение 1.txt";
//   * ВидДанных - Строка - определяет преобразование переданных данных.
//                Возможна передача одного из значений:
//                  - ИмяФайла - Строка - полное имя файла вложения;
//                  - Адрес - Строка - адрес во временном хранилище значения типа ДвоичныеДанные;
//                  - Текст - Строка - текст вложения;
//   * Данные - Строка - данные для формирования вложения;
//  ОтборЖурналаРегистрации - Структура, Неопределено - настройки выгрузки журнала регистрации:
//    * ДатаНачала    - Дата - начало периода журнала;
//    * ДатаОкончания - Дата - конец периода журнала;
//    * События       - Массив - список событий;
//    * Метаданные    - Массив, Неопределено - массив метаданных для отбора;
//    * Уровень       - Строка - уровень важности событий журнала регистрации. Возможные значения:
//       - "Ошибка" - будет выполнен отбор по событиям с УровеньЖурналаРегистрации.Ошибка;
//       - "Предупреждение" - будет выполнен отбор по событиям с УровеньЖурналаРегистрации.Предупреждение;
//       - "Информация" - будет выполнен отбор по событиям с УровеньЖурналаРегистрации.Информация;
//       - "Примечание" - будет выполнен отбор по событиям с УровеньЖурналаРегистрации.Примечание.
//
// Возвращаемое значение:
//  Структура - результат отправки сообщения:
//   * КодОшибки - Строка - идентификатор ошибки при отправки:
//                          - <Пустая строка> - отправка выполнена успешно;
//                          - "НеверныйФорматЗапроса" - переданы некорректные параметры
//                             сообщения в техническую поддержку;
//                          - "НеизвестнаяОшибка" - при отправке сообщения возникли ошибки;
//                          - "НеизвестнаяОшибкаСервиса" - при отправке сообщения возникли проблемы с сервисом;
//                          - "ОтсутствуетОбязательныйПараметрЗапроса" - отсутствует обязательный параметр
//                             сообщения в техническую поддержку;
//                          - "ОшибкаФайловойСистемы" - ошибка файловой системы;
//                          - "ПревышенМаксимальныйРазмерВложения" - превышен максимальный размер вложения;
//                          - "ПревышенМаксимальныйРазмерЖурналаРегистрации" - превышен максимальный размер
//                             журнала регистрации;
//                          - "ПустойПараметрЗапроса" - не заполнен обязательный параметр
//                             сообщения в техническую поддержку;
//   * СообщениеОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//   * ИспользуетсяИнформационныйЦентр - Булево - признак использования Информационного центра.
//   * СообщениеВИнформационныйЦентр - Структура, Неопределено - параметры передачи обращения в Информационный центр.
//                                                    Когда не используется Информационный центр, тогда Неопределено:
//    ** Тема - Строка - тема обращения
//    ** Текст - Строка - текст обращения
//    ** ИспользоватьСтандартныйШаблон - Булево - если Истина, то текст обращения будет заполнен по шаблону
//                                              из метода ИнформационныйЦентрСервер.ШаблонТекстаВТехПоддержку;
//    ** Вложения - Массив из Структура - массив сложения из структур с полями:
//     *** ИмяФайла - Строка - имя файла-вложения с расширением, например "file.txt";
//     *** АдресВоВременномХранилище - Строка - адрес файла-вложения во временном хранилище;
//    ** ОбработчикЗавершения - ОписаниеОповещения, Неопределено - описание оповещения о закрытии формы нового обращения;
//    ** ДополнительныеДанные - Структура - произвольная структура данных, которую можноп ередать в службу поддержки.
//                                        Эта структура должна быть сериализуемой в JSON;
//   * URLСтраницы - Строка - URL страницы отправки сообщения.
//
Функция ПодготовитьСообщение( Экспорт
```

Пример вызова
```bsl
Результат = СообщенияВСлужбуТехническойПоддержки.ПодготовитьСообщение();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
