---
title: Стандартные подсистемы клиент
slug: bsp/стандартные-подсистемы-клиент
---


## УстановитьРасширенныйЗаголовокПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает заголовок главного окна приложения, используя значение константы
// ЗаголовокПриложения и заголовок приложения по умолчанию.
//
// Параметры:
//   ПриЗапуске - Булево - Истина, если вызывается при начале работы программы.
//
Процедура УстановитьРасширенныйЗаголовокПриложения(ПриЗапуске = Ложь) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.УстановитьРасширенныйЗаголовокПриложения(ПриЗапуске);
```
</details>

## ПоказатьВопросПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показать форму вопроса.
//
// Параметры:
//   ОписаниеОповещенияОЗавершении - ОписаниеОповещения - описание процедуры, которая будет вызвана после закрытия окна
//                                                        вопроса со следующими параметрами:
//                                                          РезультатВопроса - Структура:
//                                                            Значение - результат выбора пользователя: значение
//                                                                       системного перечисления или значение,
//                                                                       связанное с нажатой кнопкой. В случае закрытия
//                                                                       диалога по истечении времени - значение
//                                                                       Таймаут.
//                                                            БольшеНеЗадаватьЭтотВопрос - Булево - результат выбора
//                                                                                                  пользователя в
//                                                                                                  одноименном флажке.
//                                                          ДополнительныеПараметры - Структура
//   ТекстВопроса                  - Строка, ФорматированнаяСтрока - текст задаваемого вопроса.
//   Кнопки                        - РежимДиалогаВопрос
//                                 - СписокЗначений     - может быть задан список значений, в котором:
//                                       Значение - содержит значение, связанное с кнопкой и возвращаемое при
//                                                  ее нажатии. В качестве значения может использоваться значение
//                                                  перечисления КодВозвратаДиалога, а также другие значения,
//                                                  поддерживающее XDTO-сериализацию.
//                                       Представление - текст кнопки.
//
//   ДополнительныеПараметры       - см. СтандартныеПодсистемыКлиент.ПараметрыВопросаПользователю.
//
Процедура ПоказатьВопросПользователю(ОписаниеОповещенияОЗавершении, ТекстВопроса, Кнопки, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПоказатьВопросПользователю(ОписаниеОповещенияОЗавершении, ТекстВопроса, Кнопки, ДополнительныеПараметры);
```
</details>

## ПараметрыВопросаПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую структуру дополнительных параметров для процедуры ПоказатьВопросПользователю.
//
// Возвращаемое значение:
//  Структура:
//    * КнопкаПоУмолчанию             - Произвольный - определяет кнопку по умолчанию по типу кнопки или по связанному
//                                                     с ней значению.
//    * Таймаут                       - Число        - интервал времени в секундах до автоматического закрытия окна
//                                                     вопроса.
//    * КнопкаТаймаута                - Произвольный - кнопка (по типу кнопки или по связанному с ней значению),
//                                                     на которой отображается количество секунд, оставшихся до
//                                                     истечения таймаута.
//    * Заголовок                     - Строка       - заголовок вопроса.
//    * ПредлагатьБольшеНеЗадаватьЭтотВопрос - Булево - если Истина, то в окне вопроса будет доступен одноименный флажок.
//    * БольшеНеЗадаватьЭтотВопрос    - Булево       - принимает значение, выбранное пользователем в соответствующем
//                                                     флажке.
//    * БлокироватьВесьИнтерфейс      - Булево       - если Истина, форма вопроса открывается, блокируя работу всех
//                                                     остальных открытых окон, включая главное окно.
//    * Картинка                      - Картинка     - картинка, выводимая в окне вопроса.
//    * ТекстФлажка                   - Строка       - текст флажка "Больше не спрашивать".
//
Функция ПараметрыВопросаПользователю() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ПараметрыВопросаПользователю() 
```
</details>

## ОткрытьСписокАктивныхПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при необходимости открыть форму списка активных пользователей,
// которые в данный момент времени работают с системой.
//
// Параметры:
//    ПараметрыФормы - Структура        - см. описание параметра Параметры метода ОткрытьФорму в синтакс-помощнике.
//    ВладелецФормы  - ФормаКлиентскогоПриложения - см. описание параметра Владелец метода ОткрытьФорму в синтакс-помощнике.
//
Процедура ОткрытьСписокАктивныхПользователей(ПараметрыФормы = Неопределено, ВладелецФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ОткрытьСписокАктивныхПользователей(ПараметрыФормы, ВладелецФормы);
```
</details>

## ВыбратьОбъектыМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открыть выбор объектов метаданных.
//
// Параметры:
//  ПараметрыФормы - см. СтандартныеПодсистемыКлиентСервер.ПараметрыВыбораОбъектовМетаданных
//  ОписаниеОповещенияОЗакрытии - ОписаниеОповещения - оповещение, вызываемое при закрытии формы с параметрами:
//			# ВыбранныеОбъектыМетаданных - СписокЗначений - полные имена выбранных объектов метаданных,
//				или ссылки на идентификаторы объектов метаданных, если параметр ВыбиратьСсылки установлен в Истина.
//			# ДополнительныеПараметры - Произвольный - дополнительные параметры, переданные при создании оповещения.
//		Если ОписаниеОповещенияОЗакрытии не указано, то будет вызвано оповещение, которое можно получить
//		с помощью обработчика ОбработкаОповещения:
//			# ИмяСобытия - Строка - "ВыборОбъектовМетаданных"
//			# Параметр - СписокЗначений - выбранные объекты метаданных.
//			# Источник - см. СтандартныеПодсистемыКлиентСервер.ПараметрыВыбораОбъектовМетаданных.УникальныйИдентификаторИсточник
//
Процедура ВыбратьОбъектыМетаданных(ПараметрыФормы, ОписаниеОповещенияОЗакрытии = Неопределено) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ВыбратьОбъектыМетаданных(ПараметрыФормы, ОписаниеОповещенияОЗакрытии);
```
</details>

## ПоказатьРедакторТабличногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открыть табличный документ на просмотр или редактирование.
// При записи отредактированного табличного документа также вызывается оповещение, которое можно получить
// с помощью обработчика ОбработкаОповещения:
//	# ИмяСобытия - Строка - "Запись_ТабличныйДокумент" или "ОтменаРедактированияТабличногоДокумента"
//	# Параметр - Структура:
//	  ## ПутьКФайлу - Строка - полный путь к файлу отредактированного табличного документа.
//	  ## Представление - Строка - имя документа, заданное в ПараметрыРедактораТабличногоДокумента.ИмяДокумента
//	# Источник - ФормаКлиентскогоПриложения - форма редактора табличного документа.
//
// Параметры:
//  ТабличныйДокумент - ТабличныйДокумент - отображаемый или редактируемый табличный документ.
//  ПараметрыФормы - см. СтандартныеПодсистемыКлиент.ПараметрыРедактораТабличногоДокумента
//  ОписаниеОповещенияОЗакрытии - ОписаниеОповещения - оповещение, которое будет вызвано при закрытии
//                                                     формы редактора табличного документа.
//  Владелец - ФормаКлиентскогоПриложения - форма-владелец.
//
Процедура ПоказатьРедакторТабличногоДокумента(Знач ТабличныйДокумент, Знач ПараметрыФормы = Неопределено, Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПоказатьРедакторТабличногоДокумента(ТабличныйДокумент, ПараметрыФормы, );
```
</details>

## ПараметрыРедактораТабличногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры редактора табличного документа для СтандартныеПодсистемыКлиент.ПоказатьРедакторТабличногоДокумента.
//
// Возвращаемое значение:
//  Структура:
//   * ИмяДокумента - Строка - наименование табличного документа, выводимое в заголовке редактора.
//   * ТабличныйДокумент - ТабличныйДокумент, Строка - отображаемый или редактируемый табличный документ.
//                         Также может быть указан адрес табличного документа во временном хранилище.
//   * ПутьКФайлу - Строка - полный путь к файлу табличного документа, опционально.
//   * Редактирование - Булево - если Истина, то табличный документ можно отредактировать. По умолчанию Ложь.
//
Функция ПараметрыРедактораТабличногоДокумента() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ПараметрыРедактораТабличногоДокумента() 
```
</details>

## ПоказатьСравнениеТабличныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отрыть форму сравнения табличных документов, в которой можно посмотреть их отличия.
//
// Параметры:
//  ТабличныйДокументЛевый - ТабличныйДокумент - первый сравниваемый табличный документ.
//  ТабличныйДокументПравый - ТабличныйДокумент - второй сравниваемый табличный документ.
//  Параметры - см. ПараметрыСравненияТабличныхДокументов
//
Процедура ПоказатьСравнениеТабличныхДокументов(ТабличныйДокументЛевый, ТабличныйДокументПравый, Параметры) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПоказатьСравнениеТабличныхДокументов(ТабличныйДокументЛевый, ТабличныйДокументПравый, Параметры) 
```
</details>

## ПараметрыСравненияТабличныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры сравнения табличных документов для процедуры ПоказатьСравнениеТабличныхДокументов.
//
// Возвращаемое значение:
//  Структура:
//    * АдресТабличныхДокументов - Строка - адрес сравниваемых табличных документов во временном хранилище.
//    * Заголовок - Строка - заголовок формы. Если не задано, то "Сравнение табличных документов".
//    * ЗаголовокЛевый - Строка - заголовок первого табличного документа (слева).
//    * ЗаголовокПравый - Строка - заголовок правого табличного документа (справа).
//
Функция ПараметрыСравненияТабличныхДокументов() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ПараметрыСравненияТабличныхДокументов() 
```
</details>

## ЭтоБазоваяВерсияКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. СтандартныеПодсистемыСервер.ЭтоБазоваяВерсияКонфигурации
Функция ЭтоБазоваяВерсияКонфигурации() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ЭтоБазоваяВерсияКонфигурации() 
```
</details>

## ЭтоУчебнаяПлатформа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. СтандартныеПодсистемыСервер.ЭтоУчебнаяПлатформа
Функция ЭтоУчебнаяПлатформа() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ЭтоУчебнаяПлатформа() 
```
</details>

## ВывестиИнформациюОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает метод ПоказатьИнформациюОбОшибке объекта ОбработкаОшибок.
// Требуется использовать для возможности автоматического тестирования,
// чтобы перехватывать ошибки с помощью расширения.
//
// Параметры:
//  ИнформацияОбОшибке - ИнформацияОбОшибке
//
// Пример:
//	// Параметры:
//	//  Результат - см. ДлительныеОперацииКлиент.НовыйРезультатДлительнойОперации
//	//  ДополнительныеПараметры - Неопределено
//	//
//	&НаКлиенте
//	Процедура ОбновитьТекущийСписокЗавершение(Результат, ДополнительныеПараметры) Экспорт
//		Если Результат = Неопределено Тогда
//			Возврат;
//		КонецЕсли;
//		Если Результат.Статус = "Ошибка" Тогда
//			СтандартныеПодсистемыКлиент.ВывестиИнформациюОбОшибке(Результат.ИнформацияОбОшибке);
//			Возврат;
//		КонецЕсли;
//		... // Статус = "Выполнено"
//	КонецПроцедуры
//
Процедура ВывестиИнформациюОбОшибке(ИнформацияОбОшибке) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ВывестиИнформациюОбОшибке(ИнформацияОбОшибке) 
```
</details>

## НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает видимость указанному элементу, если ошибка
// не подходит по категории с учетом параметра ОшибкаТребуетЗавершениеРаботы.
// Устанавливает в заголовок текст обязательной отправки,
// если администратор настроил Отправлять в объекте
// РежимОтправкиИнформацииОбОшибке, в противном случае
// (СпрашиватьПользователя или Авто) текст необязательной отправки.
// Рекомендуется вызывать ПриОткрытии своей формы ошибки.
//
// Параметры:
//  Элемент - ПолеФормы, КнопкаФормы - элемент которому будет установлена видимость и заголовок.
//  ИнформацияОбОшибке  - ИнформацияОбОшибке - ошибка по категории которой уточняется необходимость отправки отчета.
//  ОшибкаТребуетЗавершениеРаботы - Булево - учитывается при настройке видимости ссылки. По ошибкам,
//    из-за которых требуется завершение работы или перезапуск, как правило обязательно отправляется отчет.
//
// Пример:
//	#Область ОписаниеПеременных
//	&НаКлиенте
//	Перем ОтчетОбОшибке, ОтчетИнформацияОбОшибке;
//	#КонецОбласти
//	#Область ОбработчикиСобытийФормы
//	&НаКлиенте
//	Процедура ПриОткрытии(Отказ)
//		Если Параметры.ИнформацияОбОшибке <> Неопределено Тогда
//			ОтчетИнформацияОбОшибке = Параметры.ИнформацияОбОшибке;
//			ОтчетОбОшибке = Новый ОтчетОбОшибке(ОтчетИнформацияОбОшибке);
//			СтандартныеПодсистемыКлиент.НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке(
//				Элементы.СформироватьОтчетОбОшибке, ОтчетИнформацияОбОшибке);
//		КонецЕсли;
//	КонецПроцедуры
//	&НаКлиенте
//	Процедура ПриЗакрытии(ЗавершениеРаботы)
//		Если ОтчетОбОшибке <> Неопределено Тогда
//			СтандартныеПодсистемыКлиент.ОтправитьОтчетОбОшибке(ОтчетОбОшибке, ОтчетИнформацияОбОшибке);
//		КонецЕсли;
//	КонецПроцедуры
//	#КонецОбласти
//	#Область ОбработчикиСобытийЭлементовШапкиФормы
//	&НаКлиенте
//	Процедура СформироватьОтчетОбОшибкеНажатие(Элемент)
//		СтандартныеПодсистемыКлиент.ПоказатьОтчетОбОшибке(ОтчетОбОшибке);
//	КонецПроцедуры
//	#КонецОбласти
//
Процедура НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке(Элемент, ИнформацияОбОшибке, ОшибкаТребуетЗавершениеРаботы = Ложь) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке(Элемент, ИнформацияОбОшибке, ОшибкаТребуетЗавершениеРаботы);
```
</details>

## ПоказатьОтчетОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает отчет об ошибке для проверки и настройки состава отчета,
// либо в режиме отправки (если указан адрес сервиса для отправки и администратор
// не настроил НеОтправлять в объекте РежимОтправкиИнформацииОбОшибке)
// либо в режиме записи в файл в противном случае.
//
// Параметры:
//  ОтчетДляОтправки - ОтчетОбОшибке
//
// Пример:
//	#Область ОписаниеПеременных
//	&НаКлиенте
//	Перем ОтчетОбОшибке, ОтчетИнформацияОбОшибке;
//	#КонецОбласти
//	#Область ОбработчикиСобытийФормы
//	&НаКлиенте
//	Процедура ПриОткрытии(Отказ)
//		Если Параметры.ИнформацияОбОшибке <> Неопределено Тогда
//			ОтчетИнформацияОбОшибке = Параметры.ИнформацияОбОшибке;
//			ОтчетОбОшибке = Новый ОтчетОбОшибке(ОтчетИнформацияОбОшибке);
//			СтандартныеПодсистемыКлиент.НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке(
//				Элементы.СформироватьОтчетОбОшибке, ОтчетИнформацияОбОшибке);
//		КонецЕсли;
//	КонецПроцедуры
//	&НаКлиенте
//	Процедура ПриЗакрытии(ЗавершениеРаботы)
//		Если ОтчетОбОшибке <> Неопределено Тогда
//			СтандартныеПодсистемыКлиент.ОтправитьОтчетОбОшибке(ОтчетОбОшибке, ОтчетИнформацияОбОшибке);
//		КонецЕсли;
//	КонецПроцедуры
//	#КонецОбласти
//	#Область ОбработчикиСобытийЭлементовШапкиФормы
//	&НаКлиенте
//	Процедура СформироватьОтчетОбОшибкеНажатие(Элемент)
//		СтандартныеПодсистемыКлиент.ПоказатьОтчетОбОшибке(ОтчетОбОшибке);
//	КонецПроцедуры
//	#КонецОбласти
//
Процедура ПоказатьОтчетОбОшибке(ОтчетДляОтправки) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПоказатьОтчетОбОшибке(ОтчетДляОтправки) 
```
</details>

## ОтправитьОтчетОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Неинтерактивно отправляет отчет об ошибке, если ошибка подходит
// по категории для отправки с учетом параметра ЗавершениеРаботы и
// администратор настроил Отправлять в объекте РежимОтправкиИнформацииОбОшибке.
// Рекомендуется вызывать ПриЗакрытии своей формы ошибки.
//
// Параметры:
//  ОтчетДляОтправки - ОтчетОбОшибке
//  ИнформацияОбОшибке  - ИнформацияОбОшибке - ошибка по категории которой уточняется необходимость отправки отчета.
//  ОшибкаТребуетЗавершениеРаботы - Булево - учитывается при отправке отчета. По ошибкам,
//    из-за которых требуется завершение работы или перезапуск, как правило обязательно отправляется отчет.
//    Нужно передать то же значение, что и в процедуру НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке.
//
// Пример:
//	#Область ОписаниеПеременных
//	&НаКлиенте
//	Перем ОтчетОбОшибке, ОтчетИнформацияОбОшибке;
//	#КонецОбласти
//	#Область ОбработчикиСобытийФормы
//	&НаКлиенте
//	Процедура ПриОткрытии(Отказ)
//		Если Параметры.ИнформацияОбОшибке <> Неопределено Тогда
//			ОтчетИнформацияОбОшибке = Параметры.ИнформацияОбОшибке;
//			ОтчетОбОшибке = Новый ОтчетОбОшибке(ОтчетИнформацияОбОшибке);
//			СтандартныеПодсистемыКлиент.НастроитьВидимостьИЗаголовокСсылкиОтправкиОтчетаОбОшибке(
//				Элементы.СформироватьОтчетОбОшибке, ОтчетИнформацияОбОшибке);
//		КонецЕсли;
//	КонецПроцедуры
//	&НаКлиенте
//	Процедура ПриЗакрытии(ЗавершениеРаботы)
//		Если ОтчетОбОшибке <> Неопределено Тогда
//			СтандартныеПодсистемыКлиент.ОтправитьОтчетОбОшибке(ОтчетОбОшибке, ОтчетИнформацияОбОшибке);
//		КонецЕсли;
//	КонецПроцедуры
//	#КонецОбласти
//	#Область ОбработчикиСобытийЭлементовШапкиФормы
//	&НаКлиенте
//	Процедура СформироватьОтчетОбОшибкеНажатие(Элемент)
//		СтандартныеПодсистемыКлиент.ПоказатьОтчетОбОшибке(ОтчетОбОшибке);
//	КонецПроцедуры
//	#КонецОбласти
//
Процедура ОтправитьОтчетОбОшибке(ОтчетДляОтправки, ИнформацияОбОшибке, ОшибкаТребуетЗавершениеРаботы = Ложь) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ОтправитьОтчетОбОшибке(ОтчетДляОтправки, ИнформацияОбОшибке, ОшибкаТребуетЗавершениеРаботы);
```
</details>

## ПропуститьПредупреждениеПередЗавершениемРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает выдачу предупреждения пользователю при завершении работы программы.
//
Процедура ПропуститьПредупреждениеПередЗавершениемРаботыСистемы() Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПропуститьПредупреждениеПередЗавершениемРаботыСистемы() 
```
</details>

## ПередНачаломРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить стандартные действия перед началом работы пользователя
// с областью данных, либо в локальном режиме работы.
//
// Предназначена для вызова из обработчика ПередНачаломРаботыСистемы модулей управляемого и обычного приложения.
//
// Параметры:
//  ОповещениеЗавершения - ОписаниеОповещения - не задается при вызове из обработчика ПередНачаломРаботыСистемы
//                         модулей управляемого и обычного приложения. В других случаях, после запуска будет вызвано
//                         оповещение с параметром типа Структура со свойствами:
//                         > Отказ - Булево - Ложь, если запуск выполнен успешно, или Истина, если вход в программу не
//                         выполнен;
//                         > Перезапустить - Булево - если требуется перезапуск программы;
//                         > ДополнительныеПараметрыКоманднойСтроки - Строка - для перезапуска.
//
Процедура ПередНачаломРаботыСистемы(Знач ОповещениеЗавершения = Неопределено) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПередНачаломРаботыСистемы(ОповещениеЗавершения);
```
</details>

## ПриНачалеРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить стандартные действия при начале работы пользователя
// с областью данных, либо в локальном режиме работы.
//
// Предназначена для вызова из обработчика ПриНачалеРаботыСистемы модулей управляемого и обычного приложения.
//
// Параметры:
//  ОповещениеЗавершения - ОписаниеОповещения - не задается при вызове из обработчика ПриНачалеРаботыСистемы
//                         модулей управляемого и обычного приложения. В других случаях, после запуска будет вызвано
//                         оповещение с параметром типа Структура со свойствами:
//                         > Отказ - Булево - Ложь, если запуск выполнен успешно, или Истина, если вход в программу не
//                         выполнен;
//                         > Перезапустить - Булево - если требуется перезапуск программы;
//                         > ДополнительныеПараметрыКоманднойСтроки - Строка - для перезапуска.
//
//  НепрерывноеВыполнение - Булево - только для внутреннего использования.
//                          Для перехода из обработчика ПередНачаломРаботыСистемы
//                          выполненного в режиме интерактивной обработки.
//
Процедура ПриНачалеРаботыСистемы(Знач ОповещениеЗавершения = Неопределено, НепрерывноеВыполнение = Истина) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПриНачалеРаботыСистемы(ОповещениеЗавершения, НепрерывноеВыполнение);
```
</details>

## ПередЗавершениемРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить стандартные действия перед завершением работы пользователя
// с областью данных, либо в локальном режиме работы.
//
// Предназначена для вызова из обработчика ПередЗавершениемРаботыСистемы модулей управляемого и обычного приложения.
//
// Параметры:
//  Отказ                - Булево - возвращаемое значение. Признак отказа от завершения работы
//                         для обработчика события ПередЗавершениемРаботыСистемы, либо программного отказа,
//                         либо того, что потребовалась интерактивная обработка. В случае успешного взаимодействия
//                         с пользователем завершение работы будет продолжено.
//  ТекстПредупреждения  - Строка - см. ПередЗавершениемРаботыСистемы() в синтакс-помощнике.
//
Процедура ПередЗавершениемРаботыСистемы(Отказ = Ложь, ТекстПредупреждения = "") Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПередЗавершениемРаботыСистемы(Отказ, ТекстПредупреждения);
```
</details>

## ОбработкаПолученияФормыВыбораПользователейСистемыВзаимодействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить стандартные действия при обработке получения формы выбора пользователей системы взаимодействия.
//
// Параметры:
//  НазначениеВыбора - НазначениеВыбораПользователейСистемыВзаимодействия
//  Форма - ФормаКлиентскогоПриложения
//  ИдентификаторОбсуждения - ИдентификаторОбсужденияСистемыВзаимодействия
//  Параметры - Структура
//  ВыбраннаяФорма - Строка
//  СтандартнаяОбработка - Булево
//
Процедура ОбработкаПолученияФормыВыбораПользователейСистемыВзаимодействия(НазначениеВыбора, Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ОбработкаПолученияФормыВыбораПользователейСистемыВзаимодействия(НазначениеВыбора, );
```
</details>

## ПредупреждениеПриЗавершенииРаботы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую структуру параметров для вывода предупреждения перед завершением работы программы.
// Для использования в ОбщегоНазначенияКлиентПереопределяемый.ПередЗавершениемРаботыСистемы.
//
// Возвращаемое значение:
//  Структура:
//    ТекстПредупреждения  - Строка - текст, выводимый в окне веб-браузера (или тонкого клиента) при завершении работы.
//                                    Например, "Имеются редактируемые файлы, которые не помещены в приложение".
//                                    Остальные параметры определяют внешний вид формы предупреждений,
//                                    открываемой после подтверждения в окне веб-браузера (или тонкого клиента).
//    ТекстФлажка          - Строка - если задан, то в форме предупреждений выводится флажок с указанным текстом.
//                                    Например, "Завершить редактирование файлов (5)".
//    ПоясняющийТекст      - Строка - текст, выводимый в форме сверху управляющего элемента (флажок или гиперссылка).
//                                    Например, "Редактируемые файлы, не помещенные в приложение".
//    ТекстГиперссылки     - Строка - если задан, то выводится гиперссылка с указанным текстом.
//                                    Например, "Редактируемые файлы (5)".
//    РасширеннаяПодсказка - Строка - текст подсказки, выводимый по кнопке справа от управляющего элемента (флажок или
//                                    гиперссылка). Например, "Нажмите для перехода к списку файлов,
//                                    открытых для редактирования".
//    Приоритет            - Число  - относительный порядок в списке предупреждений на форме (чем больше, тем выше).
//    ВывестиОдноПредупреждение - Булево - если Истина, то в списке предупреждений выводится только одно это
//                                         предупреждение. Т.е. такое предупреждение не совместимо с любыми другими.
//    ДействиеПриУстановленномФлажке - Структура:
//      * Форма          - Строка    - если пользователь установил флажок, то следует открыть указанную форму.
//                                     Например, "Обработка.Файлы.РедактируемыеФайлы".
//      * ПараметрыФормы - Структура - произвольная структура параметров для открытия формы.
//    ДействиеПриНажатииГиперссылки - Структура:
//      * Форма          - Строка    - путь к форме, которая должна открываться по нажатию на гиперссылку.
//                                     Например, "Обработка.Файлы.РедактируемыеФайлы".
//      * ПараметрыФормы - Структура - произвольная структура параметров для открываемой формы.
//      * ПрикладнаяФормаПредупреждения - Строка - путь к форме, которая должна открываться сразу
//                                        вместо универсальной формы в случае, когда в списке
//                                        предупреждений оказывается только одно данное предупреждение.
//                                        Например, "Обработка.Файлы.РедактируемыеФайлы".
//      * ПараметрыПрикладнойФормыПредупреждения - Структура - произвольная структура
//                                                 параметров для вышеописанной формы.
//      * РежимОткрытияОкна - РежимОткрытияОкнаФормы - режим открытия форм Форма или ПрикладнаяФормаПредупреждения.
//
Функция ПредупреждениеПриЗавершенииРаботы() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ПредупреждениеПриЗавершенииРаботы() 
```
</details>

## ПараметрыРаботыКлиентаПриЗапуске
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значения параметров, необходимых для работы клиентского кода
// при запуске конфигурации за один серверный вызов (для минимизации клиент-серверного взаимодействия
// и снижения времени запуска).
// С помощью этой функции можно обращаться к параметрам в клиентском коде, вызываемым из обработчиков событий:
// - ПередНачаломРаботыСистемы,
// - ПриНачалеРаботыСистемы.
//
// В этих обработчиках при запуске недопустимо использовать команды сброса кэша
// повторно используемых модулей, иначе запуск может привести
// к непредсказуемым ошибкам и лишним серверным вызовам.
//
// Возвращаемое значение:
//   ФиксированнаяСтруктура - параметры работы клиента при запуске.
//                            См. в ОбщегоНазначенияПереопределяемый.ПриДобавленииПараметровРаботыКлиентаПриЗапуске.
//
//
Функция ПараметрыРаботыКлиентаПриЗапуске() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ПараметрыРаботыКлиентаПриЗапуске() 
```
</details>

## ПараметрыРаботыКлиента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значения параметров, необходимых для работы клиентского кода конфигурации
// без дополнительных серверных вызовов.
//
// Возвращаемое значение:
//   ФиксированнаяСтруктура - параметры работы клиента.
//                            Состав свойств см. в ОбщегоНазначенияПереопределяемый.ПриДобавленииПараметровРаботыКлиента.
//
Функция ПараметрыРаботыКлиента() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиент.ПараметрыРаботыКлиента() 
```
</details>

## ПриГлобальномПоиске
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбщегоНазначенияКлиентПереопределяемый.ПриГлобальномПоиске
Процедура ПриГлобальномПоиске(СтрокаПоиска, ПланПоиска) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПриГлобальномПоиске(СтрокаПоиска, ПланПоиска) 
```
</details>

## ПриВыбореРезультатаГлобальногоПоиска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбщегоНазначенияКлиентПереопределяемый.ПриВыбореРезультатаГлобальногоПоиска
Процедура ПриВыбореРезультатаГлобальногоПоиска(ЭлементРезультата, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПриВыбореРезультатаГлобальногоПоиска(ЭлементРезультата, СтандартнаяОбработка) 
```
</details>

## ПриВыбореДействияРезультатаГлобальногоПоиска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбщегоНазначенияКлиентПереопределяемый.ПриВыбореДействияРезультатаГлобальногоПоиска
Процедура ПриВыбореДействияРезультатаГлобальногоПоиска(ЭлементРезультата, Действие) Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ПриВыбореДействияРезультатаГлобальногоПоиска(ЭлементРезультата, Действие) 
```
</details>

## ОбработкаПереходаПоНавигационнойСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбщегоНазначенияКлиентПереопределяемый.ОбработкаПереходаПоНавигационнойСсылке
Процедура ОбработкаПереходаПоНавигационнойСсылке(ДанныеПереходаПоНавигационнойСсылке, Экспорт
```

Пример вызова
```bsl
СтандартныеПодсистемыКлиент.ОбработкаПереходаПоНавигационнойСсылке(ДанныеПереходаПоНавигационнойСсылке, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
