---
title: Стандартные подсистемы клиент сервер
slug: bsp/стандартные-подсистемы-клиент-сервер
---


## ПараметрыВыбораОбъектовМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры выбора объектов метаданных для процедуры
// СтандартныеПодсистемыКлиент.ВыбратьОбъектыМетаданных.
//
// Возвращаемое значение:
//  Структура:
//    * КоллекцииВыбираемыхОбъектовМетаданных - СписокЗначений - фильтр по типам объектов метаданных,
//				которые могут быть выбраны. Например, выбирать только объекты метаданных справочники и документы:
//					КоллекцииВыбираемыхОбъектовМетаданных = Новый СписокЗначений;
//					КоллекцииВыбираемыхОбъектовМетаданных.Добавить("Справочники");
//					КоллекцииВыбираемыхОбъектовМетаданных.Добавить("Документы");
//
//    * ФильтрПоОбъектамМетаданных - СписокЗначений - фильтр по объектам метаданных,
//				которые могут быть выбраны. Например:
//					ФильтрПоОбъектамМетаданных = Новый СписокЗначений;
//					ФильтрПоОбъектамМетаданных.Добавить("Справочник.Товары");
//					ФильтрПоОбъектамМетаданных.Добавить("Документ.СчетНаОплату");
//    * ВыбранныеОбъектыМетаданных - СписокЗначений - полные имена выбранных объектов метаданных, которые
//    			в дереве метаданных должны быть отмечены флажком.
//    * НачальноеЗначениеВыбора - Строка - полное имя метаданных, на котором будет спозиционирован
//              список при открытии формы. Например, "Справочник.Партнеры".
//    * ВыборЕдинственного - Булево - по умолчанию Ложь. Укажите Истина, если нужно выбрать один объект метаданных.
//              При этом пометка нескольких строк будет невозможна, а выбирать можно по двойному клик по строке.
//    * ВыбиратьСсылки - Булево - по умолчанию Ложь. Укажите Истина, чтобы в возвращаемом значении вместо
//    			полных имен выбранных метаданных содержались ссылки на их идентификаторы,
//    			смотри ОбщегоНазначения.ИдентификаторыОбъектовМетаданных.
//    * ВыбиратьКоллекцииКогдаВыбраныВсеОбъекты - Булево - по умолчанию Ложь. При группировке объектов по видам,
//    			укажите Истина, чтобы в возвращаемое значение включать также типы объектов метаданных
//    			(Конфигурация, Справочники, Документы...), если у них выбраны все подчиненные строки.
//    * ВыбиратьТаблицыВнешнихИсточниковДанных - Булево - по умолчанию Ложь для совместимости.
//    * Заголовок - Строка - если не указано, то форма откроется со стандартным заголовком "Выбор объектов метаданных".
//    * СпособГруппировкиОбъектов - Строка - по умолчанию "ПоВидам". Укажите "ПоРазделам", чтобы вывести дерево
//    			объектов метаданных по разделам командного интерфейса (подсистемам, включенным в командный интерфейс)
//    			вместо группировки по технологическим типам: Справочники, Документы и т.п.
//    			Также можно указать "ПоРазделам,ПоВидам" или "ПоВидам,ПоРазделам", чтобы в форме был доступен
//    			переключатель группировки объектов метаданных.
//    * РодительскиеПодсистемы - СписокЗначений - можно указать список подсистемы, только подчиненные подсистемы
//				которых нужно отобразить в форме.
//    * ТолькоПодсистемыСКИ - Булево - по умолчанию Ложь. Укажите Истина, чтобы в списке оставить только подсистемы,
//				которые включены в командный интерфейс (разделы командного интерфейса).
//    * УникальныйИдентификаторИсточник - УникальныйИдентификатор - опционально. Уникальный идентификатор формы,
//				передаваемый в оповещение ВыборОбъектовМетаданных в качестве параметра Источник.
//				Это оповещение вызывается, если
//
Функция ПараметрыВыбораОбъектовМетаданных() Экспорт
```

Пример вызова
```bsl
Результат = СтандартныеПодсистемыКлиентСервер.ПараметрыВыбораОбъектовМетаданных() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
