---
title: Транспорт сообщений обмена
slug: bsp/транспорт-сообщений-обмена
---


## ПараметрыИнициализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры инициализации.
//
// Параметры:
//  ИдентификаторТранспорта - Строка - идентифкатор транспорта
//
// Возвращаемое значение:
//  Структура:
//   * Корреспондент - ПланОбменаСсылка, Неопределено - ссылка на узел плана обмена
//   * ИмяПланаОбмена - Строка
//   * ИмяПланаОбменаКорреспондента - Строка
//   * ИдентификаторТранспорта - Строка
//   * НастройкиТранспорта - Структура - состав повторяет реквизиты обработки транспорта
//   * ДанныеАутентификации - Структура - состав повторяет реквизиты обработки транспорта,
//   но только данные аутентификации, например: Пароль, ИмяПользоватля
//
Функция ПараметрыИнициализации(ИдентификаторТранспорта = "") Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.ПараметрыИнициализации(ИдентификаторТранспорта);
```
</details>

## Инициализация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализация обарботки транспорта.
//
// Параметры:
//  ПараметрыИнициализации - Структура:
//   * Корреспондент - ПланОбменаСсылка - ссылка на узел плана обмена. Если значение задано,
//   то будут заполнены настройки транспорта (реквизиты обработки).
//   * ИмяПланаОбмена - Строка
//   * ИмяПланаОбменаКорреспондента - Строка
//   * ИдентификаторТранспорта - Строка - доступный индентфикатор транспорта.
//   Доступные идентфикаторы см. ДоступныеТипыТранспорта
//   * НастройкиТранспорта - Структура - состав повторяет реквизиты обработки транспорта,
//   * ДанныеАутентификации - Структура - состав повторяет реквизиты обработки транспорта,
//   но только данные аутентификации, например: Пароль, ИмяПользоватля
//
// Возвращаемое значение:
//   ОбработкаОбъект.ТранспортСообщенийОбменаCOM,
//   ОбработкаОбъект.ТранспортСообщенийОбменаEMAIL,
//   ОбработкаОбъект.ТранспортСообщенийОбменаESB1C,
//   ОбработкаОбъект.ТранспортСообщенийОбменаFILE,
//   ОбработкаОбъект.ТранспортСообщенийОбменаFTP,
//   ОбработкаОбъект.ТранспортСообщенийОбменаGoogleDrive,
//   ОбработкаОбъект.ТранспортСообщенийОбменаHTTP,
//   ОбработкаОбъект.ТранспортСообщенийОбменаSM,
//   ОбработкаОбъект.ТранспортСообщенийОбменаWS,
//   ОбработкаОбъект.ТранспортСообщенийОбменаПассивныйРежим,
//   ОбработкаОбъект.ТранспортСообщенийОбменаЯндексДиск - обработка заданного типа транспорта с заполненными параметрами.
//    При инициализации создатся ВременныйКаталог, задается временное имя файла СообщениеОбмена,
//    а так же шаблоны имен файлов (ШаблоныИменДляПолученияСообщения) для получения
//
Функция Инициализация(ПараметрыИнициализации) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.Инициализация(ПараметрыИнициализации) 
```
</details>

## Деинициализация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Уничтожение обработки трансорта, удаление временного каталога обмена
//
// Параметры:
//  Транспорт - ОбработкаОбъект.ТранспортСообщенийОбменаCOM,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаEMAIL,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаESB1C,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаFILE,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаFTP,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаGoogleDrive,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаHTTP,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаSM,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаWS,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаПассивныйРежим,
//            - ОбработкаОбъект.ТранспортСообщенийОбменаЯндексДиск - обработка транспорта сообщений обмена.
//
// Возвращаемое значение:
//  Булево - Истина при удачном выполнении, Ложь - при возникновении ошибки.
//
Функция Деинициализация(Транспорт) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.Деинициализация(Транспорт) 
```
</details>

## НастройкиТранспорта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настройки транспорта.
//
// Параметры:
//  Корреспондент - ПланОбменаСсылка - корреспондент
//  ИдентификаторТранспорта - Строка - идентификатор транспорта
//
// Возвращаемое значение:
//  Структура - настройки транспорта (рекизиты обработки транспорта)
//
Функция НастройкиТранспорта(Корреспондент, ИдентификаторТранспорта) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.НастройкиТранспорта(Корреспондент, ИдентификаторТранспорта) 
```
</details>

## НастройкиТранспортаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настройки транспорта по умолчанию.
//
// Параметры:
//  Корреспондент - ПланОбменаСсылка
//  ИдентификаторТранспорта - Строка - возвращает идентификатор транспорта заданный по умолчанию
//
// Возвращаемое значение:
//  Структура - настройки транспорта по умолчанию (рекизиты обработки транспорта)
//
Функция НастройкиТранспортаПоУмолчанию(Корреспондент, ИдентификаторТранспорта = "") Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.НастройкиТранспортаПоУмолчанию(Корреспондент, ИдентификаторТранспорта);
```
</details>

## ТранспортПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Транспорт по умолчанию.
//
// Параметры:
//  Корреспондент - ПланОбменаСсылка - корреспондент
//
// Возвращаемое значение:
//  Строка - идентфикатор транспорта
//
Функция ТранспортПоУмолчанию(Корреспондент) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.ТранспортПоУмолчанию(Корреспондент) 
```
</details>

## ПараметрыТранспорта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры транспорта (обработки транспорта).
//
// Параметры:
//  ИдентификаторТранспорта - Строка - идентификатор транспорта
//
// Возвращаемое значение:
//   Неопределено, Структура - см. СтруктураПараметровТранспорта
//
Функция ПараметрыТранспорта(Знач ИдентификаторТранспорта) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.ПараметрыТранспорта(ИдентификаторТранспорта) 
```
</details>

## ПараметрТранспорта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметр транспорта (обработки транспорта).
//
// Параметры:
//  ИдентификаторТранспорта - Строка - идентификатор транспорта
//  ИмяПараметра - Строка - имя параметра транспорта. Список параметров см. СтруктураПараметровТранспорта
//
// Возвращаемое значение:
//  Произвольный
//
Функция ПараметрТранспорта(Знач ИдентификаторТранспорта, ИмяПараметра) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.ПараметрТранспорта(ИдентификаторТранспорта, ИмяПараметра) 
```
</details>

## МенеджерТранспортаПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает обработку транспорта по ее идентификатору.
//
// Параметры:
//  ИдентификаторТранспорта - Строка - идентификатор транспорта
//
// Возвращаемое значение:
//  Произвольный - менеджер обработки транспорта
//
Функция МенеджерТранспортаПоИдентификатору(ИдентификаторТранспорта) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаПоИдентификатору(ИдентификаторТранспорта) 
```
</details>

## МенеджерТранспортаFILE
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта FILE.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаFILE
//
Функция МенеджерТранспортаFILE() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаFILE() 
```
</details>

## МенеджерТранспортаCOM
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта COM.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаCOM
//
Функция МенеджерТранспортаCOM() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаCOM() 
```
</details>

## МенеджерТранспортаEMAIL
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта EMAIL.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаEMAIL
//
Функция МенеджерТранспортаEMAIL() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаEMAIL() 
```
</details>

## МенеджерТранспортаFTP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта FTP.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаFTP
//
Функция МенеджерТранспортаFTP() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаFTP() 
```
</details>

## МенеджерТранспортаHTTP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта HTTP.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаHTTP
//
Функция МенеджерТранспортаHTTP() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаHTTP() 
```
</details>

## МенеджерТранспортаWS
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта WS.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаWS
//
Функция МенеджерТранспортаWS() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаWS() 
```
</details>

## МенеджерТранспортаSM
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта SM.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаSM
//
Функция МенеджерТранспортаSM() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаSM() 
```
</details>

## МенеджерТранспортаПассивныйРежим
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта ПассивныйРежим.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаПассивныйРежим
//
Функция МенеджерТранспортаПассивныйРежим() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаПассивныйРежим() 
```
</details>

## МенеджерТранспортаESB1C
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта ESB1C.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаESB1C
//
Функция МенеджерТранспортаESB1C() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаESB1C() 
```
</details>

## МенеджерТранспортаGoogleDrive
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта GoogleDrive.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаGoogleDrive
//
Функция МенеджерТранспортаGoogleDrive() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаGoogleDrive() 
```
</details>

## МенеджерТранспортаЯндексДиск
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает менеджер обработки транспорта ЯндексДиск.
//
// Возвращаемое значение:
//  ОбработкаМенеджер.ТранспортСообщенийОбменаЯндексДиск
//
Функция МенеджерТранспортаЯндексДиск() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортСообщенийОбмена.МенеджерТранспортаЯндексДиск() 
```
</details>

## УдалитьВсеНастройкиТранспорта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удалить все настройки транспорта.
//
// Параметры:
//  Корреспондент - ПланОбменаСсылка - удаляемый узел плана обмена
//
Процедура УдалитьВсеНастройкиТранспорта(Корреспондент) Экспорт
```

Пример вызова
```bsl
ТранспортСообщенийОбмена.УдалитьВсеНастройкиТранспорта(Корреспондент) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
