---
title: Удаление помеченных объектов клиент
slug: bsp/удаление-помеченных-объектов-клиент
---


## НачатьУдалениеПомеченных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Начинает интерактивное удаление помеченных объектов.
//
// Параметры:
//   УдаляемыеОбъекты - Массив из ЛюбаяСсылка - перечень удаляемых объектов.
//   ПараметрыУдаления - см. ПараметрыИнтерактивногоУдаления
//
//   Владелец - ФормаКлиентскогоПриложения
//            - Неопределено - форма, из которой начата операция удаления.
// 							   Если не указан, то в обработку оповещения о закрытии
// 							   не будет передана подробная информация об итогах удаления.
//   ОписаниеОповещенияОЗакрытии - ОписаниеОповещения - если указано, то при окончании удаления или
//								при закрытии формы в обработку оповещения будет передан результат
//								в виде структуры со свойствами:
//                              # Успешно - Булево - Истина, если все объекты удалены успешно.
//                              # УдаленныеКоличество - Число - количество удаленных объектов.
//                              # НеУдаленныеКоличество - Число - количество неудаленных объектов.
//                              # АдресРезультата - Строка - адрес временного хранилища.
//
Процедура НачатьУдалениеПомеченных(УдаляемыеОбъекты, ПараметрыУдаления = Неопределено, Владелец = Неопределено, Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовКлиент.НачатьУдалениеПомеченных(УдаляемыеОбъекты, ПараметрыУдаления, Владелец, );
```
</details>

## ПараметрыИнтерактивногоУдаления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настройки интерактивного удаления.
//
// Возвращаемое значение:
//   Структура:
//   * Режим - Строка -  способ удаления, может принимать значения:
//		"Стандартный" - удаление объектов с контролем ссылочной целостности и сохранением возможности
//					  многопользовательской работы.
//		"Монопольный" - удаление объектов с контролем ссылочной целостности с установкой монопольного режима.
//		"Упрощенный"  - удаление объектов, при котором контроль ссылочной целостности выполняется только в непомеченных
//					  на удаление объектах. В помеченных на удаление объектах ссылки на удаляемые объекты
//					  будут очищены.
//
Функция ПараметрыИнтерактивногоУдаления() Экспорт
```

Пример вызова
```bsl
Результат = УдалениеПомеченныхОбъектовКлиент.ПараметрыИнтерактивногоУдаления() 
```
</details>

## ПерейтиКПомеченнымНаУдаление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает рабочее место Удаление помеченных.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//   ТаблицаФормы - ТаблицаФормы
//                - ДанныеФормыСтруктура
//                - Неопределено - таблица формы, связанная с динамическим списком
//
Процедура ПерейтиКПомеченнымНаУдаление(Форма, ТаблицаФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовКлиент.ПерейтиКПомеченнымНаУдаление(Форма, ТаблицаФормы);
```
</details>

## ПоказатьПомеченныеНаУдаление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет видимость помеченных на удаление и сохраняет настройку пользователя.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения
//   ТаблицаФормы - ТаблицаФормы - таблица формы, связанная с динамическим списком.
//   КнопкаФормы - КнопкаФормы - кнопка формы, связанная с командой Показать помеченные на удаление.
//
Процедура ПоказатьПомеченныеНаУдаление(Форма, ТаблицаФормы, КнопкаФормы) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовКлиент.ПоказатьПомеченныеНаУдаление(Форма, ТаблицаФормы, КнопкаФормы) 
```
</details>

## НачатьИзменениеРасписанияРегламентногоЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму для изменения расписания регламентного задания.
// Если расписание задано, то будет включено регламентное задание с установленным расписанием.
//
// Не поддерживается на мобильном платформе.
//
// Параметры:
//   ОповещениеОбИзменении - ОписаниеОповещения - обработчик изменения расписания регламентного задания.
//
Процедура НачатьИзменениеРасписанияРегламентногоЗадания(ОповещениеОбИзменении = Неопределено) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовКлиент.НачатьИзменениеРасписанияРегламентногоЗадания(ОповещениеОбИзменении);
```
</details>

## ПриИзмененииФлажкаУдалятьПоРасписанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПриИзменении для флажка, выполняющего переключение режима автоматического удаления объектов.
//
// Параметры:
//   АвтоматическиУдалятьПомеченныеОбъекты  - Булево - новое значение флажка, которое требуется обработать.
//   ОповещениеОбИзменении - ОписаниеОповещения - если ЗначениеФлажкаАвтоматическиУдалятьПомеченныеОбъекты = Истина, то процедура
//   											  будет вызвана после выбора расписания регламентного задания.
//   											  Если ЗначениеФлажкаАвтоматическиУдалятьПомеченныеОбъекты = Ложь, то процедура будет
//   											  вызвана сразу же.
//
// Пример:
//	Если ОбщегоНазначенияКлиент.ПодсистемаСуществует("СтандартныеПодсистемы.УдалениеПомеченныхОбъектов") Тогда
//		МодульУдалениеПомеченныхОбъектовКлиент = ОбщегоНазначенияКлиент.ОбщийМодуль("УдалениеПомеченныхОбъектовКлиент");
//		МодульУдалениеПомеченныхОбъектовКлиент.ПриИзмененииФлажкаУдалятьПоРасписанию(АвтоматическиУдалятьПомеченныеОбъекты);
//	КонецЕсли;
//
Процедура ПриИзмененииФлажкаУдалятьПоРасписанию(АвтоматическиУдалятьПомеченныеОбъекты, ОповещениеОбИзменении = Неопределено) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовКлиент.ПриИзмененииФлажкаУдалятьПоРасписанию(АвтоматическиУдалятьПомеченныеОбъекты, ОповещениеОбИзменении);
```
</details>

## ОбработкаОповещенияИзмененияФлажкаУдалятьПоРасписанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаОповещения для формы, на которой требуется отобразить флажок удаления по расписанию.
//
// Параметры:
//   ИмяСобытия - Строка - имя события, которое было получено обработчиком события на форме.
//   АвтоматическиУдалятьПомеченныеОбъекты - Булево - реквизит, в которое будет помещено значение.
//
// Пример:
//	Если ОбщегоНазначенияКлиент.ПодсистемаСуществует("СтандартныеПодсистемы.УдалениеПомеченныхОбъектов") Тогда
//		МодульУдалениеПомеченныхОбъектовКлиент = ОбщегоНазначенияКлиент.ОбщийМодуль("УдалениеПомеченныхОбъектовКлиент");
//		МодульУдалениеПомеченныхОбъектовКлиент.ОбработкаОповещенияИзмененияФлажкаУдалятьПоРасписанию(
//			ИмяСобытия,
//			АвтоматическиУдалятьПомеченныеОбъекты);
//	КонецЕсли;
//
Процедура ОбработкаОповещенияИзмененияФлажкаУдалятьПоРасписанию(Знач ИмяСобытия, Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовКлиент.ОбработкаОповещенияИзмененияФлажкаУдалятьПоРасписанию(ИмяСобытия, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
