---
title: Удаление помеченных объектов переопределяемый
slug: bsp/удаление-помеченных-объектов-переопределяемый
---


## ПриОпределенииОбъектовСКомандойПоказатьПомеченные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определить объекты метаданных, в формах списков которых
// будет выведена команда показать помеченные и перейти к помеченным на удаление.
// см. УдалениеПомеченныхОбъектовКлиент.ПоказатьПомеченныеНаУдаление и УдалениеПомеченныхОбъектовКлиент.ПерейтиКПомеченнымНаУдаление.
//
// Параметры:
//  Объекты - Массив из ОбъектМетаданных - объекты метаданных, в формы списка которых будут добавлены команды скрытия
//                                         помеченных на удаления.
//
// Пример:
//	Объекты.Добавить(Метаданные.Справочники.Номенклатура);
//	Объекты.Добавить(Метаданные.Справочники.Партнеры);
//
Процедура ПриОпределенииОбъектовСКомандойПоказатьПомеченные(Объекты) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовПереопределяемый.ПриОпределенииОбъектовСКомандойПоказатьПомеченные(Объекты) 
```
</details>

## ПередУдалениемГруппыОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается вне транзакции перед удалением группы связанных объектов.
//
// Параметры:
//  Контекст - Структура - произвольные данные, которые можно проинициализировать для передачи
//                         в УдалениеПомеченныхОбъектовПереопределяемый.ПослеУдаленияГруппыОбъектов.
//  УдаляемыеОбъекты - Массив из ЛюбаяСсылка - объекты, которые будут удалены.
//
Процедура ПередУдалениемГруппыОбъектов(Контекст, УдаляемыеОбъекты) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовПереопределяемый.ПередУдалениемГруппыОбъектов(Контекст, УдаляемыеОбъекты) 
```
</details>

## ПослеУдаленияГруппыОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается вне транзакции после удаления группы связанных объектов.
// Например, для очистки связанных данных на внешних ресурсах и других операций,
// которые недопустимо выполнять в транзакции удаления.
//
// Параметры:
//  Контекст - см. УдалениеПомеченныхОбъектовПереопределяемый.ПередУдалениемГруппыОбъектов.Контекст
//  Успешно - Булево - Истина, если группа объектов успешно удалена.
//
Процедура ПослеУдаленияГруппыОбъектов(Контекст, Успешно) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовПереопределяемый.ПослеУдаленияГруппыОбъектов(Контекст, Успешно) 
```
</details>

## ПередПоискомПомеченныхНаУдаление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Вызывается перед поиском объектов, помеченных на удаление.
// В этом обработчике можно организовать удаление устаревших ключей аналитик и любых других объектов информационной
// базы, ставших более не нужными.
//
// Вместо процедуры следует использовать либо событие ПередУдалением удаляемых объектов,
// либо определить ПодчиненныеОбъекты, см. ОбщегоНазначения.ПодчиненныеОбъекты.
//
// Параметры:
//   Параметры - Структура:
//     * Интерактивное - Булево - Истина, если удаление помеченных объектов запущено пользователем;
//                                Ложь, если удаление запущено по расписанию регламентного задания.
//
Процедура ПередПоискомПомеченныхНаУдаление(Параметры) Экспорт
```

Пример вызова
```bsl
УдалениеПомеченныхОбъектовПереопределяемый.ПередПоискомПомеченныхНаУдаление(Параметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
