---
title: Универсальная интеграция
slug: bsp/универсальная-интеграция
---


## ПолучитьДанныеОбъектаПоПравилу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные объекта из Менеджера сервиса по правилу трансляции.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторПравила - Строка - идентификатор правила трансляции с типом "Чтение".
//  КлючОбъекта - Строка, Число - ключ объекта, определенный в правиле.
//
// Возвращаемое значение:
//  Структура -- данные объекта или Неопределено, если данные не получены:
// * Поле - Произвольный - произвольный состав полей.
Функция ПолучитьДанныеОбъектаПоПравилу(ИдентификаторПравила, КлючОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальнаяИнтеграция.ПолучитьДанныеОбъектаПоПравилу(ИдентификаторПравила, КлючОбъекта) 
```
</details>

## ОтправитьДанныеОбъектаПоПравилу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет данные в Менеджер сервиса.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторПравила - Строка - идентификатор правила трансляции с типом "Загрузка".
//  Данные - Структура - данные для отправки в менеджер сервиса:
//   * Поле - Произвольный - произвольный состав полей, определенный у универсальном объекте.
//
// Возвращаемое значение:
//  Структура - результат выполнения запроса:
//  * КодСостояния - Число - код состояния ответа.
//  * ТелоОтвета - Строка - тело ответа в виде строки.
//  * ДанныеОтвета - Неопределено, Структура - данные объекта или Неопределено, если данные не получены:
//    ** Поле - Произвольный - произвольный состав полей, если ответ содержит заголовок
//    						   "Content-Type: application/json" возвращается Структура.
Функция ОтправитьДанныеОбъектаПоПравилу(ИдентификаторПравила, Данные = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальнаяИнтеграция.ОтправитьДанныеОбъектаПоПравилу(ИдентификаторПравила, Данные);
```
</details>

## ИзменитьДанныеОбъектаПоПравилу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет объект в Менеджере сервиса по правилу трансляции.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторПравила - Строка - идентификатор правила трансляции с типом "Загрузка".
//  КлючОбъекта - Строка, Число - ключ объекта, определенный в правиле.
//  Данные - Структура - данные для отправки в менеджер сервиса.
//   * Поле - Произвольный - произвольный состав полей, определенный у универсальном объекте.
//
// Возвращаемое значение:
//  Структура - данные ответа:
//  * КодСостояния - Число - код состояния ответа.
//  * ТелоОтвета - Строка - тело ответа.
//  * ДанныеОтвета - Неопределено, Структура - данные объекта или Неопределено, если данные не получены:
//    ** Поле - Произвольный - произвольный состав полей, если ответ содержит заголовок
//    						   "Content-Type: application/json" возвращается Структура.
Функция ИзменитьДанныеОбъектаПоПравилу(ИдентификаторПравила, КлючОбъекта, Данные = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальнаяИнтеграция.ИзменитьДанныеОбъектаПоПравилу(ИдентификаторПравила, КлючОбъекта, Данные);
```
</details>

## ПодписатьсяНаОповещенияОбИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод позволяет подписаться на оповещения об изменении объектов в менеджере сервиса по правилам тарансляции.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторПравила - Строка - идентификатор правила трансляции.
//  КлючОбъекта - Строка - ключ объекта интеграции на обновления которого подписываемся.
//
Процедура ПодписатьсяНаОповещенияОбИзменении(ИдентификаторПравила, КлючОбъекта) Экспорт
```

Пример вызова
```bsl
УниверсальнаяИнтеграция.ПодписатьсяНаОповещенияОбИзменении(ИдентификаторПравила, КлючОбъекта) 
```
</details>

## ОтписатьсяОтОповещенийНаИзменения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод позволяет отписаться от оповещений об изменении объектов в менеджере сервиса по правилам трансляции.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторПравила - Строка - идентификатор правила трансляции
//  КлючОбъекта - Строка - ключ объекта, по которому отписываемся от оповещений об обновлениях.
//
Процедура ОтписатьсяОтОповещенийНаИзменения(ИдентификаторПравила, КлючОбъекта) Экспорт
```

Пример вызова
```bsl
УниверсальнаяИнтеграция.ОтписатьсяОтОповещенийНаИзменения(ИдентификаторПравила, КлючОбъекта) 
```
</details>

## ПрочитатьПолученныеДанныеОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция позволяет прочитать полученные данные объекта по ключу полученных данных.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ИдентификаторПравила - Строка - идентификатор правила трансляции.
//  КлючОбъекта - Строка - ключ объекта.
//
// Возвращаемое значение:
//   Структура - прочитанные полученные данные объекта:
//   * Поле - Произвольный - произвольный состав полей, определенный у универсальном объекте.
//
Функция ПрочитатьПолученныеДанныеОбъекта(ИдентификаторПравила, КлючОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальнаяИнтеграция.ПрочитатьПолученныеДанныеОбъекта(ИдентификаторПравила, КлючОбъекта) 
```
</details>

## ПодписатьсяНаОповещениеОбИзмененииОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод позволяет подписаться на оповещения об изменении объектов в менеджере сервиса.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ТипОбъекта - Строка
//  ИдентификаторОбъекта - УникальныйИдентификатор
Процедура ПодписатьсяНаОповещениеОбИзмененииОбъекта(ТипОбъекта, ИдентификаторОбъекта) Экспорт
```

Пример вызова
```bsl
УниверсальнаяИнтеграция.ПодписатьсяНаОповещениеОбИзмененииОбъекта(ТипОбъекта, ИдентификаторОбъекта) 
```
</details>

## ОтписатьсяОтОповещенияОбИзмененииОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод позволяет отписаться от оповещений об изменении объектов в менеджере сервиса по правилам трансляции.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ТипОбъекта - Строка
//  ИдентификаторОбъекта - УникальныйИдентификатор
Процедура ОтписатьсяОтОповещенияОбИзмененииОбъекта(ТипОбъекта, ИдентификаторОбъекта) Экспорт
```

Пример вызова
```bsl
УниверсальнаяИнтеграция.ОтписатьсяОтОповещенияОбИзмененииОбъекта(ТипОбъекта, ИдентификаторОбъекта) 
```
</details>

## ПолученоОповещениеОбИзмененииОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция позволяет проверить признак изменения объекта по типу и идентификатору объекта.
// @skip-warning ПустойМетод - особенность реализации.
//
// Параметры:
//  ТипОбъекта - Строка
//  ИдентификаторОбъекта - УникальныйИдентификатор
//
// Возвращаемое значение:
//  Булево - признак изменения объекта после последней подписки на изменение.
Функция ПолученоОповещениеОбИзмененииОбъекта(ТипОбъекта, ИдентификаторОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальнаяИнтеграция.ПолученоОповещениеОбИзмененииОбъекта(ТипОбъекта, ИдентификаторОбъекта) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
