---
title: Управление контактной информацией
slug: bsp/управление-контактной-информацией
---


## КонтактнаяИнформация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, содержащую контактную информацию нескольких объектов.
//
// Параметры:
//    Источник         - Массив - владельцы контактной информации.
//    Отбор - см. ОтборКонтактнойИнформации.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//   * Объект           - ЛюбаяСсылка - владелец контактной информации.
//   * Вид              - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации.
//   * Тип              - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//   * Значение         - Строка - контактная информация во внутреннем формате JSON.
//   * Представление    - Строка - представление контактной информации.
//   * Дата             - Дата   - дата, с которой действует запись контактной информации.
//   * ИдентификаторСтрокиТабличнойЧасти - Число - идентификатор строки этой табличной части
//   * ЗначенияПолей    - Строка - устаревший XML, соответствующий XDTO пакетам КонтактнаяИнформация или Адрес. Для
//                                 обратной совместимости.
//
Функция КонтактнаяИнформация(Источник, Отбор) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформация(Источник, Отбор) 
```
</details>

## ОтборКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметра Отбор для функции КонтактнаяИнформация.
//
// Возвращаемое значение:
//  Структура:
//   * ТипыКонтактнойИнформации - Массив из ПеречислениеСсылка.ТипыКонтактнойИнформации - отбор по типу контактной информации.
//   * ВидыКонтактнойИнформации - Массив из СправочникСсылка.ВидыКонтактнойИнформации - отбор по видам контактной информации.
//   * Дата                     - Дата - дата с которой действует запись контактной информации, используется при хранении
//                                       истории изменения контактной информации. Если владелец хранит историю изменений,
//                                       то при несоответствии параметра дате будет вызвано исключение.
//   * КодЯзыка - Строка - код языка, на котором необходимо получить представление контактной информации.
//                         Представления контактной информации типа Адрес будет получено путем транслитерации, на остальные
//                         типы контактной информации данных параметр не влияет.
//
Функция ОтборКонтактнойИнформации() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ОтборКонтактнойИнформации() 
```
</details>

## КонтактнаяИнформацияОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, содержащую контактную информацию нескольких объектов.
//
// Параметры:
//    СсылкиИлиОбъекты         - Массив - владельцы контактной информации.
//    ТипыКонтактнойИнформации - Массив
//                             - ПеречислениеСсылка.ТипыКонтактнойИнформации - если указаны, то будет получена
//        контактная информация только этих типов.
//    ВидыКонтактнойИнформации - Массив
//                             - СправочникСсылка.ВидыКонтактнойИнформации - если указаны, то будет возвращена
//                               контактная информация только этих видов контактной информации.
//    Дата                     - Дата   - дата с которой действует запись контактной информации,
//                              используется при хранении истории изменения контактной информации.
//                              Если владелец хранит историю изменений, то при несоответствии параметра
//                              дате будет вызвано исключение.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//    * Объект           - ЛюбаяСсылка - владелец контактной информации.
//    * Вид              - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации.
//    * Тип              - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//    * Значение         - Строка - контактная информация во внутреннем формате JSON.
//    * Представление    - Строка - представление контактной информации.
//    * Дата             - Дата - дата, с которой действует запись контактной информации.
//    * ИдентификаторСтрокиТабличнойЧасти - Число - идентификатор строки этой табличной части
//    * ЗначенияПолей    - Строка - устаревший XML, соответствующий XDTO пакетам КонтактнаяИнформация или Адрес. Для
//                                  обратной совместимости.
//
Функция КонтактнаяИнформацияОбъектов(СсылкиИлиОбъекты, Знач ТипыКонтактнойИнформации = Неопределено, Знач ВидыКонтактнойИнформации = Неопределено, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъектов(СсылкиИлиОбъекты, ТипыКонтактнойИнформации, ВидыКонтактнойИнформации, Дата);
```
</details>

## КонтактнаяИнформацияОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, содержащую контактную информацию объекта.
// Поведение, при котором возвращалось представление контактной информации, теперь считается устаревшим
// и сохранено для обратной совместимости. Для получения представления контактной информации рекомендуется
// использовать функцию ПредставлениеКонтактнойИнформацииОбъекта.
//
// Параметры:
//  СсылкаИлиОбъект - ОпределяемыйТип.ВладелецКонтактнойИнформации
//                  - СправочникОбъект
//                  - ДокументОбъект - ссылка или объект-владелец контактной информации (организация,
//                                      контрагент, партнер и т.д.).
//  ВидИлиТипКонтактнойИнформации - СправочникСсылка.ВидыКонтактнойИнформации - отбор по виду контактной информации.
//                                - ПеречислениеСсылка.ТипыКонтактнойИнформации - отбор по типу контактной информации.
//  Дата                     - Дата - дата с которой действует запись контактной информации,
//                              используется при хранении истории изменения контактной информации.
//                              Если владелец хранит историю изменений, то при несоответствии параметра
//                              дате будет вызвано исключение.
//  ТолькоПредставление      - Булево - если Истина, то возвращает только представление, иначе таблицу значений.
//                                      Для получения представления рекомендуется использовать функцию ПредставлениеКонтактнойИнформацииОбъекта.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//    * Объект           - ЛюбаяСсылка - владелец контактной информации.
//    * Вид              - СправочникСсылка.ВидыКонтактнойИнформации   - вид контактной информации.
//    * Тип              - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//    * Значение         - Строка - контактная информация во внутреннем формате JSON.
//    * Представление    - Строка - представление контактной информации.
//    * Дата             - Дата   - дата, с которой действует запись контактной информации.
//    * ИдентификаторСтрокиТабличнойЧасти - Число - идентификатор строки этой табличной части
//    * ЗначенияПолей    - Строка - устаревший XML, соответствующий XDTO пакетам КонтактнаяИнформация или Адрес. Для
//                                  обратной совместимости.
//
Функция КонтактнаяИнформацияОбъекта(СсылкаИлиОбъект, ВидИлиТипКонтактнойИнформации = Неопределено, Дата = Неопределено, ТолькоПредставление = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъекта(СсылкаИлиОбъект, ВидИлиТипКонтактнойИнформации, Дата, ТолькоПредставление);
```
</details>

## ПредставлениеКонтактнойИнформацииОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление контактной информации объекта.
//
// Параметры:
//  СсылкаИлиОбъект         - Произвольный - владелец контактной информации.
//  ВидКонтактнойИнформации - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации.
//  Разделитель             - Строка - разделитель, который добавляется в представление между записями контактной информации.
//                                     По умолчанию это запятая с последующим пробелом, для исключения
//                                     пробела необходимо использовать признак БезПробелов у параметра ДополнительныеПараметры.
//  Дата                    - Дата - дата, с которой действует запись контактной информации. Если контактная информация
//                                   хранит историю изменения, то передача даты обязательна.
//  ДополнительныеПараметры - Структура - необязательные параметры для формирования представления контактной информации:
//   * ТолькоПервая         - Булево - если Истина, то будет возвращено представление только основной(первой) записи
//                                     контактной информации. По умолчанию - Ложь;
//   * БезПробелов          - Булево - если Истина, то после разделителя не будет автоматически добавляться пробел.
//                                     По умолчанию - Ложь;
//
// Возвращаемое значение:
//  Строка
//
Функция ПредставлениеКонтактнойИнформацииОбъекта(СсылкаИлиОбъект, ВидКонтактнойИнформации, Разделитель = ",", Дата = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПредставлениеКонтактнойИнформацииОбъекта(СсылкаИлиОбъект, ВидКонтактнойИнформации, Разделитель, ", Дата, ДополнительныеПараметры);
```
</details>

## НоваяКонтактнаяИнформация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует новую таблицу контактной информации.
//
// Параметры:
//  КолонкаОбъект - Булево - если Истина, то таблица будет содержать колонку "Объект".
//                           Это нужно, если в таблице необходимо хранить контактной информацию для нескольких объектов.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//       * Объект        - ЛюбаяСсылка - владелец контактной информации.
//       * Вид           - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации.
//       * Тип           - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//       * Значение      - Строка - JSON, соответствующий структуре контактной информации.
//       * ЗначенияПолей - Строка - XML, соответствующий XDTO пакету КонтактнаяИнформация или Адрес.
//       * Представление - Строка - представление контактной информации.
//       * Дата          - Дата   - дата, с которой действует запись контактной информации.
//       * ИдентификаторСтрокиТабличнойЧасти - Число - идентификатор строки этой табличной части
//
Функция НоваяКонтактнаяИнформация(КолонкаОбъект = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.НоваяКонтактнаяИнформация(КолонкаОбъект);
```
</details>

## ДобавитьКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет контактную информацию к объекту по представлению или JSON.
//
// Параметры:
//  СсылкаИлиОбъект - СправочникСсылка
//                  - ДокументСсылка
//                  - СправочникОбъект
//                  - ДокументОбъект - ссылка или объект-владелец, содержащий контактную информацию.
//                                     Если указана ссылка, то объект-владелец будет записан в информационную базу.
//                                     Если передан объект, то запись не выполняется. Для сохранения изменений объект
//                                     необходимо будет записать отдельно.
//  ЗначениеИлиПредставление - Строка - представление, JSON или XML, соответствующее XDTO-пакету КонтактнаяИнформация
//                                      или Адрес. Если передана пустая строка, то запись не будет добавлена.
//  ВидКонтактнойИнформации  - СправочникСсылка.ВидыКонтактнойИнформации - вид добавляемой контактной информации.
//  Дата                     - Дата   - дата, с которой будет действовать запись контактной информации.
//                                      Требуется для контактной информации, у которой хранится история изменений.
//                                      Если значение не указано, то принимается текущая дата сеанса.
//  Замещать                 - Булево - если Истина (по умолчанию), то будет заменена вся контактная информация по
//                                      переданному виду контактной информации.
//                                      Если Ложь, то запись будет добавлена. Если вид контактной информации не
//                                      разрешает ввод нескольких значений, а контактная информация объекта уже
//                                      содержит запись, то запись не будет добавлена.
//  РаспознатьАдрес          - Булево - если Истина (по умолчанию), то переданное представление адреса в
//                                      ЗначениеИлиПредставление будет распознано на основе загруженных данных
//                                      адресного классификатора или с помощью веб-сервиса адресов.
//                                      Применим, когда параметр ЗначениеИлиПредставление - это представление адреса
//                                      и ВидКонтактнойИнформации.Тип = ТипыКонтактнойИнформации.Адрес.
//
Процедура ДобавитьКонтактнуюИнформацию(СсылкаИлиОбъект, ЗначениеИлиПредставление, ВидКонтактнойИнформации, Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ДобавитьКонтактнуюИнформацию(СсылкаИлиОбъект, ЗначениеИлиПредставление, ВидКонтактнойИнформации, );
```
</details>

## УстановитьКонтактнуюИнформациюОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет или изменяет контактную информацию для нескольких владельцев контактной информации.
// Важно! Если в колонке Объект у параметра КонтактнаяИнформация указана ссылка, то после добавления
// контактной информации владелец будет записан. В случае, если колонка Объект содержит объект владельца
// контактной информации, то для сохранения изменений объекты необходимо будет записать отдельно.
//
// Параметры:
//  КонтактнаяИнформация - см. УправлениеКонтактнойИнформацией.НоваяКонтактнаяИнформация
//  Замещать             - Булево -  если Истина(по умолчанию), то будет заменена вся
//                                   вся контактная информация по переданном виду контактной информации.
//                                   Если Ложь, то запись будет добавлена. Если вид контактной информации не разрешает
//                                   ввод нескольких значений, а контактная информация объекта уже содержит запись,
//                                   то запись не будет добавлена.
//
//
//
Процедура УстановитьКонтактнуюИнформациюОбъектов(КонтактнаяИнформация, Замещать = Истина) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.УстановитьКонтактнуюИнформациюОбъектов(КонтактнаяИнформация, Замещать);
```
</details>

## УстановитьКонтактнуюИнформациюОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет или изменяет контактную информацию у владельца контактной информации.
//
// Параметры:
//  СсылкаИлиОбъект - СправочникСсылка
//                  - ДокументСсылка
//                  - СправочникОбъект
//                  - ДокументОбъект - ссылка или объект владелец
//                                     контактной информации. Для ссылки после добавления контактной информации
//                                     владелец будет записан. Если передан объект, то контактная информация будет
//                                     добавлена без записи. Для сохранения изменений объект необходимо будет
//                                     записать отдельно.
//                  - ДанныеФормыСтруктура:
//                      *  Ссылка - СправочникСсылка - ссылка на объект-владельца контактной информации
//  КонтактнаяИнформация - ТаблицаЗначений - таблица, содержащая контактную информацию
//                                           Описание колонок см. функцию НоваяКонтактнаяИнформация.
//                                           Важно! Если передана пустая таблица значений и указан режим замещения, то
//                                           произойдет очистка всей контактной информации владельца контактной информации.
//  Замещать             - Булево          - если Истина(по умолчанию), то будет заменена
//                                           вся контактная информация по переданном виду контактной информации.
//                                           Если Ложь, то запись будет добавлена. Если вид контактной информации
//                                           не разрешает ввод нескольких значений, а контактная информация объекта
//                                           уже содержит запись, то запись не будет добавлена.
//
Процедура УстановитьКонтактнуюИнформациюОбъекта(СсылкаИлиОбъект, Знач КонтактнаяИнформация, Замещать = Истина) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.УстановитьКонтактнуюИнформациюОбъекта(СсылкаИлиОбъект, КонтактнаяИнформация, Замещать);
```
</details>

## СведенияОТелефоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о телефоне или факсе.
//
// Параметры:
//  КонтактнаяИнформация - Строка - телефон во внутреннем формате JSON или в XML, соответствующем XDTO-пакету контактная
//                                  информация.
//                       - Неопределено - конструктор, возвращает список незаполненных полей телефона.
//
// Возвращаемое значение:
//  Структура:
//    * Представление - Строка - полное представление телефона с добавочным номером и комментарием, например, "+7 495
//                               1234567 (+12) Звонить после 18:00".
//    * КодСтраны     - Строка - код страны. Например, +7.
//    * КодГорода     - Строка - код города. Например, 495.
//    * НомерТелефона - Строка - номер телефона. Например, 1234567.
//    * Добавочный    - Строка - добавочный номер телефона. Например, +12.
//    * Комментарий   - Строка - комментарий к номеру телефона. Например, Звонить после 18:00.
//
Функция СведенияОТелефоне(КонтактнаяИнформация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СведенияОТелефоне(КонтактнаяИнформация);
```
</details>

## НомерТелефонаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку с номером телефона без кода и дополнительного номера.
//
// Параметры:
//    КонтактнаяИнформация - Строка - строка JSON или XML контактной информации соответствующая XDTO пакету КонтактнаяИнформация.
//
// Возвращаемое значение:
//    Строка - номер телефона.
//
Функция НомерТелефонаКонтактнойИнформации(Знач КонтактнаяИнформация) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.НомерТелефонаКонтактнойИнформации(КонтактнаяИнформация) 
```
</details>

## КонтактнаяИнформацияВJSON
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует входящие форматы контактной информации во внутренний формат JSON.
//
// Параметры:
//    КонтактнаяИнформация - Строка - строка в формате XML. Структура XML-документа соответствует XDTO-пакету КонтактнаяИнформация
//                                    или Адрес (для адресов содержащих поля с национальной спецификой).
//                                    Если передана строка во внутреннем формате JSON, то возвращаемое значение будет
//                                    полностью совпадать с ней.
//                         - Структура - см. УправлениеКонтактнойИнформациейКлиентСервер.СтруктураКонтактнойИнформацииПоТипу
//                                       см. РаботаСАдресамиКлиентСервер.ПоляАдреса (для адресов содержащих поля с
//                                       национальной спецификой), см. РаботаСАдресамиКлиентСервер.СтруктураКонтактнойИнформацииПоТипу
//                                       (для других типов контактной информации содержащих поля с национальной спецификой).
//    ОжидаемыйВид - СправочникСсылка.ВидыКонтактнойИнформации
//                 - ПеречислениеСсылка.ТипыКонтактнойИнформации -
//                   используется для определения типа контактной информации, если его невозможно определить из
//                   переданной контактной информации в параметре КонтактнаяИнформация.
//
// Возвращаемое значение:
//     Строка - контактная информация во внутреннем формате JSON.
//              Поля и их описание см. УправлениеКонтактнойИнформациейКлиентСервер.ОписаниеНовойКонтактнойИнформации.
//              Дополнительные поля для конфигурации с поддержкой национальной специфики см. РаботаСАдресамиКлиентСервер.ОписаниеНовойКонтактнойИнформации
//
Функция КонтактнаяИнформацияВJSON(Знач КонтактнаяИнформация, Знач ОжидаемыйВид = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформацияВJSON(КонтактнаяИнформация, ОжидаемыйВид);
```
</details>

## КонтактнаяИнформацияВXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует все входящие форматы контактной информации в XML.
//
// Параметры:
//    ЗначенияПолей - Строка
//                  - Структура
//                  - Соответствие
//                  - СписокЗначений - описание полей контактной информации.
//                    XML должен соответствовать XDTO-пакету КонтактнаяИнформация или Адрес.
//                    Структура, Соответствие, СписокЗначений должен содержать поля в соответствии со структурой
//                    XDTO пакетов КонтактнаяИнформация или Адрес(для конфигурации с поддержкой специфики РФ).
//    Представление - Строка - представление контактной информации. Используется, если невозможно определить
//                    представление из параметра ЗначенияПолей (например, отсутствует поле Представление).
//    ОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                  - ПеречислениеСсылка.ТипыКонтактнойИнформации -
//                    Используется для определения типа, если его невозможно вычислить по полю ЗначенияПолей.
//
// Возвращаемое значение:
//     Строка - контактная информация в виде XML, соответствующего структуре XDTO пакетов КонтактнаяИнформация и Адрес.
//
Функция КонтактнаяИнформацияВXML(Знач ЗначенияПолей, Знач Представление = "", Знач ОжидаемыйВид = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформацияВXML(ЗначенияПолей, Представление, ОжидаемыйВид);
```
</details>

## ОбновитьКонтактнуюИнформациюОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует контактную информацию, хранящуюся в поле ЗначениеПолей, в формат JSON и сохраняет его
// в поле колонки Значение таблицы КонтактнаяИнформация.
// Если колонки ЗначениеПолей и Значение содержат пустые строки, то JSON будет сформирована по представлению.
// В случае, когда параметр СсылкаИлиОбъект содержит объект контактной информации,
// то для сохранения изменений преобразования необходимо будет записать объект отдельно.
// Если передана ссылка, то после конвертирования хотя бы одной строки контактной информации владелец будет записан.
//
// Параметры:
//  СсылкаИлиОбъект - ОпределяемыйТип.ВладелецКонтактнойИнформации - ссылка на объект с контактной информацией.
//                  - СправочникОбъект
//                  - ДокументОбъект - объект-владелец контактной информации (организация,
//                                    контрагент, партнер и т.д.).
//
// Возвращаемое значение:
//  Булево - если, Истина, то контактная информация была преобразована в JSON.
//
Функция ОбновитьКонтактнуюИнформациюОбъекта(СсылкаИлиОбъект) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ОбновитьКонтактнуюИнформациюОбъекта(СсылкаИлиОбъект) 
```
</details>

## ОбъектыТребующиеОбновленияКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объекты, хранящие контактную информацию в устаревших форматах XML или Ключ-Значение,
// и требующие преобразования контактной информации в современный формат JSON.
//
// Параметры:
//  ОбъектМетаданных - ОбъектМетаданных - объект с контактной информации у которого требуется определить элемент
//                     содержащие незаполненные поля в JSON.
//  РазмерПорции  - Число - количество объектов, возвращаемых за один вызов. Если не указано, то будут выбраны все объекты.
//
// Возвращаемое значение:
//  Массив - ссылки на объекты.
//
Функция ОбъектыТребующиеОбновленияКонтактнойИнформации(ОбъектМетаданных, РазмерПорции = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ОбъектыТребующиеОбновленияКонтактнойИнформации(ОбъектМетаданных, РазмерПорции);
```
</details>

## ТипКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тип контактной информации.
//
// Параметры:
//    КонтактнаяИнформация - Строка - контактная информация в виде XML, соответствующего структуре XDTO-пакетов
//                                    КонтактнаяИнформация и Адрес.
//
// Возвращаемое значение:
//    ПеречислениеСсылка.ТипыКонтактнойИнформации - соответствующий тип.
//
Функция ТипКонтактнойИнформации(Знач КонтактнаяИнформация) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ТипКонтактнойИнформации(КонтактнаяИнформация) 
```
</details>

## КонтактнаяИнформацияПоПредставлению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует представление контактной информации во внутренний формат JSON.
//
// Для адресов, введенных в свободной форме, корректное преобразование не гарантируется.
//
//  Параметры:
//      Представление - Строка  - строковое представление контактной информации, выводимое пользователю.
//      ОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                    - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                    - Структура - вид или тип контактной информации.
//
// Возвращаемое значение:
//      Строка - контактная информация в виде JSON.
//
Функция КонтактнаяИнформацияПоПредставлению(Представление, ОжидаемыйВид) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформацияПоПредставлению(Представление, ОжидаемыйВид) 
```
</details>

## ПредставлениеКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление контактной информации (адреса, телефона, электронной почты и т.п.).
//
// Параметры:
//    КонтактнаяИнформация - Строка - строка JSON или XML контактной информации
//                                    соответствующая XDTO пакетам КонтактнаяИнформация или Адрес.
//                         - ОбъектXDTO - XDTO-объект КонтактнаяИнформация или Адрес.
//                         - Структура - см. РаботаСАдресами.СведенияОбАдресе
//                         - Структура - см. УправлениеКонтактнойИнформацией.СведенияОТелефоне
//    ПеревестиВТранслит - Булево - Истина, если требуется перевести представление контактной информации в транслит.
//
// Возвращаемое значение:
//    Строка - представление контактной информации.
//
Функция ПредставлениеКонтактнойИнформации(Знач КонтактнаяИнформация, Знач ПеревестиВТранслит = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПредставлениеКонтактнойИнформации(КонтактнаяИнформация, ПеревестиВТранслит);
```
</details>

## АдресВведенВСвободнойФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет, что адрес был введен в свободной форме.
//
//  Параметры:
//      КонтактнаяИнформация - Строка - строка JSON или XML контактной информации, соответствующая XDTO-пакетам
//                                      КонтактнаяИнформация или Адрес.
//
//  Возвращаемое значение:
//      Булево - новое значение.
//
Функция АдресВведенВСвободнойФорме(Знач КонтактнаяИнформация) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.АдресВведенВСвободнойФорме(КонтактнаяИнформация) 
```
</details>

## КомментарийКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает комментарий контактной информации.
//
// Параметры:
//  КонтактнаяИнформация - Строка - строка JSON или XML или объект XDTO, соответствующие XDTO-пакетам
//                                   КонтактнаяИнформация или Адрес.
//
// Возвращаемое значение:
//  Строка - комментарий контактной информации или пустая строка,
//           если значение параметра не является контактной информацией.
//
Функция КомментарийКонтактнойИнформации(КонтактнаяИнформация) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КомментарийКонтактнойИнформации(КонтактнаяИнформация) 
```
</details>

## УстановитьКомментарийКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает новый комментарий для контактной информации.
//
// Параметры:
//   КонтактнаяИнформация - Строка
//                        - ОбъектXDTO - строка JSON или XML контактной информации, соответствующая XDTO
//                                       пакетам КонтактнаяИнформация или Адрес.
//   Комментарий          - Строка             - новое значение комментария.
//
Процедура УстановитьКомментарийКонтактнойИнформации(КонтактнаяИнформация, Знач Комментарий) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.УстановитьКомментарийКонтактнойИнформации(КонтактнаяИнформация, Комментарий) 
```
</details>

## СтранаАдресаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о стране адреса.
// Если переданная строка не содержит информации об адресе, то будет вызвано исключение.
// Если передана пустая строка, то возвращается пустая структура.
// Если страна не существует в справочнике, но есть в классификаторе стран, то поле Ссылка результата не будет заполнено.
// Если страна не существует в классификаторе стран, то будет заполнено только поле Наименование.
//
// Параметры:
//    Адрес - Структура
//          - Строка - адрес в формате JSON или строка XML соответствующая XDTO-пакетам КонтактнаяИнформация
//                     или Адрес.
//
// Возвращаемое значение:
//    Структура - описание страны адреса. Содержит поля:
//        * Ссылка             - СправочникСсылка.СтраныМира
//                             - Неопределено - ссылка на элемент справочника страны мира.
//        * Наименование       - Строка - наименование страны.
//        * Код                - Строка - код страны.
//        * НаименованиеПолное - Строка - полное наименование страны.
//        * КодАльфа2          - Строка - двузначный буквенный код страны Альфа-2.
//        * КодАльфа3          - Строка - трехзначный буквенный код страны Альфа-3.
//
Функция СтранаАдресаКонтактнойИнформации(Знач Адрес) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СтранаАдресаКонтактнойИнформации(Адрес) 
```
</details>

## ДоменАдресаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает домен сетевого адреса для веб-ссылки или адреса электронной почты.
//
// Параметры:
//    КонтактнаяИнформация - Строка - строка JSON или XML контактной информации соответствующая XDTO пакету КонтактнаяИнформация.
//
// Возвращаемое значение:
//    Строка - домен адреса.
//
Функция ДоменАдресаКонтактнойИнформации(Знач КонтактнаяИнформация) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ДоменАдресаКонтактнойИнформации(КонтактнаяИнформация) 
```
</details>

## РазличияКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сравнивает два экземпляра контактной информации.
//
// Параметры:
//    Данные1 - ОбъектXDTO - объект с контактной информацией.
//            - Строка     - контактная информация в формате XML.
//            - Структура  - описание контактной информацию. Ожидаются поля:
//                 * ЗначенияПолей - Строка
//                                 - Структура
//                                 - СписокЗначений
//                                 - Соответствие - поля контактной информации.
//                 * Представление - Строка - представление. Используется в случае, если не удалось вычислить
//                                            представление из ЗначенияПолей (отсутствие в них поля Представление).
//                 * Комментарий - Строка - комментарий. Используется в том случае, если не удалось вычислить комментарий
//                                          из ЗначенияПолей.
//                 * ВидКонтактнойИнформации - СправочникСсылка.ВидыКонтактнойИнформации
//                                           - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                                           - Структура -
//                                             используется в том случае, если не удалось вычислить тип из ЗначенияПолей.
//    Данные2 - ОбъектXDTO
//            - Строка
//            - Структура - смотри описание параметра Данные1.
//
// Возвращаемое значение:
//     ТаблицаЗначений: - таблица отличающихся полей со следующими колонками:
//        * Путь      - Строка - XPath, идентифицирующий отличающееся значение. Значение "ТипКонтактнойИнформации"
//                               означает, что переданные экземпляры контактной информации различаются типом.
//        * Описание  - Строка - описание отличающегося реквизита в терминах предметной области.
//        * Значение1 - Строка - значение, соответствующая объекту, переданному в параметре Данные1.
//        * Значение2 - Строка - значение, соответствующая объекту, переданному в параметре Данные2.
//
Функция РазличияКонтактнойИнформации(Знач Данные1, Знач Данные2) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.РазличияКонтактнойИнформации(Данные1, Данные2) 
```
</details>

## СоздатьВТКонтактнаяИнформация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу с контактной информацией нескольких объектов.
//
// Параметры:
//    МенеджерВременныхТаблиц  - МенеджерВременныхТаблиц - в менеджере создается временная таблица
//     ВТКонтактнаяИнформация с полями:
//     * Объект        - ЛюбаяСсылка - владелец контактной информации.
//     * Вид           - СправочникСсылка.ВидыКонтактнойИнформации - ссылка на вид контактной информации.
//     * Тип           - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//     * ЗначенияПолей - Строка - XML соответствующий XDTO пакету КонтактнаяИнформация или Адрес.
//     * Представление - Строка - представление контактной информации.
//    МассивОбъектов           - Массив - владельцы контактной информации.
//    ТипыКонтактнойИнформации - Массив - если указаны, то временная таблица будет содержать только контактную
//                                        информацию этих типов.
//    ВидыКонтактнойИнформации - Массив - если указаны, то временная таблица будет содержать только контактную
//                                        информацию этих видов.
//    Дата                     - Дата   - дата, с которой действует запись контактной информации, используется при
//                                        хранении истории изменения контактной информации. Если владелец хранит историю
//                                        изменений, то при несоответствии параметра дате будет вызвано исключение.
//
Процедура СоздатьВТКонтактнаяИнформация(МенеджерВременныхТаблиц, МассивОбъектов, ТипыКонтактнойИнформации = Неопределено, ВидыКонтактнойИнформации = Неопределено, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.СоздатьВТКонтактнаяИнформация(МенеджерВременныхТаблиц, МассивОбъектов, ТипыКонтактнойИнформации, ВидыКонтактнойИнформации, Дата);
```
</details>

## ДанныеСтраныМира
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные о стране по справочнику стран мира или классификатору.
//
// Параметры:
//    КодСтраны    - Строка
//                 - Число - код страны по классификатору. Если не указано, то поиск по коду не производится.
//    Наименование - Строка - наименование страны, в т.ч. и международное. Если не указано, то поиск по наименованию не производится.
//
// Возвращаемое значение:
//    Структура - описание страны. Содержит поля:
//        * Ссылка             - СправочникСсылка.СтраныМира
//                             - Неопределено - соответствующий элемент справочника Страны мира.
//        * Наименование       - Строка - наименование страны.
//        * Код                - Строка - код страны.
//        * НаименованиеПолное - Строка - полное наименование страны.
//        * КодАльфа2          - Строка - двузначный буквенный код страны альфа-2.
//        * КодАльфа3          - Строка - трехзначный буквенный код страны альфа-3.
//        * УчастникЕАЭС       - Булево - страна-участник ЕАЭС.
//        * МеждународноеНаименование - Строка - международное наименование страны мира
//    Неопределено - страна не существует.
//
Функция ДанныеСтраныМира(Знач КодСтраны = Неопределено, Знач Наименование = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ДанныеСтраныМира(КодСтраны, Наименование);
```
</details>

## ДанныеКлассификатораСтранМираПоКоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные страны по коду.
//
// Параметры:
//  Код     - Строка
//          - Число - код страны по классификатору.
//  ТипКода - Строка - варианты: КодСтраны (по умолчанию), Альфа2, Альфа3.
//
// Возвращаемое значение:
//  Структура - описание страны. Содержит поля:
//     * Наименование       - Строка - наименование страны.
//     * Код                - Строка - код страны.
//     * НаименованиеПолное - Строка - полное наименование страны.
//     * КодАльфа2          - Строка - двузначный буквенный код страны альфа-2.
//     * КодАльфа3          - Строка - трехзначный буквенный код страны альфа-3.
//     * УчастникЕАЭС       - Булево - страна-участник ЕАЭС.
//  Неопределено - страна не существует.
//
Функция ДанныеКлассификатораСтранМираПоКоду(Знач Код, Знач ТипКода = "КодСтраны") Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ДанныеКлассификатораСтранМираПоКоду(Код, ТипКода);
```
</details>

## ДанныеКлассификатораСтранМираПоНаименованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные о стране по наименованию страны.
//
// Параметры:
//    Наименование - Строка - наименование страны.
//
// Возвращаемое значение:
//    Структура - описание страны. Содержит поля:
//       * Наименование       - Строка - наименование страны.
//       * Код                - Строка - код страны.
//       * НаименованиеПолное - Строка - полное наименование страны.
//       * КодАльфа2          - Строка - двузначный буквенный код страны альфа-2.
//       * КодАльфа3          - Строка - трехзначный буквенный код страны альфа-3.
//       * УчастникЕАЭС       - Булево - страна-участник ЕАЭС.
//    Неопределено - страна не существует в классификаторе.
//
Функция ДанныеКлассификатораСтранМираПоНаименованию(Знач Наименование) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ДанныеКлассификатораСтранМираПоНаименованию(Наименование) 
```
</details>

## СтранаМираПоКодуИлиНаименованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на элемент справочника страны мира по коду или наименованию.
// Если элемент справочника СтраныМиры не существует, то он будет создан на основании данных заполнения.
//
// Параметры:
//  КодИлиНаименование - Строка    - код страны, код Альфа2, код Альфа3 или наименование страны, в т.ч. международное.
//  ДанныеЗаполнения   - Структура - данные для заполнения в случае создания нового элемента.
//                                   Ключи структуры соответствуют реквизитам справочника СтраныМира.
//
// Возвращаемое значение:
//  СправочникСсылка.СтраныМира - если найдено несколько значений, то будет возвращено первое.
//                                Если не существует и данные заполнения не указаны, то возвращается пустая ссылка.
//
Функция СтранаМираПоКодуИлиНаименованию(КодИлиНаименование, ДанныеЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СтранаМираПоКодуИлиНаименованию(КодИлиНаименование, ДанныеЗаполнения);
```
</details>

## СтраныУчастникиЕАЭС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список стран Евразийского экономического союза (ЕАЭС).
// Вызов функции может инициировать HTTP-запрос к веб-сервису по работе с классификаторами
// для получения актуального списка всех стран участников ЕАЭС.
//
// Возвращаемое значение:
//  - ТаблицаЗначений - список стран Евразийского экономического союза (ЕАЭС):
//     * Ссылка             - СправочникСсылка.СтраныМира - ссылка на элемент справочника страны.
//     * Наименование       - Строка - наименование страны.
//     * Код                - Строка - код страны.
//     * НаименованиеПолное - Строка - полное наименование страны.
//     * КодАльфа2          - Строка - двузначный буквенный код страны альфа-2.
//     * КодАльфа3          - Строка - трехзначный буквенный код страны альфа-3.
//     * МеждународноеНаименование - Строка - международное наименование страны мира
//
Функция СтраныУчастникиЕАЭС() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СтраныУчастникиЕАЭС() 
```
</details>

## ЭтоСтранаУчастникЕАЭС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, является ли страна участником Евразийского экономического союза (ЕАЭС).
//
// Параметры:
//  Страна - Строка
//         - СправочникСсылка.СтраныМира - код страны, код Альфа2, код Альфа3,
//                  наименование страны или ссылка на элемент справочника Страны мира.
// Возвращаемое значение:
//    Булево - если Истина, то страна является государством-участником ЕАЭС.
//
Функция ЭтоСтранаУчастникЕАЭС(Страна) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ЭтоСтранаУчастникЕАЭС(Страна) 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик для события формы ПриСозданииНаСервере.
// Вызывается из модуля формы объекта-владельца КИ при внедрении подсистемы.
//
// Параметры:
//    Форма - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода контактной информации.
//    Объект - СправочникСсылка
//           - ДокументСсылка
//           - СправочникОбъект
//           - ДокументОбъект - объект-владелец контактной информации.
//                              Если это ссылка, то контактная информация
//                              будет получена из объекта по ссылке, иначе из таблицы КонтактнаяИнформация объекта.
//    ДополнительныеПараметры - см. ПараметрыКонтактнойИнформации.
//                            - Строка - устарел.
//    УдалитьПоложениеЗаголовкаКИ - ПоложениеЗаголовкаЭлементаФормы - устарел, следует использовать ДополнительныеПараметры.
//    УдалитьИсключаемыеВиды - Массив  - устарел,следует использовать ДополнительныеПараметры.
//    УдалитьОтложеннаяИнициализация - Массив - устарел,следует использовать ДополнительныеПараметры.
//
Процедура ПриСозданииНаСервере(Форма, Объект, Знач ДополнительныеПараметры = Неопределено, УдалитьПоложениеЗаголовкаКИ = "", Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ПриСозданииНаСервере(Форма, Объект, ДополнительныеПараметры, УдалитьПоложениеЗаголовкаКИ, );
```
</details>

## ПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик для события формы ПриЧтенииНаСервере.
// Вызывается из модуля формы объекта-владельца КИ при внедрении подсистемы.
//
// Параметры:
//    Форма  - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода контактной информации.
//    Объект - СправочникСсылка
//           - ДокументСсылка
//           - СправочникОбъект
//           - ДокументОбъект - объект-владелец контактной информации.
//    ИмяЭлементаДляРазмещения - Строка - группа, куда будут размещены элементы контактной информации.
//
Процедура ПриЧтенииНаСервере(Форма, Объект, ИмяЭлементаДляРазмещения = "ГруппаКонтактнаяИнформация") Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ПриЧтенииНаСервере(Форма, Объект, ИмяЭлементаДляРазмещения);
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик для события формы ПослеЗаписиНаСервере.
// Вызывается из модуля формы объекта-владельца КИ при внедрении подсистемы.
//
// Параметры:
//    Форма  - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода контактной информации.
//    Объект - СправочникСсылка
//           - ДокументСсылка
//           - СправочникОбъект
//           - ДокументОбъект - объект-владелец контактной информации.
//
Процедура ПослеЗаписиНаСервере(Форма, Объект) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ПослеЗаписиНаСервере(Форма, Объект) 
```
</details>

## ОбработкаПроверкиЗаполненияНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик для события формы ОбработкаПроверкиЗаполненияНаСервере.
// Вызывается из модуля формы объекта-владельца КИ при внедрении подсистемы.
//
// Параметры:
//    Форма  - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода контактной информации.
//    Объект - СправочникСсылка
//           - ДокументСсылка
//           - СправочникОбъект
//           - ДокументОбъект - объект-владелец контактной информации.
//    Отказ  - Булево - если Истина, то во время проверки были обнаружены ошибки.
//
Процедура ОбработкаПроверкиЗаполненияНаСервере(Форма, Объект, Отказ) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ОбработкаПроверкиЗаполненияНаСервере(Форма, Объект, Отказ) 
```
</details>

## ПередЗаписьюНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик для события формы ПередЗаписьюНаСервере.
// Вызывается из модуля формы объекта-владельца КИ при внедрении подсистемы.
//
// Параметры:
//    Форма  - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода контактной информации.
//    Объект - СправочникОбъект
//           - ДокументСсылка - объект-владелец контактной информации.
//             ДанныеФормыСтруктура - Объект, содержащий табличную часть с контактной информацией. Поддерживает работу
//                              со скрываемыми видами контактной информации только для уже существующих объектов,
//                              из-за невозможности установить ссылку для нового объекта.
//    Отказ  - Булево - если Истина, то объект не был записан, т.к. во время записи возникли ошибки.
//
Процедура ПередЗаписьюНаСервере(Форма, Объект, Отказ = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ПередЗаписьюНаСервере(Форма, Объект, Отказ);
```
</details>

## ОбновитьКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет (удаляет) поле ввода или комментарий на форму, обновляя данные.
// Вызывается из модуля формы объекта-владельца контактной информации.
//
// Параметры:
//    Форма     - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода контактной информации.
//    Объект    - ДанныеФормыСтруктура - объект-владелец контактной информации.
//    Результат - Неопределено - служебный реквизит, полученный из предыдущего обработчика события.
//              - Структура: - набор свойств динамический:
//      * ПоменятьМестамиЭлементы - Булево - если значения элементов меняются местами.
//      * ПервыйЭлемент - Строка - если значения элементов меняются местами.
//      * ВторойЭлемент - Строка - если значения элементов меняются местами.
//      * ОбновитьКонтекстноеМеню - Булево -  если выполняется обновление меню
//      * ИмяРеквизита - Строка - если выполняется обновление меню
//      * ДобавляемыйВид - Булево - при добавлении нового элемента
//      * ЭтоДобавлениеКомментария - Булево - при добавлении комментария
//      * ОбновитьКонтекстноеМеню - Булево - при обновлении контекстного меню
//      * ИмяЭлементаДляРазмещения - Строка -  если добавляет новый элемент, комментарий или обновляется контекстное меню
//      * Комментарий - Строка - при обновлении контекстного меню
//       * Перечитать  - Булево - если нужно полностью обновить контактную информацию в рамках элемента для размещения.
//
// Возвращаемое значение:
//    Неопределено - значение не используется, обратная совместимость.
//
Функция ОбновитьКонтактнуюИнформацию(Форма, Объект, Результат = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ОбновитьКонтактнуюИнформацию(Форма, Объект, Результат);
```
</details>

## ОбработкаЗаполненияКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки события "ОбработкаЗаполнения".
//
// Параметры:
//  Источник             - СправочникОбъект
//                       - ДокументОбъект - объект, содержащий контактную информацию.
//  ДанныеЗаполнения     - Структура - данные с контактной информацией для заполнения объекта.
//  ТекстЗаполнения      - Строка - не используется.
//  СтандартнаяОбработка - Булево - не используется.
//
Процедура ОбработкаЗаполненияКонтактнойИнформации(Источник, ДанныеЗаполнения, ТекстЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ОбработкаЗаполненияКонтактнойИнформации(Источник, ДанныеЗаполнения, ТекстЗаполнения, СтандартнаяОбработка) 
```
</details>

## ОбработкаОбновленияКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки события "ПередЗаписью" для обновления контактной информации для списков.
//
// Параметры:
//  Объект - Произвольный - объект, содержащий контактную информацию.
//  Отказ  - Булево       - не используется, обратная совместимость.
//
Процедура ОбработкаОбновленияКонтактнойИнформации(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ОбработкаОбновленияКонтактнойИнформации(Объект, Отказ) 
```
</details>

## ОбработкаЗаполненияКонтактнойИнформацииДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки события "ОбработкаЗаполнения" для документов.
//
// Параметры:
//  Источник             - Произвольный         - объект, содержащий контактную информацию.
//  ДанныеЗаполнения     - Структура            - данные с контактной информацией для заполнения объекта.
//  ТекстЗаполнения      - Строка
//                       - Неопределено - данные заполнения реквизита Наименование.
//  СтандартнаяОбработка - Булево               - не используется.
//
Процедура ОбработкаЗаполненияКонтактнойИнформацииДокумента(Источник, ДанныеЗаполнения, ТекстЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ОбработкаЗаполненияКонтактнойИнформацииДокумента(Источник, ДанныеЗаполнения, ТекстЗаполнения, СтандартнаяОбработка) 
```
</details>

## ВыполнитьОтложеннуюИнициализацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отложенную инициализацию реквизитов и элементов контактной информации.
//
// Параметры:
//  Форма                    - ФормаКлиентскогоПриложения - форма объекта-владельца, предназначенная для вывода
//                                                          контактной информации.
//  Объект                   - Произвольный - объект-владелец контактной информации.
//  ИмяЭлементаДляРазмещения - Строка - имя группы, где размещена контактная информация.
//
Процедура ВыполнитьОтложеннуюИнициализацию(Форма, Объект, ИмяЭлементаДляРазмещения = "ГруппаКонтактнаяИнформация") Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ВыполнитьОтложеннуюИнициализацию(Форма, Объект, ИмяЭлементаДляРазмещения);
```
</details>

## ВидыКонтактнойИнформацииОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает используемые виды контактной информации объекта.
//
// Параметры:
//  ВладелецКонтактнойИнформации - СправочникСсылка.ВидыКонтактнойИнформации
//                               - СправочникОбъект.ВидыКонтактнойИнформации
//                               - ДанныеФормыСтруктура:
//                                 * Ссылка - СправочникСсылка.ВидыКонтактнойИнформации - ссылка на вид КИ.
//  ТипКонтактнойИнформации - ПеречислениеСсылка.ТипыКонтактнойИнформации - отбор видов КИ по типу.
//
// Возвращаемое значение:
//  ТаблицаЗначений - виды контактной информации, где:
//    * Ссылка  - СправочникСсылка.ВидыКонтактнойИнформации
//    * Тип - ПеречислениеСсылка.ТипыКонтактнойИнформации
//    * Представление - Строка
//    * Наименование - Строка
//    * РазрешитьВводНесколькихЗначений - Булево
//    * РеквизитДопУпорядочивания - Число
//    * ОбязательноеЗаполнение - Булево
//    * ПроверятьКорректность - Булево
//    * ИдентификаторДляФормул - Строка
//    * ИмяПредопределенногоВида - Строка
//
Функция ВидыКонтактнойИнформацииОбъекта(ВладелецКонтактнойИнформации, ТипКонтактнойИнформации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ВидыКонтактнойИнформацииОбъекта(ВладелецКонтактнойИнформации, ТипКонтактнойИнформации);
```
</details>

## СодержитКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, что объект подключен к подсистеме "Контактная информация"
// и содержит табличную часть КонтактнаяИнформация.
//
// Параметры:
//  ПроверяемыйОбъект - СправочникОбъект
//                    - СправочникСсылка
//                    - ДокументОбъект
//                    - ДокументСсылка
//                    - Тип - проверяемый объект на подключение к подсистеме Контактная информация.
//
// Возвращаемое значение:
//  Булево - если Истина, то объект содержит контактную информацию.
//
Функция СодержитКонтактнуюИнформацию(ПроверяемыйОбъект) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СодержитКонтактнуюИнформацию(ПроверяемыйОбъект) 
```
</details>

## ВидКонтактнойИнформацииПоИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на вид контактной информации.
// Если по виден не был найден по имени, то выполняется поиск по именам предопределенных элементов.
//
// Параметры:
//  Имя - Строка - уникальное имя вида контактной информации.
//
// Возвращаемое значение:
//  СправочникСсылка.ВидыКонтактнойИнформации
//
Функция ВидКонтактнойИнформацииПоИмени(Имя) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ВидКонтактнойИнформацииПоИмени(Имя) 
```
</details>

## ПараметрыКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описание параметров контактной информации, используемых в обработчике ПриСозданииНаСервере.
//
// Возвращаемое значение:
//  Структура - параметры контактной информации:
//   * Индекс                   - Строка - индекс адреса.
//   * Страна                   - Строка - страна адреса.
//   * ТипПомещения             - Строка - наименование  типа помещения, который будет установлен
//                                         в форме ввода нового адреса. По умолчанию, "Квартира".
//   * ИмяЭлементаДляРазмещения - Строка - группа, куда будут размещены элементы контактной информации.
//   * СкрываемыеВиды           - Массив - виды контактной информации, которые не требуется отображать на форме.
//   * ОтложеннаяИнициализация  - Булево - если Истина, то создание полей контактной информации на форме будет отложено.
//   * ПоложениеЗаголовкаКИ     - ПоложениеЗаголовкаЭлементаФормы - может принимать значения:
//                                                             ПоложениеЗаголовкаЭлементаФормы.Верх  или
//                                                             ПоложениеЗаголовкаЭлементаФормы.Лево (по умолчанию).
//   * РазрешитьДобавлениеПолей - Булево - если Истина, то на форме владельца контактной информации, будет отображена кнопка
//                                         для добавления дополнительной контактной информации
//   * РазмещеныНаФорме         - Соответствие из КлючИЗначение - виды контактной информации, которые были размещены на
//                                               форме интерактивно, при отложенной инициализации будут созданы на форме
//                                               после вызова процедуры УправлениеКонтактнойИнформацией.ВыполнитьОтложеннуюИнициализацию:
//                                  ** Ключ - Строка - имя предопределенного вида контактной информации
//                                          - СправочникСсылка.ВидыКонтактнойИнформации
//                                  ** Значение - Булево - Истина
//   * ОбработкаНавигационнойСсылки - Булево - если истина, то отображение контактной информации с типом ВебСтраница
//   										   будет в виде гиперссылки
//   * ИсключаемыеВиды - Массив - устарело. Следует использовать РазмещеныНаФорме.
//
Функция ПараметрыКонтактнойИнформации() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПараметрыКонтактнойИнформации() 
```
</details>

## СведенияОбАдресе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает детализированную информацию об адресе в виде отдельных полей, таких как город, улица, регион, индекс и др.
// Если в конфигурации присутствует общий модуль РаботаСАдресами,
// вызов данной функции будет автоматически перенаправлен в этот модуль.
//
// Параметры:
//   Адрес                  - Строка - адрес во внутреннем формате JSON.
//                          - Неопределено - конструктор для получения пустых полей адреса.
//   ДополнительныеПараметры - Структура - для уточнения возвращаемого значения.
//     * БезПредставлений - Булево - если Истина, то поле Представление будет отсутствовать. По умолчанию Ложь.
////
// Возвращаемое значение:
//   Структура:
//        * Представление    - Строка - текстовое представление адреса. Например, "08681, Центральный регион, город
//                                      Лима, ул. Широкая, дом 1".
//        * ТипАдреса        - Строка - тип адреса. Варианты: "ВСвободнойФорме", "Иностранный".
//        * Страна           - Строка - текстовое представление страны.  Например, "Перу".
//        * КодСтраны        - Строка - код страны.  Например, "604".
//        * Индекс           - Строка - почтовый индекс. Например, "08681".
//        * Регион           - Строка - текстовое представление региона или штата.  Например, "Центральный".
//        * Город            - Строка - текстовое представление города.
//        * Улица            - Строка - текстовое представление улицы включая номер дома, корпус, строения. Например
//                                      "ул. Широкая, дом 1".
//        * ДополнительнаяИнформация - Строка - текстовое представление дополнительной информации. Например, когда
//                                     требуется указать детали, такие как квартира, офис, этаж или другие уточнения.
//
Функция СведенияОбАдресе(Адрес = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СведенияОбАдресе(Адрес, ДополнительныеПараметры);
```
</details>

## СведенияОбАдресах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает детализированную информацию об адресе в виде отдельных полей, таких как город, улица, регион, индекс и др.
// Если в конфигурации присутствует общий модуль РаботаСАдресами,
// вызов данной функции будет автоматически перенаправлен в этот модуль.
//
// Параметры:
//  Адреса - Массив из см. СведенияОбАдресе.Адрес
//  ДополнительныеПараметры - см. СведенияОбАдресе.ДополнительныеПараметры
//
// Возвращаемое значение:
//   Массив из см. СведенияОбАдресе
//
Функция СведенияОбАдресах(Адреса, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СведенияОбАдресах(Адреса, ДополнительныеПараметры);
```
</details>

## ПроверитьКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Проверяет контактную информацию.
//
// Параметры:
//   Представление  - Строка - представление контактной информации. Используется, если невозможно определить
//                           представление из параметра ЗначенияПолей (отсутствие поля Представление).
//   ЗначенияПолей  - Строка
//                  - Структура
//                  - Соответствие
//                  - СписокЗначений - описание полей контактной информации.
//   ВидИнформации  - СправочникСсылка.ВидыКонтактнойИнформации - используется для определения типа, если его невозможно
//                                                               определить по параметру ЗначенияПолей.
//   ТипИнформации  - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//   ИмяРеквизита   - Строка - имя реквизита на форме.
//   Комментарий    - Строка - текст комментария.
//   ПутьКРеквизиту - Строка - путь к реквизиту.
//
// Возвращаемое значение:
//   Число - уровень ошибок, 0 - ошибки отсутствуют.
//
Функция ПроверитьКонтактнуюИнформацию(Представление, ЗначенияПолей, ВидИнформации, ТипИнформации, Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПроверитьКонтактнуюИнформацию(Представление, ЗначенияПолей, ВидИнформации, ТипИнформации, );
```
</details>

## УстановитьСвойстваГруппыВидаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает свойства группы контактной информации.
//
// Параметры:
//    Параметры - Структура:
//        * Код    - Строка   - код вида контактной информации для идентификации элемента.
//        * Наименование - Строка - наименование вида контактной информации.
//        * Имя - Строка - имя предопределенного вида контактной информации;
//        * Используется - Булево - признак использования вида контактной информации. Значение по умолчанию Истина.
//
// Возвращаемое значение:
//   СправочникСсылка.ВидыКонтактнойИнформации - ссылка на группу.
//
Функция УстановитьСвойстваГруппыВидаКонтактнойИнформации(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.УстановитьСвойстваГруппыВидаКонтактнойИнформации(Параметры) 
```
</details>

## УстановитьСвойстваВидаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает свойства вида контактной информации.
//
// Примечание. При задании свойства Параметры.Порядок следует следить за уникальностью назначаемого значения.
// Если значения порядка окажутся неуникальными в пределах группы, то настройка
// порядка пользователем будет невозможна. В общем случае рекомендуется не
// использовать этот параметр (порядок не изменится), либо задавать значение 0.
// Для размещения видов КИ в нужной последовательности достаточно вызывать данную процедуру
// в нужной последовательности для каждого вида КИ с указанием порядка 0.
// Если предопределенный вид КИ добавляется к уже существующим в информационной базе,
// не рекомендуется назначать порядок в явном виде.
//
//
// Параметры:
//   Параметры - см. ПараметрыВидаКонтактнойИнформации.
//
Процедура УстановитьСвойстваВидаКонтактнойИнформации(Параметры) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.УстановитьСвойстваВидаКонтактнойИнформации(Параметры) 
```
</details>

## ПараметрыГруппыВидаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров группы вида контактной информации.
//
// Параметры:
//    ГруппаКонтактнойИнформации - СправочникСсылка.ВидыКонтактнойИнформации- группа контактной информации.
//
// Возвращаемое значение:
//    Структура:
//        * Имя          - Строка - уникальное имя вида контактной информации.
//        * Наименование - Строка - наименование вида контактной информации.
//        * Группа - СправочникСсылка.ВидыКонтактнойИнформации - ссылка на группу(родителя) элемента справочника.
//        * Используется - Булево - признак использования вида контактной информации. Значение по умолчанию Истина.
//
Функция ПараметрыГруппыВидаКонтактнойИнформации(ГруппаКонтактнойИнформации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПараметрыГруппыВидаКонтактнойИнформации(ГруппаКонтактнойИнформации);
```
</details>

## ПараметрыВидаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вида контактной информации для указанного типа.
// Для совместного использования с процедурами
// УправлениеКонтактнойИнформацией.УстановитьСвойстваВидаКонтактнойИнформации
// и УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуКонтактнойИнформации.
//
// Параметры:
//    ТипИлиВидКонтактнойИнформации - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                                  - Строка - тип контактной информации,
//                                  - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации для
//                                    заполнения свойства НастройкиПроверки.
//
// Возвращаемое значение:
//  Структура:
//   * Имя          - Строка - уникальное имя вида контактной информации, например "АдресКлиента".
//   * Наименование - Строка - наименование вида контактной информации, например "Адрес клиента".
//   * Вид - СправочникСсылка.ВидыКонтактнойИнформации
//         - Строка - вид контактной информации или идентификатор предопределенного элемента.
//   * Группа - СправочникСсылка.ВидыКонтактнойИнформации - группа (родитель) вида контактной информации.
//   * Тип - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//   * Порядок - Число
//             - Неопределено - положение в списке относительно других элементов в группе.
//                              Если Неопределено, то порядок не переназначается;
//                              0            - порядок назначается автоматически;
//                              Число > 0    - указанный порядок (уникальное значение в пределах группы).
//     * МожноИзменятьСпособРедактирования - Булево - признак возможности изменения свойств вида контактной информации пользователем.
//                                                    Если Ложь, то в форме вида контактной информации свойства доступны
//                                                    только для просмотра. Значение по умолчанию - Ложь.
//     * ВидРедактирования - Строка - вид редактирования: "ПолеВводаИДиалог", "ПолеВвода", "Диалог".
//                                    Если "Диалог", то форме выводится гиперссылка с представлением контактной
//                                    информации, по нажатию на которую, открывается форма соответствующего типа КИ.
//                                    Свойство применимо только для контактной информации с типом: Адрес, Телефон, Факс.
//                                    Если "ПолеВвода", то на форме выводится поле ввода.
//                                    Если "ПолеВводаИДиалог", то доступен ввод в поле и в форме соответствующего типа КИ.
//     * ВидРедактирования - Строка - определят вид редактирования значения. Варианты: "ПолеВводаИДиалог", "ПолеВвода", "Диалог".
//                                    Если "Диалог", то форме выводится гиперссылка с представлением контактной
//                                    информации, по нажатию на которую, открывается форма соответствующего типа КИ.
//                                    Свойство применимо только для контактной информации с типом: Адрес, Телефон, Факс.
//                                    Если "ПолеВвода", то на форме выводится поле ввода.
//                                    Если "ПолеВводаИДиалог", то доступен ввод в поле и в форме соответствующего типа КИ.
//     * ХранитьИсториюИзменений     - Булево - признак возможности хранения истории контактной информации.
//                                              Хранение истории допускается, если признак ВидРедактирования = "Диалог"
//                                              равен Истина. Свойство применимо если табличная часть КонтактнаяИнформация
//                                              содержит реквизит ДействуетС. Значение по умолчанию - Ложь.
//     * ОбязательноеЗаполнение       - Булево - если Истина, то требуется обязательный ввод значения в поле на форме.
//                                               Значение по умолчанию - Ложь.
//     * РазрешитьВводНесколькихЗначений - Булево - признак возможности ввода нескольких значений для данного вида.
//                                                  Значение по умолчанию - Ложь.
//     * ЗапретитьРедактированиеПользователем - Булево - признак недоступности редактирования пользователем
//                                                       вида контактной информации. Значение по умолчанию - Ложь.
//     * Используется - Булево - если Ложь, то вид контактной информации недоступен для использования пользователем.
//                               Такой вид не выводится в формах и списке видов контактной информации.
//                               Значение по умолчанию - Истина.
//     * МеждународныйФорматАдреса          - Булево - если Истина, то ввод адресов возможен только в международном формате.
//                                                     Значение по умолчанию - Ложь.
//     * ВидПоляДругое                      - Строка - определяет внешний вид поля с типом Другое на форме.
//                                            Варианты: "МногострочноеШирокое", "ОднострочноеШирокое", "ОднострочноеУзкое".
//                                            Значение по умолчанию - "ОднострочноеШирокое".
//     * РедактированиеТолькоВДиалоге - Булево - устарело. Следует использовать ВидРедактирования.
//                                               Если Истина, то форме выводится гиперссылка с представлением контактной
//                                               информации по нажатию на которую, открывается форма соответствующего
//                                               типа КИ. Свойство применимо только для контактной информации с типом -
//                                               Адрес, Телефон, Факс, ВебСтраница. Значение по умолчанию - Ложь.
//     * НастройкиПроверки  - Неопределено - для типов Другое, ВебСтраница, Skype.
//                          - Структура:
//       ** ТолькоНациональныйАдрес - Булево - для типа Адрес. Если Истина, то разрешается ввод только национальных адресов.
//                                             Изменение страны у адреса не допускается.
//       ** СкрыватьНеактуальныеАдреса - Булево - для типа Адрес. Если Истина, если не требуется показывать
//                                                неактуальные адреса при вводе (только если ТолькоНациональныйАдрес = Истина).
//       ** ПроверятьКорректность - Булево - для типа Адрес значение Истина, означает, что разрешено вводить адреса,
//                                           проходящие проверку по адресному классификатору (ТолькоНациональныйАдрес = Истина).
//                                           Допускается ввод адресов других стран в свободной форме,
//                                           если свойство ТолькоНациональныйАдрес = Ложь.
//                                           Для типа АдресЭлектроннойПочты при значении Истина запрещен ввод
//                                           некорректных адресов электронной почты.
//                                           Значение по умолчанию - Ложь.
//       ** ВключатьСтрануВПредставление - Булево - для типа Адрес. если Истина, то Наименование страны всегда
//                                                  добавляется в представление адреса, даже когда другие поля адреса пустые.
//                                                  Значение по умолчанию - Ложь.
//       ** УказыватьОКТМО - Булево - для типа Адрес. признак возможности ручного ввода кода ОКМТО в форме ввода адреса.
//       ** ТелефонСДобавочнымНомером - Булево - для типа Телефон и Факс. Если Истина, то в форме ввода телефона
//                                               доступен ввод добавочного номера. Значение по умолчанию - Истина.
//       ** ВводитьНомерПоМаске - Булево  - для типа Телефон или Факс. Если Истина, требуется ввод телефона по маске.
//       ** МаскаНомераТелефона  - Строка - для типа Телефон или Факс. Содержит посимвольную строку маски
//                                          ввода текста в поле.
//
Функция ПараметрыВидаКонтактнойИнформации(ТипИлиВидКонтактнойИнформации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПараметрыВидаКонтактнойИнформации(ТипИлиВидКонтактнойИнформации);
```
</details>

## ПараметрыАдреса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вида контактной информации типа Адрес.
// Для совместного использования с процедурами
// УправлениеКонтактнойИнформацией.УстановитьСвойстваВидаКонтактнойИнформации
// и УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуКонтактнойИнформации.
//
// Возвращаемое значение:
//  см. ПараметрыВидаКонтактнойИнформации
//
Функция ПараметрыАдреса() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПараметрыАдреса() 
```
</details>

## ПараметрыАдресаЭлектроннойПочты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вида контактной информации типа АдресЭлектроннойПочты.
// Для совместного использования с процедурами
// УправлениеКонтактнойИнформацией.УстановитьСвойстваВидаКонтактнойИнформации
// и УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуКонтактнойИнформации.
//
// Возвращаемое значение:
//  см. ПараметрыВидаКонтактнойИнформации
//
Функция ПараметрыАдресаЭлектроннойПочты() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПараметрыАдресаЭлектроннойПочты() 
```
</details>

## ПараметрыТелефона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вида контактной информации типа Телефон.
// Для совместного использования с процедурами
// УправлениеКонтактнойИнформацией.УстановитьСвойстваВидаКонтактнойИнформации
// и УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуКонтактнойИнформации.
//
// Возвращаемое значение:
//  см. ПараметрыВидаКонтактнойИнформации
//
Функция ПараметрыТелефона() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ПараметрыТелефона() 
```
</details>

## ЗаписатьКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает контактную информацию из XML в поля табличной части Контактная информация объекта.
//
// Параметры:
//    Объект - СправочникОбъект - объект конфигурации, содержащий табличную часть контактная информация.
//    Значение - Строка - контактная информация в внутреннем формате JSON.
//    ВидИнформации - СправочникСсылка.ВидыКонтактнойИнформации - ссылка на вид контактной информации.
//    ТипИнформации - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//    ИдентификаторСтроки - Число - идентификатор строки табличной части.
//    Дата - Дата - дата, с которой действует запись контактной информации,
//                  используется при хранении истории изменения контактной информации.
//
Процедура ЗаписатьКонтактнуюИнформацию(Объект, Знач Значение, ВидИнформации, ТипИнформации, ИдентификаторСтроки = 0, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ЗаписатьКонтактнуюИнформацию(Объект, Значение, ВидИнформации, ТипИнформации, ИдентификаторСтроки, Дата);
```
</details>

## ОбновитьКонтактнуюИнформациюДляСписков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет представление контактной информации в служебном поле ВидДляСписка,
// используемое для вывода ее в динамических списках и отчетах.
//
// Параметры:
//  Объект -ОпределяемыйТип.ВладелецКонтактнойИнформации - ссылка на объект конфигурации, содержащий табличную часть
//  контактная информация.
//
Процедура ОбновитьКонтактнуюИнформациюДляСписков(Объект = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ОбновитьКонтактнуюИнформациюДляСписков(Объект);
```
</details>

## ОбновитьКонтактнуюИнформациюДляСписковОтложенно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отложенное обновление контактной информации для списков.
//
// Параметры:
//  Параметры    - Структура - параметры обработчика обновления.
//  РазмерПорции - Число - размер порции обрабатываемых данных за один запуск.
//
Процедура ОбновитьКонтактнуюИнформациюДляСписковОтложенно(Параметры, РазмерПорции = 1000) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.ОбновитьКонтактнуюИнформациюДляСписковОтложенно(Параметры, РазмерПорции);
```
</details>

## СнятьПризнакПредопределенныйДляВидовКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет информацию о соответствии элемента справочника виде контактной информации предопределенному значению,
// которое помечено как удаленное. Для однократного вызова в обработчиках обновления по отказу от предопределенных
// элементов справочника ВидыКонтактнойИнформации.
//
Процедура СнятьПризнакПредопределенныйДляВидовКонтактнойИнформации() Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформацией.СнятьПризнакПредопределенныйДляВидовКонтактнойИнформации() 
```
</details>

## КонтактнаяИнформацияXMLПоПредставлению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Обратная совместимость.

// Устарела. Следует использовать УправлениеКонтактнойИнформацией.КонтактнаяИнформацияПоПредставлению.
// Преобразует представление контактной информации в XML строку соответствующую структуре
// XDTO пакетам КонтактнаяИнформация и Адрес.
// Для адресов, введенных в свободной форме, корректное преобразование не гарантируется.
//
//  Параметры:
//      Представление - Строка  - строковое представление контактной информации, выводимое пользователю.
//      ОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                    - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                    - Структура - вид или тип контактной информации.
//
// Возвращаемое значение:
//      Строка - контактная информация в виде XML, соответствующего структуре XDTO пакетов КонтактнаяИнформация и Адрес.
//
Функция КонтактнаяИнформацияXMLПоПредставлению(Представление, ОжидаемыйВид) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КонтактнаяИнформацияXMLПоПредставлению(Представление, ОжидаемыйВид) 
```
</details>

## ОписаниеКоманд
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание команд, разбитое по типам контактной информации.
// Полученное соответствие используется в УправлениеКонтактнойИнформациейПереопределяемый.ПриОпределенииНастроек
//
// Возвращаемое значение:
//   Соответствие из КлючИЗначение:
//     * Ключ     - ПеречислениеСсылка.ТипыКонтактнойИнформации
//     * Значение - см. КомандыТипаКонтактнойИнформации
//
Функция ОписаниеКоманд() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ОписаниеКоманд() 
```
</details>

## КомандыТипаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание команд, предназначенные для типа контактной информации, переданного в качестве параметра.
// Полученное соответствие используется в УправлениеКонтактнойИнформациейПереопределяемый.ПриОпределенииНастроек
//
// Параметры:
//   Тип - ПеречислениеСсылка.ТипыКонтактнойИнформации
//
// Возвращаемое значение:
//   Структура - состав полей зависит от типа контактной информации. Для типа Адрес: ВвестиКомментарийКАдресу,
//   ПоказатьНаКартеGoogle, ЗапланироватьВстречу, ПоказатьИсториюИзменений.
//     Для типа Телефон: ПозвонитьПоТелефону, ОтправитьSMS, ПоказатьИсториюИзменений.
//     Для типа Факс: ОтправитьФакс, ПоказатьИсториюИзменений.
//     Для типа АдресЭлектронной почты: НаписатьЭлектронноеПисьмо.
//     Для типа Skype: ПозвонитьSkype, НачатьЧатSkype.
//     Для типа ВебСтраница: ОткрытьВебСтраницу.
//     Для типа Другое: ОткрытьОкноДругое.
//     Состав полей:
//     * ВвестиКомментарийКАдресу  - см. ОписаниеКомандыПоИмени
//     * ПоказатьНаКартеGoogle     - см. ОписаниеКомандыПоИмени
//     * ЗапланироватьВстречу      - см. ОписаниеКомандыПоИмени
//     * ПоказатьИсториюИзменений  - см. ОписаниеКомандыПоИмени
//     * ПозвонитьПоТелефону       - см. ОписаниеКомандыПоИмени
//     * ОтправитьSMS              - см. ОписаниеКомандыПоИмени
//     * ОтправитьФакс             - см. ОписаниеКомандыПоИмени
//     * НаписатьЭлектронноеПисьмо - см. ОписаниеКомандыПоИмени
//     * ПозвонитьSkype            - см. ОписаниеКомандыПоИмени
//     * НачатьЧатSkype            - см. ОписаниеКомандыПоИмени
//     * ОткрытьВебСтраницу        - см. ОписаниеКомандыПоИмени
//     * ОткрытьОкноДругое         - см. ОписаниеКомандыПоИмени
//
Функция КомандыТипаКонтактнойИнформации(Тип) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.КомандыТипаКонтактнойИнформации(Тип) 
```
</details>

## ОписаниеКомандыПоИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с описанием команды контактной информации.
// Полученное соответствие используется в УправлениеКонтактнойИнформациейПереопределяемый.ПриОпределенииНастроек
//
// Параметры:
//   ИмяКоманды - Строка - имя команды, описание которой нужно получить.
//
// Возвращаемое значение:
//   см. СвойстваКоманды
//
Функция ОписаниеКомандыПоИмени(ИмяКоманды) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.ОписаниеКомандыПоИмени(ИмяКоманды) 
```
</details>

## СвойстваКоманды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру для описания команд контактной информации.
// Полученная структура используется в УправлениеКонтактнойИнформациейПереопределяемый.ПриОпределенииНастроек
//
// Параметры:
//   Заголовок - Строка   - заголовок команды.
//   Подсказка - Строка   - подсказка команды.
//   Картинка  - Картинка - картинка команды.
//   Действие  - Строка   - полный путь к процедуре, которую необходимо выполнить.
//                            Например, "СтандартныеПодсистемыКлиент.ОткрытьФормуДокументаВстреча".
//   ИзменяетСохраняемыеДанные - Булево
//
// Возвращаемое значение:
//   Структура:
//     * Заголовок - Строка
//     * Подсказка - Строка
//     * Картинка  - Картинка
//     * Действие  - Строка
//     * ИзменяетСохраняемыеДанные - Булево
//
Функция СвойстваКоманды(Заголовок, Подсказка, Картинка = "", Действие = "", ИзменяетСохраняемыеДанные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформацией.СвойстваКоманды(Заголовок, Подсказка, Картинка, Действие, ИзменяетСохраняемыеДанные);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
