---
title: Управление контактной информацией клиент
slug: bsp/управление-контактной-информацией-клиент
---


## НачатьВыбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события НачалоВыбора поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма                - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Элемент              - ПолеФормы        - элемент формы, содержащий представление контактной информации.
//     Модифицированность   - Булево           - устанавливаемый флаг модифицированности формы.
//     СтандартнаяОбработка - Булево           - устанавливаемый флаг стандартной обработки события формы.
//     ПараметрыОткрытия    - Структура        - параметры открытия формы ввода контактной информации.
//
Процедура НачатьВыбор(Форма, Элемент, Модифицированность = Истина, СтандартнаяОбработка = Ложь, ПараметрыОткрытия = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачатьВыбор(Форма, Элемент, Модифицированность, СтандартнаяОбработка, ПараметрыОткрытия);
```
</details>

## НачатьИзменение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПриИзменении поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма             - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Элемент           - ПолеФормы        - элемент формы, содержащий представление контактной информации.
//     ЭтоТабличнаяЧасть - Булево           - флаг того, что элемент является частью таблицы формы.
//
Процедура НачатьИзменение(Форма, Элемент, ЭтоТабличнаяЧасть = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачатьИзменение(Форма, Элемент, ЭтоТабличнаяЧасть);
```
</details>

## НачатьОчистку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события Очистка поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма        - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ИмяРеквизита - Строка           - имя реквизита формы, связанного с представление контактной информации.
//
Процедура НачатьОчистку(Знач Форма, Знач ИмяРеквизита) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачатьОчистку(Форма, ИмяРеквизита) 
```
</details>

## НачатьВыполнениеКоманды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик команды, связанной с контактной информацией (написать письмо, открыть адрес, и т.п.).
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма      - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ИмяКоманды - Строка           - имя автоматически сгенерированной команды действия.
//
Процедура НачатьВыполнениеКоманды(Знач Форма, Знач ИмяКоманды) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачатьВыполнениеКоманды(Форма, ИмяКоманды) 
```
</details>

## НачатьОбработкуНавигационнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик навигационной ссылки для открытия веб-страницы.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//   Форма                - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//   Элемент              - ПолеФормы - элемент формы, содержащий представление контактной информации.
//   НавигационнаяСсылкаФорматированнойСтроки - Строка - значение гиперссылки форматированной строки. Параметр
//                                                       передается по ссылке.
//   СтандартнаяОбработка  - Булево - в данный параметр передается признак выполнения стандартной
//                                системной) обработки события. Если в теле процедуры-обработчика
//                                установить данному параметру значение Ложь, стандартная обработка события
//                                производиться не будет.
//
Процедура НачатьОбработкуНавигационнойСсылки(Форма, Элемент, НавигационнаяСсылкаФорматированнойСтроки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачатьОбработкуНавигационнойСсылки(Форма, Элемент, НавигационнаяСсылкаФорматированнойСтроки, СтандартнаяОбработка) 
```
</details>

## ОбработкаНавигационнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик навигационной ссылки для открытия веб-страницы.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//   Форма                - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//   Элемент              - ПолеФормы - элемент формы, содержащий представление контактной информации.
//   НавигационнаяСсылкаФорматированнойСтроки - Строка - значение гиперссылки форматированной строки. Параметр
//                                                       передается по ссылке.
//   СтандартнаяОбработка  - Булево - в данный параметр передается признак выполнения стандартной
//                                системной) обработки события. Если в теле процедуры-обработчика
//                                установить данному параметру значение Ложь, стандартная обработка события
//                                производиться не будет.
//
Процедура ОбработкаНавигационнойСсылки(Форма, Элемент, НавигационнаяСсылкаФорматированнойСтроки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ОбработкаНавигационнойСсылки(Форма, Элемент, НавигационнаяСсылкаФорматированнойСтроки, СтандартнаяОбработка) 
```
</details>

## АвтоПодборАдреса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события АвтоПодбор поля формы контактной информации для подбора вариантов адреса по введенной строке.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Элемент                  - ПолеФормы      - элемент формы, содержащий представление контактной информации.
//     Текст                    - Строка         - строка текста, введенная пользователем в поле контактной информации.
//     ДанныеВыбора             - СписокЗначений - содержит список значений, который будет использован при стандартной
//                                                 обработке события.
//     ПараметрыПолученияДанных - Структура
//                              - Неопределено - содержит параметры поиска, которые будут переданы
//                                в метод ПолучитьДанныеВыбора. Подробнее см. описание расширения поля формы для
//                                поля ввода АвтоПодбор в синтакс-помощнике.
//     Ожидание -   Число       - интервал в секундах после ввода текста, через который произошло событие.
//                                Если 0, то это означает, что событие было вызвано не по поводу ввода текста,
//                                а для формирования списка быстрого выбора.
//     СтандартнаяОбработка     - Булево         - в данный параметр передается признак выполнения стандартной
//                                системной) обработки события. Если в теле процедуры-обработчика
//                                установить данному параметру значение Ложь, стандартная обработка события
//                                производиться не будет.
//
Процедура АвтоПодборАдреса(Элемент, Текст, ДанныеВыбора, ПараметрыПолученияДанных, Ожидание, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.АвтоПодборАдреса(Элемент, Текст, ДанныеВыбора, ПараметрыПолученияДанных, Ожидание, СтандартнаяОбработка) 
```
</details>

## ОбработкаВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаВыбора поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма   - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ВыбранноеЗначение    - Строка        - выбранное значение, которое будет установлено как значение поля ввода
//                                            контактной информации.
//     ИмяРеквизита         - Строка        - имя реквизита формы, связанного с представление контактной информации.
//     СтандартнаяОбработка - Булево        - в данный параметр передается признак выполнения стандартной
//                                            (системной) обработки события. Если в теле процедуры-обработчика
//                                            установить данному параметру значение Ложь, стандартная обработка события
//                                            производиться не будет.
//
Процедура ОбработкаВыбора(Знач Форма, Знач ВыбранноеЗначение, Знач ИмяРеквизита, СтандартнаяОбработка = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ОбработкаВыбора(Форма, ВыбранноеЗначение, ИмяРеквизита, СтандартнаяОбработка);
```
</details>

## ОткрытьФормуВводаАдреса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открытие формы адреса формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма     - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Результат - Произвольный     - данные, переданные обработчиком команды.
//
Процедура ОткрытьФормуВводаАдреса(Форма, Результат) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуВводаАдреса(Форма, Результат) 
```
</details>

## КонтрольОбновленияФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик возможного обновления формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма     - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Результат - Произвольный     - данные, переданные обработчиком команды.
//
Процедура КонтрольОбновленияФормы(Форма, Результат) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.КонтрольОбновленияФормы(Форма, Результат) 
```
</details>

## СтранаМираОбработкаВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаВыбора страны мира.
// Реализует функционал автоматического заведения элемента справочника СтраныМира после выбора.
//
// Параметры:
//     Элемент              - ПолеФормы    - элемент, содержащий редактируемую страну мира.
//     ВыбранноеЗначение    - Произвольный - значение выбора.
//     СтандартнаяОбработка - Булево       - устанавливаемый флаг стандартной обработки события формы.
//
Процедура СтранаМираОбработкаВыбора(Элемент, ВыбранноеЗначение, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.СтранаМираОбработкаВыбора(Элемент, ВыбранноеЗначение, СтандартнаяОбработка) 
```
</details>

## ПараметрыФормыКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор для параметров открытия формы контактной информации в ОткрытьФормуКонтактнойИнформации.
// Состав полей может быть расширен в общем модуле РаботаСАдресамиКлиент свойствами с национальной спецификой.
//
// Параметры:
//  ВидКонтактнойИнформации  - СправочникСсылка.ВидыКонтактнойИнформации - вид редактируемой контактной информации.
//                           - см. УправлениеКонтактнойИнформацией.ПараметрыВидаКонтактнойИнформации
//  Значение                 - Строка - сериализованное значение полей контактной информации в формате JSON или XML.
//  Представление            - Строка - представление контактной информации.
//  Комментарий              - Строка - комментарий контактной информации.
//  ТипКонтактнойИнформации  - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации.
//                             Если указан, то в возвращаемую структуру добавляются поля соответствующие типу.
//
// Возвращаемое значение:
//  Структура:
//   * ВидКонтактнойИнформации - см. УправлениеКонтактнойИнформацией.ПараметрыВидаКонтактнойИнформации
//   * ТолькоПросмотр          - Булево - если Истина, то форма будет открыта в режиме только просмотра.
//   * Значение                - Строка - значение полей контактной информации в формате JSON или XML.
//   * Представление           - Строка - представление контактной информации.
//   * ТипКонтактнойИнформации - ПеречислениеСсылка.ТипыКонтактнойИнформации - тип контактной информации, если был указан
//                                                                            в параметрах.
//   * Страна                  - Строка - страна мира, только если указан тип контактной информации Адрес.
//   * Регион                  - Строка - значение поля региона, только если указан тип контактной информации Адрес.
//                                       Актуально для стран ЕАЭС.
//   * Индекс                  - Строка - почтовый индекс, только если указан тип контактной информации Адрес.
//   * ТипПомещения            - Строка - тип помещения в форме ввода нового адреса, , только если указан тип контактной
//                                       информации Адрес.
//   * КодСтраны               - Строка - телефонный код страны мира, только если указан тип контактной информации Телефон.
//   * КодГорода               - Строка - телефонный код города, только если указан тип контактной информации Телефон.
//   * НомерТелефона           - Строка - телефонный номер, только если указан тип контактной информации Телефон.
//   * Добавочный              - Строка - добавочный телефонный номер, только если указан тип контактной информации Телефон.
//   * Заголовок               - Строка - заголовок формы. По умолчанию, представление вида контактной информации.
//   * ТипАдреса               - Строка - варианты: Пустая строка (по умолчанию), "ВСвободнойФорме", "ЕАЭС";
//                                       Для РФ: "Муниципальный" или "АдминистративноТерриториальный".
//                                       Если не указан (пустая строка), то для существующего адреса будет установлен адрес
//                                       выбранный пользователем в форме ввода адреса, для нового адреса - Муниципальный".
//
Функция ПараметрыФормыКонтактнойИнформации(ВидКонтактнойИнформации, Значение, Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформациейКлиент.ПараметрыФормыКонтактнойИнформации(ВидКонтактнойИнформации, Значение, );
```
</details>

## ОткрытьФормуКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает соответствующую форму для просмотра и ввода контактной информации.
//
// Параметры:
//    Параметры    - см. ПараметрыФормыКонтактнойИнформации
//    Владелец     - Произвольный - параметр для открываемой формы.
//    Оповещение   - ОписаниеОповещения - для обработки закрытия формы.
//
//  Возвращаемое значение:
//   ФормаКлиентскогоПриложения
//
Функция ОткрытьФормуКонтактнойИнформации(Параметры, Владелец = Неопределено, Оповещение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуКонтактнойИнформации(Параметры, Владелец, Оповещение);
```
</details>

## СоздатьЭлектронноеПисьмо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает письмо по контактной информации.
//
// Параметры:
//  ЗначенияПолей   - Строка
//                  - Структура
//                  - Соответствие
//                  - СписокЗначений - значение контактной информации.
//  ПараметрыПисьма - см. ПараметрыПисьмаSMS
//  УдалитьОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                       - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                       - Структура - устарело, следует использовать ПараметрыПисьма.
//  УдалитьИсточникКонтактнойИнформации - ЛюбаяСсылка - устарело, следует использовать ПараметрыПисьма.
//  УдалитьИмяРеквизита  - Строка - устарело, следует использовать ПараметрыПисьма.
//
Процедура СоздатьЭлектронноеПисьмо(Знач ЗначенияПолей, Знач ПараметрыПисьма = Неопределено, Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.СоздатьЭлектронноеПисьмо(ЗначенияПолей, ПараметрыПисьма, );
```
</details>

## СоздатьSMS
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает сообщение SMS по контактной информации.
//
// Параметры:
//  ЗначенияПолей - Строка
//                - Структура
//                - Соответствие
//                - СписокЗначений - контактная информация.
//  ПараметрыSMS  - см. ПараметрыПисьмаSMS
//  УдалитьОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                       - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                       - Структура - устарело, следует использовать ПараметрыSMS.
//  УдалитьИсточникКонтактнойИнформации - ЛюбаяСсылка - устарело, следует использовать ПараметрыSMS.
//
Процедура СоздатьSMS(Знач ЗначенияПолей, Знач ПараметрыSMS = Неопределено, Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.СоздатьSMS(ЗначенияПолей, ПараметрыSMS, );
```
</details>

## ПараметрыПисьмаSMS
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор для параметров процедур СоздатьЭлектронноеПисьмо и СоздатьSMS.
//
// Возвращаемое значение:
//  Структура:
//    * Представление - Строка - представление контактной информации. Используется, если невозможно определить
//                                представление из параметра. ЗначенияПолей (отсутствие поля Представление).
//    * ОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                    - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                    - Структура - для определения типа, если его невозможно вычислить по ЗначенияПолей.
//    * ИсточникКонтактнойИнформации - ЛюбаяСсылка - объект-владелец контактной информации.
//    * ИмяРеквизита  - Строка - имя реквизита вызывающей формы, в которой нужно привязать сообщение об ошибке.
//                               Если не задано, то сообщение выводится в виде окна с предупреждением.
//
Функция ПараметрыПисьмаSMS() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформациейКлиент.ПараметрыПисьмаSMS() 
```
</details>

## ПозвонитьПоТелефону
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Совершает звонок на переданный номер телефона по SIP телефонии,
// а если она не доступна, то с использованием программы Skype.
//
// Параметры:
//  НомерТелефона -Строка - номер телефона, на который будет осуществлен звонок.
//
Процедура ПозвонитьПоТелефону(НомерТелефона) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ПозвонитьПоТелефону(НомерТелефона) 
```
</details>

## ПозвонитьНаSkype
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Совершает звонок в программе Skype.
//
// Параметры:
//  ЛогинSkype - Строка - логин Skype.
//
Процедура ПозвонитьНаSkype(ЛогинSkype) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ПозвонитьНаSkype(ЛогинSkype) 
```
</details>

## НачатьБеседуВSkype
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открыть окно беседы(чат) в программе Skype
//
// Параметры:
//  ЛогинSkype - Строка - логин Skype.
//
Процедура НачатьБеседуВSkype(ЛогинSkype) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачатьБеседуВSkype(ЛогинSkype) 
```
</details>

## ПерейтиПоВебСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает ссылку по контактной информации.
//
// Параметры:
//  ЗначенияПолей - Строка
//                - Структура
//                - Соответствие
//                - СписокЗначений - контактная информация.
//  Представление - Строка - представление. Используется, если невозможно определить представление из параметра.
//                            ЗначенияПолей (отсутствие поля "Представление").
//  ОжидаемыйВид  - СправочникСсылка.ВидыКонтактнойИнформации
//                - ПеречислениеСсылка.ТипыКонтактнойИнформации
//                - Структура -
//                      Используется для определения типа, если его невозможно вычислить по полю ЗначенияПолей.
//
Процедура ПерейтиПоВебСсылке(Знач ЗначенияПолей, Знач Представление = "", ОжидаемыйВид = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ПерейтиПоВебСсылке(ЗначенияПолей, Представление, ОжидаемыйВид);
```
</details>

## ПоказатьАдресНаКарте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает адрес в браузере с помощью интерактивных карт. Например на Google Maps.
//
// Параметры:
//  Адрес                       - Строка - текстовое представление адреса.
//  ИмяКартографическогоСервиса - Строка - имя картографического сервиса, в котором необходимо показать адрес.
//                                         Например, GoogleMaps.
//
Процедура ПоказатьАдресНаКарте(Адрес, ИмяКартографическогоСервиса) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ПоказатьАдресНаКарте(Адрес, ИмяКартографическогоСервиса) 
```
</details>

## ОткрытьФормуИсторииИзменений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает форму с историей изменения контактной информации.
//
// Параметры:
//  Форма                         - ФормаКлиентскогоПриложения - форма с контактной информацией.
//  ПараметрыКонтактнойИнформации - Структура - сведения об элементе контактной информации.
//  АсинхронныйВызов              - Булево - служебный параметр.
//
Процедура ОткрытьФормуИсторииИзменений(Форма, ПараметрыКонтактнойИнформации, АсинхронныйВызов = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ОткрытьФормуИсторииИзменений(Форма, ПараметрыКонтактнойИнформации, АсинхронныйВызов);
```
</details>

## НачалоВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Синхронные обработчики

// Обработчик события НачалоВыбора поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма                - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Элемент              - ПолеФормы        - элемент формы, содержащий представление контактной информации.
//     Модифицированность   - Булево           - устанавливаемый флаг модифицированности формы.
//     СтандартнаяОбработка - Булево           - устанавливаемый флаг стандартной обработки события формы.
//     ПараметрыОткрытия    - Структура        - параметры открытия формы ввода контактной информации.
//
Процедура НачалоВыбора(Форма, Элемент, Модифицированность = Истина, СтандартнаяОбработка = Ложь, ПараметрыОткрытия = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.НачалоВыбора(Форма, Элемент, Модифицированность, СтандартнаяОбработка, ПараметрыОткрытия);
```
</details>

## Очистка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события Очистка поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма        - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ИмяРеквизита - Строка           - имя реквизита формы, связанного с представление контактной информации.
//
Процедура Очистка(Знач Форма, Знач ИмяРеквизита) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.Очистка(Форма, ИмяРеквизита) 
```
</details>

## ВыполнитьКоманду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик команды, связанной с контактной информацией (написать письмо, открыть адрес, и т.п.).
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма      - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ИмяКоманды - Строка           - имя автоматически сгенерированной команды действия.
//
Процедура ВыполнитьКоманду(Знач Форма, Знач ИмяКоманды) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ВыполнитьКоманду(Форма, ИмяКоманды) 
```
</details>

## ПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПриИзменении поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Форма             - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Элемент           - ПолеФормы        - элемент формы, содержащий представление контактной информации.
//     ЭтоТабличнаяЧасть - Булево           - флаг того, что элемент является частью таблицы формы.
//
Процедура ПриИзменении(Форма, Элемент, ЭтоТабличнаяЧасть = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ПриИзменении(Форма, Элемент, ЭтоТабличнаяЧасть);
```
</details>

## АвтоПодбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать АвтоПодборАдреса.
// Обработчик события АвтоПодбор поля формы контактной информации.
// Вызывается из подключаемых действий при внедрении подсистемы "Контактная информация".
//
// Параметры:
//     Текст                - Строка         - строка текста, введенная пользователем в поле контактной информации.
//     ДанныеВыбора         - СписокЗначений - содержит список значений, который будет использован при стандартной
//                                             обработке события.
//     СтандартнаяОбработка - Булево         - в данный параметр передается признак выполнения стандартной
//                                             (системной) обработки события. Если в теле процедуры-обработчика
//                                             установить данному параметру значение Ложь, стандартная обработка события
//                                             производиться не будет.
//
Процедура АвтоПодбор(Знач Текст, ДанныеВыбора, СтандартнаяОбработка = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.АвтоПодбор(Текст, ДанныеВыбора, СтандартнаяОбработка);
```
</details>

## ПредставлениеПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ПриИзменении.
//
// Параметры:
//     Форма             - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Элемент           - ПолеФормы        - элемент формы, содержащий представление контактной информации.
//     ЭтоТабличнаяЧасть - Булево           - флаг того, что элемент является частью таблицы формы.
//
Процедура ПредставлениеПриИзменении(Форма, Элемент, ЭтоТабличнаяЧасть = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеКонтактнойИнформациейКлиент.ПредставлениеПриИзменении(Форма, Элемент, ЭтоТабличнаяЧасть);
```
</details>

## ПредставлениеНачалоВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать НачалоВыбора.
//
// Параметры:
//     Форма                - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     Элемент              - ПолеФормы        - элемент формы, содержащий представление контактной информации.
//     Модифицированность   - Булево           - устанавливаемый флаг модифицированности формы.
//     СтандартнаяОбработка - Булево           - устанавливаемый флаг стандартной обработки события формы.
//
// Возвращаемое значение:
//  Неопределено - не используется, обратная совместимость.
//
Функция ПредставлениеНачалоВыбора(Форма, Элемент, Модифицированность = Истина, СтандартнаяОбработка = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформациейКлиент.ПредставлениеНачалоВыбора(Форма, Элемент, Модифицированность, СтандартнаяОбработка);
```
</details>

## ПредставлениеОчистка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать Очистка.
//
// Параметры:
//     Форма        - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ИмяРеквизита - Строка           - имя реквизита формы, связанного с представление контактной информации.
//
// Возвращаемое значение:
//  Неопределено - не используется, обратная совместимость.
//
Функция ПредставлениеОчистка(Форма, ИмяРеквизита) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформациейКлиент.ПредставлениеОчистка(Форма, ИмяРеквизита) 
```
</details>

## ПодключаемаяКоманда
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ВыполнитьКоманду.
//
// Параметры:
//     Форма      - ФормаКлиентскогоПриложения - форма владельца контактной информации.
//     ИмяКоманды - Строка           - имя автоматически сгенерированной команды действия.
//
// Возвращаемое значение:
//  Неопределено - не используется, обратная совместимость.
//
Функция ПодключаемаяКоманда(Форма, ИмяКоманды) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеКонтактнойИнформациейКлиент.ПодключаемаяКоманда(Форма, ИмяКоманды) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
