---
title: Учет оригиналов первичных документов
slug: bsp/учет-оригиналов-первичных-документов
---


## ПриСозданииНаСервере_ФормаДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события "ПриСозданииНаСервере" формы документа.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения:
//   * Объект - ДанныеФормыСтруктура, ДокументОбъект - основной реквизит формы.
//  Расположение - ГруппаФормы - группа, в которой будет располагаться надпись о текущем состоянии оригинала.
//		           Если Неопределено, тогда надпись будет расположена в нижнем правом углу формы. Необязательный.
//
Процедура ПриСозданииНаСервере_ФормаДокумента(Форма, Расположение = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ПриСозданииНаСервере_ФормаДокумента(Форма, Расположение);
```
</details>

## ПриСозданииНаСервере_ФормаСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события "ПриСозданииНаСервере" формы списка.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма списка документа.
//  Список - ТаблицаФормы - основной список формы.
//  Расположение - ПолеФормы - колонка списка, перед которой будут располагаться новые колонки состояний.
//		                       Если Неопределено, тогда колонки будут расположены в конце списка. Необязательный.
//
Процедура ПриСозданииНаСервере_ФормаСписка(Форма, Список, Расположение = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ПриСозданииНаСервере_ФормаСписка(Форма, Список, Расположение);
```
</details>

## ПриПолученииДанныхНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события "ПриПолученииДанныхНаСервере" формы списка.
//
// Параметры:
//  СтрокиСписка - СтрокиДинамическогоСписка - строки списка документов.
//
Процедура ПриПолученииДанныхНаСервере(СтрокиСписка) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ПриПолученииДанныхНаСервере(СтрокиСписка) 
```
</details>

## УстановитьНовоеСостояниеОригинала
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается для записи новых или изменении текущих состояний оригиналов первичных документов.
//
// Параметры:
//  ОбъектыЗаписи - Массив из Структура - массив данных об изменяемом состоянии оригинала, в случае множественного
//										  изменения состояний документов:
//                 * ОбщееСостояние    - Булево - Истина, если текущее состояние является общим.
//                 * Ссылка 		   - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - документ,
//												  для которого необходимо изменить состояние оригинала.
//                 * СостояниеОригиналаПервичногоДокумента - СправочникСсылка.СостоянияОригиналовПервичныхДокументов -
//                                                           текущие состояние оригинала первичного документа.
//                 * ПервичныйДокумент - Строка - идентификатор первичного документа.
//                                                Задается, если данное состояние не является общим.
//                 * Извне 			   - Булево - Истина, если первичный документ был добавлен пользователем вручную.
//                                                Задается, если данное состояние не является общим.
//                - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - ссылка на документ, для которого
//												  необходимо изменить состояние оригинала, в случае единичного изменения.
//  СостояниеОригинала - СправочникСсылка.СостоянияОригиналовПервичныхДокументов - ссылка на устанавливаемое состояние.
//
// Возвращаемое значение:
//  Строка - "Изменено", если состояние оригинала документа не повторяется и было записано;
//           "НеИзменено";
//           "НеПроведено".
//
Функция УстановитьНовоеСостояниеОригинала(Знач ОбъектыЗаписи, Знач СостояниеОригинала) Экспорт
```

Пример вызова
```bsl
Результат = УчетОригиналовПервичныхДокументов.УстановитьНовоеСостояниеОригинала(ОбъектыЗаписи, СостояниеОригинала) 
```
</details>

## СведенияОСостоянииОригиналаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные о текущем общем состоянии оригинала документа по ссылке.
//
//	Параметры:
//  Документ - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - ссылка на документ, для которого необходимо
//																			получить сведения об общем состоянии.
//
//  Возвращаемое значение:
//    Структура:
//    * Ссылка - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - ссылка на документ.
//    * СостояниеОригиналаПервичногоДокумента - СправочникСсылка.СостоянияОригиналовПервичныхДокументов - текущее общее
//        состояние оригинала документа.
//
Функция СведенияОСостоянииОригиналаПоСсылке(Документ) Экспорт
```

Пример вызова
```bsl
Результат = УчетОригиналовПервичныхДокументов.СведенияОСостоянииОригиналаПоСсылке(Документ) 
```
</details>

## ЗаписатьСостоянияОригиналовПослеПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается для записи состояний оригиналов печатных форм в регистр, после печати формы.
//
//	Параметры:
//  ОбъектыПечати - СписокЗначений - список ссылок на объекты печати.
//  СписокПечати - СписокЗначений - список с именами макетов и представлениями печатных форм.
//  Записано - Булево - признак того, что состояние документа записано в регистр.
//
Процедура ЗаписатьСостоянияОригиналовПослеПечати(ОбъектыПечати, СписокПечати, Записано = Ложь) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ЗаписатьСостоянияОригиналовПослеПечати(ОбъектыПечати, СписокПечати, Записано);
```
</details>

## ОбновитьКомандыСостоянияОригинала
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет команды установки состояния оригинала на форме.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма списка документа.
//  Список - ТаблицаФормы - основной список формы. Если процедура вызывается для формы документа, то Неопределено.
//
Процедура ОбновитьКомандыСостоянияОригинала(Форма, Список = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ОбновитьКомандыСостоянияОригинала(Форма, Список);
```
</details>

## УстановитьУсловноеОформлениеВФормеСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает условное форматирование для подключаемых элементов в списке.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма списка документа.
//  Список - ТаблицаФормы - основной список формы.
//
Процедура УстановитьУсловноеОформлениеВФормеСписка(Форма, Список) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.УстановитьУсловноеОформлениеВФормеСписка(Форма, Список) 
```
</details>

## ДополнитьПрофильРольюДляИзмененияСостоянийОригиналовДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в описание профиля поставляемых групп доступа роль для изменения состояния оригинала.
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа
//
Процедура ДополнитьПрофильРольюДляИзмененияСостоянийОригиналовДокументов(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ДополнитьПрофильРольюДляИзмененияСостоянийОригиналовДокументов(ОписаниеПрофиля) 
```
</details>

## ДополнитьПрофильРольюДляНастройкиСостоянийОригиналовДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в описание профиля поставляемых групп доступа роль для настройки списка состояния оригинала.
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДополнитьПрофильРольюДляНастройкиСостоянийОригиналовДокументов(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ДополнитьПрофильРольюДляНастройкиСостоянийОригиналовДокументов(ОписаниеПрофиля) 
```
</details>

## ДополнитьПрофильРольюДляЧтенияСостоянийОригиналовДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в описание профиля поставляемых групп доступа роль для чтения состояния оригинала.
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДополнитьПрофильРольюДляЧтенияСостоянийОригиналовДокументов(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ДополнитьПрофильРольюДляЧтенияСостоянийОригиналовДокументов(ОписаниеПрофиля) 
```
</details>

## ВсеСостояния
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив всех состояний оригиналов первичных документов.
//
//	Возвращаемое значение:
//  Массив из СправочникСсылка.СостоянияОригиналовПервичныхДокументов - все возможные состояния оригинала, включая
//    скрытое "Оригиналы не все".
//
Функция ВсеСостояния() Экспорт
```

Пример вызова
```bsl
Результат = УчетОригиналовПервичныхДокументов.ВсеСостояния() 
```
</details>

## ВывестиНаФормуКомандыСостоянияОригинала
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит подключаемые команды в форме. Вызывается без подключения подсистемы "Подключаемые команды".
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма списка документа.
//  Список - ТаблицаФормы - основной список формы. Если процедура вызывается для формы документа, то Неопределено.
//  СостоянияОригиналов - ТаблицаЗначений - состояния оригинала, разрешенные пользователям, и используемые при смене
//                                          состояния оригинала:
//              * Наименование	- Строка - наименование состояния оригинала;
//              * Ссылка		- СправочникСсылка.СостоянияОригиналовПервичныхДокументов - ссылка на элемент справочника СостоянияОригиналовПервичныхДокументов.
//
Процедура ВывестиНаФормуКомандыСостоянияОригинала(Форма, Список, СостоянияОригиналов) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ВывестиНаФормуКомандыСостоянияОригинала(Форма, Список, СостоянияОригиналов) 
```
</details>

## ПредставлениеГиперссылкиСостояния
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление гиперссылки состояния оригинала документа по ссылке.
//
//	Параметры:
//   Документ - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - ссылка на документ, для которого необходимо
//																			 получить представление гиперссылки состояния.
//  Возвращаемое значение:
//   Строка - представление гиперссылки состояния оригинала документа.
//
Функция ПредставлениеГиперссылкиСостояния(Документ) Экспорт
```

Пример вызова
```bsl
Результат = УчетОригиналовПервичныхДокументов.ПредставлениеГиперссылкиСостояния(Документ) 
```
</details>

## ЗаписатьСостоянияОригиналовДокументаПослеПечатиФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает состояния оригиналов печатных форм. Вызывается после печати формы.
//
// Параметры:
//   ОбъектыПечати - СписокЗначений - список документов.
//   ПечатныеФормы - СписокЗначений - наименование макетов и представление печатных форм.
//   Записано - Булево - выходной параметр. Признак того, что состояние документа записано.
//
Процедура ЗаписатьСостоянияОригиналовДокументаПослеПечатиФормы(ОбъектыПечати, ПечатныеФормы, Записано = Ложь) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ЗаписатьСостоянияОригиналовДокументаПослеПечатиФормы(ОбъектыПечати, ПечатныеФормы, Записано);
```
</details>

## ЗаписатьСостояниеОригиналаДокументаПоПечатнымФормам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает состояние оригинала печатной формы. Вызывается после печати формы.
//
// Параметры:
//   Документ - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - документ.
//   ПечатнаяФорма - Строка - имя макета печатной формы.
//   Представление - Строка - наименование печатной формы.
//   Состояние - СправочникСсылка.СостоянияОригиналовПервичныхДокументов - состояние оригинала печатной формы.
//   Извне - Булево - признак, показывающий принадлежит ли форма системе 1С.
//   Сотрудник - СправочникСсылка - сотрудник, если в оригинале документа есть сведения о сотрудниках.
//
Процедура ЗаписатьСостояниеОригиналаДокументаПоПечатнымФормам(Документ, ПечатнаяФорма, Представление, Состояние, Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ЗаписатьСостояниеОригиналаДокументаПоПечатнымФормам(Документ, ПечатнаяФорма, Представление, Состояние, );
```
</details>

## ЗаписатьОбщееСостояниеОригиналаДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает общее состояния оригинала документа.
//
// Параметры:
//   Документ - ОпределяемыйТип.ОбъектСУчетомОригиналовПервичныхДокументов - документ.
//   Состояние - СправочникСсылка.СостоянияОригиналовПервичныхДокументов - состояние оригинала.
//
Процедура ЗаписатьОбщееСостояниеОригиналаДокумента(Документ, Состояние) Экспорт
```

Пример вызова
```bsl
УчетОригиналовПервичныхДокументов.ЗаписатьОбщееСостояниеОригиналаДокумента(Документ, Состояние) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
