---
title: Файлы БТС клиент
slug: bsp/файлы-бтс-клиент
---


## ПараметрыПолученияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для получения файла с сервера на клиент.
// Для использования в ФайлыБТСКлиент.ПолучитьФайлИнтерактивно.
//
// Возвращаемое значение:
//  Структура - Параметры получения файла:
//    * ИмяФайлаИлиАдрес - Строка - Адрес во временном хранилище, либо имя файла на сервере (без пути) для
//        получения клиентом. Если указан адрес во временном хранилище, то при попытке получения файлов
//        более 4Гб будет вызвано исключение.
//    * ПутьФайлаWindows - Строка - Путь к файлу при работе сеанса на Windows сервере. Значение игнорируется,
//        если в параметре ИмяФайлаИлиАдрес указан адрес во временном хранилище или указано имя зарегистрированного
//        файла временного хранилища.
//    * ПутьФайлаLinux - Строка - Путь к файлу при работе сеанса на Linux сервере. Значение игнорируется,
//        если в параметре ИмяФайлаИлиАдрес указан адрес во временном хранилище или указано имя зарегистрированного
//        файла временного хранилища.
//    * ОписаниеОповещенияОЗавершении - ОписаниеОповещения, Неопределено - Содержит описание процедуры, которая
//        будет вызвана после получения файла. Если указано Неопределено, никакой обработчик запускаться
//        не будет. Вызываемая процедура должна иметь параметры:
//           Результат - Структура, Неопределено - при отказе от получения файла, либо структура со свойствами:
//             ИмяФайлаИлиАдрес - Строка - Адрес во временном хранилище, либо имя файла на сервере (без пути)
//             ИмяФайлаНаКлиенте - Строка - полное имя клиентского файла, полученного клиентом
//           ДополнительныеПараметры - Произвольный - значение, которое было указано при создании
//            объекта ОписаниеОповещения.
//    * БлокируемаяФорма - ФормаКлиентскогоПриложения, Неопределено - Владелец формы получения файла для блокировки.
//        Если указано Неопределено, на время загрузки будет заблокирован весь интерфейс.
//    * ЗаголовокДиалогаСохранения - Строка, Неопределено - заголовок диалога выбора и формы загрузки файла.
//        Если указано Неопределено, заголовки будут сформированы автоматически.
//    * ЗаголовокОперацииПолучения - Строка, Неопределено - заголовок формы, отображающей длительную операцию.
//    * ФильтрДиалогаСохранения - Строка, Неопределено - фильтр диалога выбора файла для сохранения.
//        Если указано Неопределено, в диалоге можно будет выбрать любой файл.
//    * ИмяФайлаДиалогаСохранения - Строка - Имя клиентского файла, которое будет предложено в диалоге
//        выбора файла для сохранения.
//    * ПоказатьВопросОткрытьСохранить - Булево - признак того, что при получении файла необходимо
//        дополнительно задать вопрос, и при положительном ответе сразу открыть файл. Если указано Ложь,
//        вопрос задаваться не будет. Если в параметре ИмяФайлаИлиАдрес указан адрес во временном хранилище,
//        то значение параметра игнорируется, а поведение регулируется платформой.
Функция ПараметрыПолученияФайла() Экспорт
```

Пример вызова
```bsl
Результат = ФайлыБТСКлиент.ПараметрыПолученияФайла() 
```
</details>

## ПараметрыПомещенияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру параметров для помещения файла из файловой системы клиента на сервер.
// Для использования в ФайлыБТСКлиент.ПоместитьФайлИнтерактивно.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//    * ИмяФайлаИлиАдрес - Строка - Адрес во временном хранилище, либо имя файла на сервере (без пути)
//        для помещения. Если указан адрес во временном хранилище, то при попытке помещения файлов более 4Гб
//        будет вызвано исключение, а для помещения файла более 100Мб потребуется расширение для работы с файлами.
//        Если указан путь к файлу на сервере, то результат будет записан в файл, а для успешной работы в веб
//        так же потребуется установка расширения для работы с файлами.
//    * ПутьФайлаWindows - Строка - Путь к файлу при работе сеанса на Windows сервере. Значение игнорируется,
//        если в параметре ИмяФайлаИлиАдрес указан адрес во временном хранилище или указано имя зарегистрированного
//        файла временного хранилища.
//    * ПутьФайлаLinux - Строка - Путь к файлу при работе сеанса на Linux сервере. Значение игнорируется,
//        если в параметре ИмяФайлаИлиАдрес указан адрес во временном хранилище или указано имя зарегистрированного
//        файла временного хранилища.
//    * ОписаниеОповещенияОЗавершении - ОписаниеОповещения, Неопределено - Содержит описание процедуры, которая
//        будет вызвана после помещения файла. Если указано Неопределено, никакой обработчик запускаться не будет
//        Вызываемая процедура должна иметь параметры:
//           Результат - Структура, Неопределено - Неопределено при отказе, либо структура со свойствами:
//             ИмяФайлаИлиАдрес - Строка - Адрес во временном хранилище, либо имя файла на сервере (без пути)
//             ИмяФайлаНаКлиенте - Строка - полное имя клиентского файла, помещенного на сервер
//          ДополнительныеПараметры - Произвольный - значение, которое было указано при создании объекта
//            ОписаниеОповещения.
//    * БлокируемаяФорма - ФормаКлиентскогоПриложения, Неопределено - Владелец формы загрузки файла для блокировки.
//        Если указано Неопределено, на время загрузки будет заблокирован весь интерфейс.
//    * ЗаголовокДиалогаВыбора - Строка, Неопределено - заголовок диалога выбора файла.
//    * ЗаголовокОперацииПомещения - Строка, Неопределено - заголовок формы, отображающей длительную операцию загрузки.
//    * ФильтрДиалогаВыбора - Строка, Неопределено - фильтр диалога выбора файла. Если указано Неопределено, в диалоге
//        можно будет выбрать любой файл.
//    * ИмяФайлаДиалогаВыбора - Строка - Имя клиентского файла, которое будет предложено в диалоге выбора файла
//    * МаксимальныйРазмер - Число, Неопределено - максимальный размер клиентского файла, доступного к помещению
//      на сервер. Если указано Неопределено, размер клиентсколго файла контролироваться не будет.
Функция ПараметрыПомещенияФайла() Экспорт
```

Пример вызова
```bsl
Результат = ФайлыБТСКлиент.ПараметрыПомещенияФайла() 
```
</details>

## ПолучитьФайлИнтерактивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает размещенный во временном хранилище или на диске сервера файл, и сохраняет его на клиенте
// в локальной файловой системе пользователя.
//
// Параметры:
//   ПараметрыПолученияФайла - см. ПараметрыПолученияФайла
Процедура ПолучитьФайлИнтерактивно(ПараметрыПолученияФайла) Экспорт
```

Пример вызова
```bsl
ФайлыБТСКлиент.ПолучитьФайлИнтерактивно(ПараметрыПолученияФайла) 
```
</details>

## ПоместитьФайлИнтерактивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает выбранный на клиенте файл из локальной файловой системы пользователя во временное хранилище
// или в файл на диске сервера.
//
// Параметры:
//   ПараметрыПомещенияФайла - см. ПараметрыПомещенияФайла
Процедура ПоместитьФайлИнтерактивно(ПараметрыПомещенияФайла) Экспорт
```

Пример вызова
```bsl
ФайлыБТСКлиент.ПоместитьФайлИнтерактивно(ПараметрыПомещенияФайла) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
