---
title: Физические лица клиент сервер локализация
slug: bsp/физические-лица-клиент-сервер-локализация
---


## ПриОпределенииФамилииИнициалов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует краткое представление полного имени физического лица.
//
// Параметры:
//  ПолноеИмя - Строка - например, "Пупкин Василий Иванович";
//            - Структура:
//                        * Фамилия  - Строка
//                        * Имя      - Строка
//                        * Отчество - Строка
//  ФорматПолногоИмени - Строка - "Фамилия,Имя,Отчество" (по умолчанию) или "Имя,Отчество,Фамилия".
//  ИнициалыВНачале    - Булево - "Фамилия И. О.", если Ложь (по умолчанию),
//                                "И. О. Фамилия", если Истина
//  Результат - Строка - фамилия и инициалы. Например, "Пупкин В. И.".
//
Процедура ПриОпределенииФамилииИнициалов(Знач ПолноеИмя, Знач ФорматПолногоИмени, Знач ИнициалыВНачале, Результат) Экспорт
```

Пример вызова
```bsl
ФизическиеЛицаКлиентСерверЛокализация.ПриОпределенииФамилииИнициалов(ПолноеИмя, ФорматПолногоИмени, ИнициалыВНачале, Результат) 
```
</details>

## ПриОпределенииЧастейПолногоИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Раскладывает полное имя физического лица на составные части - фамилию, имя и отчество.
// Если в конце полного имени встречаются "оглы", "улы", "уулу", "кызы" или "гызы",
// то они также считаются частью отчества.
//
// Параметры:
//  ПолноеИмя - Строка - полное имя в виде "Фамилия Имя Отчество".
//  ФорматИмени - Строка - определяет порядок частей имени во входном параметре.
//                         "Фамилия,Имя,Отчество"" - фамилия в начале (по умолчанию),
//                         "Имя,Отчество,Фамилия" - фамилия в конце.
//  Результат - Структура:
//   * Фамилия  - Строка - фамилия;
//   * Имя      - Строка - имя;
//   * Отчество - Строка - отчество.
//
// Пример:
//   1. ФизическиеЛицаКлиентСервер.ЧастиИмени("Иванов Иван Иванович")
//   вернет структуру со значениями свойств: "Иванов", "Иван", "Иванович".
//   2. ФизическиеЛицаКлиентСервер.ЧастиИмени("Смит Джон")
//   вернет структуру со значениями свойств: "Смит", "Джон", "".
//   3. ФизическиеЛицаКлиентСервер.ЧастиИмени("Алиев Ахмед Октай оглы")
//   вернет структуру со значениями свойств: "Алиев", "Ахмед", "Октай оглы".
//
Процедура ПриОпределенииЧастейПолногоИмени(Знач ПолноеИмя, Знач ФорматИмени, Результат) Экспорт
```

Пример вызова
```bsl
ФизическиеЛицаКлиентСерверЛокализация.ПриОпределенииЧастейПолногоИмени(ПолноеИмя, ФорматИмени, Результат) 
```
</details>

## ФИОНаписаноВерно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, верно ли написано ФИО физического лица.
//
// Параметры:
//  ФИО - Строка - фамилия, имя и отчество.
//  ТолькоНациональныеСимволы - Булево - при проверке ФИО должна включать только символы национального алфавита.
//  РезультатПроверки - Булево - возвращаемое значение. Если Истина, то ФИО написано верно.
//
Процедура ФИОНаписаноВерно(Знач ФИО, Знач ТолькоНациональныеСимволы, РезультатПроверки) Экспорт
```

Пример вызова
```bsl
ФизическиеЛицаКлиентСерверЛокализация.ФИОНаписаноВерно(ФИО, ТолькоНациональныеСимволы, РезультатПроверки) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
