---
title: Электронная подпись клиент сервер
slug: bsp/электронная-подпись-клиент-сервер
---


## НовыеСвойстваПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметра СвойстваПодписи для добавления и обновления данных электронной подписи.
// Содержит развернутое описание подписи.
//
// Возвращаемое значение:
//   Структура:
//     * Подпись             - ДвоичныеДанные - результат подписания.
//                           - Строка - подписанный КонвертXML, если передавался в данных.
//     * УстановившийПодпись - СправочникСсылка.Пользователи - пользователь, который
//                           подписал объект информационной базы.
//     * Комментарий         - Строка - комментарий, если он был введен при подписании.
//     * ИмяФайлаПодписи     - Строка - если подпись добавлена из файла.
//     * ДатаПодписи         - Дата - дата, когда подпись была сделана. Имеет смысл для случаев,
//                           когда дату невозможно извлечь из данных подписи.
//     * ПропуститьПриПродлении - Булево - не подлежит усовершенствованию, например,
//                                достоверность обеспечивается оператором электронного документооборота.
//
//     Используются при обновлении результата проверки подписи:
//     * ДатаПроверкиПодписи - Дата - дата последней проверки подписи.
//     * ПодписьВерна        - Булево - результат последней проверки подписи.
//     * ТребуетсяПроверка   - Булево - не удалось проверить подпись.
//     * ПодписьМатематическиВерна - Булево - вычисляется при проверке подписи без дополнительных атрибутов.
//     * ОшибкаМатематическойПроверкиПодписи - Строка - ошибка при ПроверитьПодпись с флагом
//                                                      ПроверитьДополнительныеАтрибуты = Ложь
//     * ОшибкаПроверкиДополнительныхАтрибутов - Строка - ошибка при проверке сертификата и атрибутов
//                                                        усовершенствованной подписи, таких как метка времени.
//     * ДополнительныеАтрибутыПровереныВручную - Булево - признак ПодписьВерна в части доп. атрибутов установлен
//         вручную (в случае ПодписьМатематическиВерна = Ложь - Исключение при ручной установке)
//     * АвторРучнойПроверкиДополнительныхАтрибутов - СправочникСсылка.Пользователи
//     * ОбоснованиеРучнойПроверкиДополнительныхАтрибутов - Строка - ссылка на организацию, подтвердившую достоверность
//                                                                   подписи, например, Оператор ЭДО
//
//     Используются при обновлении усовершенствованной подписи:
//     * ПодписанныйОбъект   - ОпределяемыйТип.ПодписанныйОбъект - объект, с которым связана подпись.
//                             Игнорируется в методах, в которые объект передается как параметр.
//     * ПорядковыйНомер     - Число - идентификатор подписи, по которому можно упорядочивать их в списке.
//                             Не заполнен, если подпись не связана с объектом.
//     * ОшибкаПриАвтоматическомПродлении - Булево - не использовать, служебный, заполняется регламентным заданием.
//     Используются для связи с машиночитаемой доверенностью:
//     * ИдентификаторПодписи - УникальныйИдентификатор
//     * РезультатПроверкиПодписиПоМЧД - Массив из Структура, Структура - МашиночитаемыеДоверенностиФНС.РезультатПроверкиПодписиПоМЧД
//
//     Производные свойства подписи:
//     * ТипПодписи          - ПеречислениеСсылка.ТипыПодписиКриптографии
//     * СрокДействияПоследнейМеткиВремени - Дата - срок действия сертификата, которым подписана
//                                           последняя метка времени (или пустая дата, если нет метки времени),
//                                           если удалось определить с помощью МенеджерКриптографии
//     * Сертификат          - ХранилищеЗначения - содержит выгрузку сертификата,
//                             который использовался для подписания (содержится в подписи).
//                           - ДвоичныеДанные
//     * Отпечаток           - Строка - отпечаток сертификата в формате строки Base64.
//     * КомуВыданСертификат - Строка - представление субъекта, полученное из двоичных данных сертификата.
//     * ОписаниеСертификата - Структура - свойство, требуемое для сертификатов, которые
//                             не могут быть переданы в метод платформы СертификатКриптографии, со свойствами:
//        ** СерийныйНомер  - Строка - серийный номер сертификата, как у объекта платформы СертификатКриптографии.
//        ** КемВыдан       - Строка - как возвращает функция ПредставлениеИздателя.
//        ** КомуВыдан      - Строка - как возвращает функция ПредставлениеСубъекта.
//        ** ДатаНачала     - Строка - дата сертификата, как у объекта платформы СертификатКриптографии в формате "ДЛФ=D".
//        ** ДатаОкончания  - Строка - дата сертификата, как у объекта платформы СертификатКриптографии в формате "ДЛФ=D".
//        ** ДействителенДо - Строка - (необязательный) минимальная дата из дат окончания открытого и закрытого ключа
//                                     (если указана в сертификате) в формате "ДЛФ=D".
//
Функция НовыеСвойстваПодписи() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.НовыеСвойстваПодписи() 
```
</details>

## РезультатПроверкиПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Результат проверки подписи.
//
// Возвращаемое значение:
//  Структура:
//   * Результат - Булево     - Истина, если проверка выполнена успешно.
//             - Строка       - описание ошибки проверки подписи.
//             - Неопределено - не удалось получить менеджер криптографии (когда не указан).
//   * ПодписьВерна        - Булево, Неопределено - результат последней проверки подписи.
//   * СертификатОтозван   - Булево - ошибка связана с тем, что сертификат отозван.
//   * ТребуетсяПроверка   - Булево - не удалось проверить подпись.
//   * ПодписьМатематическиВерна - Булево - вычисляется при проверке подписи без проверки сертификатов
//                                           и атрибутов усовершенствованной подписи, таких как метка времени.
//   * ОшибкаМатематическойПроверкиПодписи - Строка - ошибка при ПроверитьПодпись с флагом
//                                                    ПроверитьДополнительныеАтрибуты = Ложь
//   * ОшибкаПроверкиДополнительныхАтрибутов - Строка - ошибка при проверке сертификата и атрибутов усовершенствованной
//                                                      подписи, таких как метка времени.
//   * ПараметрыПроверкиСертификата - см. ЭлектроннаяПодписьКлиент.ПараметрыПроверкиПодписи.ПроверятьСертификат
//
//   * ТипПодписи          - ПеречислениеСсылка.ТипыПодписиКриптографии - не заполнен при проверке подписей конверта XML.
//   * СрокДействияПоследнейМеткиВремени - Дата - срок действия сертификата, которым подписана
//    последняя метка времени (или пустая дата, если нет метки времени), если удалось определить с помощью МенеджерКриптографии.
//   * НеподтвержденнаяДатаПодписи - Дата - неподтвержденная дата подписи.
//                                 - Неопределено - неподтвержденная дата подписи отсутствует в данных подписи и для
//                                                конверта XML.
//   * ДатаПодписиИзМетки  - Дата - дата самой ранней метки времени.
//                         - Неопределено - метка времени отсутствует в данных подписи и при проверке конверта XML.
//   * Сертификат          - ДвоичныеДанные - сертификат подписанта
//   * Отпечаток           - Строка - отпечаток сертификата в формате строки Base64.
//   * КомуВыданСертификат - Строка - представление субъекта, полученное из двоичных данных сертификата.
//
Функция РезультатПроверкиПодписи() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.РезультатПроверкиПодписи() 
```
</details>

## РезультатПроверкиПодписиВФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор для заполнения результата проверки подписи в форме.
//
// Возвращаемое значение:
//  Структура - результат проверки подписи в форме:
//   * ПорядковыйНомер - см. НовыеСвойстваПодписи.ПорядковыйНомер
//   * Объект - см. НовыеСвойстваПодписи.ПодписанныйОбъект
//   * ДатаПодписи - см. НовыеСвойстваПодписи.ДатаПодписи
//   * Комментарий - см. НовыеСвойстваПодписи.Комментарий
//   * АдресПодписи - Строка - адрес подписи во временном хранилище.
//   * Отпечаток - см. НовыеСвойстваПодписи.Отпечаток
//   * АдресСертификата - Строка - адрес сертификата во временном хранилище.
//   * ПодписьВерна - см. НовыеСвойстваПодписи.ПодписьВерна
//   * ДатаПроверкиПодписи - см. НовыеСвойстваПодписи.ДатаПроверкиПодписи
//   * КомуВыданСертификат - см. НовыеСвойстваПодписи.КомуВыданСертификат
//   * ТребуетсяПроверка - см. НовыеСвойстваПодписи.ТребуетсяПроверка
//   * УстановившийПодпись - см. НовыеСвойстваПодписи.УстановившийПодпись
//   * ТипПодписи - см. НовыеСвойстваПодписи.ТипПодписи
//   * СрокДействияПоследнейМеткиВремени - см. НовыеСвойстваПодписи.СрокДействияПоследнейМеткиВремени
//   * МашиночитаемаяДоверенность - СправочникСсылка.МашиночитаемыеДоверенности
//   * МашиночитаемаяДоверенностьВерна - Булево
//   * РезультатПроверкиПодписиПоМЧД - см. НовыеСвойстваПодписи.РезультатПроверкиПодписиПоМЧД
//   * РезультатПроверки - Структура - свойства результата проверки подписи для хранения в базе:
//     ** ПодписьМатематическиВерна - Булево
//     ** ОшибкаМатематическойПроверкиПодписи - Строка - текст ошибки.
//     ** ОшибкаПроверкиДополнительныхАтрибутов - Строка - текст ошибки.
//     ** ДополнительныеАтрибутыПровереныВручную - Булево - признак ручной проверки подписи.
//     ** АвторРучнойПроверкиДополнительныхАтрибутов - СправочникСсылка.Пользователи
//     ** ОбоснованиеРучнойПроверкиДополнительныхАтрибутов - Строка
//   * РезультатПроверкиКраткий - Строка - для отображения результата проверки подписи в форме.
//
Функция РезультатПроверкиПодписиВФорме() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.РезультатПроверкиПодписиВФорме() 
```
</details>

## ЗаполнитьСтатусПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет для отображения в форме текст проверки подписи и помещает его в атрибут РезультатПроверкиКраткий .
//
// Параметры:
//  СвойстваПодписи - см. РезультатПроверкиПодписиВФорме
//  ДатаСеанса - Дата
//
Процедура ЗаполнитьСтатусПодписи(СвойстваПодписи, ДатаСеанса) Экспорт
```

Пример вызова
```bsl
ЭлектроннаяПодписьКлиентСервер.ЗаполнитьСтатусПодписи(СвойстваПодписи, ДатаСеанса) 
```
</details>

## ИмяФайлаПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует имя файла подписи по шаблону.
//
// Параметры:
//  ИмяБезРасширения			 - Строка - исходное имя файла без расширения. Например, ПодписанныйОбъект.Наименование.
//  КомуВыданСертификат			 - Строка - владелец сертификата (фамилия, имя, организация, должность).
//  РасширениеДляФайловПодписи	 - Строка - расширение для файлов подписи, добавляемое к имени файла.
//  ТребуетсяРазделитель		 - Булево - признак дополнительной установки разделителя в имени файла.
//
// Возвращаемое значение:
//  Строка
//
Функция ИмяФайлаПодписи(ИмяБезРасширения, КомуВыданСертификат, РасширениеДляФайловПодписи, ТребуетсяРазделитель = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.ИмяФайлаПодписи(ИмяБезРасширения, КомуВыданСертификат, РасширениеДляФайловПодписи, ТребуетсяРазделитель);
```
</details>

## ПредставлениеСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.ПредставлениеСертификата.
// См. ЭлектроннаяПодпись.ПредставлениеСертификата.
//
Функция ПредставлениеСертификата(Сертификат, Отчество = Ложь, СрокДействия = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.ПредставлениеСертификата(Сертификат, Отчество, СрокДействия);
```
</details>

## ПредставлениеСубъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.ПредставлениеСубъекта.
// См. ЭлектроннаяПодпись.ПредставлениеСубъекта.
//
Функция ПредставлениеСубъекта(Сертификат, Отчество = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.ПредставлениеСубъекта(Сертификат, Отчество);
```
</details>

## ПредставлениеИздателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.ПредставлениеИздателя.
// См. ЭлектроннаяПодпись.ПредставлениеИздателя.
//
Функция ПредставлениеИздателя(Сертификат) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.ПредставлениеИздателя(Сертификат) 
```
</details>

## ЗаполнитьСтруктуруСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.СвойстваСертификата.
// См. ЭлектроннаяПодпись.СвойстваСертификата.
//
Функция ЗаполнитьСтруктуруСертификата(Сертификат) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.ЗаполнитьСтруктуруСертификата(Сертификат) 
```
</details>

## СвойстваСубъектаСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.СвойстваСубъектаСертификата.
// См. ЭлектроннаяПодпись.СвойстваСубъектаСертификата.
//
Функция СвойстваСубъектаСертификата(Сертификат) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.СвойстваСубъектаСертификата(Сертификат) 
```
</details>

## СвойстваИздателяСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.СвойстваИздателяСертификата.
// См. ЭлектроннаяПодпись.СвойстваИздателяСертификата.
//
Функция СвойстваИздателяСертификата(Сертификат) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.СвойстваИздателяСертификата(Сертификат) 
```
</details>

## ПараметрыXMLDSig
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// См. ЭлектроннаяПодписьКлиент.ПараметрыXMLDSig.
// См. ЭлектроннаяПодпись.ПараметрыXMLDSig.
//
Функция ПараметрыXMLDSig() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектроннаяПодписьКлиентСервер.ПараметрыXMLDSig() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
