---
title: Банковские карты
slug: zup/банковские-карты
---


## РазрешенПросмотрПолногоНомераКарты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает установку права просмотра основного номера держателя карты
// для текущего пользователя на момент выполнения текущей строчки кода.
//
// Возвращаемое значение:
//  Булево - Истина, если есть право просмотра основного номера держателя карты.
//           Если в момент выполнения метода установлен привилегированный режим,
//           то всегда возвращается Истина
//
Функция РазрешенПросмотрПолногоНомераКарты() Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.РазрешенПросмотрПолногоНомераКарты() 
```
</details>

## МаскированныйНомерКарты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает маскированный номер карты (первые 6 и 4 последних цифры номера, остальное - *).
//
// Параметры:
//   Карта - СправочникСсылка.БанковскиеКартыКонтрагентов - карта, номер которой нужно получить
//
// Возвращаемое значение:
//  Строка - маскированный номер карты.
//
Функция МаскированныйНомерКарты(Знач Карта) Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.МаскированныйНомерКарты(Карта) 
```
</details>

## МаскированныеНомераКарт
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает маскированные номера карт (первые 6 и 4 последних цифры номера, остальное - *).
//
// Параметры:
//   Карты - Массив из СправочникСсылка.БанковскиеКартыКонтрагентов,
//           ФиксированныйМассив из СправочникСсылка.БанковскиеКартыКонтрагентов - карты, номера которых нужно получить.
//
// Возвращаемое значение:
//  Соответствие:
//      * Ключ     - СправочникСсылка.БанковскиеКартыКонтрагентов,
//      * Значение - Строка.
//
Функция МаскированныеНомераКарт(Знач Карты) Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.МаскированныеНомераКарт(Карты) 
```
</details>

## ПолныйНомерКарты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает полный номер карты (основной номер держателя карты).
//
// Параметры:
//   Карта - СправочникСсылка.БанковскиеКартыКонтрагентов - карта, номер которой нужно получить
//
// Возвращаемое значение:
//  Строка - полный номер карты.
//
Функция ПолныйНомерКарты(Знач Карта) Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.ПолныйНомерКарты(Карта) 
```
</details>

## ПолныеНомераКарт
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает полные номера карт (основные номера держателей карт).
//
// Параметры:
//   Карты - Массив из СправочникСсылка.БанковскиеКартыКонтрагентов,
//           ФиксированныйМассив из СправочникСсылка.БанковскиеКартыКонтрагентов - карты, номера которых нужно получить.
//
// Возвращаемое значение:
//  Соответствие:
//      * Ключ     - СправочникСсылка.БанковскиеКартыКонтрагентов,
//      * Значение - Строка.
//
Функция ПолныеНомераКарт(Знач Карты) Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.ПолныеНомераКарт(Карты) 
```
</details>

## ЭтоНациональныйПлатежныйИнструмент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает, что является ли карта национальным платежным инструментом (картой «Мир»).
// Если передана ссылка, то результат определяется значением свойства ЭтоНациональныйПлатежныйИнструмент элемента.
// Если указана строка, то результат вычисляется по БИН переданного номера карты.
//
// Параметры:
//   Карта - СправочникСсылка.БанковскиеКартыКонтрагентов - карта
//         - Строка - полный номер карты (основной номер держателя карты)
//
// Возвращаемое значение:
//  Булево - Истина, если карта является национальным платежным инструментом (картой «Мир»).
//
Функция ЭтоНациональныйПлатежныйИнструмент(Знач Карта) Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.ЭтоНациональныйПлатежныйИнструмент(Карта) 
```
</details>

## Добавить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в хранилище новую банковскую карту с указанным номером или реквизитами.
// Если у владельца уже есть карта с указанным номером, то обновляется существующий элемент справочника.
// Если действующая карта с указанным номером уже зарегистрирована на другого держателя, то возникнет исключение.
//
// Параметры:
//   ДержательКарты - Справочник.ФизическиеЛица - держатель карты.
//   Карта          - Строка    - полный номер карты (основной номер держателя карты)
//                  - Структура, ФиксированнаяСтруктура - основные реквизиты карты, может содержать свойства:
//                  	* ОсновнойНомерДержателяКарты     - Строка - Основной номер держателя карты;
//                  	* ИмяДержателяКарты               - Строка - Имя держателя карты (эмбоссированный текст);
//                  	* ДатаИстеченияСрокаДействияКарты - Дата   - Дата истечения срока действия карты
//   Свойства       - Структура, ФиксированнаяСтруктура - свойства карты, может содержать свойства:
//                  	* ЭтоНациональныйПлатежныйИнструмент - Булево;
//                  	* ЭтоМеждународнаяПлатежнаяКарта     - Булево;
//
// Возвращаемое значение:
//  СправочникСсылка.БанковскиеКартыКонтрагентов - созданная карта.
//
Функция Добавить(Знач ДержательКарты, Знач Карта, Знач Свойства = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = БанковскиеКарты.Добавить(ДержательКарты, Карта, Свойства);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
