---
title: Взаиморасчеты с сотрудниками
slug: zup/взаиморасчеты-с-сотрудниками
---


## ЗарегистрироватьНачисленнуюЗарплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует факт начисления зарплаты с целью учета взаиморасчетов.
//
// Параметры:
//		Движения          - КоллекцияДвижений - коллекция наборов записей движений расчетного документа.
//  	Отказ             - Булево            - признак отказа выполнения операции.
//		Организация       - СправочникСсылка.Организации - организация
//		ПериодРегистрации - Дата                         - первое число месяца периода регистрации.
//		ПорядокВыплаты    - ПеречисленияСсылка.ХарактерВыплатыЗарплаты - порядок выплаты.
//		Начисления        - ТаблицаЗначений - см. НоваяТаблицаНачисленнойЗарплаты().
//		Удержания         - ТаблицаЗначений - см. НоваяТаблицаНачисленнойЗарплаты().
//
Процедура ЗарегистрироватьНачисленнуюЗарплату(Движения, Отказ, Организация, ПериодРегистрации, ПорядокВыплаты, Начисления = Неопределено, Удержания = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьНачисленнуюЗарплату(Движения, Отказ, Организация, ПериодРегистрации, ПорядокВыплаты, Начисления, Удержания);
```
</details>

## ЗарегистрироватьНачисленныйАванс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует факт начисления авансов с целью учета взаиморасчетов.
//
// Параметры:
//		Движения          - КоллекцияДвижений - коллекция наборов записей движений расчетного документа.
//  	Отказ             - Булево            - признак отказа выполнения операции.
//		Организация       - СправочникСсылка.Организации
//		ПериодРегистрации - Дата            - первое число месяца периода регистрации.
//		Начисления        - ТаблицаЗначений - см. НоваяТаблицаНачисленнойЗарплаты().
//		Удержания         - ТаблицаЗначений - см. НоваяТаблицаНачисленнойЗарплаты().
//
Процедура ЗарегистрироватьНачисленныйАванс(Движения, Отказ, Организация, ПериодРегистрации, Начисления = Неопределено, Удержания = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьНачисленныйАванс(Движения, Отказ, Организация, ПериодРегистрации, Начисления, Удержания);
```
</details>

## ЗарегистрироватьНалогиПереданныеВНалоговыйОрган
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует факт передачи налогов в налоговый орган с целью учета взаиморасчетов.
//
// Параметры:
//		Движения          - КоллекцияДвижений - коллекция наборов записей движений расчетного документа.
//  	Отказ             - Булево            - признак отказа выполнения операции.
//		Организация       - СправочникСсылка.Организации
//		ПериодРегистрации - Дата               - первое число месяца периода регистрации.
//		Налоги             - ТаблицаЗначений   - см. НоваяТаблицаНалоговПередаваемыхВНалоговыйОрган.
//		ДокументОснование  - ДокументСсылка    - документ основание для РН "Зарплата к выплате" (ссылка может не входить в составной тип).
//
Процедура ЗарегистрироватьНалогиПереданныеВНалоговыйОрган(Движения, Отказ, Организация, ПериодРегистрации, Налоги, ДокументОснование = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьНалогиПереданныеВНалоговыйОрган(Движения, Отказ, Организация, ПериодРегистрации, Налоги, ДокументОснование);
```
</details>

## ЗарегистрироватьВыплаченнуюЗарплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует факт выплаты зарплаты с целью учета взаиморасчетов.
//
// Параметры:
//		Движения          - КоллекцияДвижений - коллекция наборов записей движений ведомости.
//		Отказ             - Булево - признак отказа в проведении.
//		Организация       - СправочникСсылка.Организации - организация.
//		ПериодРегистрации - Дата                         - первое число месяца периода регистрации.
//		Зарплата          - ТаблицаЗначений - см. НоваяТаблицаВыплаченнойЗарплаты
//		ПорядокВыплаты    - ПеречисленияСсылка.ХарактерВыплатыЗарплаты - порядок выплаты.
//
Процедура ЗарегистрироватьВыплаченнуюЗарплату(Движения, Отказ, Организация, ПериодРегистрации, Зарплата, Знач ПорядокВыплаты = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьВыплаченнуюЗарплату(Движения, Отказ, Организация, ПериодРегистрации, Зарплата, ПорядокВыплаты);
```
</details>

## ЗарегистрироватьНачальныеОстатки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует начальные остатки по взаиморасчетам с сотрудниками.
//
// Колонки СуммаПоБухучету и ВыплатыЗаПрошлыеПериоды не обязательны, при отсутствии будут добавлены автоматически.
// СуммаПоБухучету будет установлена равной значению поля Сумма, ВыплатыЗаПрошлыеПериоды будет присвоено равно нулю.
//
// Параметры:
// 	Движения          - КоллекцияДвижений - наборы записей движений документа ввода начальных остатков.
// 	Отказ             - Булево            - признак отказа в проведении.
// 	Организация       - СправочникСсылка.Организации
// 	ПериодРегистрации - Дата            - период регистрации (начало месяца).
// 	Остатки           - ТаблицаЗначений - см. НоваяТаблицаНачальныхОстатков
//
Процедура ЗарегистрироватьНачальныеОстатки(Движения, Отказ, Организация, ПериодРегистрации, Остатки) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьНачальныеОстатки(Движения, Отказ, Организация, ПериодРегистрации, Остатки) 
```
</details>

## НоваяТаблицаНачисленнойЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую пустую таблицу значений для данных о начисленной зарплате.
//
// Возвращаемое значение:
//		ТаблицаЗначений - таблица с колонками:
//			* Организация    - СправочникСсылка.Организации    - организация, которая начислила зарплату.
//			* Сотрудник      - СправочникСсылка.Сотрудники     - сотрудник, которому начислена зарплата.
//			* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - физическое лицо сотрудника.
//			* Подразделение  - СправочникСсылка.ПодразделенияОрганизаций - подразделение, в котором начислена зарплата.
//			* СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата - статья финансирования.
//			* СтатьяРасходов       - СправочникСсылка.СтатьиРасходовЗарплата       - статья расходов.
//			* ВидДоходаИсполнительногоПроизводства - ПеречислениеСсылка.ВидыДоходовИсполнительногоПроизводства.
//			* ПервичныйРегистратор - ОпределяемыйТип.ДокументОснованиеЗарплатыКВыплате - документ-основание.
//			* Сумма                     - Число - суммы начисленной зарплаты.
//			* СуммаКорректировкиВыплаты - Число - НДФЛ к возврату (отрицательный и ранее уже удержанный НДФЛ).
//
Функция НоваяТаблицаНачисленнойЗарплаты() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.НоваяТаблицаНачисленнойЗарплаты() 
```
</details>

## НоваяТаблицаНалоговПередаваемыхВНалоговыйОрган
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает новую таблицу значений для данных о налогах, переданных в налоговый орган.
//
// Возвращаемое значение:
//		ТаблицаЗначений - таблица значений с колонками:
//			* Сотрудник      - СправочникСсылка.Сотрудники     - сотрудник, которому начислена зарплата.
//			* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - физическое лицо сотрудника.
//			* Подразделение  - СправочникСсылка.ПодразделенияОрганизаций - подразделение, в котором начислена зарплата.
//			* СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата - статья финансирования.
//			* СтатьяРасходов       - СправочникСсылка.СтатьиРасходовЗарплата       - статья расходов.
//			* ВидДоходаИсполнительногоПроизводства - ПеречислениеСсылка.ВидыДоходовИсполнительногоПроизводства.
//			* Сумма                - Число - суммы начисленной зарплаты.
//
Функция НоваяТаблицаНалоговПередаваемыхВНалоговыйОрган() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.НоваяТаблицаНалоговПередаваемыхВНалоговыйОрган() 
```
</details>

## НоваяТаблицаНачальныхОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую пустую таблицу значений для начальных остатков.
//
// Возвращаемое значение:
//		ТаблицаЗначений - таблица с колонками:
//			* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - физическое лицо сотрудника.
//			* Сотрудник      - СправочникСсылка.Сотрудники     - сотрудник, которому начислена зарплата.
//			* Подразделение  - СправочникСсылка.ПодразделенияОрганизаций - подразделение, в котором начислена зарплата.
//			* СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата - статья финансирования.
//			* СтатьяРасходов       - СправочникСсылка.СтатьиРасходовЗарплата       - статья расходов.
//			* ВидДоходаИсполнительногоПроизводства - ПеречислениеСсылка.ВидыДоходовИсполнительногоПроизводства.
// 	        * ПериодВзаиморасчетов    - Дата  - начало месяца периода взаиморасчетов.
//			* Сумма                   - Число - суммы начисленной зарплаты.
// 	        * СуммаПоБухучету         - Число - сумма начального остатка бухгалтерских взаиморасчетов (приход).
// 	        * ВыплатыЗаПрошлыеПериоды - Число - сумма начального остатка бухгалтерских взаиморасчетов (расход).
//
Функция НоваяТаблицаНачальныхОстатков() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.НоваяТаблицаНачальныхОстатков() 
```
</details>

## НоваяТаблицаВыплаченнойЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую пустую таблицу значений для данных о выплаченной зарплате.
//
// Возвращаемое значение:
//		ТаблицаЗначений - таблица значений с колонками:
//			* Сотрудник      - СправочникСсылка.Сотрудники               - сотрудник, которому выплачена зарплата
//			* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица           - физическое лицо сотрудника
//			* Подразделение  - СправочникСсылка.ПодразделенияОрганизаций -  подразделение
//			* ПериодВзаиморасчетов - Дата - период, в котором выплачивается зарплата
//			* СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата - статья финансирования
//			* СтатьяРасходов       - СправочникСсылка.СтатьиРасходовЗарплата       - статья расходов
//			* ДокументОснование    - ОпределяемыйТип.ДокументОснованиеЗарплатыКВыплате - документ-основание
//			* Сумма                - Число - выплачиваемая сумма.
//
Функция НоваяТаблицаВыплаченнойЗарплаты() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.НоваяТаблицаВыплаченнойЗарплаты() 
```
</details>

## НоваяТаблицаВыплаченнойЗарплатыПоТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую таблицу значений для данных о выплаченной зарплате по переданной табличной части.
//
// Параметры:
//		ТабличнаяЧасть - ТабличнаяЧасть - данные о выплаченной зарплате.
//		ОписаниеСоответствияКолонок - Структура - см. НовоеОписаниеСоответствияКолонокДляТаблицыВыплаченнойЗарплаты.
//
// Возвращаемое значение:
//		ТаблицаЗначений - см. НоваяТаблицаВыплаченнойЗарплаты().
//
Функция НоваяТаблицаВыплаченнойЗарплатыПоТабличнойЧасти(ТабличнаяЧасть, ОписаниеСоответствияКолонок) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.НоваяТаблицаВыплаченнойЗарплатыПоТабличнойЧасти(ТабличнаяЧасть, ОписаниеСоответствияКолонок) 
```
</details>

## НовоеОписаниеСоответствияКолонокДляТаблицыВыплаченнойЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает описание соответствия колонок входной таблицы колонкам таблицы выплаченной зарплаты.
// Предназначена для использования в функциях- конструкторах таблицы выплаченной зарплаты.
// см. НоваяТаблицаВыплаченнойЗарплаты(), см. НоваяТаблицаВыплаченнойЗарплатыПоТабличнойЧасти().
//
// Возвращаемое значение:
//		Структура - Ключ содержит имя колонки таблицы выплаченной зарплаты, значение - имя колонки входной таблицы.
//
Функция НовоеОписаниеСоответствияКолонокДляТаблицыВыплаченнойЗарплаты() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.НовоеОписаниеСоответствияКолонокДляТаблицыВыплаченнойЗарплаты() 
```
</details>

## ЗаписатьДвижения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает движения подсистемы взаиморасчетов в базу данных.
//
// Параметры:
//		Движения - КоллекцияДвижений - Коллекция наборов записей.
//		Замещать - Булево            - Определяет режим замещения существующей записи.
//		                               Значение по умолчанию: Истина.
//
Процедура ЗаписатьДвижения(Движения, Замещать = Истина) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗаписатьДвижения(Движения, Замещать);
```
</details>

## ДанныеВедомостейДляОплатыДокументом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает информацию для оплаты платежным документом указанных ведомостей.
//	Удобна для использования в процедурах заполнения платежных документов.
//	Возвращаются суммы в разрезе ведомостей и физических лиц с учетом состояния оплаты
//  (все, оплаченные, только неоплаченные).
//	Оплаты, проведенные самим документом, не учитываются.
//
// Параметры:
//   Документ	 	- ДокументСсылка                                   - платежный документ
//   Ведомости		- Массив из ОпределяемыйТип.ВедомостьЗарплатаКадры - оплачиваемые ведомости
//   ФизическиеЛица - Массив из СправочникСсылка.ФизическиеЛица        - физические лица
//   Оплаченные     - Булево, Неопределено - статус оплаты:
//						Истина       - только оплаченные
//						Ложь         - не оплаченные
//						Неопределено - состояние оплаты не учитывается.
//
// Возвращаемое значение:
//   ТаблицаЗначений - таблица с колонками:
//      * Ведомость      - ОпределяемыйТип.ВедомостьЗарплатаКадры - ведомость.
//      * ФизическоеЛицо - СправочникСсылка.ФизическиеЛица        - физическое лицо.
//      * СуммаКВыплате                 - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - выплачиваемая зарплата.
//      * ВзысканнаяСумма               - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - сумма, взысканная по
//                                                                                       исполнительным листам.
//      * КомпенсацияЗаЗадержкуЗарплаты - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - компенсация за задержку зарплаты.
//
Функция ДанныеВедомостейДляОплатыДокументом(Документ, Ведомости, ФизическиеЛица = Неопределено, Оплаченные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.ДанныеВедомостейДляОплатыДокументом(Документ, Ведомости, ФизическиеЛица, Оплаченные);
```
</details>

## УпорядочитьДанныеВедомостейДляОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Упорядочивает информацию для оплаты по представлениям ведомостей и физических лиц
// Может использоваться при заполнении платежных документов для предсказуемого порядка следования строк
//
// Параметры:
//   ДанныеВедомостейДляОплаты - ТаблицаЗначений - см. ДанныеВедомостейДляОплатыДокументом
//
Процедура УпорядочитьДанныеВедомостейДляОплаты(ДанныеВедомостейДляОплаты) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.УпорядочитьДанныеВедомостейДляОплаты(ДанныеВедомостейДляОплаты) 
```
</details>

## ПроверкиОплатыВедомостейДокументом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей правила контроля данных об оплате.
//	Предназначения для создания параметра Проверки процедуры ПроверитьОплатуВедомостейДокументом.
//
// Возвращаемое значение:
//		Структура - содержит свойства:
//			* ВедомостьПроведена - Булево - проверять, что ведомость проведена.
//			* РаботникВВедомости - Булево - проверять наличие указанного работника в ведомости.
//			* ПовторнаяВыплата   - Булево - контроль повторной выплаты по строке ведомости.
//
Функция ПроверкиОплатыВедомостейДокументом() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.ПроверкиОплатыВедомостейДокументом() 
```
</details>

## ПроверитьОплатуВедомостейДокументом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет данные по оплате зарплаты.
// Удобна для использования при проведении.
// Контролируется:
//		проведенность ведомости
//		соответствие ведомости и работника (наличие такого в ведомости)
//		попытка повторной выплаты
// Объем проверок может настраиваться параметром Проверки.
//
// Параметры:
//	Документ         - ДокументОбъект, ДокументСсылка - платежный документ (его оплаты не учитываются).
//	Отказ            - Булево - признак наличия ошибок в проверяемых данных ведомостей.
//	ОплатаВедомостей - ТаблицаЗначений - таблица сведений об оплате с колонками:
//		* Ведомость      - ДокументСсылка
//		* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//	Проверки         - Структура - выполняемые проверки, см. ПроверкиОплатыВедомостейДокументом().
//
Процедура ПроверитьОплатуВедомостейДокументом(Документ, Отказ, ОплатаВедомостей, Проверки = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ПроверитьОплатуВедомостейДокументом(Документ, Отказ, ОплатаВедомостей, Проверки);
```
</details>

## ЗарегистрироватьОплатуВедомостейДокументом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует выдачу зарплаты работникам по ведомостям.
//
// Параметры:
//	Документ         - ДокументОбъект - платежный документ.
//	Отказ            - Булево - признак отказа в выполнении операции.
//	ОплатаВедомостей - ТаблицаЗначений - таблица сведений об оплате с колонками:
//		* Ведомость      - ДокументСсылка
//		* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//
Процедура ЗарегистрироватьОплатуВедомостейДокументом(Документ, Отказ, ОплатаВедомостей) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьОплатуВедомостейДокументом(Документ, Отказ, ОплатаВедомостей) 
```
</details>

## ЗарегистрироватьОплатуВедомостей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует выдачу зарплаты работникам по ведомостям.
//
// Параметры:
//   ПлатежныйДокумент - ДокументОбъект                                   - платежный документ.
//   Организация       - СправочникСсылка.Организации                     - организация документа.
//   Ведомости		   - Массив из ОпределяемыйТип.ВедомостьЗарплатаКадры - ведомости, по которым выдается зарплата
//   ФизическиеЛица    - Массив из СправочникСсылка.ФизическиеЛица        - физические лица, которым выдается зарплата
//   Оплаченные        - Булево, Неопределено - статус оплаты:
//                          Истина       - только оплаченные
//                          Ложь         - не оплаченные
//                          Неопределено - состояние оплаты не учитывается.
//   Отказ             - Булево - признак отказа в выполнении операции.
//
Процедура ЗарегистрироватьОплатуВедомостей(ПлатежныйДокумент, Организация, Ведомости, ФизическиеЛица = Неопределено, Оплаченные = Ложь, Отказ = Ложь) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьОплатуВедомостей(ПлатежныйДокумент, Организация, Ведомости, ФизическиеЛица, Оплаченные, Отказ);
```
</details>

## ЕстьОплатаПоВедомости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, есть ли выплаты по ведомости.
//
// Параметры:
// 	Ведомость - ДокументСсылка - ведомость, оплату которой нужно проверить.
//
// Возвращаемое значение:
// 	Булево - Истина, если по ведомости производилась оплата.
//
Функция ЕстьОплатаПоВедомости(Ведомость) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.ЕстьОплатаПоВедомости(Ведомость) 
```
</details>

## ТекстЗапросаДанныеДляОплатыБезналично
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса для безналичной оплаты
//
// Параметры:
//  ИмяТипа                      - Строка - полное имя объекта метаданных.
//  ИмяПараметраВедомости        - Строка - имя параметра, в котором будут переданы оплачиваемые ведомости.
//  ИмяПараметраФизическиеЛица   - Строка - имя параметра, в котором будут переданы физические лица.
//
// Возвращаемое значение:
//  Строка - текст запроса для оплаты безналично
//
Функция ТекстЗапросаДанныеДляОплатыБезналично( Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыССотрудниками.ТекстЗапросаДанныеДляОплатыБезналично();
```
</details>

## ЗарегистрироватьОплатуВедомостейВБухгалтерскихВзаиморасчетах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела: предпочтительно использовать ЗарплатаКадры.ЗарегистрироватьОплатуВедомостей.
// Регистрирует оплату ведомостей в бухгалтерских взаиморасчетах
//
// Параметры:
//  ПлатежныйДокумент	 - ДокументОбъект - платежный документ, регистрирующий оплату ведомостей.
//  Организация			 - СправочникСсылка.Организации - организация.
//  Ведомости			 - Массив - ведомости, оплату которых требуется зарегистрировать
//  ФизическиеЛица		 - Массив - физические лица, для которых требуется зарегистрировать оплату. Если не указан - для всех физических лиц.
//  ДатаОперации		 - Дата - дата платежа.
//  Отказ				 - Булево - признак отказа в проведении.
//
Процедура ЗарегистрироватьОплатуВедомостейВБухгалтерскихВзаиморасчетах(ПлатежныйДокумент, Организация, Ведомости, ФизическиеЛица, ДатаОперации, Отказ) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыССотрудниками.ЗарегистрироватьОплатуВедомостейВБухгалтерскихВзаиморасчетах(ПлатежныйДокумент, Организация, Ведомости, ФизическиеЛица, ДатаОперации, Отказ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
