---
title: Группы сотрудников
slug: zup/группы-сотрудников
---


## ГруппыСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений с колонками Сотрудник и Группа, содержащую
// сотрудников и группы в которые сотрудники относится.
//
// Параметры:
//		Сотрудники					- Массив, ссылок на элементы справочника сотрудники
//									- СправочникСсылка.Сотрудники
//		ОбрабатыватьГруппыПоиска	- Булево, позволяет исключить из обработки
//										группы поиска.
//
// Возвращаемое значение;
//		ТаблицаЗначений
//			* Сотрудник			- СправочникСсылка.Сотрудники
//			* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//			* Группа			- СправочникСсылка.ГруппыСотрудников
//
Функция ГруппыСотрудников(Сотрудники, ОбрабатыватьГруппыПоиска = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.ГруппыСотрудников(Сотрудники, ОбрабатыватьГруппыПоиска);
```
</details>

## ГруппыСотрудниковФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений с колонками Сотрудник, физическоеЛицо
//
// Параметры:
//		ФизическиеЛица				- Массив, ссылок на элементы справочника сотрудники
//									- СправочникСсылка.ФизическиеЛица
//		ОбрабатыватьГруппыПоиска	- Булево, позволяет исключить из обработки
//										группы поиска.
//
// Возвращаемое значение;
//		ТаблицаЗначений
//			* Сотрудник			- СправочникСсылка.Сотрудники
//			* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//			* Группа			- СправочникСсылка.ГруппыСотрудников
//
Функция ГруппыСотрудниковФизическихЛиц(ФизическиеЛица, ОбрабатыватьГруппыПоиска = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.ГруппыСотрудниковФизическихЛиц(ФизическиеЛица, ОбрабатыватьГруппыПоиска);
```
</details>

## СотрудникиГруппыПоискаПоНастройкам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сотрудников, соответствующих критериям поиска
//
// Параметры:
//		НастройкиЗаполнения - настройки СКД отчета по сотрудникам.
//		ГруппаПоиска		- СправочникСсылка.ГруппыСотрудников
//
//		ТаблицаЗначений
//			* Сотрудник			- СправочникСсылка.Сотрудники
//			* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//
Функция СотрудникиГруппыПоискаПоНастройкам(НастройкиЗаполнения, ГруппаПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.СотрудникиГруппыПоискаПоНастройкам(НастройкиЗаполнения, ГруппаПоиска) 
```
</details>

## СотрудникиГруппыПоиска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сотрудников группы поиска
//
// Параметры:
//		ГруппаПоиска - СправочникСсылка.ГруппыСотрудников
//
// Возвращаемое значение:
//		ТаблицаЗначений
//			* Сотрудник			- СправочникСсылка.Сотрудники
//			* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//		Неопределено, если настройки не заданы.
//
Функция СотрудникиГруппыПоиска(ГруппаПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.СотрудникиГруппыПоиска(ГруппаПоиска) 
```
</details>

## СоставГруппСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список сотрудников входящих в состав одной из групп, переданных в параметрах.
//
// Параметры:
//		ГруппыСотрудников					- Массив ссылок на группы сотрудников
//											- СправочникСсылка.ГруппыСотрудников
//		ДополнятьСоставомПодчиненныхГрупп	- Булево
//
// Возвращаемое значение:
//		ТаблицаЗначений
//			* Сотрудник			- СправочникСсылка.Сотрудники
//			* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//			* Группа			- СправочникСсылка.ГруппыСотрудников
//
Функция СоставГруппСотрудников(СписокГруппСотрудников, ДополнятьСоставомПодчиненныхГрупп = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.СоставГруппСотрудников(СписокГруппСотрудников, ДополнятьСоставомПодчиненныхГрупп);
```
</details>

## СоздатьВТГруппыСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает в менеджере временных таблиц временную таблицу содержащую поля Сотрудник, ФизическоеЛицо, Группа.
//
// Параметры:
//		МенеджерВременныхТаблиц		- МенеджерВременныхТаблиц
//		Сотрудники					- Массив сотрудников
//										СправочникСсылка.Сотрудники
//		ОбрабатыватьГруппыПоиска	- Булево
//		ИмяВТГруппыСотрудников		- Строка
//
// Возвращаемое значение:
//		РезультатЗапроса
//
Функция СоздатьВТГруппыСотрудников(МенеджерВременныхТаблиц, Сотрудники, ОбрабатыватьГруппыПоиска = Истина, ИмяВТГруппыСотрудников = "ВТГруппыСотрудников") Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.СоздатьВТГруппыСотрудников(МенеджерВременныхТаблиц, Сотрудники, ОбрабатыватьГруппыПоиска, ИмяВТГруппыСотрудников);
```
</details>

## СоздатьВТГруппыСотрудниковФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает в менеджере временных таблиц временную таблицу содержащую поля Сотрудник, ФизическоеЛицо, Группа.
//
// Параметры:
//		МенеджерВременныхТаблиц				- МенеджерВременныхТаблиц
//		ФизическиеЛица						- Массив сотрудников
//												СправочникСсылка.ФизическиеЛица
//		ОбрабатыватьГруппыПоиска			- Булево
//		ИмяВТГруппыСотрудниковФизическихЛиц	- Строка
//
// Возвращаемое значение:
//		РезультатЗапроса
//
Функция СоздатьВТГруппыСотрудниковФизическихЛиц(МенеджерВременныхТаблиц, ФизическиеЛица, ОбрабатыватьГруппыПоиска = Истина, ИмяВТГруппыСотрудниковФизическихЛиц = "ВТГруппыСотрудниковФизическихЛиц") Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.СоздатьВТГруппыСотрудниковФизическихЛиц(МенеджерВременныхТаблиц, ФизическиеЛица, ОбрабатыватьГруппыПоиска, ИмяВТГруппыСотрудниковФизическихЛиц);
```
</details>

## ТаблицаГруппСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТаблицаГруппСотрудников(СписокСотрудников, ПоСправочникуСотрудники, ОбрабатыватьГруппыПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.ТаблицаГруппСотрудников(СписокСотрудников, ПоСправочникуСотрудники, ОбрабатыватьГруппыПоиска));
```
</details>

## СотрудникиГруппСотрудниковВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СотрудникиГруппСотрудниковВФоне(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ГруппыСотрудников.СотрудникиГруппСотрудниковВФоне(Параметры, АдресХранилища) 
```
</details>

## ДинамическийСписокГруппСотрудниковПриПолученииДанныхНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДинамическийСписокГруппСотрудниковПриПолученииДанныхНаСервере(ИмяЭлемента, Настройки, Строки) Экспорт
```

Пример вызова
```bsl
ГруппыСотрудников.ДинамическийСписокГруппСотрудниковПриПолученииДанныхНаСервере(ИмяЭлемента, Настройки, Строки) 
```
</details>

## ВосстановлениеПараметровДинамическихГрупп
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВосстановлениеПараметровДинамическихГрупп(ПараметрыОбновления = Неопределено) Экспорт
```

Пример вызова
```bsl
ГруппыСотрудников.ВосстановлениеПараметровДинамическихГрупп(ПараметрыОбновления);
```
</details>

## ЗаменитьПараметрРекурсивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаменитьПараметрРекурсивно(ЭлементыОтбора) Экспорт
```

Пример вызова
```bsl
Результат = ГруппыСотрудников.ЗаменитьПараметрРекурсивно(ЭлементыОтбора));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
