---
title: Документооборот регистрация вфн с
slug: zup/документооборот-регистрация-вфн-с
---


## СервисРегистрацииФНСПодключение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует подключение к сервису регистрации
// Общая схема работы с сервисом:
// - получение временного токена см. СервисРегистрацииФНСПодключение
// - подписание данных токена с помощью СЭП
// - получение токена авторизации см. СервисРегистрацииФНСАвторизация
// - выполнение запросов к сервису регистрации с помощью токена полученного на предыдущем шаге
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* СрокДействия	- Дата - дата и время окончания действия полученного токена
//		* Токен			- Строка - токен авторизации в формате Base64
//
Функция СервисРегистрацииФНСПодключение() Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСПодключение() 
```
</details>

## СервисРегистрацииФНСАвторизация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает токен авторизации, требующийся для выполнения всех последующих операций
//
// Параметры:
//	Токен 				- Строка - строка с содержимым токена авторизации
//	Подпись 			- ДвоичныеДанные, Строка - сформированная ЭП в формате PKSC#7
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* СрокДействия	- Дата - дата и время окончания действия полученного токена
//		* Токен			- Строка - токен авторизации в формате Base64
//
Функция СервисРегистрацииФНСАвторизация(Токен, Подпись) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСАвторизация(Токен, Подпись) 
```
</details>

## СервисРегистрацииФНССписокЗаявок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает список ранее принятых заявлений в сервисе регистрации
//
// Параметры:
//	Токен 								- Строка - строка с содержимым токена авторизации в формате Base64
//	ИмяФайла 							- Строка - имя файла контейнера для фильтрации запроса
//	Период								- Строка - период для фильтрации запроса
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено						- Булево - Истина, если функция успешно выполнена
//		* Ошибка						- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Заявления						- Массив из Структур - каждая строка содержит поля
//			** ИдентификаторЗаявления	- Строка - идентификатор принятого заявления
//			** ИмяФайла					- Строка - имя файла транспортного контейнера
//			** ДатаПолучения			- Дата - дата получения заявления
//			** КодСостояния				- Строка - код состояния ответа
//			** Описание					- Строка - описание состояния ответа
//
Функция СервисРегистрацииФНССписокЗаявок(Токен, ИмяФайла = Неопределено, Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНССписокЗаявок(Токен, ИмяФайла, Период);
```
</details>

## СервисРегистрацииФНСОтправитьЗаявку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает содержимое файла транспортного контейнера отправленного заявления в сервис регистрации
// Требуется уточнение описания метода, т.к. наблюдаются противоречия в документации
//
// Параметры:
//	Токен 				- Строка - строка с содержимым токена авторизации в формате Base64
//	ИмяФайла 			- Строка - имя файла транспортного контейнера
//	ДанныеФайла			- ДвоичныеДанные - содержимое транспортного контейнера (ZIP)
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Идентификатор	- Строка - идентификатор, присвоенный заявлению сервисом регистрации в случае успешной проверки
//		* ДатаОтправки	- Дата - дата и время успешной отправки
//
Функция СервисРегистрацииФНСОтправитьЗаявку(Токен, ИмяФайла, ДанныеФайла) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСОтправитьЗаявку(Токен, ИмяФайла, ДанныеФайла) 
```
</details>

## СервисРегистрацииФНСПолучитьЗаявку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает содержимое файла транспортного контейнера отправленного заявления в сервис регистрации
//
// Параметры:
//	Токен 							- Строка - строка с содержимым токена авторизации в формате Base64
//	ИдентификаторЗаявления 			- Строка - идентификатор, присвоенный сервисом после получения заявления
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено					- Булево - Истина, если функция успешно выполнена
//		* Ошибка					- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Файл						- ДвоичныеДанные - содержимое транспортного контейнера (ZIP)
//
Функция СервисРегистрацииФНСПолучитьЗаявку(Токен, ИдентификаторЗаявления) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСПолучитьЗаявку(Токен, ИдентификаторЗаявления) 
```
</details>

## СервисРегистрацииФНСИнформацияОЗаявке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает состояние принятого сервисом регистрации заявления
//
// Параметры:
//	Токен 							- Строка - строка с содержимым токена авторизации в формате Base64
//	ИдентификаторЗаявления 			- Строка - идентификатор, присвоенный сервисом после получения заявления
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено					- Булево - Истина, если функция успешно выполнена
//		* Ошибка					- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* ИмяФайла					- Строка - имя файла транспортного контейнера отправленного заявления
//		* ДатаПолучения				- Дата - дата приема заявления сервисом регистрации
//		* ДатаПолученияНО			- Дата - дата приема заявления в налоговом органе
//		* КодНО						- Строка - код налогового органа, принявшее заявление в обработку
//		* НаименованиеНО			- Строка - наименование налогового органа, принявшее заявление в обработку
//		* КодСостояния				- Строка - код состояния ответа
//		* Описание					- Строка - описание состояния ответа
//		* СообщениеПроверки			- Строка - сообщение проверки
//		* НаименованиеОрганизации	- Строка - наименование регистрируемой организации
//		* Идентификатор				- Строка
//		* ИдентификаторЗаявления	- Строка - наименование регистрируемой организации
//		* СписокОтветов				- Массив - содержит структуры см. ПодготовитьРеестрОтветовНаЗаявления
//
Функция СервисРегистрацииФНСИнформацияОЗаявке(Токен, ИдентификаторЗаявления) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСИнформацияОЗаявке(Токен, ИдентификаторЗаявления) 
```
</details>

## СервисРегистрацииФНССписокОтветов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает список сформированных ответов сервисом регистрации на ранее отправленное заявление
//
// Параметры:
//	Токен 						- Строка - строка с содержимым токена авторизации в формате Base64
//	ИдентификаторЗаявления 		- Строка - идентификатор, присвоенный сервисом после получения заявления
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено				- Булево - Истина, если функция успешно выполнена
//		* Ошибка				- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Ответы				- Массив - каждая строка содержит структуру см. ПодготовитьРеестрОтветовНаЗаявления
//
Функция СервисРегистрацииФНССписокОтветов(Токен, ИдентификаторЗаявления) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНССписокОтветов(Токен, ИдентификаторЗаявления) 
```
</details>

## СервисРегистрацииФНСФайлОтвета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает файл транспортного контейнера (ZIP) c ответом сервиса регистрации на ранее отправленное заявление
//
// Параметры:
//	Токен 					- Строка - строка с содержимым токена авторизации в формате Base64
//	ИдентификаторЗаявления 	- Строка - идентификатор, присвоенный сервисом после получения заявления
//	ИдентификаторОтвета 	- Строка - идентификатор ответа, полученный с помощью функции СервисРегистрацииФНССписокОтветов
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено			- Булево - Истина, если функция успешно выполнена
//		* Ошибка			- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Файл				- ДвоичныеДанные - содержимое файла
//
Функция СервисРегистрацииФНСФайлОтвета(Токен, ИдентификаторЗаявления, ИдентификаторОтвета) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСФайлОтвета(Токен, ИдентификаторЗаявления, ИдентификаторОтвета) 
```
</details>

## СервисРегистрацииФНСПлатежныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает файл в PDF формате содержащий платежный документ
//
// Параметры:
//	Токен 					- Строка - строка с содержимым токена авторизации в формате Base64
//	ПлатежныйДокумент   	- Структура - содержит поля
//		* КодНО				- Строка - код налогового органа
//		* ОКАТО				- Строка - код ОКАТО
//		* КБК				- Строка - код КБК
//		* Сумма				- Число - сумма для оплаты
//		* ИННПлательщика	- Строка - ИНН физического лица плательщика
//		* Фамилия			- Строка - фамилия физического лица плательщика
//		* Имя				- Строка - имя физического лица плательщик
//		* Отчество			- Строка - отчество физического лица плательщика
//		* АдресПлательщика	- Строка - адрес физического лица плательщика
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено			- Булево - Истина, если функция успешно выполнена
//		* Ошибка			- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Файл				- ДвоичныеДанные - содержимое файла
//
Функция СервисРегистрацииФНСПлатежныйДокумент(Токен, ПлатежныйДокумент) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСПлатежныйДокумент(Токен, ПлатежныйДокумент) 
```
</details>

## СервисРегистрацииФНСОтправитьЗаявку_20
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает содержимое файла транспортного контейнера отправленного заявления в сервис регистрации
// Требуется уточнение описания метода, т.к. наблюдаются противоречия в документации
//
// Параметры:
//	ИмяФайла 			- Строка - имя файла транспортного контейнера
//	ДанныеФайла			- ДвоичныеДанные - содержимое транспортного контейнера (ZIP)
//	СвойстваЗаявления	- Структура - см. СвойстваЗаявленияРегистрацииЮЛ()
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Идентификатор	- Строка - идентификатор, присвоенный заявлению сервисом регистрации в случае успешной проверки
//		* ДатаОтправки	- Дата - дата и время успешной отправки
//
Функция СервисРегистрацииФНСОтправитьЗаявку_20(ИмяФайла, ДанныеФайла, СвойстваЗаявления) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСОтправитьЗаявку_20(ИмяФайла, ДанныеФайла, СвойстваЗаявления) 
```
</details>

## СервисРегистрацииФНСИнформацияОЗаявке_20
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает состояние принятого сервисом регистрации заявления
//
// Параметры:
//	ИдентификаторЗаявления 			- Строка - идентификатор, присвоенный сервисом после получения заявления
//	ИдентификаторПредмета			- Строка - уникальный идентификатор предмета отправки
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено					- Булево - Истина, если функция успешно выполнена
//		* Ошибка					- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* ИмяФайла					- Строка - имя файла транспортного контейнера отправленного заявления
//		* ДатаПолучения				- Дата - дата приема заявления сервисом регистрации
//		* ДатаПолученияНО			- Дата - дата приема заявления в налоговом органе
//		* КодНО						- Строка - код налогового органа, принявшее заявление в обработку
//		* НаименованиеНО			- Строка - наименование налогового органа, принявшее заявление в обработку
//		* КодСостояния				- Строка - код состояния ответа
//		* Описание					- Строка - описание состояния ответа
//		* СообщениеПроверки			- Строка - сообщение проверки
//		* НаименованиеОрганизации	- Строка - наименование регистрируемой организации
//		* Идентификатор				- Строка
//		* ИдентификаторЗаявления	- Строка
//		* СписокОтветов				- Массив - содержит структуры см. ПодготовитьРеестрОтветовНаЗаявления
//
Функция СервисРегистрацииФНСИнформацияОЗаявке_20(ИдентификаторЗаявления, ИдентификаторПредмета) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСИнформацияОЗаявке_20(ИдентификаторЗаявления, ИдентификаторПредмета) 
```
</details>

## СервисРегистрацииФНСФайлОтвета_20
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает файл транспортного контейнера (ZIP) c ответом сервиса регистрации на ранее отправленное заявление
//
// Параметры:
//	ИдентификаторЗаявления 	- Строка - идентификатор, присвоенный сервисом после получения заявления
//	ИдентификаторОтвета 	- Строка - идентификатор ответа, полученный с помощью функции СервисРегистрацииФНССписокОтветов
//	ИдентификаторПредмета	- Строка - уникальный идентификатор предмета отправки
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено			- Булево - Истина, если функция успешно выполнена
//		* Ошибка			- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Файл				- ДвоичныеДанные - содержимое файла
//
Функция СервисРегистрацииФНСФайлОтвета_20(ИдентификаторЗаявления, ИдентификаторОтвета, ИдентификаторПредмета) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСФайлОтвета_20(ИдентификаторЗаявления, ИдентификаторОтвета, ИдентификаторПредмета) 
```
</details>

## СервисРегистрацииФНСПолучитьКодПодтверждения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет код подтверждения на указанный предмет проверки - телефон или электронную почту
//
// Параметры:
//	ПараметрыОперации - Структура - см. ПараметрыОтправкиКодаПодтверждения
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Идентификатор	- Строка - идентификатор высланного кода, если задействован режим идентификатора, иначе поле "Код"
//		* Код			- Строка - высланный код
//		* СрокДействия	- Дата - срок окончания действия кода
//		* НомерОтправки - Число - порядковый номер отправки
//		* Попыток		- Число - остаток попыток для указанного идентификатора
//
Функция СервисРегистрацииФНСПолучитьКодПодтверждения(ПараметрыОперации) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСПолучитьКодПодтверждения(ПараметрыОперации) 
```
</details>

## СервисРегистрацииФНСПроверитьКодПодтверждения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет введенный код пользователем с ожидаемым по идентификатору отправки
//
// Параметры:
//	Идентификатор	- Строка - идентификатор отправки
//	КодПроверки		- Строка - проверяемый код
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Успешно		- Булево - статус проверки
//		* СрокДействия	- Дата - срок окончания действия кода
//		* Попыток		- Число - остаток попыток для указанного идентификатора
//
Функция СервисРегистрацииФНСПроверитьКодПодтверждения(Идентификатор, КодПроверки) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСПроверитьКодПодтверждения(Идентификатор, КодПроверки) 
```
</details>

## СервисРегистрацииФНСРаботоспособность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет доступность промежуточного сервиса приема заявлений для регистрации ЮЛ
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//
Функция СервисРегистрацииФНСРаботоспособность() Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СервисРегистрацииФНСРаботоспособность() 
```
</details>

## ПараметрыОтправкиКодаПодтверждения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список параметров, необходимых для отправки кодов подтверждения
//
// Возвращаемое значение:
//	Структура:
//		* Тип				- Строка - "Телефон" или "Почта"
//		* ПредметОтправки	- Строка - номер телефона или адрес электронной почты
//		* ПовторнаяОтправка	- Булево
//		* Идентификатор		- Строка - для режима повторной отправки
//		* ШаблонСообщения	- Строка
//		* НужнаПроверка		- Булево
//
Функция ПараметрыОтправкиКодаПодтверждения() Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ПараметрыОтправкиКодаПодтверждения() 
```
</details>

## СоздатьОтправкуРегистрацииЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправка пакета на сервер ФНС, регистрация факта отправки
//
// Параметры:
//	ПараметрыОтправки			- Структура - содержит поля для отправки заявления:
//		* Токен					- Строка
//		* ИмяФайлаТранспортногоКонтейнера - Строка - имя файла для отправляемого контейнера
//		* ДанныеФайла			- ДвоичныеДанные - содержимое транспортного контейнера
//		* ПредметОтправки		- ДокументСсылка.УведомлениеОСпецрежимахНалогообложения
//		* ОтпечатокСертификата	- Строка - отпечаток сертификата с помощью которого создавалась отправка
//		* КодНО					- Строка - необязательный, содержит код налогового органа
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено 			- Булево
//		* Ошибка				- Строка
//		* Отправка				- СправочникСсылка.ОтправкиРегистрацияЮЛ - присутствует, если Выполнено = Истина
//		* ИдентификаторЗаявления- Строка
//
Функция СоздатьОтправкуРегистрацииЮЛ(ПараметрыОтправки) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СоздатьОтправкуРегистрацииЮЛ(ПараметрыОтправки) 
```
</details>

## ОбновитьСтатусОтправкиРегистрацииЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие ответов по заявке, обрабатывает их и меняет статус в ИБ
//
// Параметры:
//	ПараметрыОтправки		- Структура - содержит поля:
//		* Токен 			- Строка - строка с содержимым токена авторизации в формате Base64
//		* ОтправкаСсылка	- СправочникСсылка - ссылка на объект отправки
//		* Принудительно		- Булево - обновляет все этапы
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено			- Булево - Истина, если функция успешно выполнена
//		* Ошибка			- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* Файлы				- Массив -
//
Функция ОбновитьСтатусОтправкиРегистрацииЮЛ(ПараметрыОтправки) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ОбновитьСтатусОтправкиРегистрацииЮЛ(ПараметрыОтправки) 
```
</details>

## ОбновитьОтправкуРегистрацииЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет данные справочника ОтправкиРегистрацияЮЛ, и статусы отправки при необходимости
//
// Параметры:
//	ОтправкаСсылка 		- СправочникСсылка.ОтправкиРегистрацияЮЛ
//	ИзменяемыеРеквизиты - Структура - содержит поля для обновления реквизитов справочника
//
// Возвращаемое значение:
//	Булево - Истина, когда успешно обновлен элемент справочника
//
Функция ОбновитьОтправкуРегистрацииЮЛ(ОтправкаСсылка, ИзменяемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ОбновитьОтправкуРегистрацииЮЛ(ОтправкаСсылка, ИзменяемыеРеквизиты) 
```
</details>

## ПроверитьСтатусЗакрытия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет статус закрытия объекта отправки при его записи
//
// Параметры:
//	ОбъектОтправки - СправочникОбъект.ОтправкиРегистрацияЮЛ
//
Процедура ПроверитьСтатусЗакрытия(ОбъектОтправки) Экспорт
```

Пример вызова
```bsl
ДокументооборотРегистрацияВФНС.ПроверитьСтатусЗакрытия(ОбъектОтправки) 
```
</details>

## ПрисоединитьФайлОтправкиРегистрацииЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Присоединяет файл к отправке регистрации ЮЛ
//
// Параметры:
//	СвойстваФайла			- Структура - содержит поля:
//		* ОтправкаСсылка	- СправочникСсылка.ОтправкиРегистрацияЮЛ
//		* АдресФайла		- Строка - адрес временного хранилища
//		* НазначениеФайла	- ПеречислениеСсылка.НазначенияФайловРегистрацииЮЛ
//		* Идентификатор		- Строка - идентификатор ответа
//		* КодОтвета			- Строка
//		* ИмяФайла			- Строка - имя исходного файла
//		* Описание			- Строка - описание содержимого файла
//		* ОписаниеСервиса	- Строка - описание состояния заявления
//		* ТипСодержимого	- ПеречислениеСсылка.ТипыСодержимогоФайлов
//
// Возвращаемое значение:
//	СправочникСсылка.ОтправкиРегистрацияЮЛПрисоединенныеФайлы
//
Функция ПрисоединитьФайлОтправкиРегистрацииЮЛ(СвойстваФайла) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ПрисоединитьФайлОтправкиРегистрацииЮЛ(СвойстваФайла) 
```
</details>

## СвойстваОтправкиРегистрацииЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует базовую информацию об отправке
//
// Параметры:
//	СсылкаПоиска 					- СправочникСсылка.ОтправкиРегистрацияЮЛ, ДокументСсылка - можно передать как саму отправку, так и предмет отправки
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* ОтпечатокСертификата 		- Строка - отпечаток сертификата который использовался при подключении к сервису
//		* ОтправкаСсылка			- СправочникСсылка.ОтправкиРегистрацияЮЛ
//		* ПредметОтправки			- ДокументСсылка
//		* ИдентификаторЗаявления	- Строка - присвоенный сервером идентификатор заявки при отправке
//		* ДатаОтправки				- Дата
//		* ОписаниеОтвета			- Строка - описание состояния заявки полученное при обновлении статусов
//		* КодОтвета					- Строка - код состояния заявки полученное при обновлении статусов
//		* СтатусОтправки			- ПеречислениеСсылка.СтатусыОтправки
//		* ВерсияОбмена				- Число
//
Функция СвойстваОтправкиРегистрацииЮЛ(СсылкаПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СвойстваОтправкиРегистрацииЮЛ(СсылкаПоиска) 
```
</details>

## СвойстваЗаявленияРегистрацииЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует базовую информацию об заявлении на регистрацию
//
// Параметры:
//	СсылкаПоиска 					- ДокументСсылка - можно передать как саму отправку, так и предмет отправки
//
// Возвращаемое значение:
//	Структура - содержит поля из СвойстваОтправкиРегистрацииЮЛ() и дополнительные поля
//		* ИНН - Строка
//		* ЭлектроннаяПочта - Строка
//		* Телефон - Строка
//		* КодНО - Строка
//		* СпособПредоставленияОтвета - ПеречислениеСсылка.СпособыПолученияОтветаНаЭлГосРегистрацию
//		* Организация - СправочникСсылка.Органзация
//		* ВидДокумента - ПеречислениеСсылка.ВидыУведомленийОСпецрежимахНалогообложения
//		* ИдентификаторПредмета - Строка
//
Функция СвойстваЗаявленияРегистрацииЮЛ(СсылкаПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СвойстваЗаявленияРегистрацииЮЛ(СсылкаПоиска) 
```
</details>

## ПоследняяОтправкаПоПредмету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Ищет последнюю отправку по указанному предмету отправки
//
// Параметры:
//	ПредметОтправки - ДокументСсылка
//
// Возвращаемое значение:
//	СправочникСсылка.ОтправкиРегистрацияЮЛ
//
Функция ПоследняяОтправкаПоПредмету(ПредметОтправки) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ПоследняяОтправкаПоПредмету(ПредметОтправки) 
```
</details>

## СформироватьЭтапыОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о текущем состоянии отправленного заявления
//
// Параметры:
//	ОтправкаСсылка 			- СправочникСсылка.ОтправкиРегистрацияЮЛ
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Отправлено 		- Структура - подробнее в ТекущееСостояниеЭтапа()
//		* ПринятВОбработку 	- Структура - подробнее в ТекущееСостояниеЭтапа()
//		* Рассмотрение		- Структура - подробнее в ТекущееСостояниеЭтапа()
//
Функция СформироватьЭтапыОтправки(ОтправкаСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СформироватьЭтапыОтправки(ОтправкаСсылка) 
```
</details>

## ТаблицаЭтаповОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу этапов для отображения в общих механизмах подсистемы
//
// Параметры:
//	ПредметОтправки 			- СправочникСсылка.ОтправкиРегистрацияЮЛ
//	ДополнительныеПараметры     - Структура - может содержать поле "Отправка"
//
// Возвращаемое значение:
//	ТаблицаЗначений
//
Функция ТаблицаЭтаповОтправки(ПредметОтправки, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ТаблицаЭтаповОтправки(ПредметОтправки, ДополнительныеПараметры) 
```
</details>

## ПредставлениеСтатусаОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает представление текущего статуса отправки
//
// Параметры:
//	ОтправкаСсылка - СправочникСсылка.ОтправкиРегистрацияЮЛ
//
// Возвращаемое значение:
//	Строка
//
Функция ПредставлениеСтатусаОтправки(ОтправкаСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ПредставлениеСтатусаОтправки(ОтправкаСсылка) 
```
</details>

## СтатусыЭтаповОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание всех статусов используемых в подсистеме
//
// Параметры:
//	ЗаявлениеНаИзменение - Булево - формирует с учетом вида заявления
//
// Возвращаемое значение:
//	Структура
//
Функция СтатусыЭтаповОтправки(ЗаявлениеНаИзменение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.СтатусыЭтаповОтправки(ЗаявлениеНаИзменение);
```
</details>

## ВидыФайловОбменаСКонтролирующимОрганом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание видов файлов необходимых для конфигураций потребителей
//
// Возвращаемое значение:
//	Структура
//
Функция ВидыФайловОбменаСКонтролирующимОрганом() Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ВидыФайловОбменаСКонтролирующимОрганом() 
```
</details>

## ПолучитьОтправкиПоОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реестр не завершенных отправок заявления в сервис регистрации ЮЛ ФНС.
// В формируемый список добавляются только элементы, которые не требуют авторизации
// и отправленные в течении 2 месяцев
//
// Параметры:
//	Организация - СправочникСсылка.Организация
//
// Возвращаемое значение:
//	Массив из СправочникСсылка.ОтправкиРегистрацияЮЛ
//
Функция ПолучитьОтправкиПоОрганизации(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ПолучитьОтправкиПоОрганизации(Организация) 
```
</details>

## ИспользуетОбмен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность отправки / обмена с сервисом для указанной организации
//
// Параметры:
//	ОрганизацияСсылка - СправочникСсылка.Организации
//
// Возвращаемое значение:
//	Булево
//
Функция ИспользуетОбмен(ОрганизацияСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ИспользуетОбмен(ОрганизацияСсылка) 
```
</details>

## ПодготовитьВыгрузкуФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формируется файловый архив на основе переданных данных и помещает его во временное хранилище
//
// Параметры:
//	ОписаниеПакета - Структура - где "Ключ" имя папки, "Значение" массив из СправочникСсылка.ОтправкиРегистрацияЮЛПрисоединенныеФайлы (или другие).
//								Если передан ключ "Корень", то файлы помещаются вне папок
//
// Возвращаемое значение:
//	Структура - содержит поля
//		* Выполнено		- Булево - Истина, если функция успешно выполнена
//		* Ошибка		- Строка - описание ошибки, в случае если Выполнено = Ложь
//		* АдресФайла 	- Строка - адрес во временном хранилище
//
Функция ПодготовитьВыгрузкуФайлов(ОписаниеПакета) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ПодготовитьВыгрузкуФайлов(ОписаниеПакета) 
```
</details>

## ОписаниеОбъектовПодсистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание основных объектов подсистемы.
//
// Возвращаемое значение:
//	Структура:
//		* ТипСправочникаОтправки - Тип
//
Функция ОписаниеОбъектовПодсистемы() Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотРегистрацияВФНС.ОписаниеОбъектовПодсистемы() 
```
</details>

## ЗаписьЖурналаРегистрацииДляОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует запись в журнале регистрации в рамках этой подсистемы
//
// Параметры:
//	ПодробныйТекстОшибки 	- Строка
//	ДанныеБазы 				- Неопределено
//							- СправочникСсылка.ОтправкиРегистрацияЮЛ
//
Процедура ЗаписьЖурналаРегистрацииДляОшибки(ПодробныйТекстОшибки, ДанныеБазы = Неопределено) Экспорт
```

Пример вызова
```bsl
ДокументооборотРегистрацияВФНС.ЗаписьЖурналаРегистрацииДляОшибки(ПодробныйТекстОшибки, ДанныеБазы);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
