---
title: Документооборот СКО облачная подпись вызов сервера
slug: zup/документооборот-ско-облачная-подпись-вызов-сервера
---


## СтатусПодготовкиСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет статус проверки легитимности сертификата для обмена с КО
// Предназначена для предварительной проверки сертификата, прежде чем получать подпись к сертификату
//
// Параметры:
//	Сертификат - ДвоичныеДанные, Строка, Структура
//	ДанныеСертификата - Неопределено - используется для возрата содержимого сертификата
//	ДанныеПодписи - Неопределено - используется для возрата содержимого подписи
//	ОтпечатокСертификата - Строка - используется для возрата отпечатка сертификата
//
// Возвращаемое значение:
//  - Булево - Истина, если сертификат допустим для дальнейшей работы
//  - Неопределено - если подсистема недоступна или проверка невозможна
//
Функция СтатусПодготовкиСертификата(Сертификат, ДанныеСертификата = Неопределено, ДанныеПодписи = Неопределено, ОтпечатокСертификата = "") Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСКООблачнаяПодписьВызовСервера.СтатусПодготовкиСертификата(Сертификат, ДанныеСертификата, ДанныеПодписи, ОтпечатокСертификата);
```
</details>

## ПодготовитьСертификат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет легитимность использования сертификата для обмена с КО
//
// Параметры:
//	ДанныеСертификата - ДвоичныеДанные - если передана структура, то она должна содержать поле "Отпечаток", служит
//					полем поиска в регистре сведений "ХранилищеСертификатовПолучателей"
//	ДанныеПодписи - Неопределено, ДвоичныеДанные - если Неопределено, то проверяется только издатель сертификата, иначе ожидается "голая" подпись
//
// Возвращаемое значение:
//  Булево - Истина, если использование сертификата легитимно
//
Функция ПодготовитьСертификат(ДанныеСертификата, ДанныеПодписи = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСКООблачнаяПодписьВызовСервера.ПодготовитьСертификат(ДанныеСертификата, ДанныеПодписи);
```
</details>

## ПодготовитьСертификатСПараметрами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обертка для функции  ПодготовитьСертификат
//
// Параметры:
//	ПараметрыОперации - Струтура - содержит следующие поля
//	 	* Сертификат - Строка, Структура, ДвоичныеДанные - если передана структура, то она должна содержать поле "Отпечаток", служит
//					полем поиска в регистре сведений "ХранилищеСертификатовПолучателей"
//		* Подпись - Неопределено, ДвоичныеДанные - если Неопределено, то проверяется только издатель сертификата, иначе ожидается "голая" подпись
//
// Возвращаемое значение:
//	Булево - Истина, если использование сертификата легитимно
//
Функция ПодготовитьСертификатСПараметрами(ПараметрыОперации, АдресРезультата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСКООблачнаяПодписьВызовСервера.ПодготовитьСертификатСПараметрами(ПараметрыОперации, АдресРезультата);
```
</details>

## ЗначениеХешГОСТ2012
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет расчет значения хеша с использованием алгоритма ГОСТ2012
//
// Параметры:
//	ТелоСодержимого - ДвоичныеДанные - содержимое для вычисления значения хеша
//	ДлинаЗначения - Число - ожидаемые значения 256, 512
//
// Возвращаемое значение:
//	Строка - HEX представление вычисленного значения, для варианта 256 бит содержит 64 символа, для 512 бит - 128 символов
//
Функция ЗначениеХешГОСТ2012(ТелоСодержимого, ДлинаЗначения = 512) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСКООблачнаяПодписьВызовСервера.ЗначениеХешГОСТ2012(ТелоСодержимого, ДлинаЗначения);
```
</details>

## ПроверитьПодписьГОСТ2012
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку подписи по стандарту ГОСТ2012
//
// Параметры:
//  ИсходныеДанные     - ДвоичныеДанные - исходный содержимое документа
//  ДанныеПодписи      - ДвоичныеДанные - содержимое подписи
//  СертификатПроверки - ДвоичныеДанные - содержит данные сертификата
//
// Возвращаемое значение:
//  Булево - Истина, если проверка пройдена
//
Функция ПроверитьПодписьГОСТ2012(ИсходныеДанные, ДанныеПодписи, СертификатПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСКООблачнаяПодписьВызовСервера.ПроверитьПодписьГОСТ2012(ИсходныеДанные, ДанныеПодписи, СертификатПроверки);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
