---
title: Займы сотрудникам
slug: zup/займы-сотрудникам
---


## ЗарегистрироватьПредоставлениеЗайма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод регистрирует во взаиморасчетах выдачу займа (или очередного транша) сотруднику.
// Может быть использован кассовыми документами
// для регистрации операции по займам сотрудникам.
//
// Параметры:
//	- Движения - коллекция движений документа.
//	- Договор - ссылка на договор займа (документ).
//	- Сумма - выданная сумма
//	- ДатаПредоставления - дата операции.
//	- Организация
//	- ФизическоеЛицо
//	- Отказ.
//
Процедура ЗарегистрироватьПредоставлениеЗайма(Движения, Договор, Сумма, ДатаПредоставления, Организация, ФизическоеЛицо, Отказ) Экспорт
```

Пример вызова
```bsl
ЗаймыСотрудникам.ЗарегистрироватьПредоставлениеЗайма(Движения, Договор, Сумма, ДатаПредоставления, Организация, ФизическоеЛицо, Отказ) 
```
</details>

## ЗарегистрироватьЧастичноПогашенныйЗаем
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод регистрирует во взаиморасчетах частичное погашение займа сотрудником.
//
// Параметры:
//	- Движения - коллекция движений документа.
//	- Договор - ссылка на договор займа (документ).
//	- СуммаЗайма - погашенная сумма.
//  - Проценты - сумма погашенных процентов.
//	- ДатаРегистрации - дата операции.
//	- Организация
//	- ФизическоеЛицо
//	- Отказ.
//
Процедура ЗарегистрироватьЧастичноПогашенныйЗаем(Движения, Договор, СуммаЗайма, Проценты, ДатаРегистрации, Организация, ФизическоеЛицо, Отказ) Экспорт
```

Пример вызова
```bsl
ЗаймыСотрудникам.ЗарегистрироватьЧастичноПогашенныйЗаем(Движения, Договор, СуммаЗайма, Проценты, ДатаРегистрации, Организация, ФизическоеЛицо, Отказ) 
```
</details>

## ЗарегистрироватьПогашениеЗайма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод регистрирует внеочередное погашение займа сотруднику.
// Внеочередные погашения отличаются от погашения из зарплаты тем,
// что они не уменьшают сумму ежемесячного платежа.
//
// Может быть использован кассовыми документами
// для регистрации операции по займам сотрудникам.
//
// Параметры:
//	- Движения - коллекция движений документа.
//	- Договор - ссылка на договор займа (документ).
//	- Сумма - внесенная сумма
//	- ДатаПогашения - дата операции.
//	- Организация
//	- ФизическоеЛицо
//	- Регистратор - ссылка на документ-владелец движений.
//	- Отказ.
//
Процедура ЗарегистрироватьПогашениеЗайма(Движения, Договор, Сумма, ДатаПогашения, Организация, ФизическоеЛицо, Регистратор, Отказ) Экспорт
```

Пример вызова
```bsl
ЗаймыСотрудникам.ЗарегистрироватьПогашениеЗайма(Движения, Договор, Сумма, ДатаПогашения, Организация, ФизическоеЛицо, Регистратор, Отказ) 
```
</details>

## ОстатокЗадолженности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет полный остаток задолженности по договору займа.
//
// Параметры:
//	- Договор - договор займа (ссылка на документ).
//	- ДатаАктуальности - дата, на которую определяется задолженность.
//	- Регистратор - необязательный, позволяет исключить движения отдельного регистратора.
//
//	Возвращаемое значение - структура с полями ОбщаяСумма, СуммаЗайма, Проценты, Валюта.
//
Функция ОстатокЗадолженности(Договор, ДатаАктуальности, Регистратор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаймыСотрудникам.ОстатокЗадолженности(Договор, ДатаАктуальности, Регистратор);
```
</details>

## ИнформацияОЗадолженности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует информационный текст, содержащий сведения о состоянии задолженности.
//
// Параметры:
//	- Договор - договор займа (ссылка на документ).
//	- ДатаДокумента - дата, на которую определяется задолженность.
//	- ДокументСсылка - необязательный, позволяет исключить движения отдельного регистратора.
//
//	Возвращаемое значение - строка.
//
Функция ИнформацияОЗадолженности(Договор, ДатаДокумента, ДокументСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ЗаймыСотрудникам.ИнформацияОЗадолженности(Договор, ДатаДокумента, ДокументСсылка) 
```
</details>

## ДействующиеДоговорыЗаймаПоФизическомуЛицу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает действующие договоры займа по физическому лица на указанную дату.
//
// Параметры:
//	- Организация
//	- ФизическоеЛицо
//	- ДатаАктуальности - необязательный, дата, на которую требуется получить действующие договоры.
//  - ВключатьНевыданныеДоговоры - необязательный, указывает на необходимость включить в выборку договора, по которым
//                                 не выдано ни одного транша.
//
Функция ДействующиеДоговорыЗаймаПоФизическомуЛицу(Организация, ФизическоеЛицо, ДатаАктуальности = Неопределено, ВключатьНевыданныеДоговоры = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗаймыСотрудникам.ДействующиеДоговорыЗаймаПоФизическомуЛицу(Организация, ФизическоеЛицо, ДатаАктуальности, ВключатьНевыданныеДоговоры);
```
</details>

## ИзмененияУсловийЗаймаЗаМесяц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет изменения условий договора займа за месяц
//
// Параметры:
//	- Договор			- договор займа (ссылка на документ).
//	- Регистратор		- изменение договора займа (ссылка на документ), убирает движения регистратора.
//	- ДатаАктуальности	- необязательный, дата до которой определяются изменения условий за месяц.
//
//	Возвращаемое значение - массив соответствий с полями ДатаИзменений, ПроцентнаяСтавка,
//							РазмерПлатежа, РазмерПогашения, КоличествоДней.
//
Функция ИзмененияУсловийЗаймаЗаМесяц(Договор, Регистратор, ДатаАктуальности = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаймыСотрудникам.ИзмененияУсловийЗаймаЗаМесяц(Договор, Регистратор, ДатаАктуальности);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
