---
title: Зарплата кадры переопределяемый
slug: zup/зарплата-кадры-переопределяемый
---


## ПолучитьЗначенияПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает "заказанные" значения по умолчанию.
// Параметры:
//		ПолучаемыеЗначения - структура элементы которой имеют
//			имена, идентифицирующие получаемые значения.
//			Могут быть переданы имена значений:
//				Организация - организация по умолчанию.
//				Руководитель - руководитель организации.
//				ГлавныйБухгалтер - главбух организации.
//				ДолжностьРуководителя - должность руководителя организации.
//				Подразделение - подразделение по умолчанию.
//
//		ДатаЗначений - Дата, на которую получаются значения по умолчанию.
//
// В процедуре значения элементов структуры ПолучаемыеЗначения должны быть заполнены
// значениями, если это возможно. Если невозможно, то остается то значение, которое
// было передано в структуре.
Процедура ПолучитьЗначенияПоУмолчанию(ПолучаемыеЗначения, ДатаЗначений) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.ПолучитьЗначенияПоУмолчанию(ПолучаемыеЗначения, ДатаЗначений) 
```
</details>

## ОрганизацияНаУпрощеннойСистемеНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что организация применяет УСН.
//
// Параметры:
//			Организация
//
// Возвращаемое значение:
//			Булево - Истина, если применяется упрощенная система налогообложения.
//
Функция ОрганизацияНаУпрощеннойСистемеНалогообложения(Организация, Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПереопределяемый.ОрганизацияНаУпрощеннойСистемеНалогообложения(Организация, Период);
```
</details>

## ЗаполнитьРеквизитОрганизацияПриОднофирменномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для заполнения в документах реквизита Организация единственной организацией при однофирменном учете.
//
Процедура ЗаполнитьРеквизитОрганизацияПриОднофирменномУчете(Источник, СтандартнаяОбработка, ИмяРеквизитаОрганизация) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.ЗаполнитьРеквизитОрганизацияПриОднофирменномУчете(Источник, СтандартнаяОбработка, ИмяРеквизитаОрганизация) 
```
</details>

## УстановитьДоступностьИзмененияЭтоОбособленноеПодразделениеВФормеПодразделения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет запретить изменение признака «Это обособленное подразделение» в форме подразделения.
//
// Параметры:
// 	ДоступностьИзменения - булево, если в теле процедуры установить значение Ложь,
// 		установка признака станет недоступна в форме подразделения.
//
Процедура УстановитьДоступностьИзмененияЭтоОбособленноеПодразделениеВФормеПодразделения(ДоступностьИзменения) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.УстановитьДоступностьИзмененияЭтоОбособленноеПодразделениеВФормеПодразделения(ДоступностьИзменения) 
```
</details>

## ДополнитьСоответствиеАдресовОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет коллекцию соответствий видов контактной информации с типом Адрес, в
// зависимости от типа объекта, содержащего контактную информацию.
//
// Параметры:
//		СоответствиеАдресовОрганизаций	- Соответствие
//			* Ключ 		- Тип, тип владельца контактной информации.
//			* Значение	- Соответствие.
//				* Ключ		- СправочникСсылка.ВидыКонтактнойИнформации
//				* Значение	- СправочникСсылка.ВидыКонтактнойИнформации
//						(значение выбирается из видов контактной информации организаций:
//							ФактАдресОрганизации или ЮрАдресОрганизации).
// Пример:
//		СоответствиеВидов = Новый Соответствие;
//		СоответствиеВидов.Вставить(Справочники.ВидыКонтактнойИнформации.АдресМестаПроживанияФизическиеЛица, Справочники.ВидыКонтактнойИнформации.ФактАдресОрганизации);
//		СоответствиеВидов.Вставить(Справочники.ВидыКонтактнойИнформации.АдресПоПропискеФизическиеЛица, Справочники.ВидыКонтактнойИнформации.ЮрАдресОрганизации);
//		СоответствиеАдресовОрганизаций.Вставить(Тип("СправочникСсылка.ФизическиеЛица"), СоответствиеВидов);
//
Процедура ДополнитьСоответствиеАдресовОрганизаций(СоответствиеАдресовОрганизаций) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.ДополнитьСоответствиеАдресовОрганизаций(СоответствиеАдресовОрганизаций) 
```
</details>

## ОпределитьТипыВладельцевАдресовОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет коллекции ссылок на объекты содержащие контактную информацию организаций.
// При переопределении объектов, переопределяемые объекты:
//		1. должны быть исключены из коллекции с типом справочника Организации
//		2. поделены на коллекции (соответствия) где ключ - ссылка на объект с контактной информацией,
//			а значение СправочникСсылка.Организация
//		3. полученные коллекции должны быть добавлены в КоллекцияПоТипам с ключом
//			соответствующим типу содержащихся в коллекции объектов.
//
// Параметры:
//		КоллекцияПоТипам - Соответствие - содержит единственный элемент КлючИЗначение
//			с ключем тип СправочникСсылка.Организации и значением - массив ссылок
//			на организации.
//
//
Процедура ОпределитьТипыВладельцевАдресовОрганизаций(КоллекцияПоТипам) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.ОпределитьТипыВладельцевАдресовОрганизаций(КоллекцияПоТипам) 
```
</details>

## УстановитьОсновнойРежимВыполненияОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет основной режим выполнения обработчиков Зарплатно-кадровой библиотеки.
// По умолчанию основной режим обработчиков Зарплатно-кадровой библиотеки - "Монопольно".
//
// Параметры:
//	РежимОбновления - строка, см. описание ОбновлениеИнформационнойБазы.НоваяТаблицаОбработчиковОбновления.
//					Значения, допустимые для установки параметру: "Монопольно", "Отложенно".
//
//
Процедура УстановитьОсновнойРежимВыполненияОбновления(РежимОбновления) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.УстановитьОсновнойРежимВыполненияОбновления(РежимОбновления) 
```
</details>

## ПриОпределенииИмениКлиентскогоПриложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет имя клиентского приложения, используемое в запросах к веб-сервисам.
// Подробнее см. ЗарплатаКадры.ИмяКлиентскогоПриложения.
//
// Параметры:
//	ИмяПриложения - Строка - имя клиентского приложения, User-Agent,
//	СтандартнаяОбработка - Булево - признак формирования имени по умолчанию.
//
Процедура ПриОпределенииИмениКлиентскогоПриложения(ИмяПриложения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.ПриОпределенииИмениКлиентскогоПриложения(ИмяПриложения, СтандартнаяОбработка) 
```
</details>

## ВидыОперацийПоЗарплатеОбработкаПолученияДанныхВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаПолученияДанныхВыбора перечисления ВидыОперацийПоЗарплате.
// Используется для переопределения стандартной обработки.
//
// Параметры:
// 	ДанныеВыбора - СписокЗначений - в список помещаются сформированные данные выбора.
// 	Параметры - Структура - содержит параметры выбора.
// 	СтандартнаяОбработка - Булево - в данный параметр передается признак выполнения стандартной.
// 					Если в теле процедуры-обработчика установить параметру СтандартнаяОбработка значение Ложь,
// 					стандартная обработка события производиться не будет.
//
Процедура ВидыОперацийПоЗарплатеОбработкаПолученияДанныхВыбора(ДанныеВыбора, Параметры, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПереопределяемый.ВидыОперацийПоЗарплатеОбработкаПолученияДанныхВыбора(ДанныеВыбора, Параметры, СтандартнаяОбработка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
