---
title: Зарплата кадры периодические регистры
slug: zup/зарплата-кадры-периодические-регистры
---


## ТаблицаВТИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу записей регистра.
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистра.
//
// Возвращаемое значение:
//		ТаблицаЗначений
//
Функция ТаблицаВТИмяРегистра(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ТаблицаВТИмяРегистра(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения);
```
</details>

## ТаблицаВТИмяРегистраСрезПоследних
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу среза последних регистра.
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез.
//
// Возвращаемое значение:
//		ТаблицаЗначений
//
Функция ТаблицаВТИмяРегистраСрезПоследних(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ТаблицаВТИмяРегистраСрезПоследних(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения);
```
</details>

## СоздатьВТИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу записей регистра в менеджере временных таблиц, переданном в качестве параметра.
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистра.
//		ИмяРезультирующейТаблицы 	- Строка - имя создаваемой временной таблицы, если не задано, то
//										имя результирующей таблицы будет сформировано каК ВТ<ИмяРегистра>.
//
Процедура СоздатьВТИмяРегистра(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, ИмяРезультирующейТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПериодическиеРегистры.СоздатьВТИмяРегистра(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, ИмяРезультирующейТаблицы);
```
</details>

## ТаблицаВТИмяРегистраПериоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу периодов регистра
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистра.
//
// Возвращаемое значение:
//	ТаблицаЗначений
//
Функция ТаблицаВТИмяРегистраПериоды(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ТаблицаВТИмяРегистраПериоды(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения);
```
</details>

## СоздатьВТИмяРегистраПериоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу периодов регистра в менеджере временных таблиц, переданном в качестве параметра.
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистра.
//		ИмяРезультирующейТаблицы 	- Строка - имя создаваемой временной таблицы, если не задано, то
//										имя результирующей таблицы будет сформировано как ВТ<ИмяРегистра>Периоды.
//
Процедура СоздатьВТИмяРегистраПериоды(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, ИмяРезультирующейТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПериодическиеРегистры.СоздатьВТИмяРегистраПериоды(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, ИмяРезультирующейТаблицы);
```
</details>

## СоздатьВТИмяРегистраСрезПервых
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу среза первых регистра в менеджере временных таблиц, переданном в качестве параметра.
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез.
//		ИмяРезультирующейТаблицы 	- Строка - имя создаваемой временной таблицы, если не задано, то
//										имя результирующей таблицы будет сформировано каК ВТ<ИмяРегистра>.
//
Процедура СоздатьВТИмяРегистраСрезПервых(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, ИмяРезультирующейТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПериодическиеРегистры.СоздатьВТИмяРегистраСрезПервых(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, ИмяРезультирующейТаблицы);
```
</details>

## СоздатьВТИмяРегистраСрезПоследних
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу среза последних регистра в менеджере временных таблиц, переданном в качестве параметра.
//
// Параметры:
//		ИмяРегистра 				- Строка - имя периодического регистра сведений, как  оно
//										задано в конфигураторе.
//		МенеджерВременныхТаблиц 	- МенеджерВременныхТаблиц
//		ТолькоРазрешенные 			- Булево
//		ОписаниеФильтра 			- Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//		ПараметрыПостроения 		- Структура - см. функцию ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез.
//		ИмяРезультирующейТаблицы 	- Строка - имя создаваемой временной таблицы, если не задано, то
//										имя результирующей таблицы будет сформировано каК ВТ<ИмяРегистра>.
//
Процедура СоздатьВТИмяРегистраСрезПоследних(Знач ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, ИмяРезультирующейТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПериодическиеРегистры.СоздатьВТИмяРегистраСрезПоследних(ИмяРегистра, МенеджерВременныхТаблиц, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, ИмяРезультирующейТаблицы);
```
</details>

## ЗапросВТИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос представления ВТИмяРегистра.
//
// Параметры:
//  ИмяРегистра           - Строка - Имя регистра как задано в конфигураторе.
//  ТолькоРазрешенные     - Булево
//  ОписаниеФильтра       - Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//  ПараметрыПостроения   - Структура - см. ПараметрыПостроенияДляСоздатьВТИмяРегистра.
//  ИмяСоздаваемойТаблицы - Строка - если не указано, запрос будет создавать временную таблицу ВТ<ИмяРегистра>
//
// Возвращаемое значение:
//  Запрос
//
Функция ЗапросВТИмяРегистра(ИмяРегистра, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, ИмяСоздаваемойТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ЗапросВТИмяРегистра(ИмяРегистра, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, ИмяСоздаваемойТаблицы);
```
</details>

## ЗапросВТИмяРегистраСрез
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос представления ВТИмяРегистраСрез.
//
// Параметры:
//  ИмяРегистра           - Строка - Имя регистра как задано в конфигураторе.
//  ТолькоРазрешенные     - Булево
//  ОписаниеФильтра       - Структура - см. функцию ОписаниеФильтраДляСоздатьВТИмяРегистра.
//  ПараметрыПостроения   - Структура - См. ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез.
//  СрезПоследних         - Булево - если Истина - срез последних, если Ложь - срез первых.
//  ИмяСоздаваемойТаблицы - Строка - если не указано, запрос будет создавать временную таблицу ВТ<ИмяРегистра>СрезПоследних
//                                   или ВТ<ИмяРегистра>СрезПервых, в зависимости от значения параметра СрезПоследних
//
// Возвращаемое значение:
//  Запрос
//
Функция ЗапросВТИмяРегистраСрез(ИмяРегистра, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, СрезПоследних = Истина, ИмяСоздаваемойТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ЗапросВТИмяРегистраСрез(ИмяРегистра, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, СрезПоследних, ИмяСоздаваемойТаблицы);
```
</details>

## ЗапросВТПериодыИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос представления ВТИмяРегистраПериоды.
// Получение периодов по интервальному регистру сведений.
//
// Параметры:
//  ИмяРегистра           - Строка - Имя регистра как задано в конфигураторе.
//  ТолькоРазрешенные     - Булево
//  ОписаниеФильтра       - Структура - См. ОписаниеФильтраДляСоздатьВТИмяРегистра.
//  ПараметрыПостроения   - Структура - См. ПараметрыПостроенияДляСоздатьВТИмяРегистраПериоды.
//  ИмяСоздаваемойТаблицы - Строка - если не указано, запрос будет создавать временную таблицу ВТ<ИмяРегистра>Периоды
//
// Возвращаемое значение:
//  Запрос
//
Функция ЗапросВТПериодыИмяРегистра(ИмяРегистра, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения = Неопределено, ИмяСоздаваемойТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ЗапросВТПериодыИмяРегистра(ИмяРегистра, ТолькоРазрешенные, ОписаниеФильтра, ПараметрыПостроения, ИмяСоздаваемойТаблицы);
```
</details>

## ОписаниеФильтраДляСоздатьВТИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание источника данных - временная таблица.
//
// Параметры:
//		ТаблицаФильтра 		- Строка - имя временной таблицы
//					   		- ТаблицаЗначений
//								содержат обязательные колонки:
//									"Период" (для получения представлений среза первых или
//										среза последних)
//									"ДатаНачала" и "ДатаОкончания" (для получения таблицы регистра).
//		ИзмеренияФильтра 	- Строка - имена колонок таблицы равные именам измерений регистра,
//								по которым устанавливается фильтр, для колонок с именами отличающимися
//								от имен измерений, в значениях ключа "СоответствиеИзмеренийРегистраИзмерениямФильтра",
//								указывается соответствие имени измерения регистра имени колонки таблицы фильтра.
//								Допускается не указывать, когда ТаблицаФильтра имеет тип ТаблицаЗначений.
//		ДополнительныеПоляФильтра 		- Строка
//							- Массив - имена колонок таблицы, по которым не устанавливается фильтр,
//								но которые должны участвовать в результате запроса.
//
// Возвращаемое значение:
//		Структура - см. НовыйОписаниеФильтраДляСоздатьВТИмяРегистра.
//
Функция ОписаниеФильтраДляСоздатьВТИмяРегистра(Знач ТаблицаФильтра, ИзмеренияФильтра = "", ДополнительныеПоляФильтра = "") Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ОписаниеФильтраДляСоздатьВТИмяРегистра(ТаблицаФильтра, ИзмеренияФильтра, ДополнительныеПоляФильтра);
```
</details>

## ОписаниеФильтраДляСоздатьВТИмяРегистраПоТаблицеЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание источника данных - временная таблица.
//
// Параметры:
//		ТаблицаФильтра 			- ТаблицаЗначений -	содержат обязательные колонки:
//										"Период" (для получения представлений среза первых или
//											среза последних)
//										"ДатаНачала" и "ДатаОкончания" (для получения таблицы регистра).
//		Измерения 				- Строка - имена колонок таблицы равные именам измерений регистра,
//									по которым устанавливается фильтр, для колонок с именами отличающимися
//									от имен измерений, в значениях ключа "СоответствиеИзмеренийРегистраИзмерениямФильтра",
//									указывается соответствие имени измерения регистра имени колонки таблицы фильтра.
//									Допускается не указывать, когда ТаблицаФильтра имеет тип ТаблицаЗначений.
//		ДополнительныеПоля 		- Строка
//								- Массив - имена колонок таблицы, по которым не устанавливается фильтр,
//									но которые должны участвовать в результате запроса.
//		МенеджерВременныхТаблиц - МенеджерВременныхТаблиц
//		ИмяВТФильтр 			- Строка - имя создаваемой временной таблицы фильтра
//
// Возвращаемое значение:
//		Структура - см. НовыйОписаниеФильтраДляСоздатьВТИмяРегистра.
//
Функция ОписаниеФильтраДляСоздатьВТИмяРегистраПоТаблицеЗначений(ТаблицаФильтра, Измерения = "", ДополнительныеПоля = "", МенеджерВременныхТаблиц = Неопределено, ИмяВТФильтр = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ОписаниеФильтраДляСоздатьВТИмяРегистраПоТаблицеЗначений(ТаблицаФильтра, Измерения, ДополнительныеПоля, МенеджерВременныхТаблиц, ИмяВТФильтр);
```
</details>

## ОписаниеФильтраДляСоздатьВТИмяРегистраПоВременнойТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание источника данных - временная таблица.
//
// Параметры:
//		ИмяВТФильтр 			- Строка - имя временной таблицы
//		Измерения 				- Строка - имена колонок таблицы равные именам измерений регистра,
//									по которым устанавливается фильтр, для колонок с именами отличающимися
//									от имен измерений, в значениях ключа "СоответствиеИзмеренийРегистраИзмерениямФильтра",
//									указывается соответствие имени измерения регистра имени колонки таблицы фильтра.
//									Допускается не указывать, когда ТаблицаФильтра имеет тип ТаблицаЗначений.
//		ДополнительныеПоля 		- Строка
//								- Массив - имена колонок таблицы, по которым не устанавливается фильтр,
//									но которые должны участвовать в результате запроса.
//
// Возвращаемое значение:
//		Структура - см. НовыйОписаниеФильтраДляСоздатьВТИмяРегистра.
//
Функция ОписаниеФильтраДляСоздатьВТИмяРегистраПоВременнойТаблице(ИмяВТФильтр, Измерения = "", ДополнительныеПоля = "") Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ОписаниеФильтраДляСоздатьВТИмяРегистраПоВременнойТаблице(ИмяВТФильтр, Измерения, ДополнительныеПоля);
```
</details>

## ОписаниеФильтраДляСоздатьВТИмяРегистраПоЗначению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание источника данных - временная таблица.
//
// Параметры:
//		ОписаниеПериода 		- Структура - см. ОписаниеПериодаДляСоздатьВТИмяРегистра
//		Измерение 				- Строка - имена колонок таблицы равные именам измерений регистра,
//									по которым устанавливается фильтр, для колонок с именами отличающимися
//									от имен измерений, в значениях ключа "СоответствиеИзмеренийРегистраИзмерениямФильтра",
//									указывается соответствие имени измерения регистра имени колонки таблицы фильтра.
//									Допускается не указывать, когда ТаблицаФильтра имеет тип ТаблицаЗначений.
//		ЗначениеИзмерения 		- Произвольный - значение измерения.
//
// Возвращаемое значение:
//		Структура - см. НовыйОписаниеФильтраДляСоздатьВТИмяРегистра.
//
Функция ОписаниеФильтраДляСоздатьВТИмяРегистраПоЗначению(ОписаниеПериода, Измерение = "", ЗначениеИзмерения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ОписаниеФильтраДляСоздатьВТИмяРегистраПоЗначению(ОписаниеПериода, Измерение, ЗначениеИзмерения);
```
</details>

## ОписаниеФильтраДляСоздатьВТИмяРегистраПоСпискуЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание источника данных - временная таблица.
//
// Параметры:
//		ОписаниеПериода 		- Структура - см. ОписаниеПериодаДляСоздатьВТИмяРегистра
//		Измерение 				- Строка - имена колонок таблицы равные именам измерений регистра,
//									по которым устанавливается фильтр, для колонок с именами отличающимися
//									от имен измерений, в значениях ключа "СоответствиеИзмеренийРегистраИзмерениямФильтра",
//									указывается соответствие имени измерения регистра имени колонки таблицы фильтра.
//									Допускается не указывать, когда ТаблицаФильтра имеет тип ТаблицаЗначений.
//		СписокЗначенийИзмерения	- Массив - значения измерений.
//
// Возвращаемое значение:
//		Структура - см. НовыйОписаниеФильтраДляСоздатьВТИмяРегистра.
//
Функция ОписаниеФильтраДляСоздатьВТИмяРегистраПоСпискуЗначений(ОписаниеПериода, Измерение = "", СписокЗначенийИзмерения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ОписаниеФильтраДляСоздатьВТИмяРегистраПоСпискуЗначений(ОписаниеПериода, Измерение, СписокЗначенийИзмерения);
```
</details>

## ПараметрыПостроенияДляСоздатьВТИмяРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры построения для СоздатьВТИмяРегистра.
//
// Возвращаемое значение:
//		Структура:
//			* ИндексироватьПо 							- Неопределено - см. функцию ПараметрыПостроенияВТИмяРегистра.
//			* Отборы 									- Массив - см. функцию ПараметрыПостроенияВТИмяРегистра.
//			* ВключатьЗаписиНаНачалоПериода 			- Булево - если истина в результирующую таблицу будут
//															включены значения по измерениям фильтра на начало периода
//															(применимо при построении запросов к регистрам с периодичностью.
//															Секунда, День, Месяц, Квартал или Год).
//			* ИмяВременнойТаблицыЗаписейНаНачалоПериода - Строка - задает имя временной таблицы записей на начало периода.
//			* ИспользуемоеИмяВременнойТаблицыЗаписейНаНачалоПериода - Строка - по окончании работы метода ЗапросВТИмяРегистра
//			                                                          будет сохранено имя временной таблицы, содержащей записи
//			                                                          на начало периода, если задано значение
//			                                                          ИмяВременнойТаблицыЗаписейНаНачалоПериода, то будет
//			                                                          содержать значение
//			                                                          ИмяВременнойТаблицыЗаписейНаНачалоПериода.
//			* ОтборыЗаписейНаНачалоПериода 				- Массив - описания отбора (см.ДобавитьВКоллекциюОтбор), применяется к таблице
//															формирующий записи на начало периода, при формировании результирующей таблицы.
//
Функция ПараметрыПостроенияДляСоздатьВТИмяРегистра() Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ПараметрыПостроенияДляСоздатьВТИмяРегистра() 
```
</details>

## ПараметрыПостроенияДляСоздатьВТИмяРегистраПериоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры построения для СоздатьВТИмяРегистраПериоды.
//
// Возвращаемое значение:
//		Структура - содержит структуры со свойствами:
//			* ИндексироватьПо 							- Неопределено - см. функцию ПараметрыПостроенияВТИмяРегистра.
//			* Отборы 									- Массив - см. функцию ПараметрыПостроенияВТИмяРегистра.
//			* ВключатьЗаписиНаНачалоПериода 			- Булево - если истина в результирующую таблицу будут
//															включены значения по измерениям фильтра на начало периода
//															(применимо при построении запросов к регистрам с периодичностью.
//															Секунда, День, Месяц, Квартал или Год).
//			* ИмяВременнойТаблицыЗаписейНаНачалоПериода - Строка - задает имя временной таблицы записей на начало периода.
//			* ИспользуемоеИмяВременнойТаблицыЗаписейНаНачалоПериода - Строка - по окончании работы метода ЗапросВТИмяРегистра
//			                                                          будет сохранено имя временной таблицы, содержащей записи
//			                                                          на начало периода, если задано значение
//			                                                          ИмяВременнойТаблицыЗаписейНаНачалоПериода, то будет
//			                                                          содержать значение
//			                                                          ИмяВременнойТаблицыЗаписейНаНачалоПериода.
//			* ОтборыЗаписейНаНачалоПериода 				- Массив - описания отбора (см.ДобавитьВКоллекциюОтбор), применяется к таблице
//															формирующий записи на начало периода, при формировании результирующей таблицы.
//
Функция ПараметрыПостроенияДляСоздатьВТИмяРегистраПериоды() Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ПараметрыПостроенияДляСоздатьВТИмяРегистраПериоды() 
```
</details>

## ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры построения для СоздатьВТИмяРегистраСрез.
//
// Возвращаемое значение:
//		Структура:
//			* ИндексироватьПо 			- Неопределено 	- см. функцию ПараметрыПостроенияВТИмяРегистра.
//			* Отборы 					- Массив 		- см. функцию ПараметрыПостроенияВТИмяРегистра.
//			* ВсеЗаписи 				- Булево - если Истина в результирующую таблицу будут включены
//											записи таблицы фильтра, для которых нет записей в регистре.
//			* ВключаяГраницу 			- Булево - если Ложь из результирующей таблицы будут исключены
//											записи с периодами равными ограничивающим.
//			* ОтборыПрименяемыеКСрезу - Массив - коллекции, аналогичных коллекции ключа Отборы, но применяемый
//											к полученному срезу.
//
Функция ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез() Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыПериодическиеРегистры.ПараметрыПостроенияДляСоздатьВТИмяРегистраСрез() 
```
</details>

## СформироватьДвиженияИнтервальногоРегистраПоИзменениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения интервального регистра сведений по изменениям первичного регистра
//
// Параметры:
//	ИмяРегистра - Строка - Имя регистра сведений, имеющего интервальную версию.
//	НаборЗаписей - НаборЗаписей - набор записей регистра сведений.
//
Процедура СформироватьДвиженияИнтервальногоРегистраПоИзменениям(ИмяРегистра, НаборЗаписей) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПериодическиеРегистры.СформироватьДвиженияИнтервальногоРегистраПоИзменениям(ИмяРегистра, НаборЗаписей) 
```
</details>

## ОбновитьДвиженияИнтервальногоРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет движения интервального регистра сведений
//		КадроваяИсторияСотрудников
//
// Параметры:
//	ИмяРегистра - Строка - Имя регистра сведений, имеющего интервальную версию.
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц
Процедура ОбновитьДвиженияИнтервальногоРегистра(ИмяРегистра, МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыПериодическиеРегистры.ОбновитьДвиженияИнтервальногоРегистра(ИмяРегистра, МенеджерВременныхТаблиц) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
