---
title: Зарплата кадры состав документов
slug: zup/зарплата-кадры-состав-документов
---


## НовоеОписаниеСоставаОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для методов служебного API использование не контролируем
// АПК:581-выкл
// АПК:299-выкл

// Возвращает описание состава объекта.
//
// Возвращаемое значение:
//  Структура - список параметров состава объекта:
//   * ИмяРеквизитаКраткийСостав                      - Строка - имя реквизита краткий состав объекта
//   * ИмяТабличнойЧастиФизическиеЛица                - Строка - имя табличной части физические лица объекта
//   * ЗаполнятьТабличнуюЧастьФизическиеЛицаДокумента - Булево - заполнять табличную часть Физические лица объекта
//   * ИспользоватьКраткийСостав                      - Булево - заполнять реквизит краткий состав объекта
//   * ЗаполнятьСоставДокументов                      - Булево - заполнять регистр состава документов для отбора в
//                                                               списках и журналов
//   * ЗаполнятьФизическиеЛицаПоСотрудникам           - Булево - заполнять физические лица по сотрудникам в табличных
//                                                               частях/шапке объекта
//   * ИспользоватьОграничениеДоступа                 - Булево - заполнять регистр Физические лица объекта для
//                                                               ограничения доступа
//   * ОписаниеХраненияСотрудниковФизическихЛиц       - Массив - массив структур(см ОписаниеСоставаТабличныхЧастей),
//      Необходим для заполнения физических лиц и/или сотрудников
//      для добавления используется ДобавитьОписаниеХраненияСотрудниковФизическихЛиц
//   * ОписаниеЗаполненияФизическихЛицПоСотрудникам   - Массив - массив структур(см ОписаниеСоставаТабличныхЧастей),
//      Необходим для заполнения физических лиц по сотрудникам
//      для добавления используется ДобавитьОписаниеХраненияСотрудниковФизическихЛиц.
//
Функция НовоеОписаниеСоставаОбъекта() Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.НовоеОписаниеСоставаОбъекта() 
```
</details>

## ОписаниеХраненияСотрудниковФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание хранения сотрудников и физических лиц объекта.
//
// Возвращаемое значение:
//  Структура - список параметров хранения сотрудников и физических лиц документа:
//   * ИмяТаблицы             - Строка - имя таблицы с сотрудниками и/или физическими лицами, если данные в шапке,
//                                       указывать Неопределено
//   * ПолеФизическоеЛицо     - Строка - имя поля физическое лицо, если отсутствует, указываем Неопределено
//   * ПолеСотрудник          - Строка - имя поля сотрудник, если отсутствует, указываем Неопределено
//   * ВключатьВКраткийСостав - Булево - включать ли физическое лицо в краткий состав документа.
//
Функция ОписаниеХраненияСотрудниковФизическихЛиц() Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ОписаниеХраненияСотрудниковФизическихЛиц() 
```
</details>

## ДобавитьОписаниеХраненияСотрудниковФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в массив описание хранения сотрудников физических лиц.
//
// Параметры:
//			МассивОписаний     - Массив - содержит структуры со свойствами см. НовоеОписаниеСоставаОбъекта.
//			ИмяТаблицы         - Строка - имя таблицы, хранящей сотрудников и/или физические лица
//			ПолеФизическоеЛицо - Строка - имя реквизита ФизическоеЛицо.
//			ПолеСотрудник      - Строка - имя реквизита Сотрудник.
//
Процедура ДобавитьОписаниеХраненияСотрудниковФизическихЛиц(МассивОписаний, ИмяТаблицы = Неопределено, ПолеФизическоеЛицо = Неопределено, ПолеСотрудник = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыСоставДокументов.ДобавитьОписаниеХраненияСотрудниковФизическихЛиц(МассивОписаний, ИмяТаблицы, ПолеФизическоеЛицо, ПолеСотрудник);
```
</details>

## ОписаниеСоставаОбъектаФизическоеЛицоВШапке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание состава документа, в случае хранения физических лиц в табличных частях.
//
// Возвращаемое значение:
//  Структура - см. НовоеОписаниеСоставаОбъекта.
//
Функция ОписаниеСоставаОбъектаФизическоеЛицоВШапке(ИмяРеквизитаФизическоеЛицо = "ФизическоеЛицо", ИмяРеквизитаСотрудник = "Сотрудник") Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ОписаниеСоставаОбъектаФизическоеЛицоВШапке(ИмяРеквизитаФизическоеЛицо, ИмяРеквизитаСотрудник);
```
</details>

## ОписаниеСоставаОбъектаПоМетаданнымФизическиеЛицаВТабличныхЧастях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание состава объекта по метаданным, в случае хранения физических лиц в табличных частях.
//
// Возвращаемое значение:
//  Структура - см. НовоеОписаниеСоставаОбъекта.
//
Функция ОписаниеСоставаОбъектаПоМетаданнымФизическиеЛицаВТабличныхЧастях(МетаданныеОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ОписаниеСоставаОбъектаПоМетаданнымФизическиеЛицаВТабличныхЧастях(МетаданныеОбъекта) 
```
</details>

## СоставОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сотрудников и физических лиц объекта
//
// Параметры:
//	Источник - ДокументОбъект, СправочникОбъект - объект для которого необходимо получить состав,
//				в модуле менеджера соответствующего объекта метаданных должен быть реализован метод
//				ОписаниеСоставаОбъекта
//
// Возвращаемое значение:
//   см. НовыйСоставОбъекта - структура с составом объекта
//
Функция СоставОбъекта(Источник) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.СоставОбъекта(Источник) 
```
</details>

## СоставОбъектаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сотрудников и физических лиц объекта по ссылке
//
// Параметры:
//	Источник - ДокументСслка, СправочникСсылка - ссылка на объект для которого необходимо получить состав,
//				в модуле менеджера соответствующего объекта метаданных должен быть реализован метод
//				ОписаниеСоставаОбъекта
//
// Возвращаемое значение:
//   см. НовыйСоставОбъекта - структура с составом объекта
//
Функция СоставОбъектаПоСсылке(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.СоставОбъектаПоСсылке(Ссылка) 
```
</details>

## СоставОбъектаПоДаннымФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сотрудников и физических лиц объекта
//
// Параметры:
//	ДанныеФормыОбъекта - ДанныеФормыСтруктура - данные формы содержащие данные объекта
//              для которого необходимо получить состав,
//				в модуле менеджера соответствующего объекта метаданных должен быть реализован метод
//				ОписаниеСоставаОбъекта
//
// Возвращаемое значение:
//   см. НовыйСоставОбъекта - структура с составом объекта
//
Функция СоставОбъектаПоДаннымФормы(ДанныеФормыОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.СоставОбъектаПоДаннымФормы(ДанныеФормыОбъекта) 
```
</details>

## ЗарегистрироватьОбработчикиОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в список Обработчики процедуры-обработчики обновления,
// необходимые данной подсистеме.
//
// Параметры:
//   Обработчики - ТаблицаЗначений - см. описание функции НоваяТаблицаОбработчиковОбновления
//                                   общего модуля ОбновлениеИнформационнойБазы.
//
Процедура ЗарегистрироватьОбработчикиОбновления(Обработчики) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыСоставДокументов.ЗарегистрироватьОбработчикиОбновления(Обработчики) 
```
</details>

## ДокументыФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДокументыФизическихЛиц(МассивФизическихЛиц, ОбъектыМетаданных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ДокументыФизическихЛиц(МассивФизическихЛиц, ОбъектыМетаданных);
```
</details>

## ДокументыСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДокументыСотрудников(МассивСотрудников, ОбъектыМетаданных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ДокументыСотрудников(МассивСотрудников, ОбъектыМетаданных);
```
</details>

## ФизическиеЛицаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ФизическиеЛицаДокументов(МассивДокументов) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ФизическиеЛицаДокументов(МассивДокументов) 
```
</details>

## ОписаниеОбъектаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОписаниеОбъектаПоСсылке(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ОписаниеОбъектаПоСсылке(Ссылка) 
```
</details>

## ОписаниеОбъектаПоПолномуИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание объекта по полному имени.
//
// Параметры:
//  ИмяОбъекта - Строка
//
// Возвращаемое значение: см. НовоеОписаниеСоставаОбъекта
Функция ОписаниеОбъектаПоПолномуИмени(ИмяОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ЗарплатаКадрыСоставДокументов.ОписаниеОбъектаПоПолномуИмени(ИмяОбъекта) 
```
</details>

## ПередУничтожениемПерсональныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ЗащитаПерсональныхДанныхПереопределяемый.ПередУничтожениемПерсональныхДанных
Процедура ПередУничтожениемПерсональныхДанных(Объект, Субъекты, ВыполнитьЗаписьОбъекта) Экспорт
```

Пример вызова
```bsl
ЗарплатаКадрыСоставДокументов.ПередУничтожениемПерсональныхДанных(Объект, Субъекты, ВыполнитьЗаписьОбъекта) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
