---
title: Интеграция с 1С документооборот базовая функциональность
slug: zup/интеграция-с-1с-документооборот-базовая-функциональность
---


## ВыполнитьЗапросАсинхронно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запрос к сервису 1С:Документооборот в фоновом задании.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Запрос - ОбъектXDTO - выполняемый запрос.
//   УникальныйИдентификатор - УникальныйИдентификатор - уникальный идентификатор формы, из которой выполняется запрос.
//   НаименованиеФоновогоЗадания - Строка - представление длительной операции, которое будет выведено в интерфейс.
//
// Возвращаемое значение:
//   см. ДлительныеОперации.ВыполнитьВФоне
//
Функция ВыполнитьЗапросАсинхронно(Прокси, Запрос, УникальныйИдентификатор, НаименованиеФоновогоЗадания = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьЗапросАсинхронно(Прокси, Запрос, УникальныйИдентификатор, НаименованиеФоновогоЗадания);
```
</details>

## ВыполнитьЗапросВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запрос к сервису 1С:Документооборот из фонового задания.
//
// Параметры:
//   Параметры - Структура:
//     * ИнтеграцияС1СДокументооборотWSОпределения - ХранилищеЗначения
//     * ИнтеграцияС1СДокументооборотВерсияСервиса - Строка
//     * ИнтеграцияС1СДокументооборотИмяПользователя - Строка
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияJWT - Булево
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияОС - Булево
//     * ИнтеграцияС1СДокументооборотМестоположениеПрокси - Строка
//     * ИнтеграцияС1СДокументооборотПароль - Строка
//     * ИнтеграцияС1СДокументооборотПарольИзвестен - Булево
//     * ЗапросСтрока - Строка
//   АдресХранилища - Строка - адрес хранилища, куда будет помещен результат запроса.
//
Процедура ВыполнитьЗапросВФоне(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьЗапросВФоне(Параметры, АдресХранилища) 
```
</details>

## ВыполнитьПакетныйЗапросАсинхронно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет пакетный запрос к сервису 1С:Документооборот в фоновом задании.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Запросы - Массив из ОбъектXDTO - запросы пакета.
//   УникальныйИдентификатор - УникальныйИдентификатор - уникальный идентификатор формы, из которой выполняется запрос.
//   НаименованиеФоновогоЗадания - Строка - представление длительной операции, которое будет выведено в интерфейс.
//   ПроверятьПодчиненные - Булево - указывает требуется ли проверять результаты запросов, входящих в пакет.
//
// Возвращаемое значение:
//   см. ДлительныеОперации.ВыполнитьВФоне
//
Функция ВыполнитьПакетныйЗапросАсинхронно(Прокси, Запросы, УникальныйИдентификатор, НаименованиеФоновогоЗадания = "", Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьПакетныйЗапросАсинхронно(Прокси, Запросы, УникальныйИдентификатор, НаименованиеФоновогоЗадания, );
```
</details>

## ВыполнитьПакетныйЗапросВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запрос к сервису 1С:Документооборот из фонового задания.
//
// Параметры:
//   Параметры - Структура:
//     * ИнтеграцияС1СДокументооборотWSОпределения - ХранилищеЗначения
//     * ИнтеграцияС1СДокументооборотВерсияСервиса - Строка
//     * ИнтеграцияС1СДокументооборотИмяПользователя - Строка
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияJWT - Булево
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияОС - Булево
//     * ИнтеграцияС1СДокументооборотМестоположениеПрокси - Строка
//     * ИнтеграцияС1СДокументооборотПароль - Строка
//     * ИнтеграцияС1СДокументооборотПарольИзвестен - Булево
//     * ЗапросыСтрока - Массив из Строка
//     * ПроверятьПодчиненные - Булево
//   АдресХранилища - Строка - адрес хранилища, куда будет помещен результат запроса.
//
Процедура ВыполнитьПакетныйЗапросВФоне(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьПакетныйЗапросВФоне(Параметры, АдресХранилища) 
```
</details>

## ЗаписатьОбъектВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает изменения объекта в Документообороте в фоновом задании.
//
// Параметры:
//   Параметры - Структура:
//     * ИнтеграцияС1СДокументооборотWSОпределения - ХранилищеЗначения
//     * ИнтеграцияС1СДокументооборотВерсияСервиса - Строка
//     * ИнтеграцияС1СДокументооборотИмяПользователя - Строка
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияJWT - Булево
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияОС - Булево
//     * ИнтеграцияС1СДокументооборотМестоположениеПрокси - Строка
//     * ИнтеграцияС1СДокументооборотПароль - Строка
//     * ИнтеграцияС1СДокументооборотПарольИзвестен - Булево
//     * ОбъектСтрока - Строка - строковое предствление объекта XDTO с сохраняемыми данными.
//   АдресХранилища - Строка - адрес хранилища, куда будет помещен результат запроса.
//
Процедура ЗаписатьОбъектВФоне(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаписатьОбъектВФоне(Параметры, АдресХранилища) 
```
</details>

## ОбъектXDTOВСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует объект XDTO из пространства имен "HTTP://www.1c.ru/dm" в строку.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - объект XDTO xml представление которого требуется получить.
//
// Возвращаемое значение:
//   Строка
//
Функция ОбъектXDTOВСтроку(Прокси, ОбъектXDTO) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ОбъектXDTOВСтроку(Прокси, ОбъектXDTO) 
```
</details>

## ПараметрыДлительнойОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для обращения к сервису 1С:Документооборот в фоновом задании.
//
// Параметры:
//   ИспользоватьКэш - Булево - при проверке возможности авторизации без пароля не требуется использовать кэш.
//
// Возвращаемое значение:
//   Структура:
//     * ИнтеграцияС1СДокументооборотWSОпределения - ХранилищеЗначения
//     * ИнтеграцияС1СДокументооборотВерсияСервиса - Строка
//     * ИнтеграцияС1СДокументооборотИмяПользователя - Строка
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияJWT - Булево
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияОС - Булево
//     * ИнтеграцияС1СДокументооборотМестоположениеПрокси - Строка
//     * ИнтеграцияС1СДокументооборотПароль - Строка
//     * ИнтеграцияС1СДокументооборотПарольИзвестен - Булево
//
Функция ПараметрыДлительнойОперации(ИспользоватьКэш = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПараметрыДлительнойОперации(ИспользоватьКэш);
```
</details>

## ПодключитьсяИПолучитьВерсиюСервисаВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет подключение к сервису 1С:Документооборот из фонового задания, и делает запрос версии сервиса.
//
// Параметры:
//   Параметры - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПараметрыДлительнойОперации
//   АдресХранилища - Строка - адрес хранилища, куда будет помещен результат запроса.
//
Процедура ПодключитьсяИПолучитьВерсиюСервисаВФоне(Параметры, АдресХранилища = "") Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПодключитьсяИПолучитьВерсиюСервисаВФоне(Параметры, АдресХранилища);
```
</details>

## ПолучитьОбъектВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает объект из Документооборота в фоновом задании.
//
// Параметры:
//   Параметры - Структура:
//     * ИнтеграцияС1СДокументооборотWSОпределения - ХранилищеЗначения
//     * ИнтеграцияС1СДокументооборотВерсияСервиса - Строка
//     * ИнтеграцияС1СДокументооборотИмяПользователя - Строка
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияJWT - Булево
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияОС - Булево
//     * ИнтеграцияС1СДокументооборотМестоположениеПрокси - Строка
//     * ИнтеграцияС1СДокументооборотПароль - Строка
//     * ИнтеграцияС1СДокументооборотПарольИзвестен - Булево
//     * Тип - Строка
//     * ID - Строка
//     * Колонки - Массив из Строка - необязательно, состав заполняемых колонок.
//               - Строка - если список колонок разделен через запятую.
//     * ПравилоИнтеграции - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом3 - правило интеграции для
//         заполнения объекта ИС.
//     * ВнешнийОбъектИС - ЛюбаяСсылка - передается для заполнения свойства externalObject.
//   АдресХранилища - Строка - адрес хранилища, куда будет помещен результат запроса.
//
Процедура ПолучитьОбъектВФоне(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьОбъектВФоне(Параметры, АдресХранилища) 
```
</details>

## ПолучитьПроксиВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает прокси веб-сервиса Документооборота в фоновом задании, с настройками, переданными напрямую.
//
// Параметры:
//   Параметры - Структура:
//     * ИнтеграцияС1СДокументооборотWSОпределения - ХранилищеЗначения
//     * ИнтеграцияС1СДокументооборотВерсияСервиса - Строка
//     * ИнтеграцияС1СДокументооборотИмяПользователя - Строка
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияJWT - Булево
//     * ИнтеграцияС1СДокументооборотИспользуетсяАутентификацияОС - Булево
//     * ИнтеграцияС1СДокументооборотМестоположениеПрокси - Строка
//     * ИнтеграцияС1СДокументооборотПароль - Строка
//     * ИнтеграцияС1СДокументооборотПарольИзвестен - Булево
//
// Возвращаемое значение:
//   WSПрокси - прокси веб-сервиса Документооборота.
//   Неопределено - в случае, если прокси веб-сервиса получить не удалось.
//
Функция ПолучитьПроксиВФоне(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьПроксиВФоне(Параметры) 
```
</details>

## СтрокаВОбъектXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует строку в объект XDTO из пространства имен "HTTP://www.1c.ru/dm".
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Строка - Строка - xml представление объекта XDTO.
//
// Возвращаемое значение:
//   ОбъектXDTO
//
Функция СтрокаВОбъектXDTO(Прокси, Строка) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СтрокаВОбъектXDTO(Прокси, Строка) 
```
</details>

## ВыполнитьОбменДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обмен данными с 1С:Документооборотом по правилам интеграции.
//
Процедура ВыполнитьОбменДанными() Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьОбменДанными() 
```
</details>

## АдресВебСервиса1СДокументооборот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает адрес публикации веб-сервиса Документооборот.
//
// Возвращаемое значение:
//   Строка - адрес сервиса.
//
Функция АдресВебСервиса1СДокументооборот() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.АдресВебСервиса1СДокументооборот() 
```
</details>

## ВерсияСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает версию сервиса из параметров сеанса.
//
// Возвращаемое значение:
//   Строка - версия сервиса.
//
Функция ВерсияСервиса() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВерсияСервиса() 
```
</details>

## ВыполнитьЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запрос к сервису, превращая сообщения об ошибках в вид, понятный пользователю.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Запрос - ОбъектXDTO - выполняемый запрос.
//
// Возвращаемое значение:
//   ОбъектXDTO - результат выполнения запроса.
//
Функция ВыполнитьЗапрос(Прокси, Запрос) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьЗапрос(Прокси, Запрос) 
```
</details>

## ВыполнитьПакетныйЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет пакет запросов к сервису Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Запросы - Массив из ОбъектXDTO - запросы пакета.
//   ПроверятьПодчиненные - Булево - указывает требуется ли проверять результаты запросов, входящих в пакет.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMBatchResponse.
//
Функция ВыполнитьПакетныйЗапрос(Прокси, Запросы, ПроверятьПодчиненные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ВыполнитьПакетныйЗапрос(Прокси, Запросы, ПроверятьПодчиненные);
```
</details>

## ДобавитьСтрокуИнвертируемыхКонстант
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет строку инвертируемых констант в таблицу зависимости констант.
//
// Параметры:
//   ТаблицаКонстант - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗависимостиКонстант
//   ИмяРодительскойКонстанты - Строка - имя родительской константы как оно задано в конфигураторе.
//   ИмяПодчиненнойКонстанты - Строка - имя подчиненной константы как оно задано в конфигураторе.
//
Процедура ДобавитьСтрокуИнвертируемыхКонстант(ТаблицаКонстант, ИмяРодительскойКонстанты, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуИнвертируемыхКонстант(ТаблицаКонстант, ИмяРодительскойКонстанты, );
```
</details>

## ДобавитьСтрокуСоответствияТипов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет строку в таблицу соответствия типов.
//
// Параметры:
//   Таблица - ТаблицаЗначений - таблица соответствия типов.
//   ИмяТипаXDTO - Строка - имя типа XDTO
//   ТипОбъектаИС - Тип - тип объекта ИС.
//
Процедура ДобавитьСтрокуСоответствияТипов(Таблица, ИмяТипаXDTO, ТипОбъектаИС) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(Таблица, ИмяТипаXDTO, ТипОбъектаИС) 
```
</details>

## ДобавитьСтрокуТаблицыЗависимостиКонстант
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет строку в таблицу зависимости констант.
//
// Параметры:
//   ТаблицаКонстант - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗависимостиКонстант
//   ИмяРодительскойКонстанты - Строка - имя родительской константы как оно задано в конфигураторе
//   ЗначениеРодительскойКонстанты - Произвольный - значение родительской константы
//   ИмяПодчиненнойКонстанты - Строка - имя подчиненной константы как оно задано в конфигураторе
//   ЗначениеПодчиненнойКонстанты - Произвольный - значение подчиненной константы
//
Процедура ДобавитьСтрокуТаблицыЗависимостиКонстант(ТаблицаКонстант, ИмяРодительскойКонстанты, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуТаблицыЗависимостиКонстант(ТаблицаКонстант, ИмяРодительскойКонстанты, );
```
</details>

## ДопРеквизитПоИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на дополнительный реквизит по уникальному имени.
//
// Параметры:
//   ИмяДопРеквизита - Строка - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИмяДопРеквизита
//
// Возвращаемое значение:
//   ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения
//
Функция ДопРеквизитПоИмени(ИмяДопРеквизита) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДопРеквизитПоИмени(ИмяДопРеквизита) 
```
</details>

## ДоступенФункционалВерсииСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает доступность функционала версии web-сервиса Документооборота.
//
// Параметры:
//   ВерсияСервиса - Строка - версия web-сервиса Документооборота, содержащая требуемый функционал.
//   Оптимистично - Булево - признак необходимости вернуть Истина, если версия сервиса пока неизвестна.
//
// Возвращаемое значение:
//   Булево - Истина, если web-сервис Документооборота указанной версии доступен.
//
Функция ДоступенФункционалВерсииСервиса(ВерсияСервиса = "", Оптимистично = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДоступенФункционалВерсииСервиса(ВерсияСервиса, Оптимистично);
```
</details>

## ЕстьПодсистемаДО2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, встроены ли в конфигурации модули БИД, предназначенные для интеграции с 1С:Документооборотом редакции 2.
//
// Возвращаемое значение:
//   Булево
//
Функция ЕстьПодсистемаДО2() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЕстьПодсистемаДО2() 
```
</details>

## ЕстьПодсистемаДО3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, встроены ли в конфигурации модули БИД, предназначенные для интеграции с 1С:Документооборотом редакции 3.
//
// Возвращаемое значение:
//   Булево
//
Функция ЕстьПодсистемаДО3() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЕстьПодсистемаДО3() 
```
</details>

## ЕстьУникальныйИдентификатор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет значение на объектный тип, содержащий уникальный идентификатор.
//
// Параметры:
//   Значение - Произвольный - проверяемое значение.
//
// Возвращаемое значение:
//   Булево - Признак наличия у объекта уникального идентификатора.
//
Функция ЕстьУникальныйИдентификатор(Значение) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЕстьУникальныйИдентификатор(Значение) 
```
</details>

## ЗависимостиКонстант
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, описывающую зависимость констант в конфигурации.
// Каждая строка таблицы означает:
// для родительской константы со значением Х допустимо только значение Y для подчиненной константы.
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//     * ИмяРодительскойКонстанты - Строка
//     * ИмяПодчиненнойКонстанты - Строка
//     * ЗначениеРодительскойКонстанты - Произвольный
//     * ЗначениеПодчиненнойКонстанты - Произвольный
//
Функция ЗависимостиКонстант() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗависимостиКонстант() 
```
</details>

## ЗаписатьОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает изменения объекта в Документообороте.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объект - ОбъектXDTO - XDTO объект с сохраняемыми данными.
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMUpdateResponse.
//
Функция ЗаписатьОбъект(Прокси, Объект) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаписатьОбъект(Прокси, Объект) 
```
</details>

## ЗаписатьОбъекты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает изменения объектов в Документообороте.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объекты - Массив из ОбъектXDTO - массив XDTO объектов с сохраняемыми данными.
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMUpdateResponse.
//
Функция ЗаписатьОбъекты(Прокси, Объекты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаписатьОбъекты(Прокси, Объекты) 
```
</details>

## ЗаписатьОбъектыЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для записи изменений объектов в Документообороте.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объекты - Массив из ОбъектXDTO - массив XDTO объектов с сохраняемыми данными.
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMUpdateRequest.
//
Функция ЗаписатьОбъектыЗапрос(Прокси, Объекты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаписатьОбъектыЗапрос(Прокси, Объекты) 
```
</details>

## ЗаписатьОшибку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает ошибку в ЖР.
//
// Параметры:
//   ТекстОшибки - Строка - текст ошибки.
//   СобытиеВторогоУровня - Строка - имя события, добавляемое через точку к имени события по умолчанию.
//
Процедура ЗаписатьОшибку(ТекстОшибки, СобытиеВторогоУровня = "") Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаписатьОшибку(ТекстОшибки, СобытиеВторогоУровня);
```
</details>

## ЗаписатьПредупреждение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает предупреждение в ЖР.
//
// Параметры:
//   ТекстПредупреждения - Строка - текст предупреждения.
//   СобытиеВторогоУровня - Строка - имя события, добавляемое через точку к имени события по умолчанию.
//
Процедура ЗаписатьПредупреждение(ТекстПредупреждения, СобытиеВторогоУровня = "") Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаписатьПредупреждение(ТекстПредупреждения, СобытиеВторогоУровня);
```
</details>

## ЗаполнитьЗначенияСвойствXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет свойства объекта-приемника по объекту-источнику.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Приемник - ОбъектXDTO - заполняемый объект.
//   Источник - ОбъектXDTO - источник данных заполнения.
//
Процедура ЗаполнитьЗначенияСвойствXDTO(Прокси, Приемник, Источник) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьЗначенияСвойствXDTO(Прокси, Приемник, Источник) 
```
</details>

## ЗаполнитьОбъектXDTOИзОбъектногоРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет объект XDTO (приемник) по реквизиту (источник).
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Источник - ФормаКлиентскогоПриложения, Структура - содержит реквизиты или свойства,
//     по которым заполняется объект XDTO.
//   ИмяРеквизита - Строка - имя объектного реквизита источника.
//   Приемник - ОбъектXDTO - содержит заполняемое свойство.
//   ТипОбъектаXDTO - Строка - тип XDTO заполняемого свойства.
//   ЗаполнятьВсегда - Булево - признак заполнения, даже если объектный реквизит не заполнен.
//
Процедура ЗаполнитьОбъектXDTOИзОбъектногоРеквизита(Прокси, Источник, ИмяРеквизита, Приемник, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьОбъектXDTOИзОбъектногоРеквизита(Прокси, Источник, ИмяРеквизита, Приемник, );
```
</details>

## ЗаполнитьОбъектныйРеквизит
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет объектный реквизит (приемник) по объекту XDTO (источник).
//
// Параметры:
//   Приемник - Произвольный - объект, содержащий реквизиты или свойства,
//     которые должны быть заполнены по свойству объекта XDTO.
//   Источник - ОбъектXDTO, СвойствоXDTO - объект XDTO или его свойство, по которому будет заполнен объектный реквизит.
//   ИмяРеквизита - Строка - имя объектного реквизита.
//   ЗаполнятьПредставление - Булево - признак необходимости заполнения реквизита представления
//     по свойству objectID.presentation.
//
Процедура ЗаполнитьОбъектныйРеквизит(Приемник, Источник, ИмяРеквизита, ЗаполнятьПредставление = Ложь) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьОбъектныйРеквизит(Приемник, Источник, ИмяРеквизита, ЗаполнятьПредставление);
```
</details>

## ЗаполнитьПодписиОбъектаXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет объект XDTO электронными подписями.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - объект XDTO со свойством signatures, куда будут добавлены подписи.
//   МассивПодписей - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//
Процедура ЗаполнитьПодписиОбъектаXDTO(Прокси, ОбъектXDTO, МассивПодписей) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьПодписиОбъектаXDTO(Прокси, ОбъектXDTO, МассивПодписей) 
```
</details>

## ЗаполнитьРеквизитФормыИзXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет указанный реквизит формы по свойству объекта XDTO.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма, реквизит которой заполняется.
//   ИмяРеквизитаФормы - Строка - имя заполняемого реквизита.
//   ОбъектXDTO - ОбъектXDTO - источник данных заполнения.
//   ИмяСвойстваXDTO - Строка - имя свойства-источника данных.
//
Процедура ЗаполнитьРеквизитФормыИзXDTO(Форма, ИмяРеквизитаФормы, ОбъектXDTO, ИмяСвойстваXDTO) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьРеквизитФормыИзXDTO(Форма, ИмяРеквизитаФормы, ОбъектXDTO, ИмяСвойстваXDTO) 
```
</details>

## ЗаполнитьРеквизитыИзПотребителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты объекта XDTO по объекту ИС.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - заполняемый объект.
//   ОбъектИС - ЛюбаяСсылка - источник заполнения.
//
Процедура ЗаполнитьРеквизитыИзПотребителя(Прокси, ОбъектXDTO, ОбъектИС) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьРеквизитыИзПотребителя(Прокси, ОбъектXDTO, ОбъектИС) 
```
</details>

## ЗначениеРеквизитаПоОбъектуXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение реквизита объекта ИС по значению реквизита объекта ДО.
//
// Параметры:
//   ОбъектXDTO - ОбъектXDTO - исходный объект, соответствие которому нужно найти.
//   ТипРеквизита - Тип - тип заполняемого реквизита объекта ИС.
//   ИмяРеквизита - Строка - имя заполняемого реквизита ИС.
//   ТипОбъекта - Тип - тип заполняемого объекта ИС.
//   Объект - Произвольный - заполняемый объект ИС.
//   ЭтоДополнительноеСвойство - Булево - истина, если переданный объект является доп. свойством.
//   Свойство - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения - свойство-владелец.
//   ПараметрыВыбора - Соответствие из КлючИЗначение - параметры выбора:
//     * Ключ - Строка - имя параметра вида "Отбор.Владелец".
//     * Значение - Произвольный - значение параметра (отбора).
//   СоздаватьЕслиНеНайден - Булево - автоматически создавать новый элемент справочника ИС, в случае,
//     если не удалось подобрать существующий элемент по значению реквизита объекта ДО.
//
// Возвращаемое значение:
//   ЛюбаяСсылка - ссылка на найденный или созданный объект.
//
Функция ЗначениеРеквизитаПоОбъектуXDTO(ОбъектXDTO, ТипРеквизита, ИмяРеквизита = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗначениеРеквизитаПоОбъектуXDTO(ОбъектXDTO, ТипРеквизита, ИмяРеквизита, );
```
</details>

## ИмяДопРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает уникальное имя дополнительного реквизита для последующего использования в правилах интеграции.
//
// Параметры:
//   ДопРеквизит - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения - дополнительный реквизит.
//
// Возвращаемое значение:
//   Строка - имя дополнительного реквизита.
//
Функция ИмяДопРеквизита(ДопРеквизит) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИмяДопРеквизита(ДопРеквизит) 
```
</details>

## ИмяСобытияЖурналаРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает локализованное имя события журнала регистрации для интеграции с ДО.
//
// Параметры:
//   СобытиеВторогоУровня - Строка - имя события, добавляемое через точку к имени события по умолчанию.
//
// Возвращаемое значение:
//   Строка - Интеграция с 1С:Документооборотом
//        или Интеграция с 1С:Документооборотом.<ИмяСобытияВторогоУровня>.
//
Функция ИмяСобытияЖурналаРегистрации(СобытиеВторогоУровня = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИмяСобытияЖурналаРегистрации(СобытиеВторогоУровня);
```
</details>

## ИндексКартинкиЭлементаСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает индекс картинки элемента справочника.
//
// Возвращаемое значение:
//   Число - индекс картинки.
//
Функция ИндексКартинкиЭлементаСправочника() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИндексКартинкиЭлементаСправочника() 
```
</details>

## ИнтеграцияС1СДокументооборотПередЗаписьюДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Назначает новому документу идентификатор основания, если это возможно.
//
// Параметры:
//   Источник - ДокументОбъект - записываемый документ.
//   Отказ - Булево - признак необходимости отказаться от записи.
//   РежимЗаписи - РежимЗаписиДокумента - режим записи документа.
//   РежимПроведения - РежимПроведенияДокумента - режим проведения документа.
//
Процедура ИнтеграцияС1СДокументооборотПередЗаписьюДокумента(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИнтеграцияС1СДокументооборотПередЗаписьюДокумента(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ИнтеграцияС1СДокументооборотПередЗаписьюСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Назначает новому элементу справочника идентификатор основания, если это возможно.
//
// Параметры:
//   Источник - СправочникОбъект - записываемый справочник.
//   Отказ - Булево - признак необходимости отказаться от записи.
//
Процедура ИнтеграцияС1СДокументооборотПередЗаписьюСправочника(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИнтеграцияС1СДокументооборотПередЗаписьюСправочника(Источник, Отказ) 
```
</details>

## ИспользоватьПрисоединенныеФайлы1СДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, используются ли присоединенные файлы ДО.
//
// Возвращаемое значение:
//   Булево
//
Функция ИспользоватьПрисоединенныеФайлы1СДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИспользоватьПрисоединенныеФайлы1СДокументооборота() 
```
</details>

## НайтиСписокОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значения, доступные для выбора по запросу DMGetObjectListRequest.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ТипОбъектаВыбораXDTO - Строка - имя типа объекта, значения которого требуется получить.
//   УсловияОтбораОбъектов - ОбъектXDTO - объект XDTO типа DMObjectListQuery.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMGetObjectListResponse.
//
Функция НайтиСписокОбъектов(Прокси, ТипОбъектаВыбораXDTO, УсловияОтбораОбъектов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.НайтиСписокОбъектов(Прокси, ТипОбъектаВыбораXDTO, УсловияОтбораОбъектов);
```
</details>

## НайтиСписокОбъектовЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос DMGetObjectListRequest для получения значений, доступных для выбора.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ТипОбъектаВыбораXDTO - Строка - имя типа объекта, значения которого требуется получить.
//   УсловияОтбораОбъектов - ОбъектXDTO - объект XDTO типа DMObjectListQuery:
//     * columnConformity - СписокXDTO
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMGetObjectListRequest.
//
Функция НайтиСписокОбъектовЗапрос(Прокси, ТипОбъектаВыбораXDTO, УсловияОтбораОбъектов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.НайтиСписокОбъектовЗапрос(Прокси, ТипОбъектаВыбораXDTO, УсловияОтбораОбъектов);
```
</details>

## НовоеИсходящееПисьмо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает объект XDTO исходящего письма, заполненный по умолчанию.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Предмет - Структура - описание предмета (ID, type).
//
// Возвращаемое значение:
//   ОбъектXDTO - новое исходящее письмо.
//
Функция НовоеИсходящееПисьмо(Прокси, Предмет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.НовоеИсходящееПисьмо(Прокси, Предмет);
```
</details>

## ОбновитьПовторноИспользуемыеПараметры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает все сохраненные значения функций с повторным использованием возвращаемых значений и параметры сеанса.
//
Процедура ОбновитьПовторноИспользуемыеПараметры() Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ОбновитьПовторноИспользуемыеПараметры() 
```
</details>

## ОбработкаЗаполненияДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ОбработкаЗаполнения для документов.
//
// Параметры:
//   Источник - ОпределяемыйТип.ИнтеграцияС1СДокументооборотДокументыОбъектыПереопределяемый
//   ДанныеЗаполнения - Произвольный - значение, которое используется как основание для заполнения.
//   СтандартнаяОбработка - Булево - признак выполнения стандартной обработки события.
//
Процедура ОбработкаЗаполненияДокументы(Источник, ДанныеЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ОбработкаЗаполненияДокументы(Источник, ДанныеЗаполнения, СтандартнаяОбработка) 
```
</details>

## ОбработкаЗаполненияСправочники
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ОбработкаЗаполнения для справочников.
//
// Параметры:
//   Источник - ОпределяемыйТип.ИнтеграцияС1СДокументооборотСправочникиОбъектыПереопределяемый
//   ДанныеЗаполнения - Произвольный - значение, которое используется как основание для заполнения.
//   ТекстЗаполнения - Строка
//                   - Неопределено
//   СтандартнаяОбработка - Булево - признак выполнения стандартной обработки события.
//
Процедура ОбработкаЗаполненияСправочники(Источник, ДанныеЗаполнения, ТекстЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ОбработкаЗаполненияСправочники(Источник, ДанныеЗаполнения, ТекстЗаполнения, СтандартнаяОбработка) 
```
</details>

## ОписаниеВебСервисов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание веб-сервиса 1С:Документооборота.
//
// Возвращаемое значение:
//   Строка
//
Функция ОписаниеВебСервисов() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ОписаниеВебСервисов() 
```
</details>

## ПередЗаписьюНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает в дополнительные свойства идентификатор объекта-основания. Вызывается перед записью объекта.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма записываемого объекта.
//   Объект - ДокументОбъект, СправочникОбъект - записываемый объект.
//   ПараметрыЗаписи - Структура - структура, содержащая параметры записи.
//
Процедура ПередЗаписьюНаСервере(Форма, Объект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПередЗаписьюНаСервере(Форма, Объект, ПараметрыЗаписи) 
```
</details>

## ПоддерживаетсяАутентификацияОС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность использования аутентификации ОС платформой 1С:Предприятия.
// Возвращает Истина для версий 8.3.7 и старше под MS Windows, и Ложь в остальных случаях.
//
// Возвращаемое значение:
//   Булево
//
Функция ПоддерживаетсяАутентификацияОС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПоддерживаетсяАутентификацияОС() 
```
</details>

## ПодходящийТип
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает подходящий тип потребителя для объекта XDTO.
//
// Параметры:
//   ТипыКандидаты - Массив из Тип - массив типов, из которых требуется выбрать подходящий.
//   ЗначениеСвойстваXDTO - ОбъектXDTO - значение свойства объекта XDTO, в соответствии с типом которого
//     нужно выбрать подходящий тип.
//   ТипТекущегоЗначения - Тип - если реквизит объекта ИС имеет составной тип, и в нем уже установлено какое-то
//     определенное значение, тип текущего значения будет более приоритетным при выборе подходящего типа.
//
// Возвращаемое значение:
//   Тип - один из элементов массива ТипыКандидаты, подходящий для типа объекта XDTO.
//
Функция ПодходящийТип(ТипыКандидаты, ЗначениеСвойстваXDTO = Неопределено, ТипТекущегоЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПодходящийТип(ТипыКандидаты, ЗначениеСвойстваXDTO, ТипТекущегоЗначения);
```
</details>

## ПолучитьНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки базы Документооборота.
//
// Возвращаемое значение:
//   ФиксированнаяСтруктура:
//     * НужноИзвлечьТекст - Булево
//     * ИспользоватьЭлектронныеЦифровыеПодписи - Булево
//     * ДобавлятьРаботуВЕжедневныйОтчетПриВыполненииЗадачи - Булево
//     * ФактическийИсполнительЗадач - Строка - объект XDTO типа DMActualTasksPerformer.
//     * ВестиУчетСканКопийОригиналовДокументов - Булево
//     * ПоказыватьЗанятыеФайлыПриЗавершенииРаботы - Булево
//     * ИспользоватьАвтозаполнениеФайлов - Булево
//     * ИзменятьЗаданияЗаднимЧислом - Булево
//     * СписокИсполнителейЗадач - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//     * ЗаголовокСообщенияВОбластиПредпросмотра - Строка
//     * СписокРасширенийСканКопийОригиналов - Строка
//     * ДоступныЗадачиМне - Булево
//
Функция ПолучитьНастройки() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьНастройки() 
```
</details>

## ПолучитьНастройкиЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для получения настроек базы Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMGetSettingsRequest.
//
Функция ПолучитьНастройкиЗапрос(Прокси) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьНастройкиЗапрос(Прокси) 
```
</details>

## ПолучитьНовыйОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает заполненный по-умолчанию объект из Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Тип - Строка - имя типа XDTO объекта.
//   Предмет - Структура - Используется для получения бизнес-процессов:
//     * ID - Строка - уникальный идентификатор объекта в Документооборот.
//     * type - Строка - имя типа XDTO.
//   Колонки - Массив из Строка - необязательно, состав заполняемых колонок.
//           - Строка - если список колонок разделен через запятую.
//   ВидДокументаДОID - Строка - идентификатор вида документа, если требуется получить новый документ данного вида.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMGetNewObjectResponse.
//
Функция ПолучитьНовыйОбъект(Прокси, Тип, Предмет = Неопределено, Колонки = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьНовыйОбъект(Прокси, Тип, Предмет, Колонки, );
```
</details>

## ПолучитьНовыйОбъектЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для получения заполненного по-умолчанию объекта из Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Тип - Строка - имя типа XDTO объекта.
//   Колонки - Массив из Строка - необязательно, состав заполняемых колонок.
//           - Строка - если список колонок разделен через запятую.
//   ВидДокументаДОID - Строка - идентификатор вида документа, если требуется получить новый документ данного вида.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMGetNewObjectRequest.
//
Функция ПолучитьНовыйОбъектЗапрос(Прокси, Тип, Колонки = Неопределено, ВидДокументаДОID = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьНовыйОбъектЗапрос(Прокси, Тип, Колонки, ВидДокументаДОID);
```
</details>

## ПолучитьОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает объект из Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Тип - Строка - имя типа XDTO.
//   ID - Строка - уникальный идентификатор объекта в Документообороте.
//   Колонки - Массив из Строка - необязательно, состав заполняемых колонок.
//           - Строка - если список колонок разделен через запятую.
//   ПравилоИнтеграции - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом3 - правило интеграции для
//     заполнения объекта ИС.
//   ВнешнийОбъектИС - ЛюбаяСсылка - передается для заполнения свойства externalObject.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO заданного типа.
//
Функция ПолучитьОбъект(Прокси, Тип, ID, Колонки = Неопределено, ПравилоИнтеграции = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьОбъект(Прокси, Тип, ID, Колонки, ПравилоИнтеграции, );
```
</details>

## ПолучитьОбъекты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает объекты из Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объекты - Массив из Структура:
//     * ID - Строка
//     * Тип - Строка
//     * ВнешнийОбъектИС - ЛюбаяСсылка - передается для заполнения свойства externalObject.
//   Колонки - Массив из Строка - необязательно, состав заполняемых колонок.
//           - Строка - если список колонок разделен через запятую.
//   ПравилоИнтеграции - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом3 - правило интеграции для
//     заполнения объекта ИС.
//
// Возвращаемое значение:
//   СписокXDTO - список объектов XDTO заданного типа.
//
Функция ПолучитьОбъекты(Прокси, Объекты, Колонки = Неопределено, ПравилоИнтеграции = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьОбъекты(Прокси, Объекты, Колонки, ПравилоИнтеграции);
```
</details>

## ПолучитьОбъектыЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для получения объектов из Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объекты - Массив из Структура:
//     * ID - Строка
//     * Тип - Строка
//     * ВнешнийОбъектИС - ЛюбаяСсылка - передается для заполнения свойства externalObject.
//   Колонки - Массив из Строка - необязательно, состав заполняемых колонок.
//           - Строка - если список колонок разделен через запятую.
//   ПравилоИнтеграции - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом3 - правило интеграции для
//     заполнения объекта ИС.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMRetrieveRequest.
//
Функция ПолучитьОбъектыЗапрос(Прокси, Объекты, Колонки = Неопределено, ПравилоИнтеграции = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьОбъектыЗапрос(Прокси, Объекты, Колонки, ПравилоИнтеграции);
```
</details>

## ПолучитьПрокси
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает прокси веб-сервиса Документооборота с настройками авторизации из параметров сеанса или, если это
// невозможно, например, при создании прокси в фоновом задании, с настройками, переданными напрямую.
//
// Параметры:
//   ВызыватьИсключение - Булево - Истина, если при невозможности получения следует вызвать исключение.
//   ИмяПользователя - Строка - имя пользователя ДО, или
//                   - Неопределено - признак необходимости получить имя, сохраненное в параметрах сеанса.
//   Пароль - Строка - пароль пользователя ДО, или
//          - Неопределено - признак необходимости получить пароль, сохраненное в параметрах сеанса.
//   АдресВебСервисаДокументооборота - Строка - адрес веб-сервиса ДО, или
//                                   - Неопределено - признак необходимости использовать ранее сохраненный адрес.
//   ИспользуетсяАутентификацияОС - Булево - неявно возвращаемое значение,
//     признак необходимости использовать аутентификацию ОС (8.3.7 и выше).
//   ИспользуетсяАутентификацияJWT - Булево - неявно возвращаемое значение,
//     признак необходимости использовать аутентификацию через JWT-токены (8.3.21 и выше).
//   ТекстСообщенияОбОшибке - Строка - неявно возвращаемое значение, текст сообщения об ошибке.
//   ПользовательЗаданияОбмена - Булево - вызов выполняется для настройки пользователя задания обмена.
//     Параметры сеанса текущего пользователя изменяться не будут.
//
// Возвращаемое значение:
//   WSПрокси - прокси веб-сервиса Документооборота.
//   Неопределено - в случае, если прокси веб-сервиса получить не удалось.
//
Функция ПолучитьПрокси(ВызыватьИсключение = Истина, ИмяПользователя = Неопределено, Пароль = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьПрокси(ВызыватьИсключение, ИмяПользователя, Пароль, );
```
</details>

## ПолучитьРеквизитыОбъектаИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реквизиты объекта потребителя указанного типа.
//
// Параметры:
//   ТипОбъектаИС - Строка - полное имя метаданных объекта.
//   ДляВыражения - Булево - возвращает список реквизитов для составления выражения на встроенном языке.
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//     * Имя - Строка
//     * Представление - Строка
//     * Тип - ОписаниеТипов
//     * ЭтоТаблица - Булево
//     * Таблица - Строка
//     * ТаблицаДляСортировки - Строка
//     * ЭтоДополнительныйРеквизитИС - Булево
//     * ДополнительныйРеквизитИС - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения
//     * СвязиПараметровВыбора - Массив из Структура:
//         ** Имя - Строка
//         ** ПутьКДанным - Строка
//     * Порядок - Число
//
Функция ПолучитьРеквизитыОбъектаИС(ТипОбъектаИС, ДляВыражения = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучитьРеквизитыОбъектаИС(ТипОбъектаИС, ДляВыражения);
```
</details>

## ПользователюРазрешеноИспользованиеИнтеграции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность интеграции для текущего пользователя. Может переопределяться
// при отказе от использования поставляемой роли ИспользованиеИнтеграцииС1СДокументооборотом.
//
// Возвращаемое значение:
//   Булево - Истина, если использование интеграции разрешено.
//
Функция ПользователюРазрешеноИспользованиеИнтеграции() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПользователюРазрешеноИспользованиеИнтеграции() 
```
</details>

## ПометитьНаУдалениеСнятьПометкуОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает объект на удаление или снимает пометку.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ID - Строка - идентификатор помечаемого на удаление объекта в Документообороте.
//   Тип - Строка - имя типа XDTO помечаемого на удаление объекта.
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMDeleteResponse.
//
Функция ПометитьНаУдалениеСнятьПометкуОбъекта(Прокси, ID, Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПометитьНаУдалениеСнятьПометкуОбъекта(Прокси, ID, Тип) 
```
</details>

## ПометитьНаУдалениеСнятьПометкуОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает объекты на удаление или снимает пометку.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объекты - Массив из Структура:
//     * ID - Строка
//     * Тип - Строка
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMDeleteResponse.
//
Функция ПометитьНаУдалениеСнятьПометкуОбъектов(Прокси, Объекты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПометитьНаУдалениеСнятьПометкуОбъектов(Прокси, Объекты) 
```
</details>

## ПометитьНаУдалениеСнятьПометкуОбъектовЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для пометки объектов на удаление или для снятия пометки.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объекты - Массив из Структура:
//     * ID - Строка
//     * Тип - Строка
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMDeleteRequest.
//
Функция ПометитьНаУдалениеСнятьПометкуОбъектовЗапрос(Прокси, Объекты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПометитьНаУдалениеСнятьПометкуОбъектовЗапрос(Прокси, Объекты) 
```
</details>

## ПравилоЗаполненияИзРеквизитаОбъектаДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей правило заполнения из реквизита объекта ДО.
//
// Параметры:
//   Имя - Строка - имя реквизита объекта XDTO.
//   Представление - Строка - представление реквизита объекта ДО.
//   Обновлять - Булево - требуется ли обновлять реквизит объекта ИС из реквизита объекта ДО.
//
// Возвращаемое значение:
//  Структура:
//     * Имя - Строка
//     * Представление - Строка
//     * Обновлять - Булево
//
Функция ПравилоЗаполненияИзРеквизитаОбъектаДО(Имя, Представление = "", Обновлять = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПравилоЗаполненияИзРеквизитаОбъектаДО(Имя, Представление, Обновлять);
```
</details>

## ПредельноеКоличествоВыбираемыхОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает предельное количество объектов, выбираемых сервисом при получении списков.
//
// Параметры:
//   Тип - Строка - тип объекта XDTO
//
// Возвращаемое значение:
//   Число - предельное количество элементов, выбираемых за раз
//
Функция ПредельноеКоличествоВыбираемыхОбъектов(Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПредельноеКоличествоВыбираемыхОбъектов(Тип) 
```
</details>

## ПредопределенноеЗначениеДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запрашивает ссылку на предопределенный объект Документооборота по заданному имени и типу.
//
// Параметры:
//   ТипОбъекта - Строка - Имя класса XDTO, предопределенный объект которого требуется получить.
//   ИмяПредопределенногоЭлемента - Строка - Имя предопределенного элемента.
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMObject.
//
Функция ПредопределенноеЗначениеДО(ТипОбъекта, ИмяПредопределенногоЭлемента) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПредопределенноеЗначениеДО(ТипОбъекта, ИмяПредопределенногоЭлемента) 
```
</details>

## ПредставлениеТипаОбъектаXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление типа объекта XDTO Документооборота по имени типа.
//
// Параметры:
//   ТипXDTO - Строка - имя типа объекта XDTO.
//
// Возвращаемое значение:
//   Строка - представление типа объекта XDTO Документооборота по имени типа.
//
Функция ПредставлениеТипаОбъектаXDTO(ТипXDTO) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПредставлениеТипаОбъектаXDTO(ТипXDTO) 
```
</details>

## ПриЗаписиКонстанты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при записи констант подсистемы Интеграция с 1С:Документооборотом.
//
// Параметры:
//   Источник - КонстантаМенеджерЗначения - записываемая константа.
//   Отказ - Булево - флаг отказа от выполнения записи.
//
Процедура ПриЗаписиКонстанты(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриЗаписиКонстанты(Источник, Отказ) 
```
</details>

## ПриОпределенииЗначенияРеквизитаПоОбъектуXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при заполнении реквизита объекта ИС по значению реквизита объекта ДО.
//
// Параметры:
//   Результат - Произвольный - заполняемое значение реквизита объекта ИС.
//   ЗначениеЗаполнения - ОбъектXDTO - исходный объект, соответствие которому нужно найти.
//                      - Структура - структура со свойствами:
//     * ТипXDTOОбъекта - Строка - тип XDTO объекта, из значения свойства которого выполняется заполнение.
//     * ИмяСвойства - Строка - имя свойства, из значения свойства которого выполняется заполнение.
//     * ЗначениеСвойства - Произвольный - значение заполнения, соответствие которому нужно найти.
//   ТипРеквизита - Тип - тип заполняемого реквизита объекта ИС.
//   ИмяРеквизита - Строка - имя заполняемого реквизита ИС.
//   ТипОбъекта - Тип - тип заполняемого объекта ИС.
//   Объект - Произвольный - заполняемый объект ИС.
//   ЭтоДополнительноеСвойство - Булево - истина, если переданный объект является доп. свойством.
//   Свойство - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения - свойство-владелец.
//   ПараметрыВыбора - Соответствие из КлючИЗначение - параметры выбора:
//     * Ключ - Строка - имя параметра вида "Отбор.Владелец".
//     * Значение - Произвольный - значение параметра (отбора).
//
Процедура ПриОпределенииЗначенияРеквизитаПоОбъектуXDTO(Результат, ЗначениеЗаполнения, ТипРеквизита, ИмяРеквизита, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриОпределенииЗначенияРеквизитаПоОбъектуXDTO(Результат, ЗначениеЗаполнения, ТипРеквизита, ИмяРеквизита, );
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команды Документооборота на форму объекта при создании на сервере.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма, из которой вызвана процедура.
//   МестоРазмещенияКоманд - ГруппаФормы - место для размещения, по умолчанию - командная панель формы.
//   ПараметрыОповещения - Структура - параметры, где может быть установлен источник команды.
//   Ссылка - ЛюбаяСсылка - ссылка на объект ИС, являющийся основным объектом формы.
//
Процедура ПриСозданииНаСервере(Форма, МестоРазмещенияКоманд = Неопределено, ПараметрыОповещения = Неопределено, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриСозданииНаСервере(Форма, МестоРазмещенияКоманд, ПараметрыОповещения, );
```
</details>

## ПриСозданииНаСервереФормРазмещаемыхНаРабочемСтоле
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании форм интеграции, размещаемых на рабочем столе.
// Позволяет отказаться от их создания при работе в неразделенном сеансе или при выполнении обновления ИБ.
//
// Параметры:
//   Отказ - Булево - отказ от создания.
//
Процедура ПриСозданииНаСервереФормРазмещаемыхНаРабочемСтоле(Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриСозданииНаСервереФормРазмещаемыхНаРабочемСтоле(Отказ) 
```
</details>

## ПриложениеЯвляетсяВебКлиентом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истину, если клиентское приложение является веб клиентом, иначе Ложь.
//
// Возвращаемое значение:
//   Булево
//
Функция ПриложениеЯвляетсяВебКлиентом() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриложениеЯвляетсяВебКлиентом() 
```
</details>

## ПроверитьВозвратВебСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возврат WEB-сервиса. В случае возврата объекта типа DMError вызывает исключение.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Ответ - ОбъектXDTO - проверяемый результат вызова сервиса.
//
Процедура ПроверитьВозвратВебСервиса(Прокси, Ответ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПроверитьВозвратВебСервиса(Прокси, Ответ) 
```
</details>

## ПроверитьТип
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет тип объекта XDTO.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - проверяемый объект
//   Тип - Строка - имя типа для проверки
//
// Возвращаемое значение:
//   Булево - Истина если объект является объектом указанного типа и Ложь в противном случае.
//
Функция ПроверитьТип(Прокси, ОбъектXDTO, Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПроверитьТип(Прокси, ОбъектXDTO, Тип) 
```
</details>

## СвойствоСуществует
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет существует ли свойство в объекте XDTO.
//
// Параметры:
//   ОбъектXDTO - ОбъектXDTO - исходный объект, свойство которого нужно проверить.
//   ИмяСвойства - Строка - имя свойства.
//   ВызыватьИсключение - Булево - вызывать исключение в случае, если не существует свойства с указанным именем.
//
// Возвращаемое значение:
//   Булево - свойство существует.
//
Функция СвойствоСуществует(ОбъектXDTO, ИмяСвойства, ВызыватьИсключение = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СвойствоСуществует(ОбъектXDTO, ИмяСвойства, ВызыватьИсключение);
```
</details>

## СвойствоУстановлено
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет было ли установлено свойство в объекте XDTO.
//
// Параметры:
//   ОбъектXDTO - ОбъектXDTO - исходный объект, свойство которого нужно проверить.
//   ИмяСвойства - Строка - имя свойства.
//
// Возвращаемое значение:
//   Булево - свойство установлено.
//
Функция СвойствоУстановлено(ОбъектXDTO, ИмяСвойства) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СвойствоУстановлено(ОбъектXDTO, ИмяСвойства) 
```
</details>

## СерверРаботаетПодWindows
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина, если сервер работает под Windows, и Ложь в противном случае.
//
// Возвращаемое значение:
//   Булево
//
Функция СерверРаботаетПодWindows() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СерверРаботаетПодWindows() 
```
</details>

## СогласованВ1СДокументооборот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак состояния "Согласован" по данным документооборота.
//
// Параметры:
//   СсылкаНаОбъект - ЛюбаяСсылка - ссылка на объект ИС.
//
// Возвращаемое значение:
//   Булево - состояние согласования в ДО.
//
Функция СогласованВ1СДокументооборот(СсылкаНаОбъект) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СогласованВ1СДокументооборот(СсылкаНаОбъект) 
```
</details>

## СоздатьDMLink
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект DMLink.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ИдентификаторОбъектаДО - Строка - идентификатор объекта ДО.
//   ТипОбъектаДО - Строка - тип объекта XDTO.
//   ОбъектИС - ЛюбаяСсылка - ссылка на объект ИС.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMLink.
//
Функция СоздатьDMLink(Прокси, ИдентификаторОбъектаДО = "", ТипОбъектаДО = "", ОбъектИС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьDMLink(Прокси, ИдентификаторОбъектаДО, ТипОбъектаДО, ОбъектИС);
```
</details>

## СоздатьExternalObject
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект ExternalObject.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ВнешнийОбъектИС - ЛюбаяСсылка - ссылка на внешний объект ИС.
//   ID - Строка - идентификатор внешнего объекта ИС.
//   Тип - Строка - тип внешнего объекта ИС.
//   Наименование - Строка - наименование внешнего объекта ИС.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа ExternalObject.
//
Функция СоздатьExternalObject(Прокси, ВнешнийОбъектИС = Неопределено, ID = "", Тип = "", Наименование = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьExternalObject(Прокси, ВнешнийОбъектИС, ID, Тип, Наименование);
```
</details>

## СоздатьExternalObjectID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект ExternalObjectID.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ВнешнийОбъектИС - ЛюбаяСсылка - ссылка на внешний объект ИС.
//   ID - Строка - идентификатор внешнего объекта ИС.
//   Тип - Строка - тип внешнего объекта ИС.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа ExternalObjectID.
//
Функция СоздатьExternalObjectID(Прокси, ВнешнийОбъектИС = Неопределено, ID = "", Тип = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьExternalObjectID(Прокси, ВнешнийОбъектИС, ID, Тип);
```
</details>

## СоздатьObjectID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект DMObjectID.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ID - Строка - идентификатор объекта XDTO.
//   Тип - Строка - тип объекта XDTO.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMObjectID.
//
Функция СоздатьObjectID(Прокси, ID = "", Тип = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьObjectID(Прокси, ID, Тип);
```
</details>

## СоздатьИзДанныхСсылочногоОбъектаДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект XDTO из структуры данных ссылочного объекта ДО.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ДанныеСсылочногоОбъектаДО - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO, наследуемый от типа DMObject.
//
Функция СоздатьИзДанныхСсылочногоОбъектаДО(Прокси, ДанныеСсылочногоОбъектаДО) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьИзДанныхСсылочногоОбъектаДО(Прокси, ДанныеСсылочногоОбъектаДО) 
```
</details>

## СоздатьНовыйОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новый объект в Документообороте.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Объект - ОбъектXDTO - описание создаваемого объекта.
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO типа DMCreateResponse или DMError.
//
Функция СоздатьНовыйОбъект(Прокси, Объект) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьНовыйОбъект(Прокси, Объект) 
```
</details>

## СоздатьОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает XDTO объект указанного типа из пространства имен веб-сервиса Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ТипОбъекта - Строка - тип объекта XDTO.
//   ВнешнийОбъектИС - ЛюбаяСсылка - передается для заполнения свойств name и externalObject.
//   ЗаполнитьИзВнешнегоОбъекта - Булево - требуется заполнить объект XDTO из внешнего объекта ИС.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO указанного типа.
//
Функция СоздатьОбъект(Прокси, ТипОбъекта, ВнешнийОбъектИС = Неопределено, ЗаполнитьИзВнешнегоОбъекта = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьОбъект(Прокси, ТипОбъекта, ВнешнийОбъектИС, ЗаполнитьИзВнешнегоОбъекта);
```
</details>

## СоздатьОбъектXDTOДляСохраненияПодписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает XDTO объект для передачи массива подписей в Документооборот.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ДанныеВладельцаПодписи - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеВладельцаПодписи
//
// Возвращаемое значение:
//   ОбъектXDTO - Объект XDTO с заполненным свойством signatures.
//
Функция СоздатьОбъектXDTOДляСохраненияПодписей(Прокси, ДанныеВладельцаПодписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьОбъектXDTOДляСохраненияПодписей(Прокси, ДанныеВладельцаПодписи) 
```
</details>

## СокращенноеНаименованиеКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сокращенное наименование интегрируемой конфигурации для вывода в заголовках и декорациях.
//
// Возвращаемое значение:
//   Строка - сокращенное наименование конфигурации.
//
Функция СокращенноеНаименованиеКонфигурации() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СокращенноеНаименованиеКонфигурации() 
```
</details>

## СсылкаИзUUID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает ссылку на объект по имени объекта конфигурации и ID.
//
// Параметры:
//   Тип - Строка - тип объекта конфигурации.
//   UUID - Строка - идентификатор объекта конфигурации.
//
// Возвращаемое значение:
//   ЛюбаяСсылка - ссылка на объект.
//
Функция СсылкаИзUUID(Тип, UUID) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СсылкаИзUUID(Тип, UUID) 
```
</details>

## СсылкиПоВнешнимОбъектам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылки на объекты этой конфигурации по информации о них в объекте ДО.
//
// Параметры:
//   ОбъектXDTO - ОбъектXDTO - потомок DMObject, объект ДО.
//              - Структура - содержит идентификатор и тип внешнего объекта:
//     * ID - Строка - идентификатор внешнего объекта по данным 1С:Документооборота;
//     * type - Строка - тип внешнего объекта по данным 1С:Документооборота.
//
// Возвращаемое значение:
//   Массив из ЛюбаяСсылка - массив ссылок на связанные объекты этой конфигурации.
//
Функция СсылкиПоВнешнимОбъектам(ОбъектXDTO) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СсылкиПоВнешнимОбъектам(ОбъектXDTO) 
```
</details>

## ТаймаутСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таймаут прокси веб-сервиса Документооборота, возможно, переопределенный в настройках.
//
// Возвращаемое значение:
//   Число - таймаут в секундах.
//
Функция ТаймаутСервиса() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ТаймаутСервиса() 
```
</details>

## ТекущийПользовательДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает текущего пользователя 1С:Документооборота.
//
// Возвращаемое значение:
//   Массив из ОбъектXDTO - Объект XDTO типа DMUser, DMEmployee или Неопределено.
//
Функция ТекущийПользовательДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ТекущийПользовательДокументооборота() 
```
</details>

## ТекущийПользовательДокументооборотаЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для получения текущего пользователя 1С:Документооборота.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMGetCurrentUserRequest.
//
Функция ТекущийПользовательДокументооборотаЗапрос(Прокси) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ТекущийПользовательДокументооборотаЗапрос(Прокси) 
```
</details>

## УстановитьВерсиюСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает версию сервиса в параметрах сеанса.
//
// Параметры:
//   ИзФоновогоЗадания - Булево - процедура запускается из фонового задания.
//   ТекстОшибки - Строка - неявно возвращаемое значение, текст сообщения об ошибке,
//     полученный при определении версии сервиса.
//
Процедура УстановитьВерсиюСервиса(ИзФоновогоЗадания = Ложь, ТекстОшибки = "") Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.УстановитьВерсиюСервиса(ИзФоновогоЗадания, ТекстОшибки);
```
</details>

## УстановитьПараметрыСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметры сеанса работы с подсистемой "Интеграция с 1С:Документооборотом".
//
// Параметры:
//   ИмяПараметра - Строка
//   УстановленныеПараметры - Массив из Строка
//
Процедура УстановитьПараметрыСеанса(ИмяПараметра, УстановленныеПараметры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.УстановитьПараметрыСеанса(ИмяПараметра, УстановленныеПараметры) 
```
</details>

## УстановитьПараметрыСеансаПоМассивуИмен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметры сеанса по массиву имен.
//
// Параметры:
//   ИменаПараметров - Массив из Строка - массив строк с именами параметров сеанса к установке.
//
Процедура УстановитьПараметрыСеансаПоМассивуИмен(ИменаПараметров) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.УстановитьПараметрыСеансаПоМассивуИмен(ИменаПараметров) 
```
</details>

## УстановитьШтрихкод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в связанный документ в ДО штрихкод по объекту ИС.
//
// Параметры:
//   ОбъектИС - ЛюбаяСсылка - объект ИС, источник данных заполнения.
//   ID - Строка - идентификатор объекта Документооборота.
//   Тип - Строка - XDTO-тип объекта Документооборота
//
Процедура УстановитьШтрихкод(ОбъектИС, ID, Тип) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.УстановитьШтрихкод(ОбъектИС, ID, Тип) 
```
</details>

## ЭтоОбъектноеЗначение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли значение объектным, т.е. наследуется от типа DMObject.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Значение - Произвольный - проверяемое значение.
//
// Возвращаемое значение:
//   Булево - Истина, в случае, если значение является потомком типа DMObject, иначе Ложь.
//
Функция ЭтоОбъектноеЗначение(Прокси, Значение) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЭтоОбъектноеЗначение(Прокси, Значение) 
```
</details>

## ЭтоОбъектноеСвойство
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли свойство объектным, т.е. наследуется от типа DMObject.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - объект, содержащий проверяемое свойство
//   ИмяСвойстваXDTO - Строка - имя проверяемого свойства
//
// Возвращаемое значение:
//   Булево - Истина, в случае, если свойство является потомком типа DMObject, иначе Ложь
//
Функция ЭтоОбъектноеСвойство(Прокси, ОбъектXDTO, ИмяСвойстваXDTO) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЭтоОбъектноеСвойство(Прокси, ОбъектXDTO, ИмяСвойстваXDTO) 
```
</details>

## ДанныеФайловОбъектаИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные хранящихся на стороне ДО файлов.
//
// Параметры:
//   Источник - ЛюбаяСсылка - ссылка на исходный объект ИС.
//   ИдентификаторФормы - УникальныйИдентификатор - идентификатор форма-владельца хранилища.
//   СписокРасширений - Строка - список расширений файлов, которые требуется получать из ДО через запятую.
//
// Возвращаемое значение:
//   Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеФайла
//
Функция ДанныеФайловОбъектаИС(Источник, ИдентификаторФормы, Знач СписокРасширений = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДанныеФайловОбъектаИС(Источник, ИдентификаторФормы, СписокРасширений);
```
</details>

## ДобавитьКомандуПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду печати в таблицу печатных форм объекта.
//
// Параметры:
//   ПечатныеФормы - ТаблицаЗначений:
//     * МенеджерПечати - Строка - имя объекта, в модуле менеджера которого располагается
//                                 процедура Печать, формирующая табличные документы для этой команды.
//     * ИмяКоманды - Строка
//     * ПредставлениеКоманды - Строка
//     * ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//   КомандаПечати - см. УправлениеПечатью.КомандыПечатиФормы
//
Процедура ДобавитьКомандуПечати(ПечатныеФормы, КомандаПечати) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьКомандуПечати(ПечатныеФормы, КомандаПечати) 
```
</details>

## ЗаполнитьКоллекциюПечатныхФорм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет коллекцию печатных форм объекта по имени менеджера печати и команде менеджера печати.
//
// Параметры:
//   ВнешнийОбъект - ЛюбаяСсылка - внешний объект.
//   ИмяКоманды - Строка - имя команды.
//   ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//   КоллекцияПечатныхФорм - ТаблицаЗначений - неявно возвращаемое значение.
//
Процедура ЗаполнитьКоллекциюПечатныхФорм(ВнешнийОбъект, ИмяКоманды, ДополнительныеПараметры, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьКоллекциюПечатныхФорм(ВнешнийОбъект, ИмяКоманды, ДополнительныеПараметры, );
```
</details>

## ЗаполнитьТаблицуМенеджеровПечатиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает таблицу менеджеров печати форм объектов.
//
// Параметры:
//   МенеджерОбъекта - Строка - полное имя метаданных менеджера объекта.
//   ПечатныеФормы - ТаблицаЗначений:
//     * МенеджерПечати - Строка - имя объекта, в модуле менеджера которого располагается
//                                 процедура Печать, формирующая табличные документы для этой команды.
//     * ИмяКоманды - Строка
//     * ПредставлениеКоманды - Строка
//     * ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//
Процедура ЗаполнитьТаблицуМенеджеровПечатиОбъекта(МенеджерОбъекта, ПечатныеФормы) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьТаблицуМенеджеровПечатиОбъекта(МенеджерОбъекта, ПечатныеФормы) 
```
</details>

## ИмяПечатнойФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует имя файла печатной формы объекта ИС для помещения в ДО.
//
// Параметры:
//   Источник - ЛюбаяСсылка - ссылка на исходный объект ИС.
//   ПредставлениеКоманды - Строка - синоним команды печати.
//   СинонимМакета - Строка - синоним макета печатной формы.
//   ИмяМакета - Строка - имя макета печатной формы.
//
// Возвращаемое значение:
//   Строка
//
Функция ИмяПечатнойФормы(Источник, ПредставлениеКоманды, СинонимМакета, ИмяМакета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИмяПечатнойФормы(Источник, ПредставлениеКоманды, СинонимМакета, ИмяМакета) 
```
</details>

## ИндексПиктограммыФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получается индекс пиктограммы файла - индекс в картинке КоллекцияПиктограммФайлов.
//
// Параметры:
//   Расширение - Строка - расширение файла.
//   ПометкаУдаления - Булево - файл помечен на удаление.
//
// Возвращаемое значение:
//   Число
//
Функция ИндексПиктограммыФайла(Расширение, ПометкаУдаления = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИндексПиктограммыФайла(Расширение, ПометкаУдаления);
```
</details>

## КоличествоФайловСвязанногоОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает количество прикрепленных файлов к связанному объекту 1С:Документооборот.
//
// Параметры:
//   ID - Строка - идентификатор объекта Документооборота.
//   Тип - Строка - XDTO-тип объекта Документооборота.
//   ВключаяУдаленные - Булево - учитывать ли помеченные на удаление файлы.
//
// Возвращаемое значение:
//   Число - количество прикрепленных файлов.
//
Функция КоличествоФайловСвязанногоОбъекта(ID, Тип, ВключаяУдаленные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.КоличествоФайловСвязанногоОбъекта(ID, Тип, ВключаяУдаленные);
```
</details>

## КомандыПечатиФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает команды печати формы.
//
// Параметры:
//   ИмяФормы - Строка - имя формы объекта.
//
// Возвращаемое значение:
//   см. УправлениеПечатью.КомандыПечатиФормы
//
Функция КомандыПечатиФормы(ИмяФормы) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.КомандыПечатиФормы(ИмяФормы) 
```
</details>

## КонтрольОтправкиФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор таблицы, кэширующей значения для последующего внесения в регистр
// сведений КонтрольОтправкиФайловВ1СДокументооборот.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//     * Источник - ЛюбаяСсылка - ссылка на исходный объект ИС.
//     * ИмяФайла - Строка - имя печатной формы.
//     * ТабличныйДокумент - ТабличныйДокумент - сформированная печатная форма.
//
Функция КонтрольОтправкиФайлов() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.КонтрольОтправкиФайлов() 
```
</details>

## МенеджерыПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений с информацией о менеджерах печати объекта.
//
// Параметры:
//   МенеджерОбъекта - Строка - полное имя метаданных менеджера объекта.
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//     * ИмяКоманды - Строка - имя команды менеджера печати.
//     * МенеджерПечати - Строка - имя объекта, в модуле менеджера которого располагается
//         процедура Печать, формирующая табличные документы для этой команды.
//     * ПредставлениеКоманды - Строка - представление команды печати для отображения на формах.
//     * ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//
Функция МенеджерыПечати(МенеджерОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.МенеджерыПечати(МенеджерОбъекта) 
```
</details>

## ПечатныеФормыКСозданию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует параметры создания файлов объекта ДО из печатных форм объекта ИС.
//
// Параметры:
//   Источник - ЛюбаяСсылка - ссылка на исходный объект ИС.
//   ПрисоединяемыеПечатныеФормы - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПрисоединяемыеПечатныеФормы
//   ТипФайловСохраненияПечатныхФорм - ПеречислениеСсылка.ТипыФайловСохраненияПечатныхФормОбъектов - тип файла,
//     в котором сохраняется печатная форма.
//   КонтрольОтправкиФайлов - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.КонтрольОтправкиФайлов
//   ТолькоОбновление - Булево - Истина, если выполняется только обновление существующих форм.
//   ИдентификаторФормы - УникальныйИдентификатор - идентификатор форма-владельца хранилища.
//
// Возвращаемое значение:
//   Массив Из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.НовыеПараметрыСозданияФайла
//
Функция ПечатныеФормыКСозданию(Источник, ПрисоединяемыеПечатныеФормы, ТипФайловСохраненияПечатныхФорм, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПечатныеФормыКСозданию(Источник, ПрисоединяемыеПечатныеФормы, ТипФайловСохраненияПечатныхФорм, );
```
</details>

## ПриОпределенииНаличияПрисоединенныхФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при определении наличия файлов, хранимых в интегрируемой конфигурации.
//
// Параметры:
//   ВладелецФайлов - Произвольный - объект-владелец.
//   ЕстьФайлы - Булево, Неопределено - неявно возвращаемое значение, признак наличия присоединенных файлов.
//
Процедура ПриОпределенииНаличияПрисоединенныхФайлов(ВладелецФайлов, ЕстьФайлы) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриОпределенииНаличияПрисоединенныхФайлов(ВладелецФайлов, ЕстьФайлы) 
```
</details>

## ПрисоединенныеФайлыВИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список присоединенных файлов, хранимых в ИС.
//
// Параметры:
//   ВладелецФайлов - Произвольный - объект-владелец.
//
// Возвращаемое значение:
//   Массив из ЛюбаяСсылка - список ссылок на прикрепленные файлы.
//
Функция ПрисоединенныеФайлыВИС(ВладелецФайлов) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПрисоединенныеФайлыВИС(ВладелецФайлов) 
```
</details>

## ПрисоединяемыеПечатныеФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор таблицы значений, описывающей присоединяемые печатные формы.
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//     * ИмяКоманды - Строка - имя команды менеджера печати.
//     * ПредставлениеКоманды - Строка - представление команды печати для отображения на формах.
//     * МенеджерПечати - Строка - имя менеджера печати, как оно задано в конфигураторе.
//     * Обновлять - Булево - обновлять значение.
//     * РольФайлаID - Строка - идентификатор роли файла печатной формы на стороне ДО.
//     * ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//
Функция ПрисоединяемыеПечатныеФормы() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПрисоединяемыеПечатныеФормы() 
```
</details>

## ПриПолученииПрисоединенныхФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении присоединенных файлов.
//
// Параметры:
//   ВладелецФайлов - Произвольный - объект-владелец.
//   ДанныеФайлов - Массив из см. РаботаСФайлами.ДанныеФайла
//
Процедура ПриПолученииПрисоединенныхФайлов(ВладелецФайлов, ДанныеФайлов) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриПолученииПрисоединенныхФайлов(ВладелецФайлов, ДанныеФайлов) 
```
</details>

## ПриПоявленииПрисоединенныхФайловДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак наличия присоединенных файлов ДО для объекта ИС. Вызывается при добавлении
// связи с объектом ДО, имеющим файлы, при добавлении файла из интерфейса ИС и при фоновом обновлении.
//
// Параметры:
//   ID - Строка - идентификатор объекта Документооборота.
//   Тип - Строка - XDTO-тип объекта Документооборота.
//   ОбъектИС - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект ИС.
//   НаличиеПрисоединенныхФайлов - Булево - Истина, если в ДО есть присоединенные файлы.
//
Процедура ПриПоявленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриПоявленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС, );
```
</details>

## ПриУдаленииПрисоединенныхФайловДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Снимает признак наличия присоединенных файлов для объекта ИС, если их нет в самой ИС. Вызывается при
// удалении связи с объектом ДО и при фоновом обновлении.
//
// Параметры:
//   ID - Строка - идентификатор объекта Документооборота.
//   Тип - Строка - XDTO-тип объекта Документооборота.
//   ОбъектИС - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - объект ИС.
//
Процедура ПриУдаленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПриУдаленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС) 
```
</details>

## РасширениеСохраняемойПечатнойФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает расширение по типу файла сохраняемой печатной формы.
//
// Параметры:
//   ТипФайла - ПеречислениеСсылка.ТипыФайловСохраненияПечатныхФормОбъектов - тип сохраняемого файла.
//
// Возвращаемое значение:
//   Строка - расширение файла.
//
Функция РасширениеСохраняемойПечатнойФормы(ТипФайла) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.РасширениеСохраняемойПечатнойФормы(ТипФайла) 
```
</details>

## СоздатьФайлЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает запрос для создания файла в Документообороте.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ФайлXDTO - ОбъектXDTO - объект XDTO типа DMFile.
//   ВладелецID - Строка - идентификатор владельца файла в Документообороте.
//   ВладелецТип - Строка - тип владельца файла в Документообороте.
//   ВладелецПредставление - Строка - представление владельца файла в Документообороте.
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMAddFileRequest.
//
Функция СоздатьФайлЗапрос(Прокси, ФайлXDTO, ВладелецID, ВладелецТип, ВладелецПредставление = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьФайлЗапрос(Прокси, ФайлXDTO, ВладелецID, ВладелецТип, ВладелецПредставление);
```
</details>

## ТипФайлаСохраняемойПечатнойФормыПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тип файла сохраняемой печатной формы по умолчанию.
//
// Возвращаемое значение:
//   ПеречислениеСсылка.ТипыФайловСохраненияПечатныхФормОбъектов - тип по умолчанию.
//
Функция ТипФайлаСохраняемойПечатнойФормыПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ТипФайлаСохраняемойПечатнойФормыПоУмолчанию() 
```
</details>

## ФайлXDTOИзПараметровСоздания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает и заполняет объект XDTO типа DMFile по данным из параметров создания.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ПараметрыСоздания - Структура - ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.НовыеПараметрыСозданияФайла
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMFile.
//
Функция ФайлXDTOИзПараметровСоздания(Прокси, ПараметрыСоздания) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ФайлXDTOИзПараметровСоздания(Прокси, ПараметрыСоздания) 
```
</details>

## ЗаполнитьПолнуюРоль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет объект XDTO, описывающий полную роль.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ПолнаяРольXDTO - ОбъектXDTO - объект XDTO типа DMCompleteRole.
//   Роль - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//   ОсновнойОбъектАдресации - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//   ДополнительныйОбъектАдресации - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//
Процедура ЗаполнитьПолнуюРоль(Прокси, ПолнаяРольXDTO, Роль, ОсновнойОбъектАдресации = Неопределено, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗаполнитьПолнуюРоль(Прокси, ПолнаяРольXDTO, Роль, ОсновнойОбъектАдресации, );
```
</details>

## УчастникЗадач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует объект XDTO, описывающий участника задачи.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   Исполнитель - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//   ОсновнойОбъектАдресации - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//   ДополнительныйОбъектАдресации - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО
//
// Возвращаемое значение:
//   ОбъектXDTO - объект XDTO типа DMTaskParticipant.
//
Функция УчастникЗадач(Прокси, Исполнитель, ОсновнойОбъектАдресации = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.УчастникЗадач(Прокси, Исполнитель, ОсновнойОбъектАдресации, );
```
</details>

## URIПространстваИменВебСервисаДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает URI пространства имен веб-сервиса 1С:Документооборот.
//
// Возвращаемое значение:
//   Строка
//
Функция URIПространстваИменВебСервисаДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.URIПространстваИменВебСервисаДокументооборота() 
```
</details>

## ИмяВебСервисаДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя веб-сервиса 1С:Документооборот.
//
// Возвращаемое значение:
//   Строка
//
Функция ИмяВебСервисаДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ИмяВебСервисаДокументооборота() 
```
</details>

## КлючСопоставленияПользователяТокенаДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ключ сопоставления пользователя, который будет передан в токена доступа.
// Ключ зависит от текущих настроек, это может быть имя пользователя ИБ или пользователь ОС.
//
// Возвращаемое значение:
//   Строка
//
Функция КлючСопоставленияПользователяТокенаДоступа() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.КлючСопоставленияПользователяТокенаДоступа() 
```
</details>

## ПараметрыТокенаДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров, необходимую для формирования токена доступа.
//
// Возвращаемое значение:
//   Структура:
//     * Эмитент - Строка
//     * ВремяСоздания - Число
//     * ВремяЖизни - Число
//     * Идентификатор - УникальныйИдентификатор
//     * Получатели - Массив из Строка
//     * КлючСопоставленияПользователя - Строка
//
Функция ПараметрыТокенаДоступа() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПараметрыТокенаДоступа() 
```
</details>

## ПолучателиТокенаДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив получателей, необходимый для формирования токена доступа.
//
// Возвращаемое значение:
//   Массив из Строка
//
Функция ПолучателиТокенаДоступа() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПолучателиТокенаДоступа() 
```
</details>

## ПсевдонимВебСервисаДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает псевдоним веб-сервиса 1С:Документооборот.
//
// Возвращаемое значение:
//   Строка
//
Функция ПсевдонимВебСервисаДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПсевдонимВебСервисаДокументооборота() 
```
</details>

## ТекстТокенаДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текстовое представление JWT-токена для авторизации в веб-сервисе Документооборота.
//
// Возвращаемое значение:
//   Строка
//
Функция ТекстТокенаДоступа() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ТекстТокенаДоступа() 
```
</details>

## ЭмитентТокенаДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает эмитента, необходимого для формирования токена доступа.
//
// Возвращаемое значение:
//   Строка
//
Функция ЭмитентТокенаДоступа() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЭмитентТокенаДоступа() 
```
</details>

## ДанныеПодписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует таблицу подписей на форме в массив структурированных данных подписей.
//
// Параметры:
//   ТаблицаПодписей - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей
//
// Возвращаемое значение:
//   Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//
Функция ДанныеПодписей(ТаблицаПодписей) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДанныеПодписей(ТаблицаПодписей) 
```
</details>

## ДанныеПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные, из которых будет формироваться XDTO объект DMSignature, для передачи в ДО.
//
// Параметры:
//   Подпись - ДвоичныеДанные - двоичные данные подписи.
//   ДвоичныеДанныеСертификата - ДвоичныеДанные - двоичные данные сертификата.
//   СвойстваПодписи - Структура - тут может быть или структура СвойстваПодписи, которую возвращает БСП при
//     добавлении новой подписи, или строка таблицы подписей, если это уже существующая на стороне ДО подпись.
//
// Возвращаемое значение:
//   см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//
Функция ДанныеПодписи(Подпись, ДвоичныеДанныеСертификата, СвойстваПодписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДанныеПодписи(Подпись, ДвоичныеДанныеСертификата, СвойстваПодписи) 
```
</details>

## ПроверитьПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет подписи из массива ВыделенныеСтроки. Если массив выделенных строк не передан - проверяет все
// подписи из таблицы подписей.
//
// Параметры:
//   МенеджерКриптографии - МенеджерКриптографии - объект Менеджера криптографии.
//   ТаблицаПодписей - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей
//   УникальныйИдентификатор - УникальныйИдентификатор - идентификатор управляемой формы объекта Документооборота.
//   ВыделенныеПодписи - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиент.ВыделенныеПодписи
//   АдресСлепкаДокумента - Строка - адрес временного хранилища двоичных данных документа Документооборота.
//
Процедура ПроверитьПодписи(МенеджерКриптографии, ТаблицаПодписей, УникальныйИдентификатор, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПроверитьПодписи(МенеджерКриптографии, ТаблицаПодписей, УникальныйИдентификатор, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
