---
title: Интеграция с 1С документооборот базовая функциональность клиент переопределяемый
slug: zup/интеграция-с-1с-документооборот-базовая-функциональность-клиент-переопределяемый
---


## ВыполнитьКомандуПечатиЛистаСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из форм согласуемых объектов. Предназначена для вывода листа согласования в случаях,
// когда добавление команды в подменю печати невозможно или нежелательно, а также для внедрения в конфигурации
// без подсистемы БСП УправлениеПечатью.
//
// Параметры:
//   ПредметСогласования - ЛюбаяСсылка - согласуемый объект.
//   ВладелецФормы - ФормаКлиентскогоПриложения - необязательный, форма-источник команды.
//
Процедура ВыполнитьКомандуПечатиЛистаСогласования(ПредметСогласования, ВладелецФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ВыполнитьКомандуПечатиЛистаСогласования(ПредметСогласования, ВладелецФормы);
```
</details>

## ВыполнитьПрограммноДобавленнуюКоманду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из форм обработки, соответствующих процессам, документам и задачам ДО. Предназначена для обработки
// команд, добавленных программно при вызове процедуры ДополнительнаяОбработкаФормы<...> переопределяемого модуля.
//
// Параметры:
//   Команда - КомандаФормы - вызванная пользователем команда.
//   ЭтаФорма - ФормаКлиентскогоПриложения - форма обработки, откуда вызвана команда.
//
Процедура ВыполнитьПрограммноДобавленнуюКоманду(Команда, ЭтаФорма) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ВыполнитьПрограммноДобавленнуюКоманду(Команда, ЭтаФорма) 
```
</details>

## ОткрытьПанельАдминистрированияБИД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед выполнением команды ОткрытьПанель обработки ПанельАдминистрированияБИД.
// Позволяет переопределить форму НастройкаИнтеграцииС1СДокументооборотом.
//
// Параметры:
//   ПараметрыВыполненияКоманды - Произвольный - Параметры выполнения команды ОткрытьПанель.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная
//     форма НастройкаИнтеграцииС1СДокументооборотом открыта не будет.
//
// Пример:
//	СтандартнаяОбработка = Ложь;
//	ОткрытьФорму(
//		"Обработка.ПанельАдминистрированияБИД.Форма.НастройкаИнтеграцииС1СДокументооборотомПереопределяемый",
//		Новый Структура,
//		ПараметрыВыполненияКоманды.Источник,
//		"Обработка.ПанельАдминистрированияБИД.Форма.НастройкаИнтеграцииС1СДокументооборотомПереопределяемый"
//			+ ?(ПараметрыВыполненияКоманды.Окно = Неопределено, ".ОтдельноеОкно", ""),
//		ПараметрыВыполненияКоманды.Окно);
//
Процедура ОткрытьПанельАдминистрированияБИД(ПараметрыВыполненияКоманды, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ОткрытьПанельАдминистрированияБИД(ПараметрыВыполненияКоманды, СтандартнаяОбработка) 
```
</details>

## ПередСозданиемБизнесПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед созданием бизнес-процесса и позволяет отказаться от запуска.
//
// Параметры:
//   Предмет - ЛюбаяСсылка - ссылка на объект интегрируемой системы, или
//           - Структура - описание объекта ДО, со свойствами:
//               ID - Строка - идентификатор;
//               type - Строка - тип;
//               name - Строка - наименование предмета.
//   Отказ - Булево - при установке в Истина процесс запущен не будет.
//
// Пример:
//	Если ТипЗнч(Предмет) = Тип("ДокументСсылка._ДемоЗаказПокупателя") Тогда
//		ТекстСообщения = "";
//		Если Не ПродажиВызовСервера.ЗаказЗаполненКорректно(Предмет, ТекстСообщения) Тогда
//			Отказ = Истина;
//			ПоказатьПредупреждение(, ТекстСообщения);
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПередСозданиемБизнесПроцесса(Предмет, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПередСозданиемБизнесПроцесса(Предмет, Отказ) 
```
</details>

## ПриИзмененииСостоянияСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при изменении состояния согласования в ДО. Предназначен для изменения формы
// согласуемого объекта, если доработка самого модуля формы нежелательна.
//
// Параметры:
//   ПредметСогласования - ЛюбаяСсылка - согласуемый объект.
//   Источник - ФормаКлиентскогоПриложения - форма-источник вызова.
//   Состояние - ПеречислениеСсылка.СостоянияСогласованияВДокументообороте.
//   ВызовИзФормыОбъекта - Булево - Истина, если изменение состояния вызвано пользователем из формы объекта.
//
Процедура ПриИзмененииСостоянияСогласования(ПредметСогласования, Источник, Состояние, ВызовИзФормыОбъекта) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПриИзмененииСостоянияСогласования(ПредметСогласования, Источник, Состояние, ВызовИзФормыОбъекта) 
```
</details>

## ПриОпределенииПредложенияАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сохраненный ранее признак состоявшегося показа окна авторизации.
//
// Параметры:
//   АвторизацияПредложена - Булево - неявно возвращаемое значение,
//     Истина, если авторизация была предложена в этом сеансе, и Ложь в противном случае.
//
Процедура ПриОпределенииПредложенияАвторизации(АвторизацияПредложена) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПриОпределенииПредложенияАвторизации(АвторизацияПредложена) 
```
</details>

## ПриРазложенииПолногоИмениФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить разложение полного имени файла на составляющие.
//
// Параметры:
//   СтруктураИмениФайла - Структура:
//     * ПолноеИмя - Строка - Содержит полный путь к файлу, т.е. полностью соответствует входному
//         параметру ПолноеИмяФайла.
//     * Путь - Строка - Содержит путь к каталогу, в котором лежит файл.
//     * Имя - Строка - Содержит имя файла с расширением, без пути к файлу.
//     * Расширение - Строка - Содержит расширение файла.
//     * ИмяБезРасширения - Строка - Содержит имя файла без расширения и без пути к файлу.
//
Процедура ПриРазложенииПолногоИмениФайла(СтруктураИмениФайла) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПриРазложенииПолногоИмениФайла(СтруктураИмениФайла) 
```
</details>

## ПриСохраненииНастроекПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при сохранении массива пользовательских настроек МассивСтруктур.
//
// Параметры:
//   МассивСтруктур - Массив - массив структур с полями "Объект", "Настройка", "Значение".
//   НужноОбновитьПовторноИспользуемыеЗначения - Булево - требуется обновить повторно используемые значения.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная
//     обработка вызываться не будет.
//
Процедура ПриСохраненииНастроекПользователя(МассивСтруктур, НужноОбновитьПовторноИспользуемыеЗначения, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПриСохраненииНастроекПользователя(МассивСтруктур, НужноОбновитьПовторноИспользуемыеЗначения, );
```
</details>

## ПриСохраненииПредложенияАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запоминает факт показа окна авторизации, чтобы больше не беспокоить пользователя в пределах сеанса.
//
Процедура ПриСохраненииПредложенияАвторизации() Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПриСохраненииПредложенияАвторизации() 
```
</details>

## ПриУстановкеОтбораПриВыбореСвязанногоОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает отбор при выборе объекта ДО, связанного с объектом ИС.
//
// Параметры:
//   СвязываемыйОбъект - ЛюбаяСсылка - объект ИС, связываемый с объектом ДО.
//   ТипОбъектаДокументооборота - Строка - тип выбираемого объекта ДО.
//   Отбор - Структура, Неопределено - неявно возвращаемое значение, отбор, накладываемый перед
//     предъявлением пользователю.
//
// Пример:
//	Если ТипЗнч(СвязываемыйОбъект) = Тип("СправочникСсылка.Контрагенты")
//			И ТипОбъектаДокументооборота = "DMCorrespondent" Тогда
//		ЗначенияРеквизитов = ОбщегоНазначенияУТВызовСервера.ЗначенияРеквизитовОбъекта(
//			СвязываемыйОбъект, "Наименование, ИНН, КПП");
//		Если ЗначениеЗаполнено(ЗначенияРеквизитов.ИНН) Тогда
//			Отбор = Новый Структура;
//			Отбор.Вставить("inn", ЗначенияРеквизитов.ИНН);
//			Отбор.Вставить("kpp", ЗначенияРеквизитов.КПП);
//		ИначеЕсли ЗначениеЗаполнено(ЗначенияРеквизитов.Наименование) Тогда
//			Отбор = Новый Структура;
//			Отбор.Вставить("name", ЗначенияРеквизитов.Наименование);
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПриУстановкеОтбораПриВыбореСвязанногоОбъекта(СвязываемыйОбъект, ТипОбъектаДокументооборота, Отбор) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентПереопределяемый.ПриУстановкеОтбораПриВыбореСвязанногоОбъекта(СвязываемыйОбъект, ТипОбъектаДокументооборота, Отбор) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
