---
title: Интеграция с 1С документооборот базовая функциональность клиент сервер
slug: zup/интеграция-с-1с-документооборот-базовая-функциональность-клиент-сервер
---


## ДанныеПравилаИнтеграции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей ключевые данные правила интеграции.
//
// Возвращаемое значение:
//  Структура:
//     * Ссылка - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом - правило.
//              - Неопределено
//     * ПредставлениеОбъектаДО - Строка - представление объекта ДО.
//     * ПредставлениеОбъектаИС - Строка - представление объекта ИС.
//     * ТипОбъектаДО - Строка - тип объекта ДО.
//     * ТипОбъектаИС - Строка - тип объекта ИС.
//     * ИдентификаторВидаДокумента - Строка - идентификатор вида документа ДО.
//     * ТипВидаДокумента - Строка - тип вида документа ДО.
//
Функция ДанныеПравилаИнтеграции() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПравилаИнтеграции() 
```
</details>

## ДанныеРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей реквизит объекта ДО.
//
// Возвращаемое значение:
//  Структура:
//     * Имя - Строка
//     * Тип - Строка
//     * Представление - Строка
//     * ЭтоДополнительныйРеквизитДО - Булево
//     * ДополнительныйРеквизитДОID - Строка
//     * ДополнительныйРеквизитДОТип - Строка
//     * ЭтоТаблица - Булево
//     * Таблица - Строка
//
Функция ДанныеРеквизита() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеРеквизита() 
```
</details>

## ДанныеСсылочногоОбъектаДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных объекта 1С:Документооборот ссылочного типа.
//
// Параметры:
//   ID - Строка - идентификатор объекта ДО.
//   Тип - Строка - тип объекта XDTO.
//   Наименование - Строка - имя объекта ДО.
//   Представление - Строка - представление объекта ДО.
//   НавигационнаяСсылка - Строка - навигационная ссылка на объект ДО.
//
// Возвращаемое значение:
//   Структура - данные владельца подписей:
//     * ID - Строка - идентификатор объекта ДО.
//     * Тип - Строка - тип объекта XDTO.
//     * Наименование - Строка - имя объекта ДО.
//     * Представление - Строка - представление объекта ДО.
//     * НавигационнаяСсылка - Строка - навигационная ссылка на объект ДО.
//
Функция ДанныеСсылочногоОбъектаДО(ID, Тип, Наименование = "", Представление = "", НавигационнаяСсылка = "") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеСсылочногоОбъектаДО(ID, Тип, Наименование, Представление, НавигационнаяСсылка);
```
</details>

## ДанныеФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных файла.
//
// Параметры:
//   Наименование - Строка - имя объекта ДО.
//   ID - Строка - идентификатор объекта ДО.
//   Тип - Строка - тип объекта XDTO.
//   Расширение - Строка - расширение файла.
//   РольФайлаID - Строка - роль файла.
//
// Возвращаемое значение:
//   Структура - данные владельца подписей:
//     * Наименование - Строка - имя объекта ДО.
//     * ID - Строка - идентификатор объекта ДО.
//     * Тип - Строка - тип объекта XDTO.
//     * Расширение - Строка - расширение файла.
//     * РольФайлаID - Строка - роль файла.
//                   - Неопределено
//     * СсылкаНаДвоичныеДанныеФайла - Строка - адрес данных файла во временном хранилище.
//     * Описание - Строка - описание файла.
//     * Размер - Число - размер файла.
//     * ДатаМодификации - Дата - дата модификации файла.
//     * ДатаМодификацииУниверсальная - Дата - дата модификации файла универсальная.
//     * ИмяФайла - Строка - имя файла с расширением.
//     * Текст - Строка - текст файла.
//
Функция ДанныеФайла(Наименование, ID, Тип, Расширение = "", РольФайлаID = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеФайла(Наименование, ID, Тип, Расширение, РольФайлаID);
```
</details>

## ИзвлечьТекстOpenDocument
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлечь текст из файла OpenDocument и возвратить его в виде строки.
//
// Параметры:
//   ПутьКФайлу - Строка - Полное имя файла.
//   Отказ - Булево - Отказ.
//
// Возвращаемое значение:
//   Строка - Извлеченный текст.
//
Функция ИзвлечьТекстOpenDocument(ПутьКФайлу, Отказ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ИзвлечьТекстOpenDocument(ПутьКФайлу, Отказ) 
```
</details>

## ИзвлечьТекстИзТекстовогоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлекает текст в соответствии с кодировкой.
// Если кодировка не задана - сама вычисляет кодировку.
//
// Параметры:
//   ПолноеИмяФайла - Строка - Полное имя файла.
//   Кодировка - Строка - Кодировка.
//   Отказ - Булево - Отказ.
//
// Возвращаемое значение:
//   Строка - Извлеченный текст.
//
Функция ИзвлечьТекстИзТекстовогоФайла(ПолноеИмяФайла, Кодировка, Отказ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ИзвлечьТекстИзТекстовогоФайла(ПолноеИмяФайла, Кодировка, Отказ) 
```
</details>

## ИмяСРасширением
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает имя с расширением (если расширение пусто - только имя).
//
// Параметры:
//   ПолноеНаименование - Строка - полное наименование файла.
//   Расширение - Строка - расширение файла.
//
// Возвращаемое значение:
//   Строка - Имя с расширением. Если расширение пусто - только имя.
//
Функция ИмяСРасширением(ПолноеНаименование, Расширение) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ИмяСРасширением(ПолноеНаименование, Расширение) 
```
</details>

## КраткоеПредставлениеРазмера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку с размером файла в кратком и удобном для чтения формате.
//
// Параметры:
//   Размер - Число - размер файла в байтах.
//
// Возвращаемое значение:
//   Строка - размер файла в виде 123.4 Кб
//
Функция КраткоеПредставлениеРазмера(Знач Размер) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.КраткоеПредставлениеРазмера(Размер) 
```
</details>

## НовыеПараметрыСозданияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустые параметры создания файла для вызова
// ИнтеграцияС1СДокументооборотБазоваяФункциональностьВызовСервера.СоздатьФайлВДокументообороте.
//
// Параметры:
//   ТекущийФайл - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеФайла
//
// Возвращаемое значение:
//   Структура:
//     * ТекущийФайл - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеФайла
//     * АдресВременногоХранилищаФайла - Неопределено
//     * Владелец - Неопределено
//     * ЯвляетсяСканКопией - Булево
//     * ШаблонID - Строка
//     * ВнешнийОбъект - Структура:
//       ** ID - Строка
//       ** type - Строка
//       ** name - Строка
//
Функция НовыеПараметрыСозданияФайла(ТекущийФайл) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.НовыеПараметрыСозданияФайла(ТекущийФайл) 
```
</details>

## ПредставлениеУчастникаЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление участника задачи ДО.
//
// Параметры:
//   Исполнитель - Строка - представление исполнителя. Роль или сотрудник.
//   ОсновнойОбъектАдресации - Строка - представление основного объекта адресации.
//   ДополнительныйОбъектАдресации - Строка - представление дополнительного объекта адресации.
//
// Возвращаемое значение:
//   Строка
//
Функция ПредставлениеУчастникаЗадачи(Исполнитель, ОсновнойОбъектАдресации, ДополнительныйОбъектАдресации) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ПредставлениеУчастникаЗадачи(Исполнитель, ОсновнойОбъектАдресации, ДополнительныйОбъектАдресации) 
```
</details>

## РазмерВКб
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает размер файла в килобайтах.
//
// Параметры:
//   Размер - Число - размер файла в байтах.
//
// Возвращаемое значение:
//   Число - размер файла в Кб.
//
Функция РазмерВКб(Знач Размер) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.РазмерВКб(Размер) 
```
</details>

## РазмерВМб
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает размер файла в мегабайтах.
//
// Параметры:
//   Размер - Число - размер файла в байтах.
//
// Возвращаемое значение:
//   Число - размер файла в Мб.
//
Функция РазмерВМб(Знач Размер) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.РазмерВМб(Размер) 
```
</details>

## ПодробноеПредставлениеРазмера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку с размером файла в удобном для чтения формате с указанием количества байт.
//
// Параметры:
//   Размер - Число - размер файла в байтах.
//
// Возвращаемое значение:
//   Строка - размер файла в виде 123.4 Кб (123 456 байт)
//
Функция ПодробноеПредставлениеРазмера(Знач Размер) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ПодробноеПредставлениеРазмера(Размер) 
```
</details>

## ПолучитьСтрокуСРазмеромФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить строку с представлением размера файла - например для отображения в Состояние при передаче файла.
//
// Параметры:
//   РазмерВМб - Число - Размер в Мб.
//
// Возвращаемое значение:
//   Строка - размера файла.
//
Функция ПолучитьСтрокуСРазмеромФайла(Знач РазмерВМб) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ПолучитьСтрокуСРазмеромФайла(РазмерВМб) 
```
</details>

## РазмерФайлаПревышаетМаксимальноДопустимый
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сверяет размер файла с максимально допустимым размером, заданным в настройках интеграции.
//
// Параметры:
//   МаксРазмерФайла - Число - максимально допустимый размер файла.
//   Размер - Число - размер файла в байтах.
//   ИмяФайла - Строка - наименование файла.
//   ВызыватьИсключение - Булево - вызывать исключение если максимальный размер превышен.
//   ТекстСообщения - Строка - неявно возвращаемое значение, текст сообщения пользователю.
//
// Возвращаемое значение:
//   Булево - размер файла превышает максимально допустимый.
//
Функция РазмерФайлаПревышаетМаксимальноДопустимый(МаксРазмерФайла, Размер, ИмяФайла, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.РазмерФайлаПревышаетМаксимальноДопустимый(МаксРазмерФайла, Размер, ИмяФайла, );
```
</details>

## РазделитьПароль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разделяет пароль на две независимые части для последующего восстановления функцией СобратьПароль.
//
// Параметры:
//   Пароль - Строка - разделяемый пароль.
//
// Возвращаемое значение:
//   Массив из Строка - массив из двух строк, содержащих шестнадцатиричное представление пароля.
//
Функция РазделитьПароль(Пароль) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.РазделитьПароль(Пароль) 
```
</details>

## РасширениеФайлаВСписке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина, если файл с таким расширением находится в списке расширений.
//
// Параметры:
//   СписокРасширений - Строка - Список расширений.
//   РасширениеФайла - Строка - Расширение файла.
//
// Возвращаемое значение:
//   Булево
//
Функция РасширениеФайлаВСписке(СписокРасширений, РасширениеФайла) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.РасширениеФайлаВСписке(СписокРасширений, РасширениеФайла) 
```
</details>

## СвойстваФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей свойства файла.
//
// Возвращаемое значение:
//   Структура:
//     * ИдентификаторФайла - Строка - идентификатор файла в 1С:Документооборот.
//                          - Неопределено
//     * ИмяФайла - Строка - имя файла.
//                - Неопределено
//     * ОписаниеФайла - Строка - описание файла.
//                     - Неопределено
//     * Редактируется - Булево - файл находится на редактировании.
//                     - Неопределено
//     * Зашифрован - Булево - файл зашифрован.
//                  - Неопределено
//     * ДанныеПодписейФайла - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//                           - Неопределено
//     * УникальныйИдентификатор - УникальныйИдентификатор - идентификатор управляемой формы объекта.
//                               - Неопределено
//     * ВладелецФайла - Строка - идентификатор владельца файла в 1С:Документооборот.
//                     - Неопределено
//
Функция СвойстваФайла() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СвойстваФайла() 
```
</details>

## СервисДоступен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность сервиса ДО по номеру версии.
//
// Параметры:
//   ВерсияСервиса - Строка - версия сервиса ДО.
//
// Возвращаемое значение:
//   Булево
//
Функция СервисДоступен(ВерсияСервиса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СервисДоступен(ВерсияСервиса) 
```
</details>

## СобратьПароль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Собирает пароль из двух частей, ранее разделенных функцией РазделитьПароль.
// В случае повреждения строк возвращает Неопределено.
//
// Параметры:
//   РазделенныйПароль - Массив из Строка - две строки, содержащие разделенный пароль.
//
// Возвращаемое значение:
//   Строка - собранный пароль или
//   Неопределено - если строки повреждены.
//
Функция СобратьПароль(Знач РазделенныйПароль) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СобратьПароль(РазделенныйПароль) 
```
</details>

## СообщениеВПредпросмотр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сообщение в HTML представление, которое будет отображаться в области предпросмотра.
//
// Параметры:
//   Сообщение - Строка - сообщение для области предпросмотра.
//   ЗаголовокСообщенияВОбластиПредпросмотра - Строка - заголовок, содержащий настройки вывода сообщения.
//
// Возвращаемое значение:
//   Строка - HTML представление сообщения.
//
Функция СообщениеВПредпросмотр(Сообщение, ЗаголовокСообщенияВОбластиПредпросмотра) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СообщениеВПредпросмотр(Сообщение, ЗаголовокСообщенияВОбластиПредпросмотра) 
```
</details>

## СтрокаСообщенияОНедопустимостиПодписанияЗашифрованногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Строку сообщения о недопустимости подписания зашифрованного файла.
//
// Параметры:
//   ФайлСсылка - ЛюбаяСсылка - Ссылка на файл.
//
// Возвращаемое значение:
//   Строка
//
Функция СтрокаСообщенияОНедопустимостиПодписанияЗашифрованногоФайла(ФайлСсылка = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтрокаСообщенияОНедопустимостиПодписанияЗашифрованногоФайла(ФайлСсылка);
```
</details>

## ТипОперацииНадЗадачей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей тип операции над задачей.
//
// Возвращаемое значение:
//   Структура:
//     * ВыполнитьДействиеЗадачи - Булево
//     * ВзятьВРаботу - Булево
//     * ОтменитьВзятиеВРаботу - Булево
//     * Перенаправить - Булево
//     * УстановитьФлаг - Булево
//     * ВыполнитьПодключаемоеДействиеЗадачи - Булево
//     * ВыполнитьДействиеЗадачиПоШаблону - Булево
//
Функция ТипОперацииНадЗадачей() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ТипОперацииНадЗадачей() 
```
</details>

## ЭтоРасширениеСканКопии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли переданное значение расширением скан-копии.
//
// Параметры:
//   Расширение - Строка - расширение файла.
//   СписокРасширенийСканКопийОригиналов - Строка - список расширений скан-копий.
//
// Возвращаемое значение:
//   Булево - Истина, если переданное значение является расширением скан-копии.
//
Функция ЭтоРасширениеСканКопии(Расширение, Знач СписокРасширенийСканКопийОригиналов) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ЭтоРасширениеСканКопии(Расширение, СписокРасширенийСканКопийОригиналов) 
```
</details>

## ДанныеВладельцаПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных владельца подписи.
//
// Параметры:
//   Наименование - Строка - имя объекта ДО.
//   ID - Строка - идентификатор объекта ДО.
//   Тип - Строка - тип объекта XDTO.
//   Зашифрован - Булево - владелец подписи зашифрован.
//   МассивПодписей - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//
// Возвращаемое значение:
//   Структура - данные владельца подписей:
//     * Наименование - Строка - имя объекта ДО.
//     * ID - Строка - идентификатор объекта ДО.
//     * Тип - Строка - тип объекта XDTO.
//     * Зашифрован - Булево - владелец подписи зашифрован.
//     * МассивПодписей - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//                      - Неопределено
//
Функция ДанныеВладельцаПодписи(Наименование, ID, Тип, Зашифрован, МассивПодписей = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеВладельцаПодписи(Наименование, ID, Тип, Зашифрован, МассивПодписей);
```
</details>

## ДанныеПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные, из которых будет формироваться XDTO объект DMSignature, для передачи в ДО.
//
// Параметры:
//   Подпись - ДвоичныеДанные - двоичные данные подписи.
//   ДвоичныеДанныеСертификата - ДвоичныеДанные - двоичные данные сертификата.
//   СвойстваПодписи - Структура - тут может быть или структура СвойстваПодписи, которую возвращает БСП при
//     добавлении новой подписи, или строка таблицы подписей, если это уже существующая на стороне ДО подпись.
//
// Возвращаемое значение:
//   см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураПодписи
//
Функция ДанныеПодписи(Подпись, ДвоичныеДанныеСертификата, СвойстваПодписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи(Подпись, ДвоичныеДанныеСертификата, СвойстваПодписи) 
```
</details>

## ДополнитьПодписиОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет соответствие подписей объектов.
//
// Параметры:
//   ПодписиОбъектов - Соответствие из КлючИЗначение:
//     * Ключ - Строка - идентификатор объекта ДО, являющегося владельцем подписи.
//     * Значение - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеВладельцаПодписи
//   Наименование - Строка - имя объекта ДО.
//   ID - Строка - идентификатор объекта ДО.
//   Тип - Строка - тип объекта XDTO.
//   Зашифрован - Булево - владелец подписи зашифрован.
//   МассивПодписей - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДанныеПодписи
//
Процедура ДополнитьПодписиОбъектов(ПодписиОбъектов, Наименование, ID, Тип, Зашифрован, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ДополнитьПодписиОбъектов(ПодписиОбъектов, Наименование, ID, Тип, Зашифрован, );
```
</details>

## ПараметрыПроверкиЭП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для проверки электронно-цифровой подписи.
//
// Параметры:
//   ДанныеСтроки - ДанныеФормыЭлементДерева - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей
//   СоответствиеИдОбъектаИДвоичныхДанных - Соответствие из КлючИЗначение:
//     * Ключ - Строка - идентификатор объекта.
//     * Значение - ДвоичныеДанные - двоичные данные объекта.
//   АдресСлепкаДокумента - Строка - адрес временного хранилища двоичных данных документа Документооборота.
//
// Возвращаемое значение:
//   Структура:
//     * ФорматДатыПроверки - Строка
//     * ДвоичныеДанныеОбъекта - ДвоичныеДанные
//                             - Неопределено
//     * Подпись - ДвоичныеДанные
//               - Неопределено
//
Функция ПараметрыПроверкиЭП(ДанныеСтроки, СоответствиеИдОбъектаИДвоичныхДанных, АдресСлепкаДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ПараметрыПроверкиЭП(ДанныеСтроки, СоответствиеИдОбъектаИДвоичныхДанных, АдресСлепкаДокумента) 
```
</details>

## ПодписьВыделена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет выделена ли подпись в переданных данных строки строки из таблицы подписей.
//
// Параметры:
//   ВыделенныеПодписи - Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиент.ВыделенныеПодписи
//   ДанныеСтроки - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей
//
// Возвращаемое значение:
//   Булево
//
Функция ПодписьВыделена(ВыделенныеПодписи, ДанныеСтроки) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ПодписьВыделена(ВыделенныеПодписи, ДанныеСтроки) 
```
</details>

## СтрокаСообщенияОНедопустимостиПодписанияЗанятогоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Строку сообщения о недопустимости подписания занятого файла.
//
// Параметры:
//   ФайлСсылка - ЛюбаяСсылка - Ссылка на файл.
//
// Возвращаемое значение:
//   Строка
//
Функция СтрокаСообщенияОНедопустимостиПодписанияЗанятогоФайла(ФайлСсылка = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтрокаСообщенияОНедопустимостиПодписанияЗанятогоФайла(ФайлСсылка);
```
</details>

## СтруктураПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей данные электронной подписи.
//
// Возвращаемое значение:
//   Структура:
//     * Подпись - ДвоичныеДанные
//               - Неопределено
//     * ДвоичныеДанныеСертификата - ДвоичныеДанные
//                                 - Неопределено
//     * Сертификат - ХранилищеЗначения
//                  - Неопределено
//     * Отпечаток - Строка
//                 - Неопределено
//     * ДатаПодписи - Дата
//                   - Неопределено
//     * Комментарий - Строка
//                   - Неопределено
//     * ИмяФайлаПодписи - Строка
//                       - Неопределено
//     * КомуВыданСертификат - Строка
//                           - Неопределено
//     * УстановившийПодпись - Строка
//                           - Неопределено
//     * УстановившийПодписьИд - Строка
//                             - Неопределено
//
Функция СтруктураПодписи() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураПодписи() 
```
</details>

## СтруктураСтрокиДереваПодписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры, описывающей строку дерева подписей.
//
// Параметры:
//   СтрокаДереваПодписей - ДанныеФормыЭлементДерева - строка дерева подписей:
//     * АдресПодписи - Строка
//     * АдресСертификата - Строка
//     * ДатаПодписи - Дата
//     * ДатаПодписиИКомментарий - Строка
//     * Зашифрован - Булево
//     * ИмяФайлаПодписи - Строка
//     * ИндексКартинки - Число
//     * Комментарий - Строка
//     * КомуВыданСертификат - Строка
//     * КомуВыданСертификатИСтатус - Строка
//     * Неверна - Булево
//     * НомерСтроки - Число
//     * Объект - Строка
//     * ОбъектИд - Строка
//     * ОбъектИмя - Строка
//     * ОбъектТип - Строка
//     * Отпечаток - Строка
//     * ПодписьВерна - Булево
//     * Статус - Строка
//     * УстановившийПодпись - Строка
//     * УстановившийПодписьИд - Строка
//
// Возвращаемое значение:
//   Структура:
//     * АдресПодписи - Строка
//     * АдресСертификата - Строка
//     * ДатаПодписи - Дата
//     * ДатаПодписиИКомментарий - Строка
//     * Зашифрован - Булево
//     * ИмяФайлаПодписи - Строка
//     * ИндексКартинки - Число
//     * Комментарий - Строка
//     * КомуВыданСертификат - Строка
//     * КомуВыданСертификатИСтатус - Строка
//     * Неверна - Булево
//     * НомерСтроки - Число
//     * Объект - Строка
//     * ОбъектИд - Строка
//     * ОбъектИмя - Строка
//     * ОбъектТип - Строка
//     * Отпечаток - Строка
//     * ПодписьВерна - Булево
//     * Статус - Строка
//     * УстановившийПодпись - Строка
//     * УстановившийПодписьИд - Строка
//
Функция СтруктураСтрокиДереваПодписей(СтрокаДереваПодписей) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей(СтрокаДереваПодписей) 
```
</details>

## ТаблицаПодписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует 2-уровневое дерево в массив.
//
// Параметры:
//   ДеревоПодписей - ДанныеФормыДерево - см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей
//   ВыделенныеСтроки - Массив из Число - выделенные строки в дереве подписей.
//   ОбъектID - Строка - заполняется если нужно получить подписи конкретного объекта.
//
// Возвращаемое значение:
//   Массив из см. ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.СтруктураСтрокиДереваПодписей
//
Функция ТаблицаПодписей(ДеревоПодписей, ВыделенныеСтроки = Неопределено, ОбъектID = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотБазоваяФункциональностьКлиентСервер.ТаблицаПодписей(ДеревоПодписей, ВыделенныеСтроки, ОбъектID);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
