---
title: Интеграция с 1С документооборот базовая функциональность переопределяемый
slug: zup/интеграция-с-1с-документооборот-базовая-функциональность-переопределяемый
---


## ПриПоявленииПрисоединенныхФайловДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак наличия присоединенных файлов ДО для объекта ИС. Вызывается при добавлении
// связи с объектом ДО, имеющим файлы, при добавлении файла из интерфейса ИС и при фоновом обновлении.
//
// Параметры:
//   ID - Строка - идентификатор объекта Документооборота.
//   Тип - Строка - XDTO-тип объекта Документооборота.
//   ОбъектИС - ЛюбаяСсылка - объект ИС.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриПоявленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриПоявленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС, СтандартнаяОбработка) 
```
</details>

## ПриУдаленииПрисоединенныхФайловДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Снимает признак наличия присоединенных файлов для объекта ИС, если их нет в самой ИС. Вызывается при
// удалении связи с объектом ДО и при фоновом обновлении.
//
// Параметры:
//   ID - Строка - идентификатор объекта Документооборота.
//   Тип - Строка - XDTO-тип объекта Документооборота.
//   ОбъектИС - ЛюбаяСсылка - объект ИС.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриУдаленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриУдаленииПрисоединенныхФайловДокументооборота(ID, Тип, ОбъектИС, СтандартнаяОбработка) 
```
</details>

## ПриОпределенииНаличияПрисоединенныхФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при определении наличия файлов, хранимых в интегрируемой конфигурации.
//
// Параметры:
//   ВладелецФайлов - Произвольный - объект-владелец.
//   ЕстьФайлы - Булево, Неопределено - неявно возвращаемое значение, признак наличия присоединенных файлов.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриОпределенииНаличияПрисоединенныхФайлов(ВладелецФайлов, ЕстьФайлы, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииНаличияПрисоединенныхФайлов(ВладелецФайлов, ЕстьФайлы, СтандартнаяОбработка) 
```
</details>

## ПриПолученииПрисоединенныхФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении присоединенных файлов.
//
// Параметры:
//   ВладелецФайлов - Произвольный - объект-владелец.
//   ДанныеФайлов - Массив из см. РаботаСФайлами.ДанныеФайла
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриПолученииПрисоединенныхФайлов(ВладелецФайлов, ДанныеФайлов, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриПолученииПрисоединенныхФайлов(ВладелецФайлов, ДанныеФайлов, СтандартнаяОбработка) 
```
</details>

## ДополнительнаяОбработкаФормыБизнесПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании форм бизнес-процессов 1С:Документооборота. Позволяет выполнить дополнительные действия.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма бизнес-процесса Документооборота.
//   Отказ - Булево - признак отказа от создания формы.
//   СтандартнаяОбработка - Булево - стандартная обработка при создании формы на сервере.
//
Процедура ДополнительнаяОбработкаФормыБизнесПроцесса(Форма, Отказ, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ДополнительнаяОбработкаФормыБизнесПроцесса(Форма, Отказ, СтандартнаяОбработка) 
```
</details>

## ДополнительнаяОбработкаФормыДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании форм документов Документооборота. Позволяет выполнить дополнительные действия.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма документа Документооборота.
//   Отказ - Булево - признак отказа от создания формы.
//   СтандартнаяОбработка - Булево - стандартная обработка при создании формы на сервере.
//
Процедура ДополнительнаяОбработкаФормыДокумента(Форма, Отказ, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ДополнительнаяОбработкаФормыДокумента(Форма, Отказ, СтандартнаяОбработка) 
```
</details>

## ДополнительнаяОбработкаФормыЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании формы задачи Документооборота. Позволяет выполнить дополнительные действия.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма задачи Документооборота.
//   Отказ - Булево - признак отказа от создания формы.
//   СтандартнаяОбработка - Булево - стандартная обработка при создании формы на сервере.
//
Процедура ДополнительнаяОбработкаФормыЗадачи(Форма, Отказ, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ДополнительнаяОбработкаФормыЗадачи(Форма, Отказ, СтандартнаяОбработка) 
```
</details>

## ДополнитьСоответствиеТипов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет таблицу соответствия поддерживаемых типов.
//
// Параметры:
//   Таблица - ТаблицаЗначений - неявно возвращаемое значение с колонками:
//     * ИмяТипаXDTO - Строка - имя типа XDTO.
//     * ТипОбъектаИС - Тип - тип объекта ИС.
//
// Пример:
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMBankAccount", Тип("СправочникСсылка._ДемоБанковскиеСчета"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMMeasurementUnit", Тип("СправочникСсылка._ДемоЕдиницыИзмерения"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMContactPerson", Тип("СправочникСсылка._ДемоКонтактныеЛица"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMCorrespondent", Тип("СправочникСсылка._ДемоКонтрагенты"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMProduct", Тип("СправочникСсылка._ДемоНоменклатура"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMOrganization", Тип("СправочникСсылка._ДемоОрганизации"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMSubdivision", Тип("СправочникСсылка._ДемоПодразделения"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMCashFlowItem", Тип("СправочникСсылка._ДемоСтатьиДвиженияДенежныхСредств"));
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуСоответствияТипов(
//		Таблица, "DMEmployee", Тип("СправочникСсылка._ДемоСотрудники"));
//
Процедура ДополнитьСоответствиеТипов(Таблица) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ДополнитьСоответствиеТипов(Таблица) 
```
</details>

## ЗаполнитьРеквизитыИзПотребителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет свойства объекта XDTO из реквизитов объекта конфигурации-потребителя. По умолчанию заполняется
// только наименование и идентификатор. При необходимости обеспечить заполнение других реквизитов объектов
// ДО, создаваемых по ссылкам, следует заполнить соответствующие свойства объекта XDTO. Эти же значения будут
// использованы при поиске соответствий для справочников, имеющих внешние ключи (ИНН, КПП).
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - заполняемый объект.
//   СсылкаНаПотребитель - ЛюбаяСсылка - ссылка на исходный объект конфигурации-потребителя.
//
// Пример:
//	Если ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПроверитьТип(Прокси, ОбъектXDTO, "DMCorrespondent")
//			И ТипЗнч(СсылкаНаПотребитель) = Тип("СправочникСсылка._ДемоКонтрагенты") Тогда
//		Реквизиты = ОбщегоНазначения.ЗначенияРеквизитовОбъекта(СсылкаНаПотребитель, "ИНН, КПП, ЮрФизЛицо");
//		ОбъектXDTO.inn = Реквизиты.ИНН;
//		ОбъектXDTO.kpp = Реквизиты.КПП;
//		Если Реквизиты.ЮрФизЛицо = Перечисления._ДемоЮрФизЛицо.ЮрЛицо Тогда
//			ОбъектXDTO.legalPrivatePerson = "LglPerson";
//		ИначеЕсли Реквизиты.ЮрФизЛицо = Перечисления._ДемоЮрФизЛицо.ФизЛицо Тогда
//			ОбъектXDTO.legalPrivatePerson = "Individ";
//		ИначеЕсли Реквизиты.ЮрФизЛицо = Перечисления._ДемоЮрФизЛицо.ИндивидуальныйПредприниматель Тогда
//			ОбъектXDTO.legalPrivatePerson = "IndividualEntrepreneur";
//		ИначеЕсли Реквизиты.ЮрФизЛицо = Перечисления._ДемоЮрФизЛицо.ЮрЛицоНеРезидент Тогда
//			ОбъектXDTO.legalPrivatePerson = "LglPersonNonResident";
//		КонецЕсли;
//	ИначеЕсли ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПроверитьТип(Прокси, ОбъектXDTO, "DMOrganization")
//			И ТипЗнч(СсылкаНаПотребитель) = Тип("СправочникСсылка._ДемоОрганизации") Тогда
//		Реквизиты = ОбщегоНазначения.ЗначенияРеквизитовОбъекта(СсылкаНаПотребитель, "ИНН, КПП");
//		ОбъектXDTO.inn = Реквизиты.ИНН;
//		ОбъектXDTO.kpp = Реквизиты.КПП;
//	ИначеЕсли ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПроверитьТип(Прокси, ОбъектXDTO, "DMBankAccount")
//			И ТипЗнч(СсылкаНаПотребитель) = Тип("СправочникСсылка._ДемоБанковскиеСчета") Тогда
//		Реквизиты = ОбщегоНазначения.ЗначенияРеквизитовОбъекта(СсылкаНаПотребитель, "Владелец, НомерСчета");
//		ОбъектXDTO.number = Реквизиты.НомерСчета;
//		Если ТипЗнч(Реквизиты.Владелец) = Тип("СправочникСсылка._ДемоКонтрагенты") Тогда
//			ТипВладельцаXDTO = "DMCorrespondent";
//		ИначеЕсли ТипЗнч(Реквизиты.Владелец) = Тип("СправочникСсылка._ДемоОрганизации") Тогда
//			ТипВладельцаXDTO = "DMOrganization";
//		КонецЕсли;
//		ОбъектXDTO.owner = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьОбъект(
//			Прокси,
//			ТипВладельцаXDTO,
//			Реквизиты.Владелец);
//		Если ЗначениеЗаполнено(Реквизиты.Банк) Тогда
//			ОбъектXDTO.bank = ИнтеграцияС1СДокументооборотБазоваяФункциональность.СоздатьОбъект(
//				Прокси,
//				"DMBank",
//				Реквизиты.Банк);
//		КонецЕсли;
//	Иначе //...
//	КонецЕсли;
//
Процедура ЗаполнитьРеквизитыИзПотребителя(Прокси, ОбъектXDTO, СсылкаНаПотребитель) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ЗаполнитьРеквизитыИзПотребителя(Прокси, ОбъектXDTO, СсылкаНаПотребитель) 
```
</details>

## ЗаполнитьФормуИзПотребителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты формы по данным объекта интегрированной системы.
//
// Параметры:
//   ВнешнийОбъект - ЛюбаяСсылка - ссылка на объект-основание.
//   Форма - ФормаКлиентскогоПриложения - форма обработки ИнтеграцияС1СДокументооборот, соответствующая заполняемому
//    объекту Документооборота.
//
Процедура ЗаполнитьФормуИзПотребителя(ВнешнийОбъект, Форма) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ЗаполнитьФормуИзПотребителя(ВнешнийОбъект, Форма) 
```
</details>

## ПередЗаписьюДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед записью входящих, исходящих, внутренних документов Документооборота.
// Позволяет выполнить дополнительные проверки перед записью, и отказаться от записи.
//
// Параметры:
//   Прокси - WSПрокси - объект для подключения к web-сервисам Документооборота.
//   ОбъектXDTO - ОбъектXDTO - заполняемый объект. Тип DMInternalDocument, DMIncomingDocument, DMOutgoingDocument.
//   Форма - ФормаКлиентскогоПриложения - форма документа Документооборота.
//   Отказ - Булево - признак отказа от записи документа.
//
Процедура ПередЗаписьюДокумента(Прокси, ОбъектXDTO, Форма, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПередЗаписьюДокумента(Прокси, ОбъектXDTO, Форма, Отказ) 
```
</details>

## ПередЗаписьюОбъектаИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед записью объектов интегрированной системы через механизм обмена с 1С:Документооборот.
// Позволяет выполнить дополнительные проверки перед записью, изменить ДополнительныеСвойства и отказаться от записи.
//
// Параметры:
//   ОбъектИС - ДокументОбъект
//            - СправочникОбъект - изменяемый объект ИС.
//   Отказ - Булево - признак отказа от записи.
//   РежимЗаписиДокумента - РежимЗаписиДокумента - позволяет изменить режим записи.
//   РежимПроведенияДокумента - РежимПроведенияДокумента - позволяет изменить режим проведения документа.
//
Процедура ПередЗаписьюОбъектаИС(ОбъектИС, Отказ, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПередЗаписьюОбъектаИС(ОбъектИС, Отказ, );
```
</details>

## ПолучитьРеквизитыОбъектаИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет таблицу реквизитов объекта по типу объекта.
//
// Параметры:
//   ИмяОбъектаИС - Строка - имя типа объекта потребителя.
//   Реквизиты - ТаблицаЗначений - Таблица описания реквизитов.
//
Процедура ПолучитьРеквизитыОбъектаИС(ИмяОбъектаИС, Реквизиты) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПолучитьРеквизитыОбъектаИС(ИмяОбъектаИС, Реквизиты) 
```
</details>

## ПриДобавленииПодсистемыВДеревоИнтегрируемыхОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при добавлении подсистемы в дерево интегрируемых объектов, с помощью которого настраивается
// интеграция. По умолчанию выводятся подсистемы первого уровня, включаемые в командный интерфейс, и
// подчиненные им.
//
// Параметры:
//   Подсистема - ОбъектМетаданных - добавляемая подсистема, содержащая интегрируемые объекты.
//   Отказ - Булево - при установке в Ложь подсистема будет пропущена вместе со всеми подчиненными.
//
Процедура ПриДобавленииПодсистемыВДеревоИнтегрируемыхОбъектов(Подсистема, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриДобавленииПодсистемыВДеревоИнтегрируемыхОбъектов(Подсистема, Отказ) 
```
</details>

## ПриЗаписиКонстанты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при записи констант подсистемы Интеграция с 1С:Документооборотом.
//
// Параметры:
//   Источник - КонстантаМенеджерЗначения - записываемая константа.
//   Отказ - Булево - флаг отказа от выполнения записи.
//
Процедура ПриЗаписиКонстанты(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриЗаписиКонстанты(Источник, Отказ) 
```
</details>

## ПриЗаполненииКоллекцииПечатныхФорм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет коллекцию печатных форм объекта по имени менеджера печати и команде менеджера печати.
//
// Параметры:
//   ВнешнийОбъект - ЛюбаяСсылка - внешний объект.
//   ИмяКоманды - Строка - имя команды.
//   ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//   КоллекцияПечатныхФорм - ТаблицаЗначений - неявно возвращаемое значение.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриЗаполненииКоллекцииПечатныхФорм(ВнешнийОбъект, ИмяКоманды, ДополнительныеПараметры, КоллекцияПечатныхФорм, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриЗаполненииКоллекцииПечатныхФорм(ВнешнийОбъект, ИмяКоманды, ДополнительныеПараметры, КоллекцияПечатныхФорм, );
```
</details>

## ПриЗаполненииСвойстваОбъектаXDTOПоЗначению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при заполнении свойства объекта XDTO по значению в ИС (например, по значению реквизита объекта ИС).
//
// Параметры:
//   Значение - Произвольный - значение, которым заполняются свойства объекта XDTO для передачи в ДО.
//   Свойства - ФормаКлиентскогоПриложения
//            - СтрокаТаблицыЗначений - заполняемый набор данных, которым будет заполнен объект XDTO для передачи в ДО.
//            - см. ИнтеграцияС1СДокументооборот.СтруктураРеквизитовЗаполняемогоОбъектаДО
//   ТипОбъекта - Строка - тип заполняемого объекта, например, "DMInternalObject".
//   ИмяСвойства - Строка - имя заполняемого свойства, например, "Контрагент", "СостояниеСогласование".
//   ТипСвойства - Строка - тип заполняемого свойства, например, "DMCorrespondent", "DMDocumentStatus".
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартное заполнение
//     свойства по значению Значение производиться не будет.
//
// Пример:
//	Если ТипСвойства = "DMDocumentStatus" И ИмяСвойства = "СостояниеСогласование" Тогда
//		Если Значение = Перечисления._ДемоСостоянияЗаказаПокупателя.Согласован Тогда
//			Свойства[ИмяСвойства] = "Approved";
//			СтандартнаяОбработка = Ложь;
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПриЗаполненииСвойстваОбъектаXDTOПоЗначению(Значение, Свойства, ТипОбъекта, ИмяСвойства, ТипСвойства, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриЗаполненииСвойстваОбъектаXDTOПоЗначению(Значение, Свойства, ТипОбъекта, ИмяСвойства, ТипСвойства, );
```
</details>

## ПриЗаполненииТаблицыМенеджеровПечатиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает таблицу менеджеров печати форм объектов.
//
// Параметры:
//   МенеджерОбъекта - Строка - полное имя метаданных менеджера объекта.
//   ПечатныеФормы - ТаблицаЗначений:
//     * МенеджерПечати - Строка - имя объекта, в модуле менеджера которого располагается
//                                 процедура Печать, формирующая табличные документы для этой команды.
//     * ИмяКоманды - Строка
//     * ПредставлениеКоманды - Строка
//     * ДополнительныеПараметры - Строка - (необязательный) произвольные параметры для передачи в менеджер печати.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
// Пример:
//	КомандыПечати = ИнтеграцияС1СДокументооборотБазоваяФункциональность.КомандыПечатиФормы(
//		МенеджерОбъекта + ".Форма.ФормаСписка");
//
//	Для Каждого Команда Из КомандыПечати Цикл
//		Строка = ПечатныеФормы.Добавить();
//		Строка.МенеджерПечати = Команда.МенеджерПечати;
//		Строка.ИмяКоманды = Команда.Идентификатор;
//		Строка.ПредставлениеКоманды = Команда.Представление;
//	КонецЦикла;
//
Процедура ПриЗаполненииТаблицыМенеджеровПечатиОбъекта(МенеджерОбъекта, ПечатныеФормы, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриЗаполненииТаблицыМенеджеровПечатиОбъекта(МенеджерОбъекта, ПечатныеФормы, СтандартнаяОбработка) 
```
</details>

## ПриЗаполненииФормыОбъектаДОПоОбъектуИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при заполнении формы объекта ДО при его создании на основании объекта ИС. Позволяет дозаполнить объект
// ДО способом, не поддерживаемым правилами интеграции.
//
// Параметры:
//   ОбъектИС - Произвольный - ссылка на объект ИС.
//   Форма - ФормаКлиентскогоПриложения - форма объекта 1С:Документооборота.
//   Правило - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом - применяемое правило.
//
Процедура ПриЗаполненииФормыОбъектаДОПоОбъектуИС(ОбъектИС, Форма, Правило) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриЗаполненииФормыОбъектаДОПоОбъектуИС(ОбъектИС, Форма, Правило) 
```
</details>

## ПриИзмененииСостоянияСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при изменении состояния согласования в ДО. Предназначена для изменения согласуемого объекта.
//
// Параметры:
//   ПредметСогласования - ЛюбаяСсылка - согласуемый объект.
//   Состояние - ПеречислениеСсылка.СостоянияСогласованияВДокументообороте.
//   ВызовИзФормыОбъекта - Булево - Истина, если изменение состояния вызвано пользователем из формы объекта.
//   Установил - Строка - представление пользователя, установившего новое состояние.
//   ДатаУстановки - Дата - Дата установки нового состояния.
//
// Пример:
//	Если ВызовИзФормыОбъекта Тогда
//		Возврат;
//	КонецЕсли;
//
//	Если ТипЗнч(ПредметСогласования) = Тип("ДокументСсылка._ДемоЗаказПокупателя") Тогда
//
//		Объект = ПредметСогласования.ПолучитьОбъект();
//		Если Состояние = Перечисления.СостоянияСогласованияВДокументообороте.НаСогласовании Тогда
//			Объект.Состояние = Перечисления._ДемоСостоянияЗаказаПокупателя.НаСогласовании;
//		ИначеЕсли Состояние = Перечисления.СостоянияСогласованияВДокументообороте.НеСогласован Тогда
//			Объект.Состояние = Перечисления._ДемоСостоянияЗаказаПокупателя.НеСогласован;
//		ИначеЕсли Состояние = Перечисления.СостоянияСогласованияВДокументообороте.Согласован Тогда
//			Объект.Состояние = Перечисления._ДемоСостоянияЗаказаПокупателя.Согласован;
//		Иначе
//			Объект.Состояние = Перечисления._ДемоСостоянияЗаказаПокупателя.Подготовлен;
//		КонецЕсли;
//		Объект.Записать(РежимЗаписиДокумента.Запись);
//
//	КонецЕсли;
//
Процедура ПриИзмененииСостоянияСогласования(ПредметСогласования, Состояние, ВызовИзФормыОбъекта, Установил, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриИзмененииСостоянияСогласования(ПредметСогласования, Состояние, ВызовИзФормыОбъекта, Установил, );
```
</details>

## ПриОбработкеУниверсальногоСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнительная обработка сообщения XDTO.
//
// Параметры:
//   Сообщение - ОбъектXDTO - объект XDTO, потомок DMILRequest.
//   Результат - ОбъектXDTO - неявно возвращаемое значение. Объект XDTO,
//     потомок DMILResponse, если сообщение считается обработанным.
//             - Неопределено - если сообщение требует дальнейшей обработки.
//
Процедура ПриОбработкеУниверсальногоСообщения(Сообщение, Результат) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОбработкеУниверсальногоСообщения(Сообщение, Результат) 
```
</details>

## ПриОпределенииЗначенияРеквизитаПоОбъектуXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при заполнении реквизита объекта ИС по значению реквизита объекта ДО. При установке
// в параметр Результат значения, отличного от Неопределено, стандартное заполнение не выполняется.
//
// Параметры:
//   Результат - Произвольный - заполняемое значение реквизита объекта ИС.
//   ЗначениеЗаполнения - ОбъектXDTO - исходный объект, соответствие которому нужно найти.
//                      - Структура - структура со свойствами:
//     * ТипXDTOОбъекта - Строка - тип XDTO объекта, из значения свойства которого выполняется заполнение.
//     * ИмяСвойства - Строка - имя свойства, из значения свойства которого выполняется заполнение.
//     * ЗначениеСвойства - Произвольный - значение заполнения, соответствие которому нужно найти.
//   ТипРеквизита - Тип - тип заполняемого реквизита объекта ИС.
//   ИмяРеквизита - Строка - имя заполняемого реквизита ИС.
//   ТипОбъекта - Тип - тип заполняемого объекта ИС.
//   Объект - Произвольный - заполняемый объект ИС.
//   ЭтоДополнительноеСвойство - Булево - истина, если переданный объект является доп. свойством.
//   Свойство - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения - свойство-владелец.
//   ПараметрыВыбора - Соответствие из КлючИЗначение - параметры выбора:
//     * Ключ - Строка - имя параметра вида "Отбор.Владелец".
//     * Значение - Произвольный - значение параметра (отбора).
//
// Пример:
//	Если ИнтеграцияС1СДокументооборотБазоваяФункциональность.СвойствоУстановлено(ОбъектXDTO, "objectID")
//			И ОбъектXDTO.objectID.type = "DMDocumentStatus"
//			И ТипРеквизита = Тип("Булево")
//			И ИмяРеквизита = "Согласован" Тогда
//		Результат = (ОбъектXDTO.objectID.ID = "Согласован");
//	КонецЕсли;
//	Если ТипРеквизита = Тип("СправочникСсылка._ДемоЕдиницыИзмерения")
//			И ПараметрыВыбора <> Неопределено Тогда
//		Запрос = Новый Запрос(
//			"ВЫБРАТЬ ПЕРВЫЕ 1
//			|	Ссылка
//			|ИЗ
//			|	Справочник._ДемоЕдиницыИзмерения
//			|ГДЕ
//			|	Владелец = &Владелец
//			|	И Наименование = &Наименование
//			|");
//		Запрос.УстановитьПараметр("Наименование", ОбъектXDTO.name);
//		Запрос.УстановитьПараметр("Владелец", ПараметрыВыбора["Отбор.Владелец"]);
//		Выборка = Запрос.Выполнить().Выбрать();
//		Если Выборка.Следующий() Тогда
//			Результат = Выборка.Ссылка;
//		КонецЕсли;
//	КонецЕсли;
//	Если ТипРеквизита = Тип("СправочникСсылка._ДемоБанковскиеСчета")
//			И ОбъектXDTO.Свойства().Получить("number") <> Неопределено
//			И ИнтеграцияС1СДокументооборотБазоваяФункциональность.СвойствоУстановлено(ОбъектXDTO, "number") Тогда
//		Запрос = Новый Запрос(
//			"ВЫБРАТЬ ПЕРВЫЕ 1
//			|	Ссылка
//			|ИЗ
//			|	Справочник._ДемоБанковскиеСчета
//			|ГДЕ
//			|	НомерСчета = &НомерСчета
//			|");
//		Запрос.УстановитьПараметр("НомерСчета", ОбъектXDTO.number);
//		Выборка = Запрос.Выполнить().Выбрать();
//		Если Выборка.Следующий() Тогда
//			Результат = Выборка.Ссылка;
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПриОпределенииЗначенияРеквизитаПоОбъектуXDTO(Результат, ЗначениеЗаполнения, ТипРеквизита, ИмяРеквизита, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииЗначенияРеквизитаПоОбъектуXDTO(Результат, ЗначениеЗаполнения, ТипРеквизита, ИмяРеквизита, );
```
</details>

## ПриОпределенииИндексаКартинкиЭлементаСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить индекс картинки элемента справочника.
//
// Параметры:
//   ИндексаКартинки - Число - индекс картинки.
//
Процедура ПриОпределенииИндексаКартинкиЭлементаСправочника(ИндексаКартинки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииИндексаКартинкиЭлементаСправочника(ИндексаКартинки) 
```
</details>

## ПриОпределенииНеобходимостиВыводитьКомандуПрисоединенныхФайловДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить проверку необходимости вывода команды присоединенных файлов из библиотеки
// интеграции с 1С:Документооборотом на форму объекта ИС.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - проверяемая форма.
//   Результат - Булево - неявно возвращаемое значение, результат проверки. Если результат равен Истина,
//     команда "Файлы ДО" будет выводиться на форму.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная проверка
//     производиться не будет.
//
// Пример:
//	ИмяФормыМассив = СтрРазделить(Форма.ИмяФормы, ".");
//	ИмяТипаОбъектаФормы = СтрШаблон("%1.%2", ИмяФормыМассив[0], ИмяФормыМассив[1]);
//	Правила = ИнтеграцияС1СДокументооборотВызовСервера.ПодходящиеПравила(,,ИмяТипаОбъектаФормы);
//
//	Если Правила.Количество() = 0 Тогда
//		// Возможно в переопределяемом модуле прописано автоматическое создание правил для данного типа объекта ИС
//		СозданныеПравила = ИнтеграцияС1СДокументооборотВызовСервера.СоздатьПравилаИнтеграцииАвтоматически(
//			ИмяТипаОбъектаФормы);
//		Если СозданныеПравила.Количество() > 0 Тогда
//			Правила = ИнтеграцияС1СДокументооборотВызовСервера.ПодходящиеПравила(,,ИмяТипаОбъектаФормы);
//		КонецЕсли;
//	КонецЕсли;
//
//	Результат = (Правила.Количество() <> 0);
//
Процедура ПриОпределенииНеобходимостиВыводитьКомандуПрисоединенныхФайловДО(Форма, Результат, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииНеобходимостиВыводитьКомандуПрисоединенныхФайловДО(Форма, Результат, );
```
</details>

## ПриОпределенииОбновляемыхРеквизитовПроведенногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет реквизиты проведенного документа, подлежащие обновлению при их изменении в ДО.
//
// Параметры:
//   ПолноеИмя - Строка - полное имя объекта, как оно задано в метаданных, напр., Документ.ЗаказКлиента.
//   ОбновляемыеРеквизиты - Массив из Строка - неявно возвращаемое значение, имена реквизитов, обновление которых возможно.
//
// Пример:
//	ОбновляемыеРеквизиты.Добавить("Комментарий");
//	Если ПолноеИмя = "Документ.ЗаказКлиента" Тогда
//		ОбновляемыеРеквизиты.Добавить("Состояние");
//	КонецЕсли;
//
Процедура ПриОпределенииОбновляемыхРеквизитовПроведенногоДокумента(ПолноеИмя, ОбновляемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииОбновляемыхРеквизитовПроведенногоДокумента(ПолноеИмя, ОбновляемыеРеквизиты) 
```
</details>

## ПриОпределенииОбъектовПоддерживающихАвтонастройку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при построении списка интегрируемых объектов. В переданную таблицу следует добавить
// типы объектов, поддерживающих автоматическую настройку бесшовной интеграции с созданием правил
// интеграции и заполнением связанных данных.
//
// Параметры:
//   Объекты - ТаблицаЗначений - заполняемая таблица с колонками:
//     ИмяТипаОбъекта - Строка - полное имя типа, как задано в метаданных.
//     ОписаниеВыполняемыхДействий - Строка - необязательна, краткое описание действий, выполняемых
//        при автоматической настройке.
//
// Пример:
//	Строка = Объекты.Добавить();
//	Строка.ИмяТипаОбъекта = "Справочник._ДемоДоговорыКонтрагентов";
//	Строка.ОписаниеВыполняемыхДействий =
//		НСтр("ru = 'Будут созданы правила интеграции и виды внутренних документов для всех видов договоров.'");
//
Процедура ПриОпределенииОбъектовПоддерживающихАвтонастройку(Объекты) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииОбъектовПоддерживающихАвтонастройку(Объекты) 
```
</details>

## ПриОпределенииПодходящихОбъектовДляДобавленияСвязи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при добавлении связи к объекту ИС, связанному с объектом ДО.
// Позволяет дополнить список подходящих объектов, предъявляемый пользователю,
// теми объектами, которые не могут быть определены автоматически по ссылкам
// из шапки или из табличных частей объекта ИС.
//
// Параметры:
//   ОбъектИС - Произвольный - ссылка на объект ИС.
//   ПодходящиеОбъекты - Массив из ЛюбаяСсылка - дополняемый массив объектов ИС, подходящих для добавления связи.
//
Процедура ПриОпределенииПодходящихОбъектовДляДобавленияСвязи(ОбъектИС, ПодходящиеОбъекты) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииПодходящихОбъектовДляДобавленияСвязи(ОбъектИС, ПодходящиеОбъекты) 
```
</details>

## ПриОпределенииПоясненияСостоянияСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить получение пояснения к состоянию согласования, предназначенное для чтения пользователем.
//
// Параметры:
//   Установил - Строка - представление пользователя, установившего новое состояние.
//   ДатаУстановки - Дата - дата и время установки нового состояния.
//   Пояснение - Строка - пояснение к состоянию согласования.
//
Процедура ПриОпределенииПоясненияСостоянияСогласования(Установил, ДатаУстановки, Пояснение) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииПоясненияСостоянияСогласования(Установил, ДатаУстановки, Пояснение) 
```
</details>

## ПриОпределенииПредельногоКоличестваВыбираемыхОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить предельное количество объектов, выбираемых сервисом при получении списков.
//
// Параметры:
//   Тип - Строка - тип объекта XDTO
//   ПредельноеКоличество - Число - предельное количество элементов, выбираемых за раз.
//
// Пример:
//	Если Тип = "DMCorrespondent" Тогда ПредельноеКоличество = 50 ИначеЕсли <...>
//
Процедура ПриОпределенииПредельногоКоличестваВыбираемыхОбъектов(Тип, ПредельноеКоличество) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииПредельногоКоличестваВыбираемыхОбъектов(Тип, ПредельноеКоличество) 
```
</details>

## ПриОпределенииПредельногоКоличестваОбъектовВСообщенииОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить предельное количество объектов, которые будут выгружены в сообщение
// обмена с 1С:Документооборот.
//
// Параметры:
//   ПредельноеКоличествоОбъектовВСообщении - Число - предельное количество объектов.
//
// Пример:
//	ПредельноеКоличествоОбъектовВСообщении = 100;
//
Процедура ПриОпределенииПредельногоКоличестваОбъектовВСообщенииОбмена(ПредельноеКоличествоОбъектовВСообщении) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииПредельногоКоличестваОбъектовВСообщенииОбмена(ПредельноеКоличествоОбъектовВСообщении) 
```
</details>

## ПриОпределенииПредставленияВидаОбъектаПотребителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет представление вида объекта интегрируемой конфигурации.
//
// Параметры:
//   Правило - СправочникОбъект.ПравилаИнтеграцииС1СДокументооборотом
//           - СправочникОбъект.ПравилаИнтеграцииС1СДокументооборотом3 - правило, для которого
//     определяется представление.
//   ПредставлениеВидаОбъектаПотребителя - Строка - неявно возвращаемое значение, переопределяемое представление
//             вида объекта. По умолчанию определяется как представление объекта с ключевыми реквизитами.
//
// Пример:
//	Если Правило.ТипОбъектаИС = "Документ.ПоступлениеТоваровУслуг" Тогда
//		СтруктураПоиска = Новый Структура;
//		СтруктураПоиска.Вставить("Ключевой", Истина);
//		СтруктураПоиска.Вставить("ИмяРеквизитаОбъектаИС", "ВидОперации");
//		КлючевыеРеквизиты = Правило.ПравилаЗаполненияРеквизитовИС.НайтиСтроки(СтруктураПоиска);
//		Если КлючевыеРеквизиты.Количество() > 0 Тогда
//			ВидОперации = КлючевыеРеквизиты[0].ЗначениеРеквизитаИС;
//			Если ВидОперации = Перечисления.ВидыОперацийПоступлениеТоваровУслуг.Товары Тогда
//				ПредставлениеВидаОбъектаПотребителя = НСтр("ru = 'Товары (накладная)'");
//			КонецЕсли;
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПриОпределенииПредставленияВидаОбъектаПотребителя(Правило, ПредставлениеВидаОбъектаПотребителя) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииПредставленияВидаОбъектаПотребителя(Правило, ПредставлениеВидаОбъектаПотребителя) 
```
</details>

## ПриОпределенииПредставленияОбъектаПотребителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет представление объекта интегрируемой конфигурации. Используется, если стандартное
// представление из синонима и ключевых реквизитов через запятую оказывается недостаточно читабельным.
//
// Параметры:
//   Правило - СправочникОбъект.ПравилаИнтеграцииС1СДокументооборотом
//           - СправочникОбъект.ПравилаИнтеграцииС1СДокументооборотом3 - правило, для которого
//     определяется представление.
//   ПредставлениеОбъектаПотребителя - Строка - неявно возвращаемое значение, переопределяемое представление
//             объекта. По умолчанию собирается из синонима объекта и значений ключевых реквизитов правила.
//
// Пример:
//	Если Правило.ТипОбъектаИС = "Документ.ПоступлениеТоваровУслуг" Тогда
//		СтруктураПоиска = Новый Структура;
//		СтруктураПоиска.Вставить("Ключевой", Истина);
//		СтруктураПоиска.Вставить("ИмяРеквизитаОбъектаИС", "ВидОперации");
//		КлючевыеРеквизиты = Правило.ПравилаЗаполненияРеквизитовИС.НайтиСтроки(СтруктураПоиска);
//		Если КлючевыеРеквизиты.Количество() > 0 Тогда
//			ВидОперации = КлючевыеРеквизиты[0].ЗначениеРеквизитаИС;
//			Если ВидОперации = Перечисления.ВидыОперацийПоступлениеТоваровУслуг.Товары Тогда
//				ПредставлениеОбъектаПотребителя = НСтр("ru = 'Поступление товаров'");
//			ИначеЕсли ВидОперации = Перечисления.ВидыОперацийПоступлениеТоваровУслуг.Услуги Тогда
//				ПредставлениеОбъектаПотребителя = НСтр("ru = 'Поступление услуг'");
//			КонецЕсли;
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПриОпределенииПредставленияОбъектаПотребителя(Правило, ПредставлениеОбъектаПотребителя) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииПредставленияОбъектаПотребителя(Правило, ПредставлениеОбъектаПотребителя) 
```
</details>

## ПриОпределенииРазрешенияПользователяИспользоватьИнтеграцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить получение доступности интеграции для текущего пользователя. Может переопределяться
// при отказе от использования поставляемой роли ИспользованиеИнтеграцииС1СДокументооборотом.
//
// Параметры:
//   Разрешено - Булево - Истина, если использование интеграции разрешено.
//
Процедура ПриОпределенииРазрешенияПользователяИспользоватьИнтеграцию(Разрешено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииРазрешенияПользователяИспользоватьИнтеграцию(Разрешено) 
```
</details>

## ПриОпределенииРазрешенияПользователяНаЗапускСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить получение возможности запуска согласования в ДО.
//
// Параметры:
//   ПредметСогласования - ЛюбаяСсылка - согласуемый объект ИС.
//   ТекстПредупреждения - Строка - неявно возвращаемое значение, текст предупреждения.
//   Разрешено - Булево - Истина, если запуск согласования разрешен, Ложь - запрещен, Неопределено - согласно ролям.
//
// Пример:
//	Если ТипЗнч(ПредметСогласования) = Тип("ДокументСсылка._ДемоЗаказПокупателя") Тогда
//		Если ПредметСогласования.Состояние <> Перечисления._ДемоСостоянияЗаказаПокупателя.НаСогласовании Тогда
//			ТекстПредупреждения = НСтр("ru = 'Создание процесса согласования разрешено только на основании
//				|документов в состоянии ""На согласовании"".'");
//			Разрешено = Ложь;
//		КонецЕсли;
//	КонецЕсли;
//
Процедура ПриОпределенииРазрешенияПользователяНаЗапускСогласования(ПредметСогласования, ТекстПредупреждения, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииРазрешенияПользователяНаЗапускСогласования(ПредметСогласования, ТекстПредупреждения, );
```
</details>

## ПриОпределенииРазрешенияПользователяНаПрерываниеСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить получение возможности прерывания согласования в ДО.
//
// Параметры:
//   ПредметСогласования - ЛюбаяСсылка - согласуемый объект ИС.
//   ПредметДО - Структура - описание связанного объекта ДО:
//      name - Строка - представление связанного объекта.
//      ID - Строка - идентификатор связанного объекта.
//      type - Строка - имя типа XDTO.
//   ТекстПредупреждения - Строка - неявно возвращаемое значение, текст предупреждения.
//   Разрешено- Булево - Истина, если прерывание согласования разрешено, Ложь - запрещено, Неопределено - согласно ролям.
//
Процедура ПриОпределенииРазрешенияПользователяНаПрерываниеСогласования(ПредметСогласования, ПредметДО, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииРазрешенияПользователяНаПрерываниеСогласования(ПредметСогласования, ПредметДО, );
```
</details>

## ПриОпределенииСокращенногоНаименованияКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Уточняет сокращенное наименование интегрируемой конфигурации для вывода в заголовках и декорациях.
//
// Параметры:
//   СокращенноеНаименование - Строка - неявно возвращаемое значение, краткое название конфигурации.
//
// Пример:
//	СокращенноеНаименование = НСтр("ru = '1С:ERP УП'");
//
Процедура ПриОпределенииСокращенногоНаименованияКонфигурации(СокращенноеНаименование) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииСокращенногоНаименованияКонфигурации(СокращенноеНаименование) 
```
</details>

## ПриОпределенииТаймаутаСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при определении таймаута веб-сервиса. При необходимости таймаут может быть вынесен в
// настройки администратора интеграции и переопределен в этой процедуре.
//
// Параметры:
//   Таймаут - Число - неявно возвращаемое значение, время в секундах, по истечении которого вызов
//     веб-сервиса Документооборота считается неудачным.
//
Процедура ПриОпределенииТаймаутаСервиса(Таймаут) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииТаймаутаСервиса(Таймаут) 
```
</details>

## ПриОпределенииТиповОбъектовПоддерживающихИнтеграцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет типы объектов ИС, поддерживающие бесшовную интеграцию. По умолчанию заполняется всеми
// типами, входящими в состав типов параметров общих команд подсистемы ИнтеграцияС1СДокументооборотом.
//
// Параметры:
//   Типы - Массив из Тип - массив объектов типа Тип.
//
Процедура ПриОпределенииТиповОбъектовПоддерживающихИнтеграцию(Типы) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииТиповОбъектовПоддерживающихИнтеграцию(Типы) 
```
</details>

## ПриОпределенииШтрихкодаДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить получение штрихкода документа для присвоения связанному документу ДО.
//
// Параметры:
//   Документ - ЛюбаяСсылка - объект ИС, на основании которого создается документ ДО.
//   Штрихкод - Строка - штрихкод для присвоения связанному документу ДО.
//
// Пример:
//	Если ПолучитьФункциональнуюОпцию("ИспользоватьШтрихкодированиеПечатныхФормОбъектов") Тогда
//		ШестнадцатиричноеЧисло = НРег(СтрЗаменить(Документ.УникальныйИдентификатор(), "-", ""));
//		ДлинаСтроки = СтрДлина(ШестнадцатиричноеЧисло);
//		Результат = 0;
//		Для НомерСимвола = 1 По ДлинаСтроки Цикл
//			Результат = Результат * 16 + Найти("0123456789abcdef",
//				Сред(ШестнадцатиричноеЧисло, НомерСимвола, 1)) - 1;
//		КонецЦикла;
//		Штрихкод = Формат(Результат, "ЧГ=0");
//	Иначе
//		Штрихкод = "";
//	КонецЕсли;
//
Процедура ПриОпределенииШтрихкодаДокумента(Документ, Штрихкод) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриОпределенииШтрихкодаДокумента(Документ, Штрихкод) 
```
</details>

## ПриПолученииWSПрокси
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении WSПрокси. Переопределяется, если в конфигурации есть возможность настройки интернет-прокси.
//
// Параметры:
//   ИнтернетПрокси - Неопределено - неявно возвращаемое значение, может быть инициализировано значением
//     типа ИнтернетПрокси.
//
Процедура ПриПолученииWSПрокси(ИнтернетПрокси) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриПолученииWSПрокси(ИнтернетПрокси) 
```
</details>

## ПриПолученииТаблицыЗависимостиКонстант
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить или дополнить список зависимых друг от друга констант. Необходимо, когда при
// включении одной константы, какие-либо другие константы должны выключаться и наоборот.
//
// Параметры:
//   ТаблицаКонстант - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ЗависимостиКонстант
//
// Пример:
//	ИнтеграцияС1СДокументооборотБазоваяФункциональность.ДобавитьСтрокуТаблицыЗависимостиКонстант(
//		ТаблицаКонстант,
//		"ИспользоватьСогласованиеЧерез1СДокументооборот",
//		Истина,
//		"ИспользоватьВнутреннееСогласованиеЗаявокНаВозвратТоваровОтКлиентов",
//		Ложь);
//
Процедура ПриПолученииТаблицыЗависимостиКонстант(ТаблицаКонстант) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриПолученииТаблицыЗависимостиКонстант(ТаблицаКонстант) 
```
</details>

## ПриПолученииТокенаДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить получение JWT-токена для авторизации в веб-сервисе Документооборота.
//
// Параметры:
//   ТекстТокенаДоступа - Строка - неявно возвращаемое значение, JWT-токен строкой.
//
// Пример:
//	ТокенДоступа = Новый ТокенДоступа;
//	ПараметрыТокена = ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПараметрыТокенаДоступа();
//	ЗаполнитьЗначенияСвойств(ТокенДоступа, ПараметрыТокена);
//	КлючПодписиТокена = Константы.КлючПодписиТокенаДоступа1СДокументооборот.Получить();
//	ТокенДоступа.Подписать(АлгоритмПодписиТокенаДоступа.HS256, КлючПодписиТокена);
//	ТекстТокенаДоступа = Строка(ТокенДоступа);
//
Процедура ПриПолученииТокенаДоступа(ТекстТокенаДоступа) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриПолученииТокенаДоступа(ТекстТокенаДоступа) 
```
</details>

## ПриПроверкеСоответствияПравилаФункциональнымОпциям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет соответствие правила интеграции функциональным опциям. Вызывается при выборе подходящего правила
// и позволяет отказаться от правил, связанных с объектами, выключенными по ФО.
//
// Параметры:
//   Правило - СправочникСсылка.ПравилаИнтеграцииС1СДокументооборотом - проверяемое правило.
//   ТипОбъектаДО - Строка - Тип объекта ДО.
//   ТипОбъектаИС - Строка - Тип объекта ИС (полное имя в метаданных).
//   Отказ - Булево - при установке в Истина правило не будет использоваться.
//   ИмяКлючевогоРеквизита - Строка - имя ключевого реквизита правила.
//   ЗначениеКлючевогоРеквизита - Произвольный - значение ключевого реквизита правила.
//
// Пример:
//	Если ТипОбъектаИС = "Документ.ПоступлениеНМА"
//			И Не ПолучитьФункциональнуюОпцию("ВедетсяУчетНМА") Тогда
//		Отказ = Истина;
//		Возврат;
//	КонецЕсли;
//
Процедура ПриПроверкеСоответствияПравилаФункциональнымОпциям(Правило, ТипОбъектаДО, ТипОбъектаИС, Отказ, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриПроверкеСоответствияПравилаФункциональнымОпциям(Правило, ТипОбъектаДО, ТипОбъектаИС, Отказ, );
```
</details>

## ПриСозданииНаСервереФормыВыбораПравила
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет представление формы выбора правила интеграции. Используется при неоднозначности правил и
// позволяет предложить пользователю менее техногенную форму выбора.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма ВыборПравила обработки ИнтеграцияС1СДокументооборот.
//
// Пример:
//	Форма.Заголовок = НСтр("ru = 'Форма документа'");
//	Форма.Автозаголовок = Ложь;
//	Форма.Пояснение = НСтр("ru = 'Выберите вид документа:'");
//	Форма.Элементы.Пояснение.Видимость = Истина;
//
Процедура ПриСозданииНаСервереФормыВыбораПравила(Форма) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриСозданииНаСервереФормыВыбораПравила(Форма) 
```
</details>

## ПриСозданииПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании объекта ИС по ссылке в реквизите объекта ДО. Может использоваться для
// дозаполнения реквизитов нового объекта ИС, например, если стандартный обработчик заполнения не
// заполняет обязательные реквизиты по умолчанию.
// Внимание, поскольку данная процедура может выполняться в ходе обмена данными с ДО, в ней
// не рекомендуется выполнять никакие обращения к веб-сервису ДО, а также получать прокси сервиса ДО.
//
// Параметры:
//   ОбъектИС - Произвольный - созданный, но еще не записанный объект ИС.
//   ОбъектXDTO - ОбъектXDTO - исходный объект, соответствие которому не найдено в текущей ИБ.
//   ЗаполняемыйОбъектИС - Произвольный - объект ИС, в ходе заполнения которого вызывается создание
//     ОбъектИС по ссылке. Обеспечивает контекст, необходимый для заполнения ОбъектИС.
//
// Пример:
//	Если ТипЗнч(ОбъектИС) = Тип("СправочникОбъект._ДемоОрганизации") Тогда
//		ОбъектИС.ЮрФизЛицо = Перечисления.ЮрФизЛицо.ЮрЛицо;
//		Если ОбъектXDTO.objectID.type = "DMOrganization"
//				И ОбъектXDTO.objectID.ID = "ИндивидуальныйПредприниматель" Тогда
//			ОбъектИС.ЮрФизЛицо = Перечисления.ЮрФизЛицо.ИндивидуальныйПредприниматель;
//		КонецЕсли;
//	КонецЕсли;
//	Если ТипЗнч(ОбъектИС) = Тип("СправочникОбъект._ДемоБанковскиеСчета")
//			И ОбъектXDTO.objectID.type = "DMBankAccount" Тогда
//		ОбъектИС.НомерСчета = ОбъектXDTO.number;
//	КонецЕсли;
//
Процедура ПриСозданииПоСсылке(ОбъектИС, ОбъектXDTO, ЗаполняемыйОбъектИС = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриСозданииПоСсылке(ОбъектИС, ОбъектXDTO, ЗаполняемыйОбъектИС);
```
</details>

## ПриУстановкеПравилаЗаполненияПриВыгрузкеПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить установку правила заполнения при выгрузке по умолчанию.
//
// Параметры:
//   ПравилаЗаполнения - Соответствие из КлючИЗначение - соответствие имен реквизитов свойствам XDTO:
//     * Ключ - Строка - имя реквизита.
//     * Значение - Строка - наименование свойства XDTO.
//   Приемник - Строка - имя XDTO-типа приемника.
//   Источник - Строка - полное имя объекта метаданных-источника.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриУстановкеПравилаЗаполненияПриВыгрузкеПоУмолчанию(ПравилаЗаполнения, Приемник, Источник, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриУстановкеПравилаЗаполненияПриВыгрузкеПоУмолчанию(ПравилаЗаполнения, Приемник, Источник, );
```
</details>

## ПриУстановкеПравилаЗаполненияПриЗагрузкеПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить установку правила заполнения при загрузке по умолчанию.
//
// Параметры:
//   ПравилаЗаполнения - Соответствие из КлючИЗначение - соответствие имен реквизитов свойствам XDTO:
//     * Ключ - Строка - имя реквизита.
//     * Значение - см. ИнтеграцияС1СДокументооборотБазоваяФункциональность.ПравилоЗаполненияИзРеквизитаОбъектаДО
//   Приемник - Строка - полное имя объекта метаданных-приемника.
//   Источник - Строка - имя XDTO-типа источника.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная обработка
//     производиться не будет.
//
Процедура ПриУстановкеПравилаЗаполненияПриЗагрузкеПоУмолчанию(ПравилаЗаполнения, Приемник, Источник, Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПриУстановкеПравилаЗаполненияПриЗагрузкеПоУмолчанию(ПравилаЗаполнения, Приемник, Источник, );
```
</details>

## ПроверитьСоответствиеОпределяемыхТиповИПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при обновлении БИД, и сверяет корректность состав определяемых типов с планом обмена.
//
// Параметры:
//   Ошибки - Массив из Строка - список ошибок, выявленных в ходе проверки.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная проверка
//     производиться не будет.
//
Процедура ПроверитьСоответствиеОпределяемыхТиповИПланаОбмена(Ошибки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПроверитьСоответствиеОпределяемыхТиповИПланаОбмена(Ошибки, СтандартнаяОбработка) 
```
</details>

## ПроверитьСоответствиеОпределяемыхТиповМеждуСобой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при обновлении БИД, и сверяет корректность состав определяемых типов между собой.
//
// Параметры:
//   Ошибки - Массив из Строка - список ошибок, выявленных в ходе проверки.
//   СтандартнаяОбработка - Булево - неявно возвращаемое значение, признак того, что стандартная проверка
//     производиться не будет.
//
Процедура ПроверитьСоответствиеОпределяемыхТиповМеждуСобой(Ошибки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.ПроверитьСоответствиеОпределяемыхТиповМеждуСобой(Ошибки, СтандартнаяОбработка) 
```
</details>

## УстановитьРежимыИзмененияВПроведенномДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает доступные для выбора режимы изменения реквизита в проведенном документе.
//
// Параметры:
//   ТипОбъектаИС - Строка - представление типа объекта интегрированной системы.
//   РеквизитИС - Строка - представление реквизита интегрированной системы.
//   СписокВыбора - СписокЗначений из ПеречислениеСсылка.РежимИзмененияПроведенногоДокументаДанными1СДокументооборота -
//     доступные значения режимов изменения реквизита.
//
// Пример:
//	Если ТипОбъектаИС = "Документ.ЗаказКлиента" И РеквизитИС = "Статус" Тогда
//		СписокВыбора.Очистить();
//		СписокВыбора.Добавить(
//			Перечисления.РежимИзмененияПроведенногоДокументаДанными1СДокументооборота.РазрешеноСПерепроведением);
//		СписокВыбора.Добавить(
//			Перечисления.РежимИзмененияПроведенногоДокументаДанными1СДокументооборота.Запрещено);
//	КонецЕсли;
//
Процедура УстановитьРежимыИзмененияВПроведенномДокументе(ТипОбъектаИС, РеквизитИС, СписокВыбора) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотБазоваяФункциональностьПереопределяемый.УстановитьРежимыИзмененияВПроведенномДокументе(ТипОбъектаИС, РеквизитИС, СписокВыбора) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
