---
title: Интеграция с 1С документооборот клиент сервер
slug: zup/интеграция-с-1с-документооборот-клиент-сервер
---


## ПредставлениеТипаОбъектаXDTO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление типа объекта XDTO Документооборота по имени типа.
//
// Параметры:
//   ТипXDTO - Строка - имя типа объекта XDTO.
//
// Возвращаемое значение:
//   Строка - представление типа объекта XDTO Документооборота по имени типа.
//
Функция ПредставлениеТипаОбъектаXDTO(ТипXDTO) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ПредставлениеТипаОбъектаXDTO(ТипXDTO) 
```
</details>

## ЧислоВСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует длительность интервала времени в строку вида час:мин.
//
// Параметры:
//   Длительность - Число - длительность интервала времени в секундах.
//   ПредставлениеНуля - Строка - представление интервала нулевой длительности.
//
// Возвращаемое значение:
//   Строка - представление интервала в виде час:мин.
//
Функция ЧислоВСтроку(Длительность, ПредставлениеНуля = "'") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ЧислоВСтроку(Длительность, ПредставлениеНуля);
```
</details>

## ЧислоИзСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует строку вида час:мин в длительность интервала времени.
//
// Параметры:
//   ДлительностьСтр - Строка - представление интервала времени в виде строки час:мин.
//
// Возвращаемое значение:
//   Число - длительность интервала времени в секундах.
//
Функция ЧислоИзСтроки(ДлительностьСтр) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ЧислоИзСтроки(ДлительностьСтр) 
```
</details>

## ПроверитьФормат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку строки на соответствие представлению интервала времени в виде час:мин.
//
// Параметры:
//   ДлительностьСтр - Строка - проверяемая строка.
//
// Возвращаемое значение:
//   Булево - Истина, если переданная строка соответствует виду час:мин, и Ложь в противном случае.
//
Функция ПроверитьФормат(ДлительностьСтр) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ПроверитьФормат(ДлительностьСтр) 
```
</details>

## ПредставлениеПроектаЗадачи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку представления проекта и проектной задачи для одного поля.
//
// Параметры:
//   Проект - ЛюбаяСсылка, Строка - ссылка или строка представления проекта.
//   ПроектнаяЗадача - ЛюбаяСсылка, Строка - ссылка или строка представления проектной задачи.
//
// Возвращаемое значение:
//   Строка
//
Функция ПредставлениеПроектаЗадачи(Проект, ПроектнаяЗадача) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ПредставлениеПроектаЗадачи(Проект, ПроектнаяЗадача) 
```
</details>

## ДобавитьЗначениеКСтрокеЧерезРазделитель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет к Строке Разделитель и ДобавляемоеЗначение в случае, если Строка и
// ДобавляемоеЗначение не пустые. Если Строка пустая или ДобавляемоеЗначение
// не заполнено - то добавляет к Строке ДобавляемоеЗначение.
//
// Параметры:
//   ИсходнаяСтрока - Строка - Модифицируется в процедуре.
//   Разделитель - Строка - Разделитель.
//   ДобавляемоеЗначение - Строка - Добавляемое значение.
//
Процедура ДобавитьЗначениеКСтрокеЧерезРазделитель(ИсходнаяСтрока, Разделитель, ДобавляемоеЗначение) Экспорт
```

Пример вызова
```bsl
ИнтеграцияС1СДокументооборотКлиентСервер.ДобавитьЗначениеКСтрокеЧерезРазделитель(ИсходнаяСтрока, Разделитель, ДобавляемоеЗначение) 
```
</details>

## КартинкаПоРолиПредмета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает картинку предмета из библиотеки согласно его роли.
//
// Параметры:
//   РольПредмета - Строка - роль предмета.
//
// Возвращаемое значение:
//   Картинка - картинка из библиотеки.
//
Функция КартинкаПоРолиПредмета(РольПредмета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.КартинкаПоРолиПредмета(РольПредмета) 
```
</details>

## НомерКартинкиПоРолиПредмета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает номер картинки предмета в коллекции согласно его роли.
//
// Параметры:
//   РольПредмета - Строка - роль предмета.
//
// Возвращаемое значение:
//   Число - номер картинки из КоллекцияРолиПредметов
//
Функция НомерКартинкиПоРолиПредмета(РольПредмета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.НомерКартинкиПоРолиПредмета(РольПредмета) 
```
</details>

## ЭтоСправочник
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли справочником тип объекта ДО.
//
// Параметры:
//   Тип - Строка - имя типа XDTO.
//
// Возвращаемое значение:
//   Булево - истина, если тип соответствует справочнику ДО.
//
Функция ЭтоСправочник(Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ЭтоСправочник(Тип) 
```
</details>

## ЭтоДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли документом в прикладном смысле тип объекта ДО.
//
// Параметры:
//   Тип - Строка - имя типа XDTO.
//
// Возвращаемое значение:
//   Булево - истина, если тип соответствует документу ДО (в прикладном смысле).
//
Функция ЭтоДокумент(Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ЭтоДокумент(Тип) 
```
</details>

## ЭтоБизнесПроцесс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли тип объекта ДО бизнес-процессом.
//
// Параметры:
//   Тип - Строка - имя типа XDTO.
//
// Возвращаемое значение:
//   Булево - истина, если тип соответствует бизнес-процессу ДО.
//
Функция ЭтоБизнесПроцесс(Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ЭтоБизнесПроцесс(Тип) 
```
</details>

## ЭтоЗадачаБизнесПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли тип объекта ДО задачей бизнес-процесса.
//
// Параметры:
//   Тип - Строка - имя типа XDTO.
//
// Возвращаемое значение:
//   Булево - истина, если тип соответствует задаче ДО.
//
Функция ЭтоЗадачаБизнесПроцесса(Тип) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ЭтоЗадачаБизнесПроцесса(Тип) 
```
</details>

## ПредставлениеСрокаДействияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает строковое представление срока действия по значениям реквизитов формы.
//
// Параметры:
//   ДатаНачала - Дата - дата начала действия.
//   Бессрочный - Булево - Истина, если документ бессрочный.
//   ДатаОкончания - Дата - дата окончания действия.
//   ПорядокПродленияID - Строка - порядок продления.
//   ПорядокПродления - Строка - описание порядка продления.
//
// Возвращаемое значение:
//   Строка - представление срока действия.
//
Функция ПредставлениеСрокаДействияДокумента(ДатаНачала, Бессрочный, ДатаОкончания,  ПорядокПродленияID, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ПредставлениеСрокаДействияДокумента(ДатаНачала, Бессрочный, ДатаОкончания, ПорядокПродленияID, );
```
</details>

## ПолучитьОбзорДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает HTML-представление документа для показа в карточке по объекту XDTO.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма обработки ИнтеграцияС1СДокументооборот с данными документа.
//
// Возвращаемое значение:
//   Строка - HTML-представление документа.
//
Функция ПолучитьОбзорДокумента(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ПолучитьОбзорДокумента(Форма) 
```
</details>

## ПолучитьСтрокуСоставДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текстовое представление состава документа.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения -  форма обработки ИнтеграцияС1СДокументооборот с данными документа.
//
// Возвращаемое значение:
//   Строка - текстовое представление состава документа.
//
Функция ПолучитьСтрокуСоставДокумента(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.ПолучитьСтрокуСоставДокумента(Форма) 
```
</details>

## РазностьДатВДнях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Строковое описание разности дат в днях с учетом склонений
//
// Параметры:
//   Дата1 - Дата - первая дата.
//   Дата2 - Дата - вторая дата.
//   ИспользоватьДатуИВремяВСрокахЗадач - Булево - признак использования даты в сроках задач.
//
// Возвращаемое значение:
//   Строка - текстовое представление разности дат.
//
Функция РазностьДатВДнях(Дата1, Дата2, ИспользоватьДатуИВремяВСрокахЗадач = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияС1СДокументооборотКлиентСервер.РазностьДатВДнях(Дата1, Дата2, ИспользоватьДатуИВремяВСрокахЗадач);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
