---
title: Интерфейсы взаимодействия БРО вызов сервера
slug: zup/интерфейсы-взаимодействия-бро-вызов-сервера
---


## СведенияОПредставителеПоРегистрацииВНалоговомОргане
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения сведений об уполномоченном представителе организации в налоговом органе.
// Параметры:
//	 РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане - должно быть непустым значением.
//	 ДатаПодписи - дата - дата, по состоянию на которую будут читаться данные представителя-физлица.
//
// Возвращаемое значение:
//   Структура - структура с полями:
//	   * ТипПодписанта - строка со значениями "1", "2";
//	   * ПредставительЮрЛицо - Булево - признак представителя юр. лица;
//	   * НаименованиеОрганизацииПредставителя - Строка - наименование организации представителя;
//	   * ДокументПредставителя - Строка - документ представителя;
//	   * Фамилия - Строка - фамилия;
//	   * Имя - Строка - имя;
//	   * Отчество - Строка - отчество;
//	   * ФИОПредставителя - Строка - ФИО представителя.
//
Функция СведенияОПредставителеПоРегистрацииВНалоговомОргане(РегистрацияВНалоговомОргане, ДатаПодписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.СведенияОПредставителеПоРегистрацииВНалоговомОргане(РегистрацияВНалоговомОргане, ДатаПодписи) 
```
</details>

## ДатаПодключения1СОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату подключения учетной записи документооборота для организации или наименьшую дату одобрения заявления.
Функция ДатаПодключения1СОтчетности(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ДатаПодключения1СОтчетности(Организация) 
```
</details>

## СведенияКвитанцииОПриемеЗаявления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения информации о регистрации заявления о ввозе товаров в налоговом органе.
// Параметры:
//	 ЗаявлениеОВвозеТоваровИлиМассив - ДокументСсылка.ЗаявлениеОВвозеТоваров, Массив.
//
// Возвращаемое значение:
//   Структура, Массив:
//	   * Выполнено              - Булево - если Истина, то функция успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//	   * ОписаниеОшибки         - Строка - описание ошибки (недостаточно прав, некорректная структура квитанции).
//	   * ЗаявлениеОВвозеТоваров - ДокументСсылка.ЗаявлениеОВвозеТоваров.
//	   * ЕстьКвитанцияОПриеме   - Булево.
//	   * РегНом                 - Строка - регистрационный номер заявления, присвоенный налоговым органом, регламентирован формат
//	                                       до 16 символов.
//	   * ДатаРег                - Строка - дата регистрации заявления в налоговом органе, регламентирован формат ДД.ММ.ГГГГ.
//
Функция СведенияКвитанцииОПриемеЗаявления(ЗаявлениеОВвозеТоваровИлиМассив) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.СведенияКвитанцииОПриемеЗаявления(ЗаявлениеОВвозеТоваровИлиМассив) 
```
</details>

## СведенияКвитанцийОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения квитанций и протоколов отчета.
// Параметры:
//   СсылкаНаОтчет - Ссылка из определяемого типа ПредметЦиклаОбмена - например,
//                                            ДокументСсылка.РегламентированныйОтчет,
//                                            СправочникСсылка.ЭлектронныеПредставленияРегламентированныхОтчетов,
//                                            ДокументСсылка.СведенияОТрудовойДеятельностиРаботниковСЗВ_ТД
//   ТипТранспортногоСообщения - Перечисления.ТипыТранспортныхСообщений - например,
//                                            Перечисления.ТипыТранспортныхСообщений.ПротоколПФР
//                             - Строка - контролирующий орган и имя поля объекта отправки, например "ФССКвитанция",
//                                        значение ТипыСодержимогоТранспортногоКонтейнера в этом случае не учитывается
//   ТипыСодержимогоТранспортногоКонтейнера - Перечисления.ТипыСодержимогоТранспортногоКонтейнера - например,
//                                            Перечисления.ТипыСодержимогоТранспортногоКонтейнера.ПротоколПФР
//                                            для получения XML протокола СЗВ-ТД,
//                                            Перечисления.ТипыСодержимогоТранспортногоКонтейнера.ПротоколПриложениеПФР
//                                            для получения XML и HTML приложений к протоколу СЗВ-М
//
// Возвращаемое значение:
//   Структура:
//     * Выполнено      - Булево          - если Истина, то функция успешно выполнена, иначе см. ОписаниеОшибки.
//     * ОписаниеОшибки - Строка          - описание ошибки, например, недостаточно прав.
//     * Сведения       - ТаблицаЗначений - содержимое РегистрСведений.СодержимоеТранспортныхКонтейнеров,
//                                          основные колонки (при строковом значении параметра "ТипТранспортногоСообщения"
//                                          возващается одна запись только с этими колонками):
//                                          ИмяФайла - Строка
//                                          ВАрхиве  - Булкво - при Истина содерджмое недоступно
//                                          Данные   - ХранилищеЗначения - ДвоичныеДанные квитанции/протокола
//                                          ТипСодержимогоФайла - Перечисления.ТипыСодержимогоФайлов - например,
//                                            Перечисления.ТипыСодержимогоФайлов.Xml
//                                          Содержимое - колонка присутствует при строковом значении параметра
//                                            "ТипТранспортногоСообщения", при значении "ФССКвитанция" для реестра
//                                            стимулирующих выплат медицинским и социальным работникам содержит
//                                            структуру:
//                                              ИдентификаторОтправки - Строка - значение узла "recriveID",
//                                              СтатусОбработки - Число - значение узла "statusGeneral",
//                                              ДатаВремяОбработки - Дата - значение узла "dateTimeReceive",
//                                              СообщенияОбОшибках - Строка - все сообщения из узла "firstErrorList"
//                                              с кодами ошибок в скобках, разделенные переводами строк,
//                                              ОшибкиПервичнойОбработки - Массив - из узла "firstErrorList":
//                                                КодОшибки - Строка - узел "errorCode",
//                                                ОписаниеОшибки - Строка - узел "errorDescription",
//                                              ПротоколОбработки - Массив - из узла "protocol" - "failedList" -
//                                              "failedBatchNoDetail":
//                                                НомерЗаписи - Строка - узел "batchNo",
//                                                ОшибкиОбработки - Массив - из узла "errorList":
//                                                  КодОшибки - Строка - узел "errorCode",
//                                                  ОписаниеОшибки - Строка - узел "errorDescription".
//
Функция СведенияКвитанцийОтчета( Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.СведенияКвитанцийОтчета();
```
</details>

## ПолучитьИмяФормыУведомленияПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает форму для уведомления
// Например: Отчет.РегламентированноеУведомлениеЛьготаТранспортЗемля.Форма.Форма2019_1
// Параметры:
//              ВидУведомления - ПеречислениеСсылка.ВидыУведомленийОСпецрежимахНалогообложения.
//              ДатаСведений - Дата, на какую дату нужна форма
Функция ПолучитьИмяФормыУведомленияПоУмолчанию(ВидУведомления, ДатаСведений) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ПолучитьИмяФормыУведомленияПоУмолчанию(ВидУведомления, ДатаСведений) 
```
</details>

## ПолучитьПроцедурыДекларированияФТСССервера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает процедуры таможенного декларирования товаров с сайта ФТС.
//
// Параметры:
//   ПараметрыОтправки - Структура - параметр структуры "ПараметрыОтправки", возвращаемый процедурой
//                                   ИнтерфейсыВзаимодействияБРОКлиент.ПолучитьПроцедурыДекларированияФТС
//                                   при РежимыРаботы.ТолькоПолучитьНастройки = Истина;
//   ПараметрыСоединения - Структура - параметр структуры "ПараметрыСоединения", возвращаемый процедурой
//                                   ИнтерфейсыВзаимодействияБРОКлиент.ПолучитьПроцедурыДекларированияФТС
//                                   при РежимыРаботы.ТолькоПолучитьНастройки = Истина.
//
// Возвращаемое значение:
//   Массив из структур с процедурами декларирования для передачи в процедуру
//   ИнтерфейсыВзаимодействияБРОКлиент.ОбработатьРезультатыПолученияПроцедурДекларированияФТС.
//
Функция ПолучитьПроцедурыДекларированияФТСССервера(Знач ПараметрыОтправки, ПараметрыСоединения) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ПолучитьПроцедурыДекларированияФТСССервера(ПараметрыОтправки, ПараметрыСоединения) 
```
</details>

## СведенияОПрисвоенииРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения квитанции о присвоении регистрационного номера партии товара.
// Параметры:
//   СсылкаНаОтчетИлиДанныеКвитанции - Ссылка из определяемого типа ПредметЦиклаОбмена - например, ссылка, возвращенная
//                                     ЭлектронныйДокументооборотСКонтролирующимиОрганамиВызовСервераПереопределяемый.ПриИзмененииСтатусаОтправкиДокумента
//                                   - ДвоичныеДанные - данные квитанции о присвоении РНПТ с КНД 1169012
//   СтатусОтправки                  - Перечисления.СтатусыОтправки - например, статус, возвращаемый
//                                     ЭлектронныйДокументооборотСКонтролирующимиОрганамиВызовСервераПереопределяемый.ПриИзмененииСтатусаОтправкиДокумента
//                                   - Неопределено - не используется при предаче двоичных данных квитанции.
//
// Возвращаемое значение:
//   Структура:
//     * ЭтоКвитанцияОПрисвоенииРНПТ - Булево          - при значении Истина заполняются остальные поля,
//     * НомерУведомления            - Строка          - номер уведомления об остатках прослеживаемого товара,
//     * ДатаУведомления             - Дата            - дата уведомления об остатках прослеживаемого товара,
//     * ДанныеКвитанции             - ДволичныеДанные - данные квитанции о присвоении РНПТ с КНД 1169012,
//     * Квитанция                   - Структура       - содержимое квитанции о присвоении РНПТ с КНД 1169012:
//       ** ДатаДокумента                - Дата   - дата формирования документа,
//       ** РНПТ                         - Строка - регистрационный номер партии товара,
//       ** ВидДокумента                 - Строка - "Уведомление об имеющихся остатках товаров, подлежащих прослеживаемости"
//                                                  или "Уведомление о ввозе товаров, подлежащих прослеживаемости, с
//                                                  территории другого государства-члена Евразийского экономического
//                                                  союза на территорию Российской Федерации и иные территории,
//                                                  находящиеся под ее юрисдикцией",
//       ** НомерУведомления             - Строка,
//       ** ДатаУведомления              - Дата,
//       ** НаименованиеСобственника     - Строка - наименование собственника товара, если это организация,
//       ** ИННСобственника              - Строка - ИНН собственника товара, если это организация,
//       ** КППСобственника              - Строка - КПП собственника товара, если это организация,
//       ** ИННФЛСобственника            - Строка - ИНН собственника товара, если это физическое лицо,
//       ** ФамилияСобственника          - Строка - фамилия собственника товара, если это физическое лицо,
//       ** ИмяСобственника              - Строка - имя собственника товара, если это физическое лицо,
//       ** ОтчествоСобственника         - Строка - отчество собственника товара, если это физическое лицо,
//       ** КодыОшибок                   - Массив - строки кодов ошибок,
//     * ОписаниеОшибки              - Строка          - описание ошибки извлечения данных квитанции, например, из-за
//                                                       недостаточности прав на документооборот с гос.органами.
//
Функция СведенияОПрисвоенииРНПТ(СсылкаНаОтчетИлиДанныеКвитанции, СтатусОтправки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.СведенияОПрисвоенииРНПТ(СсылкаНаОтчетИлиДанныеКвитанции, СтатусОтправки);
```
</details>

## ДокументыРеализацииПолномочийНО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По организации, номеру, дате, виду уведомления ищет документы реализации полномочий налоговых органов,
// сейчас возвращает квитанции о присвоении РНПТ.
// Параметры:
//   СсылкаНаУведомление - Ссылка из определяемого типа ПредметЦиклаОбмена,
//   ВозвращатьСостояние - Булево - возвращать ключ "СостояниеСдачиОтчетности".
//
// Возвращаемое значение:
//   Массив из Структур - квитанции о присвоении РНПТ, КНД 1169012, по убыванию даты:
//     * Ссылка                   - СправочникСсылка.ДокументыРеализацииПолномочийНалоговыхОрганов,
//     * РНПТ                     - Строка,
//     * ВидДокумента             - Строка - "Уведомление об имеющихся остатках товаров, подлежащих прослеживаемости"
//                                           или "Уведомление о ввозе товаров, подлежащих прослеживаемости, с
//                                           территории другого государства-члена Евразийского экономического
//                                           союза на территорию Российской Федерации и иные территории,
//                                           находящиеся под ее юрисдикцией",
//     * НомерУведомления         - Строка,
//     * ДатаУведомления          - Дата,
//     * НаименованиеСобственника - Строка - наименование собственника товара, если это организация,
//     * ФИОСобственника          - Строка - фамилия собственника товара, если это физическое лицо,
//     * ИННСобственника          - Строка - ИНН собственника товара - организации или физического лица,
//     * КППСобственника          - Строка - КПП собственника товара - организации,
//     * ОшибкиНСП                - Массив:
//        ** КодОшибки            - Строка,
//        ** ТекстОшибки          - Строка,
//     * СостояниеСдачиОтчетности - ПеречислениеСсылка.СостояниеСдачиОтчетности - возвращается, если
//                                           ВозвращатьСостояние = Истина.
//     * ОписаниеОшибки           - Строка - текст ошибки получения СостояниеСдачиОтчетности или пустая строка
//                                           при успехе, возвращается, если ВозвращатьСостояние = Истина.
//
Функция ДокументыРеализацииПолномочийНО(СсылкаНаУведомление, ВозвращатьСостояние = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ДокументыРеализацииПолномочийНО(СсылкаНаУведомление, ВозвращатьСостояние);
```
</details>

## ТекстыДляЗапросаДокументовРеализацииПолномочийНО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Тексты колонок и левого соединения с запросом документов УведомлениеОбОстаткахПрослеживаемыхТоваров,
// УведомлениеОВвозеПрослеживаемыхТоваров для получения реквизитов квитанций о присвоении РНПТ.
// Параметры:
//   ИмяДокументаВЗапросе - Строка.
//   ТолькоПризнакЗаполненияРНПТ - Булево - В запрос включить только поле ДокументыРеализацииПолномочийНО_РНПТЗаполнен.
//
// Возвращаемое значение:
//   Структура:
//     * ПеречислениеКолонок   - Строка - колонки "ДокументыРеализацииПолномочийНО_РНПТЗаполнен",
//                                        "ДокументыРеализацииПолномочийНО_Ссылка",
//                                        "ДокументыРеализацииПолномочийНО_РНПТ",
//                                        "ДокументыРеализацииПолномочийНО_ВидУведомления",
//                                        "ДокументыРеализацииПолномочийНО_НомерУведомления",
//                                        "ДокументыРеализацииПолномочийНО_ДатаУведомления",
//                                        "ДокументыРеализацииПолномочийНО_НаименованиеСобственника",
//                                        "ДокументыРеализацииПолномочийНО_ФИОСобственника",
//                                        "ДокументыРеализацииПолномочийНО_ИННСобственника",
//                                        "ДокументыРеализацииПолномочийНО_КППСобственника",
//     * СоединениеСДокументом - Строка - строка левого соединения.
//
Функция ТекстыДляЗапросаДокументовРеализацииПолномочийНО(ИмяДокументаВЗапросе = "Уведомление", ТолькоПризнакЗаполненияРНПТ = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ТекстыДляЗапросаДокументовРеализацииПолномочийНО(ИмяДокументаВЗапросе, ТолькоПризнакЗаполненияРНПТ);
```
</details>

## ОсновныеРеквизитыМашиночитаемыхДоверенностейФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения основных реквизитов действующих МЧД ФНС и МЧД ФНС распределенного реестра,
// по убыванию даты выдачи. Включаются МЧД, которые могли быть зарегистрированы из других баз и загружены в эту
// или регистрация еще не завершилась, так как их пользователь тоже может захотеть выбрать.
// При СначалаЗарегистрированные равном Истина сначала выводятся МЧД со статусом зарегистрированных в этой базе.
// Параметры:
//	 Организация               - СправочникСсылка.Организации - отбор выполняется при заданном значении.
//	 СНИЛС                     - Строка - СНИЛС представителя, отбор выполняется при заданном значении.
//	 СначалаЗарегистрированные - Булево.
//	 ПараметрыОтбора           - Структура - отбор по реквизитам, присутствующим в справочниках
//                               "МашиночитаемыеДоверенностиРаспределенныйРеестр" и "МашиночитаемыеДоверенностиФНС",
//                               например, для отбора по ИНН и КПП организации доверителя задать:
//                               Новый Структура("ДоверительЮЛ_ИНН, ДоверительЮЛ_КПП", <ИНН организаци>, <КПП>)
//                               для отбора по ИНН физического лица доверителя задать:
//                               Новый Структура("ДоверительФЛ_ИНН", <ИНН физического лица доверителя>)
//                               для отбора по ИНН физического лица представителя задать:
//                               Новый Структура("ПредставительФЛ_ИНН", <ИНН физического лица представителя>)
//                               для отбора по ИНН и КПП организации представителя, например, филиала, задать:
//                               Новый Структура("ПредставительЮЛ_ИНН, ПредставительЮЛ_КПП", <ИНН>, <КПП филиала>)
//
// Возвращаемое значение:
//   Массив - содержит структуры с полями:
//	   * Ссылка            - Справочник.МашиночитаемыеДоверенностиРаспределенныйРеестр
//                           или Справочник.МашиночитаемыеДоверенностиФНС;
//	   * НомерДоверенности - Строка;
//	   * ДатаВыдачи        - Дата;
//	   * ДатаОкончания     - Дата;
//	   * ТипДоверенности   - Строка - "МашиночитаемыеДоверенностиРаспределенныйРеестр"
//                           или "МашиночитаемыеДоверенностиФНС";
//	   * Статус            - Перечисление.СтатусыМашиночитаемойДоверенностиКО.
//
Функция ОсновныеРеквизитыМашиночитаемыхДоверенностейФНС( Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ОсновныеРеквизитыМашиночитаемыхДоверенностейФНС();
```
</details>

## СведенияДоверенностиФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сведения доверенности, указанной в справочнике "РегистрацииВНалоговомОргане".
// Параметры:
//  РегистрацииВНалоговомОргане - Неопределено или СправочникСсылка.РегистрацииВНалоговомОргане;
//  Организация                 - Неопределено или СправочникСсылка.Организация для поиска регистрации в налоговом
//                                 органе, если параметр "РегистрацииВНалоговомОргане" не задан;
//  КодНО                       - код налогового органа для поиска регистрации в налоговом органе, если параметр
//                                 "РегистрацииВНалоговомОргане" не задан;
//  КПП                         - КПП для поиска регистрации в налоговом органе, если параметр
//                                 "РегистрацииВНалоговомОргане" не задан.
//
// Возвращаемое значение:
//   Неопределено - если доверенность не указана или недостаточно прав.
//   Структура с полями справочника "ДоверенностиНалогоплательщика", "МашиночитаемыеДоверенностиФНС"
//     или "МашиночитаемыеДоверенностиРаспределенныйРеестр", а также обязательно присутствуют поля:
//    * ЕдиныйРегистрационныйНомер                          - Строка - GUID машиночитаемой доверенности
//                                                                      распределенного реестра;
//     * ЭтоМашиночитаемаяДоверенность                       - Булево;
//     * ЭтоМашиночитаемаяДоверенностьРаспределенногоРеестра - Булево;
//     * Ссылка                                              - Справочник.ДоверенностиНалогоплательщика,
//                                                             Справочник.МашиночитаемыеДоверенностиФНС или
//                                                             Справочник.МашиночитаемыеДоверенностиРаспределенныйРеестр;
//     * НомерДоверенности                                   - Строка;
//     * ДатаВыдачи                                          - Дата - может быть незаполненной только в заготовке;
//     * ДатаОкончания                                       - Дата - может быть незаполненной.
//
Функция СведенияДоверенностиФНС( Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.СведенияДоверенностиФНС();
```
</details>

## ПриИзмененииСтатусаДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При изменении статуса доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриИзмененииСтатусаДоверенности
//
Функция ПриИзмененииСтатусаДоверенности(СтатусыДоверенностей, ОпределитьОрганизации = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ПриИзмененииСтатусаДоверенности(СтатусыДоверенностей, ОпределитьОрганизации);
```
</details>

## ПриЗаполненииНалоговыхОргановДействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При заполнении налоговых органов действия доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриЗаполненииНалоговыхОргановДействия
//
Процедура ПриЗаполненииНалоговыхОргановДействия(Организации, НалоговыеОрганыДействия) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОВызовСервера.ПриЗаполненииНалоговыхОргановДействия(Организации, НалоговыеОрганыДействия) 
```
</details>

## ПриПолученииСтатусаРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При инициализации и обновлении статуса доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриИзмененииСтатусаДоверенности
//
Процедура ПриПолученииСтатусаРегистрации(Доверенность, РегистрацияВРеестре) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОВызовСервера.ПриПолученииСтатусаРегистрации(Доверенность, РегистрацияВРеестре) 
```
</details>

## ПриРегистрацииДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При регистрации доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриРегистрацииДоверенности
//
Процедура ПриРегистрацииДоверенности(Доверенность) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОВызовСервера.ПриРегистрацииДоверенности(Доверенность) 
```
</details>

## ПриОпределенииНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настройки формы списка для реестра ФТС справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриОпределенииНастроек
//
Процедура ПриОпределенииНастроек(Настройки) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОВызовСервера.ПриОпределенииНастроек(Настройки) 
```
</details>

## ПриПолученииСтатусов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение статусов для реестра ФТС справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСПереопределяемый.ПриПолученииСтатусов
//
Процедура ПриПолученииСтатусов(Доверенности, Статусы) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОВызовСервера.ПриПолученииСтатусов(Доверенности, Статусы) 
```
</details>

## ИспользуетсяОбменаПоСЭДОЧерезОператора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение флага обмена по СЭДО через оператора. Флаг возвращается установленным, если есть учетная запись
// Калуга Астрал, в ней подключен обмен с СФР в части отчетности бывшего ФСС, лицензия не истекла, а также событие,
// опубликованное через интернет, разрешает обмен через оператора, в настройках обмена с СФР (бывш. ФСС)
// скрытый флажок обмена напрямую не установлен.
// Параметры:
//   Организация - СправочникСсылка.Организация.
//
// Возвращаемое значение:
//   Булево.
//
Функция ИспользуетсяОбменаПоСЭДОЧерезОператора(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.ИспользуетсяОбменаПоСЭДОЧерезОператора(Организация) 
```
</details>

## УчетнаяЗаписьОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение учетной записи.
// Параметры:
//   Организация 			- СправочникСсылка.Организация.
//   ДопустимыеОператоры 	- Массив.
//
// Возвращаемое значение:
//   СправочникСсылка.УчетныеЗаписиДокументооборота.
//
Функция УчетнаяЗаписьОрганизации(Организация, ДопустимыеОператоры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОВызовСервера.УчетнаяЗаписьОрганизации(Организация, ДопустимыеОператоры);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
