---
title: Интерфейсы взаимодействия БРО клиент
slug: zup/интерфейсы-взаимодействия-бро-клиент
---


## ОтправитьОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Групповая отправка отчетов
//
// Параметры:
//  ВыполняемоеОповещение	 - ОписаниеОповещения - описание оповещения, вызываемого после завершения отправки.
//  Ссылки					 - Массив - Массив ссылок на рег. отчеты.
//
Процедура ОтправитьОтчеты(ВыполняемоеОповещение, Ссылки) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ОтправитьОтчеты(ВыполняемоеОповещение, Ссылки) 
```
</details>

## СформироватьИСохранитьНаДискФайлЗапросаВФНСНаПроверкуСведенийРаботников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура создает и записывает на диск файл(-ы) для представления в налоговую инспекцию
// запроса работодателя на проверку ИНН, ФИО, СНИЛС работающих лиц в электронной форме.
//
// Параметры:
//  СтруктураПараметров - Структура - варианты свойств:
//     Вариант 1:
//        * Организация - СправочникСсылка.Организации - организация, по работникам
//                        которой будут формироваться сведения для файла;
//        * ДатаПодписи - Дата - дата, на которую будут формироваться сведения для файла;
//        * РазмерПачки - Число - допустимое количество физических лиц в одном файле
//                        (необязательный параметр, по умолчанию допустимое количество равно 200;
//                        в случае превышения, будет записано необходимое количество файлов).
//     Вариант 2:
//        * РасчетПоСтраховымВзносам - ДокументСсылка.РегламентированныйОтчет - документ,
//                        по данным которого будут формироваться сведения для файла;
//        * РазмерПачки - Число - допустимое количество физических лиц в одном файле
//                        (необязательный параметр, по умолчанию допустимое количество равно 200;
//                        в случае превышения, будет записано необходимое количество файлов).
//
Процедура СформироватьИСохранитьНаДискФайлЗапросаВФНСНаПроверкуСведенийРаботников(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.СформироватьИСохранитьНаДискФайлЗапросаВФНСНаПроверкуСведенийРаботников(СтруктураПараметров) 
```
</details>

## ИзменитьСтатусОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура предназначена для установки вручную статуса отправки из экранных форм объектов,
// отображаемых на закладке "Отчеты" формы "1С-Отчетность", путем выбора значения из выпадающего списка.
//
// Параметры:
//  ПараметрыИзменения - Структура со свойствами:
//    "Форма" - ФормаКлиентскогоПриложения - форма регл. отчета или уведомления о спецрежимах налогообложения;
//    "Организация" - СправочникСсылка.Организации - организация;
//    "КонтролирующийОрган" - Перечисление.ТипыКонтролирующихОрганов - контролирующий орган;
//    "ТекстВопроса" (необязательный) - Строка - текст предупреждения при попытке установить статус "Сдано".
//
Процедура ИзменитьСтатусОтправки(ПараметрыИзменения) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ИзменитьСтатусОтправки(ПараметрыИзменения) 
```
</details>

## ПоказатьУведомлениеОбИзмененииОКТМО46
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает организациям из Московской области уведомление об изменении ОКТМО в 2018 году.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на организацию для которой нужно вывести уведомление.
//   ОповещениеПродолжения - ОписаниеОповещения - описание оповещения, вызываемого после закрытия формы.
//
Процедура ПоказатьУведомлениеОбИзмененииОКТМО46(Организация, ОповещениеПродолжения = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПоказатьУведомлениеОбИзмененииОКТМО46(Организация, ОповещениеПродолжения);
```
</details>

## ПолучитьПроцедурыДекларированияФТС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает процедуры таможенного декларирования на сайте ФТС edata.customs.ru,
// при необходимости, запрашивает логин и пароль портала ФТС и может запомнить их в 1С-Отчетности.
//
// Параметры:
//   ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//     Результат - структура дополнительных параметров получения при РежимыРаботы.ТолькоПолучитьНастройки = Истина,
//       включает элементы "ПараметрыОтправки" и "ПараметрыСоединения" для вызова функции
//       "ИнтерфейсыВзаимодействияБРОВызовСервера.ПолучитьПроцедурыДекларированияФТСССервера", иначе Массив:
//       * РегистрационныйНомер  - Строка - пример: "10013160/160620/0302033", "null" - не задан
//                                          (для выпущенных и зарегистрированных ДТ всегда задан)
//       * ДатаСоздания          - Строка - пример: "2020-06-16T17:26:16";
//       * ТипПроцедуры          - Строка - пример: "ЭК 10", "ИМ 40", число кода процедуры согласно классификатору
//                                          в решении Комиссии Таможенного союза от 20.09.2010 N 378
//                                          (ред. от 21.04.2020) "О классификаторах, используемых для заполнения
//                                          таможенных документов", приложении 1
//                                          HTTP://www.consultant.ru/document/cons_doc_LAW_105110/ec01d1f8f765126d090770e15d2f714e88c4bc67/
//       * Статус                - Строка - пример: "10", у старых ДТ пустая строка; классификатор статусов
//                                          есть в решении Комиссии Таможенного союза от 20.09.2010 N 378
//                                          (ред. от 21.04.2020) "О классификаторах, используемых для заполнения
//                                          таможенных документов", приложении 14
//                                          HTTP://www.consultant.ru/document/cons_doc_LAW_105110/6b14436828c8d727b30feb8feaf7b8f9585b03cd/
//           Только для РежимПолучения = "":
//       * Примечание            - Строка.
//           Только для РежимПолучения = "ВыпущенныеДТ":
//       * ВсегоТоваровМест      - Строка - пример: "3/2"
//       * ОбщаяСтоимость        - Строка - пример: "8 620 403,79 RUB"
//       * ДатаРешения           - Строка - пример: "16.06.2020"
//       * Отправитель           - Строка - пример: ""MICROSOFT IRELAND OPERATIONS LTD" СО СКЛАДА "TEST" ИНН  КПП "
//       * Получатель            - Строка - пример: "ООО "Тест" ИНН 9620030509 КПП 962001001"
//       * СтранаОтправления     - Строка - пример: "НИДЕРЛАНДЫ"
//       * СтранаНазначения      - Строка - пример: "РОССИЯ"
//       * СтранаПроисхождения   - Строка - пример: "РАЗНЫЕ", "КИТАЙ"
//       * ОтветственныйЗаФинУрегулирование - Строка - пример: "ООО "Тест" ИНН 9620030509 КПП 962001001" (при импорте)
//       * Идентификатор         - Строка - пример: "f9c0e49e-f5b8-3e27-b9b4-84fdf001985c"
//       * ПроцедураВЛК          - Строка - пример: "null"
//       * ДатаРегистрации       - Строка - пример: "2020-06-16T00:00:00"
//       * КодРегистрации        - Строка - пример: "10015160"
//       * ПорядковыйНомер       - Строка - пример: "0305033"
//       * Декларант             - Строка - пример: "ООО "Тест" ИНН 9620030509 КПП 962001001"
//       * ИмяОтправителя        - Строка - пример: ""MICROSOFT IRELAND OPERATIONS LTD" СО СКЛАДА "TEST""
//       * ИмяПолучателя         - Строка - пример: "ООО "Тест""
//       * Модель                - Строка - пример: "AUDRequest"
//       * ИмяСтатуса            - Строка - пример: "Saved"
//       * Версия                - Строка - пример: "4.2.0/1.0.0"
//   Организация           - СправочникСсылка.Организации - ссылка на организацию,
//                                                          настройки обмена с ФТС которой используются.
//   РежимПолучения        - Строка - "ВыпущенныеДТ" для выпущенных и зарегистриорванных деклараций на товары,
//                                    примеры результатов приведены для этого варианта;
//                                  - "" для заводимых вручную в личном кабинете ФТС процедур декларирования.
//   Отборы - Структура с необязательными свойствами, по которым выполняется отбор, если свойства присутствуют, заданы:
//     * ТипПроцедуры         - Строка - "ЭК" - экспорт, "ИМ" - импорт;
//     * ДатаРешенияС         - Дата;
//     * ДатаРешенияПо        - Дата;
//     * РегистрационныйНомер - Строка.
//   РежимыРаботы - Неопределено или Структура, в которой могут быть элементы:
//     * ТолькоПолучитьНастройки                   - Булево - по умолчанию Ложь, только получение или ввод параметров
//                                                   настройки;
//     * ПовторятьЗапросПароляПриОшибке            - Булево - по умолчанию Истина, в том числе учитывается в процедуре
//                                                   "ОбработатьРезультатыПолученияПроцедурДекларированияФТС";
//     * ПоказыватьДиалогПриОшибкеДоступаВИнтернет - Булево - по умолчанию Истина,  в том числе учитывается в процедуре
//                                                   "ОбработатьРезультатыПолученияПроцедурДекларированияФТС".
//
Процедура ПолучитьПроцедурыДекларированияФТС( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПолучитьПроцедурыДекларированияФТС();
```
</details>

## ОбработатьРезультатыПолученияПроцедурДекларированияФТС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает результаты получения процедур таможенного декларирования товаров с сайта ФТС.
//
// Параметры:
//   ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//     Результат - при незаданном оповещении "ОповещениеОПолученииНастроек" принимает результат вместо него,
//                 а также принимает Массив с полученными таможенными декларациями, формат описан в оповещении
//                 процедуры "ПолучитьПроцедурыДекларированияФТС".
//   ПроцедурыДекларирования - Неопределено или Массив процедур декларирования, результат функции
//                             "ИнтерфейсыВзаимодействияБРОВызовСервера.ПолучитьПроцедурыДекларированияФТСССервера".
//   ДополнительныеПараметрыПолучения - Структура - результат вызова процедуры "ПолучитьПроцедурыДекларированияФТС"
//                                                  при РежимыРаботы.ТолькоПолучитьНастройки = Истина,
//                                                  возвращает результаты в оповещение, заданное этой процедурой.
//   ОповещениеОПолученииНастроек - ОписаниеОповещения - описание процедуры, принимающей результат получения настроек,
//                                                       при незаданном значении вызывается "ОповещениеОЗавершении".
//     Результат - структура дополнительных параметров получения при РежимыРаботы.ТолькоПолучитьНастройки = Истина
//                 вызова процедуры "ПолучитьПроцедурыДекларированияФТС" в случае повтора попытки соединения
//                 или ввоза пароля.
//
Процедура ОбработатьРезультатыПолученияПроцедурДекларированияФТС( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ОбработатьРезультатыПолученияПроцедурДекларированияФТС();
```
</details>

## ЗапроситьВыпискуОперацийПоРасчетуСБюджетом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗапроситьВыпискуОперацийПоРасчетуСБюджетом(ОповещениеОЗавершении, Организация, РегистрацияВНалоговомОргане, Год) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ЗапроситьВыпискуОперацийПоРасчетуСБюджетом(ОповещениеОЗавершении, Организация, РегистрацияВНалоговомОргане, Год) 
```
</details>

## ПодписатьФайлXMLDSig
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подписать файл XML в формате XMLDSig сертификатом учетной записи документообороат или заданным явно,
// по умолчанию в формате, используемом для СЗВ-ТД.
//
// Параметры:
//   ОповещениеОЗавершении      - ОписаниеОповещения - описание процедуры, принимающей результат.
//     Результат                  - Строка - адрес временного хранилища с двоичными данными подписанного файла,
//                                  Неопределено - при ошибке.
//   ОрганизацияИлиСертификат   - СправочникСсылка.Организации или
//                                СправочникСсылка.УчетныеЗаписиДокументооборота или,
//                                Строка - отпечаток сертификата или,
//                                Структура - структура свойств сертификата в формате
//                                  "КриптографияЭДКОКлиент.НайтиСертификат".
//   АдресДанных                - Строка - адрес временного хранилища с двоичными данными файла, который нужно
//                                  подписать.
//   НастройкиПодписи           - Неопределено - при незаданном значении используются настройки для подписи СЗВ-ТД,
//                                Структура - может передавать специфические настройки подписи, в формате, используемом
//                                  в обработке "ДокументооборотСКонтролирующимиОрганами"
//                                  форме "КонтейнерКлиентскихМетодов" у процедуры "ПодписатьФайлXMLDSig".
//
Процедура ПодписатьФайлXMLDSig( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПодписатьФайлXMLDSig();
```
</details>

## СформироватьПакетПоЕГРЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Объединяет сканы в многостраничные tif-документы, затем подписывает их и формирует пакет для ФНС.
//
// Параметры:
//  Параметры	 - Структура - описание см в методе ПараметрыМетодаСформироватьПакетПоЕГРЮЛ
//
Процедура СформироватьПакетПоЕГРЮЛ(Параметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.СформироватьПакетПоЕГРЮЛ(Параметры) 
```
</details>

## ПараметрыМетодаСформироватьПакетПоЕГРЮЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описание параметров для метода СформироватьПакетПоЕГРЮЛ
//
// Параметры:
//  ОповещениеОЗавершении	 - ОповещениеОповещения - в данную процедуру будет передан результат:
//								Структура:
//									* Выполнено - Булево
//									* Адрес - Строка - Адрес во временном хранилище, в котором содержатся двоичные данные пакета.
//											Неопределено, если Выполнено Ложь.
//									* ИмяПакета - Строка - Имя файла архива. Неопределено, если Выполнено Ложь.
//									* ТекстИнформации - Строка
//									* ОтправкаСсылка - СправочникСсылка.ОтправкиРегистрацияЮЛ
//									* ТипОшибки - Число
//								или
//								Неопределено - в случае если пользователь нажал Отменить в форме выбора сертификата
//												или в форме ввода пароля для облачного сертификата
//  Заявление	 			 - ДокументСсылка.УведомлениеОСпецрежимахНалогообложения
//  КодНО		 			 - Строка(4) - код налогового органа, в который будет подаваться заявление
//  ОписаниеФайлов			 - Массив структур - содержит структуры с описанием приложенных сканов:
//								* ВидДокумента - Перечисление.ВидыДокументовДляЭлГосРегистрации - вид документа
// 								* АдресаФайлов - Массив - Массив адресов сканов во временном хранилище, содержащих двоичные
// 										данные файлов. Последовательность адресов в массиве	будет определять последовательность
//										листов в итоговом tif. Разрешены следующие форматы сканов - BMP, GIF, JPEG, PNG, TIFF.
//								* ТипыСодержимогоЗаявления - Перечисления.ТипыСодержимогоФайлов.XML, если заявление в формате XML,
//										отсутствует или пустое в остальных случаях
//  СпособПредоставленияОтвета - Перечисление.СпособыОтветаНаЭлГосРегистрацию - Способ получения ответа от ФНС
//	ЭлПочтаЗаявителя 		 - Строка - электронная почта заявителя
//	ИННЗаявителя 		     - Строка(12) - ИНН физ.лица заявителя. Пустая строка или строка из 12 нулей, если ИНН отсутствует
//	ПодписатьПакет			 - Булево - показать кнопку "Подписать" на форме
//	ОтправитьПакет			 - Булево - показать кнопку "Подписать и отправить" на форме
//	ВыводитьСообщения		 - Булево - выводить сообщения пользователю об статусе отправки или формирования пакета
//
Функция ПараметрыМетодаСформироватьПакетПоЕГРЮЛ() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРОКлиент.ПараметрыМетодаСформироватьПакетПоЕГРЮЛ() 
```
</details>

## СоздатьПисьмо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открыть форму отправки письма в контролирующие органы
//
// Параметры:
//  Форма                     - ФормаКлиентскогоПриложения - владелец,
//  Организация               - Справочники.ОрганизацияСсылка,
//  КонтролирующийОрган       - Строка - "ФНС", "ПФР" или "ФСГС",
//  КодКонтролирующегоОргана  - Строка - при незаполненном значении подставляется из свойств организации,
//  Тема                      - Строка - при незаполненном значении берется из имени первого вложения,
//  Вложения - СписокЗначений - значение задает адрес во временном хранилище двоичных данных вложения, представление задает имя файла вложения,
//  ДополнительныеРеквизиты   - Структура:
//    * Содержание  - Строка - необязательный ключ, при незаполненном значении берется тема,
//    * Комментарий - Строка - необязательный ключ,
//    * Категория   - Строка - необязательный ключ, определяется автоматически по имени вложения.
//
Процедура СоздатьПисьмо( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.СоздатьПисьмо();
```
</details>

## ОсуществитьОбменПоОрганизациям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет обмен с получением входящих документов, получением и отправкой ответных квитанций.
// Для проверки, что обмен с контролирующим органом доступен у организации, можно использовать вызов вида:
// ИнтерфейсыВзаимодействияБРО.ПодключенДокументооборотСКонтролирующимОрганом(Организация, КонтролирующийОрган, Ложь)
//
// Параметры:
//   Форма                      - ФормаКлиентскогоПриложения - вызывающая форма, при значении Неопределено используется
//                                встроенная скрытая форма, форма может использоваться как владелец окон, при получении
//                                уникальных идентификаторов.
//   Организации                - СправочникСсылка.Организация или их Массив - при значении Неопределено обмен
//                                осуществляется по учетным записям документооборота всех организаций, кроме
//                                помеченных на удаление.
//   ВыполняемоеОповещение      - ОписаниеОповещения - описание необязательного оповещения, вызываемого после
//                                завершения обмена, при этом на экране может быть отображен диалог с результатами обмена.
//   КонтролирующийОрган        - Строка - если гос. орган задан, обмен, по возможности, выполняется только с ним,
//                                примеры: "ФНС", "ПФР", "ФСГС", "ФСС", "ФСРАР", "РПН", "ФТС", "БанкРоссии".
//   СсылкаНаОтправляемыйОбъект - ДокументСсылка, СправочникСсылка - ссылка на отчет, если нужно обновить состояние
//                                только этого отчета.
//
Процедура ОсуществитьОбменПоОрганизациям( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ОсуществитьОбменПоОрганизациям();
```
</details>

## НастройкиОбменаОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение настроек обмена, свойств сертификата. Описание вызова см. в одноименной процедуре
// обработки "ДокументооборотСКонтролирующимиОрганами", формы "КонтейнерКлиентскихМетодов".
//
// Пример вызова:
//   ИнтерфейсыВзаимодействияБРОКлиент.НастройкиОбменаОрганизаций(Оповещение, Организация);
//
// Пример обработки результата оповещения:
//   Если Результат <> Неопределено И Результат.НастройкиОбмена[0].СвойстваСертификатаРуководителя <> Неопределено Тогда
//     СвойстваСубъекта = КриптографияЭДКОКлиентСервер.РазобратьСтрокуСубъекта(
//       Результат.НастройкиОбмена[0].СвойстваСертификатаРуководителя.Владелец);
//     ФИО = СокрЛП(СвойстваСубъекта["SN"] + " " + СвойстваСубъекта["GN"]);
//   Иначе
//     ФИО = "";
//   КонецЕсли;
Процедура НастройкиОбменаОрганизаций( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.НастройкиОбменаОрганизаций();
```
</details>

## ПриНачалеПодписания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При подписи доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСКлиентПереопределяемый.ПриНачалеПодписания
//
Процедура ПриНачалеПодписания(Организации, Файл, Полномочия, Оповещение, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПриНачалеПодписания(Организации, Файл, Полномочия, Оповещение, СтандартнаяОбработка) 
```
</details>

## ПриОбработкеНавигационнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При обработке навигационной ссылки доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСКлиентПереопределяемый.ПриОбработкеНавигационнойСсылки
//
Процедура ПриОбработкеНавигационнойСсылки( Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПриОбработкеНавигационнойСсылки();
```
</details>

## ПриИзмененииСтатусаДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При изменении статуса доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСКлиентПереопределяемый.ПриИзмененииСтатусаДоверенности
//
Процедура ПриИзмененииСтатусаДоверенности(СтатусыДоверенностей) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПриИзмененииСтатусаДоверенности(СтатусыДоверенностей) 
```
</details>

## ПриРегистрацииДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При изменении статуса доверенности справочника "МашиночитаемыеДоверенности",
// описание см. МашиночитаемыеДоверенностиФНСКлиентПереопределяемый.ПриРегистрацииДоверенности
//
Процедура ПриРегистрацииДоверенности(Доверенность, СтандартнаяОбработка, ОбработчикЗавершения) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРОКлиент.ПриРегистрацииДоверенности(Доверенность, СтандартнаяОбработка, ОбработчикЗавершения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
