---
title: Кадровый учет
slug: zup/кадровый-учет
---


## ЕстьДоговорыГПХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЕстьДоговорыГПХ(ФизическоеЛицо, Организация = Неопределено, НачалоПериода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ЕстьДоговорыГПХ(ФизическоеЛицо, Организация, НачалоПериода);
```
</details>

## КадровыеДанныеФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений заполненную данными физических лиц, перечисленными в
// параметре СписокНеобходимыхДанных.
//
// Параметры:
//	ТолькоРазрешенные - Булево
//  СписокФизическихЛиц - Массив ссылок на элементы справочника физические лица или
//						  СправочникСсылка.ФизическиеЛица.
//  КадровыеДанные 	- 	Строка - список полей данных, перечисленных через запятую.
//					-	Массив строк с полями данных, которые необходимо получить.
//	ДатаПолученияДанных	- дата на которую необходимо получить данные физических лиц,
//						  применимо к данным, носящим периодический характер (например - ФИО).
//						  Если дату не указывать, будут получены самые последние данные.
//
//  ПоляОтбораПериодическихДанных - Структура, в качестве ключа указывается имя таблицы, содержащей
//						  периодические данные (например ФИОФизическихЛиц, ГражданствоФизическихЛиц).
//						  В качестве значений коллекция условий отбора,
//						  соединяемых по "И" и применяемых к регистру сведений.
//						  Коллекция строки которой имеют поля.
//							 * ЛевоеЗначение - строка, имя поля регистра сведений.
//							 * ВидСравнения - строка, вид сравнения, допустимый в языке запросов.
//							 * ПравоеЗначение - значение для сравнения с полем ЛевоеЗначение.
//
//	Список полей, допустимых в параметре КадровыеДанные см. КадровыйУчетВнутренний.ЗапросВТКадровыеДанныеФизическихЛиц.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Таблица значений, содержащая обязательные поля ФизическоеЛицо, Период поля запрошенных
//						 кадровых данных.
//
Функция КадровыеДанныеФизическихЛиц(ТолькоРазрешенные, СписокФизическихЛиц, КадровыеДанные, ДатаПолученияДанных = '00010101', ПоляОтбораПериодическихДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.КадровыеДанныеФизическихЛиц(ТолькоРазрешенные, СписокФизическихЛиц, КадровыеДанные, ДатаПолученияДанных, ПоляОтбораПериодическихДанных);
```
</details>

## КадровыеДанныеСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений заполненную данными сотрудников, перечисленными в
// параметре СписокНеобходимыхДанных.
//
// Параметры:
//	ТолькоРазрешенные - Булево
//  СписокСотрудников - Массив ссылок на элементы справочника сотрудники или
//						  СправочникСсылка.Сотрудники.
//  КадровыеДанные - 	Строка - список полей данных, перечисленных через запятую
//						или Массив строк с полями данных, которые необходимо получить.
//	ДатаПолученияДанных	- дата на которую необходимо получить данные сотрудников,
//						применимо к данным, носящим периодический характер.
//						Если дату не указывать, будут получены самые последние данные.
//
//
//  ПоляОтбораПериодическихДанных - Структура, в качестве ключа указывается имя таблицы, содержащей
//									периодические данные (например ФИОФизическихЛиц, ГражданствоФизическихЛиц).
//									В качестве значений коллекция условий отбора,
//									соединяемых по "И" и применяемых к регистру сведений.
//									Коллекция строки которой имеют поля.
//										* ЛевоеЗначение - строка, имя поля регистра сведений.
//										* ВидСравнения - строка, вид сравнения, допустимый в языке запросов.
//										* ПравоеЗначение - значение для сравнения с полем ЛевоеЗначение.
//
//	Список полей, допустимых в параметре КадровыеДанные см. КадровыйУчетВнутренний.ЗапросВТКадровыеДанныеСотрудников.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Таблица значений, содержащая запрошенные данные.
//
Функция КадровыеДанныеСотрудников(ТолькоРазрешенные, СписокСотрудников, КадровыеДанные, ДатаПолученияДанных = '00010101', ПоляОтбораПериодическихДанных = Неопределено, ФормироватьСПериодичностьДень = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.КадровыеДанныеСотрудников(ТолькоРазрешенные, СписокСотрудников, КадровыеДанные, ДатаПолученияДанных, ПоляОтбораПериодическихДанных, ФормироватьСПериодичностьДень);
```
</details>

## ФизическиеЛицаРаботавшиеВОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений заполненную физическими лицами, работавшими в организации в
// заданном периоде.
//
// Параметры:
//	ТолькоРазрешенные - Булево
//  Организация - СправочникСсылка.Организации - организация по которой необходимо отобрать работавших
//				  в ней физических лиц.
//	НачалоПериода 		- Дата
//	ОкончаниеПериода 	- Дата
//  Подразделение - СправочникСсылка.ПодразделенияОрганизаций - подразделение, по которому необходимо отобрать
//					работавших физических лиц. Если подразделение не указывать - будут отобраны физические
//					лица по всей организации.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Таблица значений, содержащая поля Период (Дата, соответствует указанному параметру
//                       ОкончаниеПериода) и ФизическоеЛицо.
//
Функция ФизическиеЛицаРаботавшиеВОрганизации(ТолькоРазрешенные, Организация, НачалоПериода, ОкончаниеПериода, Подразделение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ФизическиеЛицаРаботавшиеВОрганизации(ТолькоРазрешенные, Организация, НачалоПериода, ОкончаниеПериода, Подразделение);
```
</details>

## ДокументыФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений заполненную данными документов физических лиц.
//
// Параметры:
//  СписокФизическихЛиц - Массив ссылок на элементы справочника физические лица или
//						  СправочникСсылка.ФизическиеЛица.
//	ТолькоРазрешенные - Булево
//  ВидДокумента		- СправочникСсылка.ВидыДокументовФизическихЛиц, вид необходимого
//						  документа.
//	ДатаПолученияДанных	- дата на которую необходимо получить данные документов физических лиц,
//						если дату не указывать, данные будут получены на текущую дату.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Таблица значений, содержащая поля.
//						Период - Дата
//						ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//						ВидДокумента - СправочникСсылка.ВидыДокументовФизическихЛиц
//						Серия - Строка
//						Номер - Строка
//						ДатаВыдачи - Дата
//						КемВыдан Строка
//						КодПодразделения - Строка
//						ЯвляетсяДокументомУдостоверяющимЛичность - Булево
//						Представление - Строка
//
Функция ДокументыФизическихЛиц(СписокФизическихЛиц, ТолькоРазрешенные, ВидДокумента = Неопределено, ДатаПолученияДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ДокументыФизическихЛиц(СписокФизическихЛиц, ТолькоРазрешенные, ВидДокумента, ДатаПолученияДанных);
```
</details>

## ПараметрыПолученияСотрудниковОрганизацийПоСпискуФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Различаются следующие подмножества сотрудников:
//		* Сотрудники принятые только по трудовым договорам (1).
//		* Сотрудники с которыми только заключен договор ГПХ (2).
//		* Сотрудники принятые по трудовым договорам ИС которыми заключены договоры ГПХ (3).
//
// Для получения сотрудников используются параметры:
//		* РаботникиПоТрудовымДоговорам.
//		* РаботникиПоДоговорамГПХ.
//
// Поддерживаются следующие сочетания параметров:
//
//		РаботникиПоТрудовымДоговорам = Истина
//		РаботникиПоДоговорамГПХ = Ложь
//			В выборку войдет только 1 подмножество сотрудников.
//
//		РаботникиПоТрудовымДоговорам = Истина
//		РаботникиПоДоговорамГПХ = Неопределено
//			В выборку войдут 1 и 3 подмножества сотрудников.
//
//		РаботникиПоТрудовымДоговорам = Истина
//		РаботникиПоДоговорамГПХ = Истина
//			В выборку войдут 1,2 и 3 подмножества сотрудников.
//
//		РаботникиПоТрудовымДоговорам = Неопределено
//		РаботникиПоДоговорамГПХ = Истина
//			В выборку войдут 2 и 3 подмножества сотрудников.
//
//		РаботникиПоТрудовымДоговорам = Ложь
//		РаботникиПоДоговорамГПХ = Истина
//			В выборку войдет только 2 подмножество сотрудников.
//
//		РаботникиПоТрудовымДоговорам = Ложь
//		РаботникиПоДоговорамГПХ = Ложь
//			Сформирует пустую таблицу.
//
// При другом сочетании параметров будет вызвано исключение.
//
// Различаются следующие сочетания:
//		РаботникиПоТрудовымДоговорам = Истина
//		ПодработкиСотрудниковПоТрудовымДоговорам = Ложь
//			В выборку попадут только головные сотрудники.
//
//		РаботникиПоТрудовымДоговорам = Истина
//		ПодработкиСотрудниковПоТрудовымДоговорам = Истина
//			В выборку попадут как головные сотрудники, так и подработки.
//
//		РаботникиПоТрудовымДоговорам = Неопределено
//		ПодработкиСотрудниковПоТрудовымДоговорам = Истина
//			В выборку попадут только подработки.
//
// При значении параметра РаботникиПоТрудовымДоговорам = Ложь, значение параметра
// ПодработкиСотрудниковПоТрудовымДоговорам игнорируется. Т.е. в выборку не попадут
// ни головные сотрудники ни подработки.
//
// При отборе подработок учитываются те же параметры отбора по периоду, организации
// и подразделению, что применяются для отбора головных сотрудников.

// Возвращает структуру параметров для СоздатьВТСотрудникиОрганизаций. Позволяет формировать списки
// сотрудников с различными сочетаниями трудовых отношений.
//
// Возвращаемое значение:
//	Структура - Содержит ключи:
//				* Организация 		- СправочникСсылка.Организации, если параметр опустить в таблицу войдут все сотрудник
//										независимо от организации.
//				* ОтбиратьПоГоловнойОрганизации - если Истина, то отбор по головной организации, иначе по текущей организации.
//													По умолчанию - ЛОЖЬ
//				* Подразделение 		- СправочникСсылка.ПодразделенияОрганизаций, в таблицу войдут сотрудники указанного подразделения
//										и всех подразделений, подчиненных указанному, если параметр опустить в таблицу войдут все сотрудники.
//				* СписокФизическихЛиц - Массив ссылок на элементы справочника ФизическиеЛица, если параметр опустить,
//										в таблицу войдут сотрудники всех физических лиц когда либо работавших в Организации.
//				* НачалоПериода 		- Дата, значение по умолчанию '00010101'. Если параметр устанавливается, параметр ОкончаниеПериода
//										обязателен к заполнению.
//				* ОкончаниеПериода	- Дата, значение по умолчанию '00010101'. При установке должно выполняться условие
//										ОкончаниеПериода >= НачалоПериода. Используется для выборки кадровых данных сотрудников, если
//										параметр не указан, выборка будет производиться на текущую дату сеанса.
//				* КадровыеДанные		- Строка, содержит список полей кадровых данных, см. описание к функции КадровыеДанныеСотрудников.
//										См. описание параметра КадровыеДанные функции КадровыйУчетВнутренний.ЗапросВТКадровыеДанныеСотрудников.
//				* Отборы				- Массив, структур описывающих отборы сотрудников
//										см. ЗарплатаКадрыОбщиеНаборыДанных.ДобавитьВКоллекциюОтбор,
//										допустимые отборы описаны см. КритерииПоискаСотрудниковПоКоллекцииОтборов.
//				* РаботникиПоТрудовымДоговорам				- Булево, Неопределено (Истина - работник по ТД, Ложь - не работает по ТД
//																Неопределено - неважно наличие ТД).
//				* ПодработкиРаботниковПоТрудовымДоговорам	- Булево.
//				* РаботникиПоДоговорамГПХ					- Булево, Неопределено (Истина - есть действующие договоры ГПХ, Ложь - нет
//																действующих договоров ГПХ, Неопределено - неважно наличие действующего
//																договора ГПХ).
//				* ВыбрасыватьИсключениеДоступа				- Булево, если Ложь будут проверяться право чтения к таблицам из которых
//																получаются данные и если такого права нет - запросы выполняться не будут
//
Функция ПараметрыПолученияСотрудниковОрганизацийПоСпискуФизическихЛиц() Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ПараметрыПолученияСотрудниковОрганизацийПоСпискуФизическихЛиц() 
```
</details>

## ПараметрыПолученияВсехСотрудниковОрганизацийПоСпискуФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для СоздатьВТСотрудникиОрганизаций.
//
// Возвращаемое значение:
//   Структура - Содержит ключи:
//				Организация 		- СправочникСсылка.Организации, если параметр опустить в таблицу войдут все сотрудник
//										независимо от организации.
//				ОтбиратьПоГоловнойОрганизации - если Истина, то отбор по головной организации, иначе по текущей организации.
//												По умолчанию - ЛОЖЬ
//				Подразделение 		- СправочникСсылка.ПодразделенияОрганизаций, в таблицу войдут сотрудники указанного подразделения
//										и всех подразделений, подчиненных указанному, если параметр опустить в таблицу войдут все сотрудники.
//				СписокФизическихЛиц - Массив ссылок на элементы справочника ФизическиеЛица, если параметр опустить,
//										в таблицу войдут сотрудники всех физических лиц когда либо работавших в Организации.
//				НачалоПериода 		- Дата, значение по умолчанию '00010101'. Если параметр устанавливается, параметр ОкончаниеПериода
//										обязателен к заполнению.
//				ОкончаниеПериода	- Дата, значение по умолчанию '00010101'. При установке должно выполняться условие
//										ОкончаниеПериода >= НачалоПериода. Используется для выборки кадровых данных сотрудников, если
//										параметр не указан, выборка будет производиться на текущую дату сеанса.
//				КадровыеДанные		- Строка, содержит список полей кадровых данных, см. описание к функции КадровыеДанныеСотрудников.
//				Отборы				- Массив, структур описывающих отборы сотрудников
//										см. ЗарплатаКадрыОбщиеНаборыДанных.ДобавитьВКоллекциюОтбор,
//										допустимые отборы описаны см. КритерииПоискаСотрудниковПоКоллекцииОтборов.
//
Функция ПараметрыПолученияВсехСотрудниковОрганизацийПоСпискуФизическихЛиц() Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ПараметрыПолученияВсехСотрудниковОрганизацийПоСпискуФизическихЛиц() 
```
</details>

## ПараметрыПолученияСотрудниковОрганизацийПоВременнойТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для СоздатьВТСотрудникиОрганизаций.
//
// Возвращаемое значение:
//	Структура - Содержит ключи:
//				* Организация 		- СправочникСсылка.Организации, если параметр опустить в таблицу войдут все сотрудник
//										независимо от организации.
//				* ОтбиратьПоГоловнойОрганизации - если Истина, то отбор по головной организации, иначе по текущей организации.
//													По умолчанию - ЛОЖЬ
//				* Подразделение 		- СправочникСсылка.ПодразделенияОрганизаций, в таблицу войдут сотрудники указанного подразделения
//										и всех подразделений, подчиненных указанному, если параметр опустить в таблицу войдут все сотрудники.
//				* ИмяВТФизическиеЛица - Строка, имя временной таблицы, содержащей физические лица (по умолчанию "ВТФизическиеЛица").
//				* ИмяПоляФизическоеЛицо - Строка, имя поля - Физическое лицо (по умолчанию "ФизическоеЛицо").
//				* НачалоПериода 		- Дата, значение по умолчанию '00010101'. Если параметр устанавливается, параметр ОкончаниеПериода
//										обязателен к заполнению.
//				* ОкончаниеПериода 	- Дата, значение по умолчанию '00010101'. При установке должно выполняться условие
//										ОкончаниеПериода >= НачалоПериода. Используется для выборки кадровых данных сотрудников, если
//										параметр не указан, выборка будет производиться на текущую дату сеанса.
//				* КадровыеДанные 		- Строка, содержит список полей кадровых данных, см. описание к функции КадровыеДанныеСотрудников.
//				* Отборы				- Массив, структур описывающих отборы сотрудников
//										см. ЗарплатаКадрыОбщиеНаборыДанных.ДобавитьВКоллекциюОтбор,
//										допустимые отборы описаны см. КритерииПоискаСотрудниковПоКоллекцииОтборов.
//				* РаботникиПоТрудовымДоговорам 				- Булево, Неопределено (Истина - работник по ТД, Ложь - не работает по ТД
//																Неопределено - неважно наличие ТД).
//				* ПодработкиРаботниковПоТрудовымДоговорам 	- Булево.
//				* РаботникиПоДоговорамГПХ 					- Булево, Неопределено (Истина - есть действующие договоры ГПХ, Ложь - нет
//																действующих договоров ГПХ, Неопределено - неважно наличие действующего
//																договора ГПХ).
//
Функция ПараметрыПолученияСотрудниковОрганизацийПоВременнойТаблице() Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ПараметрыПолученияСотрудниковОрганизацийПоВременнойТаблице() 
```
</details>

## СотрудникиОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений, заполненную сотрудниками.
//
// Параметры:
//	ТолькоРазрешенные - Булево
//	Параметры - Структура, подготовленная с помощью методов
//	            ПараметрыПолученияСотрудниковОрганизацийПоСпискуФизическихЛиц,
//	            ПараметрыПолученияСотрудниковОрганизацийПоВременнойТаблице
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Таблица значений, содержащая поля
//							* Период 			- Дата, равен значению ключа ОкончаниеПериода параметра Параметры
//						 	* Сотрудник			- СправочникСсылка.Сотрудники
//							* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//							<кадровые данные>	- указанные в ключе КадровыеДанные параметра Параметры.
//
Функция СотрудникиОрганизации(ТолькоРазрешенные, Параметры) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.СотрудникиОрганизации(ТолькоРазрешенные, Параметры) 
```
</details>

## ОсновныеСотрудникиФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений содержащую поля ФизическоеЛицо и Сотрудник. Сотрудник отбирается по принципам:
//		- Работает на указанный период.
//		- Выбирается сотрудник, работающий по основному месту работы, если такового не существует, выбирается
//			сотрудник, работающий по совместительству, принятый на наиболее раннюю дату.
//
// Параметры:
//			СписокФизическихЛиц - Массив ссылок на элементы справочника ФизическиеЛица или
//								- СправочникСсылка.ФизическиеЛица
//								- Неопределено - в таблицу войдут "основные" сотрудники всех
//									физических лиц когда либо работавших в организации.
//			ТолькоРазрешенные	- Булево
//			Организация			- СправочникСсылка.Организации
//			Период				- Дата
//
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Таблица значений, содержащая поля Сотрудник и соответствующее сотруднику ФизическоеЛицо.
//
Функция ОсновныеСотрудникиФизическихЛиц(СписокФизическихЛиц, ТолькоРазрешенные, Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ОсновныеСотрудникиФизическихЛиц(СписокФизическихЛиц, ТолькоРазрешенные, Организация, Период) 
```
</details>

## СформироватьКадровыеДвижения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет кадровые движения документа
//		КадроваяИсторияСотрудников
//
// Параметры:
//  РегистраторОбъект
//	Движения - коллекция движений, в которой необходимо заполнить кадровые движения.
//	КадровыеДвижения - таблица значений с полями:
//		ДатаСобытия
//		ВидСобытия - Перечисление.ВидыКадровыхСобытий
//		Сотрудник
//		ГоловнаяОрганизация
//		Организация
//		Подразделение
//		Должность
//		ВидЗанятости
//	ТолькоБронированиеПозиции	- Булево
//	Записывать					- Булево
//
Процедура СформироватьКадровыеДвижения(РегистраторОбъект, Движения, КадровыеДвижения, ТолькоБронированиеПозиции = Ложь, Записывать = Истина) Экспорт
```

Пример вызова
```bsl
КадровыйУчет.СформироватьКадровыеДвижения(РегистраторОбъект, Движения, КадровыеДвижения, ТолькоБронированиеПозиции, Записывать);
```
</details>

## СформироватьДвиженияВидовЗанятостиСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет движения документа по регистру сведений ВидыЗанятостиСотрудников
//
// Параметры:
//	Движения						- коллекция движений, в которой необходимо заполнить кадровые движения.
//	КоллекцияДвиженийВидовЗанятости - таблица значений с полями:
//		Сотрудник
//		ГоловнаяОрганизация
//		ФизическоеЛицо
//		ВидЗанятости
//		ДействуетДо
//	Записывать						- Булево
//
Процедура СформироватьДвиженияВидовЗанятостиСотрудников(Движения, КоллекцияВидовЗанятости, Записывать = Истина) Экспорт
```

Пример вызова
```bsl
КадровыйУчет.СформироватьДвиженияВидовЗанятостиСотрудников(Движения, КоллекцияВидовЗанятости, Записывать);
```
</details>

## ФизическоеЛицоПоФИОСНИЛСИОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает ссылку на физическое лицо, найденное по переданным фамилии, имени, отчеству СНИЛС и организации
// (см. функцию ЭлектронныйДокументооборотСКонтролирующимиОрганамиВызовСервераПереопределяемый.ФизЛицоПоФИО).
//
// Параметры:
//  Фамилия		- Строка - Фамилия физического лица.
//  Имя			- Строка - Имя физического лица.
//  Отчество	- Строка - Отчество физического лица.
//  СНИЛС		- Строка - СНИЛС физического лица.
//  Организация - СправочникСсылка.Организации - организация, в которой работает физическое лицо.
//
// Возвращаемое значение:
//   СправочникСсылка.ФизическиеЛица
//
Функция ФизическоеЛицоПоФИОСНИЛСИОрганизации(Фамилия, Имя, Отчество, СНИЛС, Организация) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ФизическоеЛицоПоФИОСНИЛСИОрганизации(Фамилия, Имя, Отчество, СНИЛС, Организация) 
```
</details>

## ПериодыИзмененияФИОФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений в строках которой содержится информация о периодах
// изменения (регистрации) фамилии, имени и отчества физических лиц.
//
// Параметры:
//		СписокФизическихЛиц - Массив, ссылок справочника ФизическиеЛица
//							- СправочникСсылка.ФизическиеЛица.
//
// Возвращаемое значение:
//		ТаблицаЗначений - содержит колонки:
//			* Период			- Дата
//			* ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица
//			* Фамилия			- Строка
//			* Имя				- Строка
//			* Отчество			- Строка
//
Функция ПериодыИзмененияФИОФизическихЛиц(СписокФизическихЛиц) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.ПериодыИзмененияФИОФизическихЛиц(СписокФизическихЛиц) 
```
</details>

## НовыеДанныеФизическогоЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую структуру для заполнения данных физического лица.
//
// Возвращаемое значение:
//  Структура:
//    * Фамилия - Строка -
//    * Имя - Строка -
//    * Отчество - Строка -
//    * ДатаРождения - Дата -
//    * МестоРождения - Строка -
//    * ИНН - Строка -
//    * СтраховойНомерПФР - Строка -
//    * Пол - ПеречислениеСсылка.ПолФизическогоЛица -
//    * ИмеетНаучныеТруды - Булево -
//    * ИмеетИзобретения - Булево -
//    * ДатаРегистрации - Дата -
//    * ЛьготаПриНачисленииПособий - ПеречислениеСсылка.ОснованияФинансированияПособияФедеральнымБюджетом -
//    * ОтношениеКОсобойЗоне - ПеречислениеСсылка.ОтношениеКОсобойЗоне -
//    * ВидОсобойЗоны - ПеречислениеСсылка.ВидыОсобойЗоныПроживанияРаботы -
//    * ПостоянноПроживалВКрыму18Марта2014Года - Булево -
//    * ПрименяетсяФЗ_20_2023 - Булево -
//    * АдресФотографии - Строка, УникальныйИдентификатор -
//    * ГруппаДоступа - СправочникСсылка.ГруппыДоступаФизическихЛиц -
//    * Образование - ТаблицаЗначений
//    * СостояниеВБраке - Массив из Структура
//    * Гражданство - Массив из Структура: см. РегистрыСведений.ГражданствоФизическихЛиц.НовоеГражданство
//    * ТрудоваяДеятельность - Массив из Структура:
//    * ЗнаниеЯзыков - Массив из Структура:
//    * УченыеСтепени - Массив из Структура:
//    * КонтактнаяИнформация - Массив из Структура: см. НоваяКонтактнаяИнформация
Функция НовыеДанныеФизическогоЛица() Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.НовыеДанныеФизическогоЛица() 
```
</details>

## НоваяКонтактнаяИнформация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Новая контактная информация.
//
// Возвращаемое значение:
//  Структура - Новая контактная информация:
//    * ЗначенияПолей - Строка -
//    * ВидИнформации - СправочникСсылка.ВидыКонтактнойИнформации -
//    * ТипИнформации - ПеречислениеСсылка.ТипыКонтактнойИнформации -
Функция НоваяКонтактнаяИнформация() Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.НоваяКонтактнаяИнформация() 
```
</details>

## НовоеФизическоеЛицо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объект справочника ФизическиеЛица, созданный по переданным фамилии,
// имени, отчеству и другим данным (см. параметр ДанныеФизическогоЛица).
//
// Параметры:
//	ФИО - Строка,Структура:
//		* Фамилия - Строка
//		* Имя - Строка
//		* Отчество	- Строка
//	ДанныеФизическогоЛица - Структура: см. НовыеДанныеФизическогоЛица
//	ПериодДанных - Дата - дата, на которую будет зарегистрирована запись о ФИО
//	Записывать - Булево - если Истина, то физическое лицо будет записано
//
// Возвращаемое значение:
//		СправочникОбъект.ФизическиеЛица
//
Функция НовоеФизическоеЛицо(Знач ФИО, Знач ДанныеФизическогоЛица = Неопределено, Знач ПериодДанных = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.НовоеФизическоеЛицо(ФИО, ДанныеФизическогоЛица, ПериодДанных, );
```
</details>

## СвязанныеОбъектыДанныхФизическогоЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Связанные объекты данных физического лица.
//
// Параметры:
//  ДанныеФизическогоЛица - Структура: см. НовыеДанныеФизическогоЛица
//
// Возвращаемое значение:
//  Структура:
//    * Гражданство - Массив из Структура: см. РегистрыСведений.ГражданствоФизическихЛиц.НовоеГражданство
//    * Образование - ТаблицаЗначений:  см. Справочники.ОбразованиеФизическихЛиц.НовыеДанныеОбОбразовании
//    * СостояниеВБраке - Массив из Структура: см. РегистрыСведений.СостоянияВБракеФизическихЛиц.НовоеСостояниеВБраке
//    * ТрудоваяДеятельность - Массив из Структура: см. РегистрыСведений.ТрудоваяДеятельностьФизическихЛиц.НоваяТрудоваяДеятельность
//    * ЗнаниеЯзыков - Массив из Структура: см. РегистрыСведений.ЗнаниеЯзыковФизическихЛиц.НовоеЗнаниеЯзыка
//    * УченыеСтепени - Массив из Структура
//    * АдресФотографии - Строка -
Функция СвязанныеОбъектыДанныхФизическогоЛица(ДанныеФизическогоЛица) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.СвязанныеОбъектыДанныхФизическогоЛица(ДанныеФизическогоЛица) 
```
</details>

## СреднесписочнаяЧисленностьРаботающих
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция рассчитывает численность всех работников, женщин и инвалидов.
// При этом за переданный период считается среднесписочная численность,
// а на конец заданного периода - списочная численность.
//
// Параметры:
//		Организация		- СправочникСсылка.Организации
//		НачалоПериода	- Дата
//		КонецПериода	- Дата
//
// Возвращаемое значение:
//		Структура - см. СтатистикаПерсонала.ДанныеОЧисленности
//
Функция СреднесписочнаяЧисленностьРаботающих(Организация, НачалоПериода, КонецПериода, ПоГоловнойОрганизации = Ложь, Точность =0) Экспорт
```

Пример вызова
```bsl
Результат = КадровыйУчет.СреднесписочнаяЧисленностьРаботающих(Организация, НачалоПериода, КонецПериода, ПоГоловнойОрганизации, Точность);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
