---
title: Контактная информация БЗК
slug: zup/контактная-информация-бзк
---


## СвернутьСведенияОбАдресе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру адреса приведенную к указанному составу полей.
//
// Параметры:
//   СведенияОбАдресе - Структура - Результат одной из функций:
//       • РаботаСАдресами.СведенияОбАдресе;
//       • КонтактнаяИнформацияБЗК.СведенияОбАдресеСТипами.
//   ИменаПолей - Строка - Имена полей возвращаемой структуры.
//       Поддерживаются все поля структуры СведенияОбАдресе.
//       Кроме того, поддерживаются поля "Корпус", "Строение", "Литера", "Сооружение", "Участок", "Квартира".
//       Примеры: "Индекс, Регион, Район, Город, НаселенныйПункт, Территория, Улица, Дом, Корпус, Строение, Квартира",
//                "Индекс, Регион, Район, НаселенныйПункт, Улица, Дом, Корпус, Квартира".
//
// Возвращаемое значение:
//   Структура - Свернутая структура адреса.
//
Функция СвернутьСведенияОбАдресе(СведенияОбАдресе, ИменаПолей, Разделитель = ", ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.СвернутьСведенияОбАдресе(СведенияОбАдресе, ИменаПолей, Разделитель, ") 
```
</details>

## СтруктураКорпусов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует массив корпусов из сведений об адресе в структуру корпусов.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе или КонтактнаяИнформацияБЗК.СтруктураКорпусов.
//                    - Массив из Структура - Значение свойства "Корпуса" результата функции СведенияОбАдресе.
//
// Возвращаемое значение:
//   Структура - Перечень корпусов в виде структуры:
//       * Корпус     - Строка
//       * Строение   - Строка
//       * Литера     - Строка
//       * Сооружение - Строка
//       * Участок    - Строка
//
Функция СтруктураКорпусов(СведенияОбАдресе, ТребуетсяЛитера = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.СтруктураКорпусов(СведенияОбАдресе, ТребуетсяЛитера);
```
</details>

## ПредставлениеКорпусов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление корпусов адреса.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе или КонтактнаяИнформацияБЗК.СтруктураКорпусов.
//   ОграничениеДлины - Число     - Используется для определения переключения между полным и кратким представлением.
//   Разделитель      - Строка    - Разделитель корпусов.
//
// Возвращаемое значение:
//   Строка - Представление корпусов.
//
Функция ПредставлениеКорпусов(СведенияОбАдресе, ОграничениеДлины = 0, Разделитель = ", ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеКорпусов(СведенияОбАдресе, ОграничениеДлины, Разделитель, ") 
```
</details>

## ПредставлениеКорпусовПолное
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает полное представление корпусов адреса.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе или КонтактнаяИнформацияБЗК.СтруктураКорпусов.
//   Разделитель      - Строка    - Разделитель корпусов.
//
// Возвращаемое значение:
//   Строка - Полное представление корпусов.
//
Функция ПредставлениеКорпусовПолное(СведенияОбАдресе, Разделитель = ", ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеКорпусовПолное(СведенияОбАдресе, Разделитель, ") 
```
</details>

## ПредставлениеКорпусовКраткое
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает краткое представление корпусов адреса.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе или КонтактнаяИнформацияБЗК.СтруктураКорпусов.
//   РазделительКорпусов - Строка - Строка вставляемая между корпусами.
//   РазделительТипа     - Строка - Строка вставляемая между типом и представлением корпуса.
//
// Возвращаемое значение:
//   Строка - Краткое представление корпусов.
//
Функция ПредставлениеКорпусовКраткое(СведенияОбАдресе, РазделительКорпусов = ", ", РазделительТипа = ". ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеКорпусовКраткое(СведенияОбАдресе, РазделительКорпусов, ", РазделительТипа);
```
</details>

## СтруктураПомещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует массив помещений из сведений об адресе в структуру помещений.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе или КонтактнаяИнформацияБЗК.СтруктураКвартир.
//                    - Массив из Структура - Значение свойства "Помещения" результата функции СведенияОбАдресе.
//
// Возвращаемое значение:
//   Структура - Перечень помещений в виде структуры:
//       * Квартира  - Строка
//       * Офис      - Строка
//       * Бокс      - Строка
//       * Помещение - Строка
//       * Комната   - Строка
//       * Этаж      - Строка
//       * АЯ        - Строка
//       * ПО        - Строка
//       * ВЧ        - Строка
//
Функция СтруктураПомещений(СведенияОбАдресе) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.СтруктураПомещений(СведенияОбАдресе) 
```
</details>

## ПредставлениеПомещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление помещений адреса.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе, КонтактнаяИнформацияБЗК.СтруктураПомещений.
//   ОграничениеДлины - Число     - Используется для определения переключения между полным и кратким представлением.
//   Разделитель      - Строка    - Строка вставляемая между помещениями.
//   РазделительТипа  - Строка    - Строка вставляемая между типом и представлением помещения.
//
// Возвращаемое значение:
//   Строка - Представление помещений.
//
Функция ПредставлениеПомещений(СведенияОбАдресе, ОграничениеДлины = 0, Разделитель = ", ", РазделительТипа = ". ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеПомещений(СведенияОбАдресе, ОграничениеДлины, Разделитель, ", РазделительТипа);
```
</details>

## ПредставлениеПомещенийПолное
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает полное представление помещений адреса.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе, КонтактнаяИнформацияБЗК.СтруктураПомещений.
//   Разделитель      - Строка    - Строка вставляемая между помещениями.
//   РазделительТипа  - Строка    - Строка вставляемая между типом и представлением помещения.
//
// Возвращаемое значение:
//   Строка - Полное представление помещений.
//
Функция ПредставлениеПомещенийПолное(СведенияОбАдресе, Разделитель = ", ", РазделительТипа = ". ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеПомещенийПолное(СведенияОбАдресе, Разделитель, ", РазделительТипа);
```
</details>

## ПредставлениеПомещенийКраткое
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает краткое представление корпусов адреса.
//
// Параметры:
//   СведенияОбАдресе - Структура - См. РаботаСАдресами.СведенияОбАдресе, КонтактнаяИнформацияБЗК.СтруктураПомещений.
//   Разделитель      - Строка    - Строка вставляемая между помещениями.
//   РазделительТипа  - Строка    - Строка вставляемая между типом и представлением помещения.
//
// Возвращаемое значение:
//   Строка - Краткое представление помещений.
//
Функция ПредставлениеПомещенийКраткое(СведенияОбАдресе, Разделитель = ", ", РазделительТипа = ". ") Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеПомещенийКраткое(СведенияОбАдресе, Разделитель, ", РазделительТипа);
```
</details>

## СведенияОбАдресеСТипами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения об адресе в виде отдельных частей адреса и различных кодов (код региона, ОКТМО и др.).
//   Возвращаемые поля содержат адресные сокращения (ул., р-н, и так далее...).
//   К корпусам типы не добавляются.
//   Для получения представления корпусов рекомендуется использовать функцию ПредставлениеКорпусов.
//
// Параметры:
//   Адрес - Строка - адрес во внутреннем формате JSON или в XML, соответствующем XDTO-пакету Адрес.
//         - ОбъектXDTO - XDTO-объект, соответствующий XDTO пакету Адрес.
//
// Возвращаемое значение:
//   Структура:
//        * Представление              - Строка - Представление адреса по административно-территориальному делению.
//        * МуниципальноеПредставление - Строка - Представление адреса по муниципальному делению.
//        * ТипАдреса                  - Строка - Основной тип адреса (только для адресов РФ).
//                                                Варианты: "Муниципальный", "Административно-территориальный".
//        * Страна                     - Строка - Представление страны.
//        * КодСтраны                  - Строка - Код страны по ОКСМ.
//        * Индекс                     - Строка - Почтовый индекс.
//        * КодРегиона                 - Строка - Код региона РФ.
//        * Регион                     - Строка - Представление региона РФ.
//        * Район                      - Строка - Представление района у адресов по административно-территориальному делению.
//        * МуниципальныйРайон         - Строка - Представление муниципального района для адреса по муниципальному делению.
//        * КодМуниципальногоРайона    - Строка - Код муниципального района:
//                                                1- муниципальный район; 2- городской округ; 3 - внутригородская территория
//                                                города федерального значения; 4 - муниципальный округ.
//                                                Если не удалось определить код, то возвращается пустая строка.
//        * Город                      - Строка - Представление города у адресов по административно-территориальному делению.
//        * Поселение                  - Строка - Представление поселения у адресов по муниципальному делению.
//        * КодПоселения               - Строка - код поселения: 1 - городское поселение; 2 - сельское поселение; 3-  межселенная
//                                                территория в составе муниципального района; 4 - внутригородской район
//                                                городского округа;
//        * ВнутригородскойРайон       - Строка - Представление внутригородского района.
//        * НаселенныйПункт            - Строка - Представление населенного пункта.
//        * Территория                 - Строка - Представление территории (элемента планировочной структуры).
//        * Улица                      - Строка - Представление улицы.
//        * Здание  - Структура
//            ** ТипЗдания - Строка - Тип объекта адресации адреса РФ согласно приказу Минфина России от 5.11.2015 г. N171н.
//            ** Номер     - Строка - Представление номера дома (только для адресов РФ).
//        * Корпуса - Структура - Перечень корпусов адреса: "Корпус", "Строение", "Литера", "Сооружение", "Участок".
//        * Квартира - Строка - Номер квартиры.
//        * НомерЗемельногоУчастка - Строка - Представление номера земельного участка (только для адресов РФ).
//        * Комментарий - Строка - комментарий об адресе.
//        * ИдентификаторАдресногоОбъекта - УникальныйИдентификатор - идентификационный код последнего адресного объекта
//                                        в иерархи адреса. Например, для адреса: Москва г., Дмитровское ш., д.9 это
//                                        будет идентификатор улицы.
//                                        Поле отсутствует, если дополнительный параметр КодыАдреса равен Ложь.
//        * ИдентификаторДома             - УникальныйИдентификатор - идентификационный код дома(строения) адресного объекта.
//                                        Поле отсутствует, если дополнительный параметр КодыАдреса равен Ложь.
//                                        Пустая строка если значение отсутствует.
//        * ИдентификаторЗемельногоУчастка - УникальныйИдентификатор - идентификационный код земельного участка
//                                       адресного объекта. При отсутствии значения - пустая строка.
//        * ДополнительныеКоды  - Структура - коды ОКТМО, ОКТМО, ОКАТО, КодИФНСФЛ, КодИФНСЮЛ, КодУчасткаИФНСФЛ, КодУчасткаИФНСЮЛ.
//                                            Поле отсутствует, если дополнительный параметр КодыАдреса равен Ложь.
//
Функция СведенияОбАдресеСТипами(Адрес) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.СведенияОбАдресеСТипами(Адрес) 
```
</details>

## ИндексИПредставлениеАдреса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с индексом и представлением адреса без индекса.
//
// Параметры:
//   ЗначениеАдреса - Строка - Адрес в формате JSON.
//
// Возвращаемое значение:
//   Структура
//       * Индекс        - Строка - Индекс адреса.
//       * Представление - Строка - Представлением адреса без индекса.
//
Функция ИндексИПредставлениеАдреса(ЗначениеАдреса) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ИндексИПредставлениеАдреса(ЗначениеАдреса) 
```
</details>

## ПредставлениеАдресаБезИндекса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление адреса без индекса.
//
// Параметры:
//   СтруктураАдреса - Структура - См. РаботаСАдресами.СведенияОбАдресе.
//
// Возвращаемое значение:
//   Строка - Представление адреса без индекса.
//
Функция ПредставлениеАдресаБезИндекса(СтруктураАдреса) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеАдресаБезИндекса(СтруктураАдреса) 
```
</details>

## СтруктураТелефона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о телефоне.
//   Возвращает корректные значения полей структуры в случае,
//   если номер телефона изначально введен без пробелов и разделителей (например: +79992223344).
//
// Параметры:
//   ЗначениеТелефона - Строка - Значение контактной информации типа "Телефон" в формате JSON.
//
// Возвращаемое значение:
//   Структура - См. УправлениеКонтактнойИнформацией.СведенияОТелефоне.
//
Функция СтруктураТелефона(ЗначениеТелефона) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.СтруктураТелефона(ЗначениеТелефона) 
```
</details>

## ПредставлениеТелефона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление телефона.
//
// Параметры:
//   ЗначениеТелефона  - Строка    - Значение контактной информации типа "Телефон" (строка json или xml).
//                     - Структура - Результат функции КонтактнаяИнформацияБЗК.СтруктураТелефона.
//   ОграничениеДлины  - Число     - Ограничение длины телефона.
//   ДляПечатиПоБуквам - Булево    - Если Истина то будет сформировано представление для функции
//                                   ПрямыеВыплатыПособийСоциальногоСтрахования.ВывестиТелефонПоБуквам.
//
// Возвращаемое значение:
//   Строка - Удобочитаемое представление телефона, например: "+7 123 456-78-90".
//
Функция ПредставлениеТелефона(ЗначениеТелефона, ОграничениеДлины = 0, ДляПечатиПоБуквам = Ложь, ВыводитьКомментарий = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеТелефона(ЗначениеТелефона, ОграничениеДлины, ДляПечатиПоБуквам, ВыводитьКомментарий);
```
</details>

## КонтактнаяИнформацияОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, содержащую контактную информацию нескольких объектов.
//   Работает аналогично функции УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъектов,
//   однако не поднимает исключение в случае, если дата не указана,
//   и поддерживает передачу одной ссылки или объекта в параметре СсылкиИлиОбъекты.
//
// Параметры:
//    СсылкиИлиОбъекты         - Массив, ФиксированныйМассив, ЛюбаяСсылка, Объект
//    ТипыКонтактнойИнформации - Массив, ПеречислениеСсылка.ТипыКонтактнойИнформации, Неопределено
//    ВидыКонтактнойИнформации - Массив, СправочникСсылка.ВидыКонтактнойИнформации, Неопределено
//    Дата                     - Дата, Неопределено
//
// Возвращаемое значение:
//  ТаблицаЗначений
//    * Объект           - ЛюбаяСсылка
//    * Вид              - СправочникСсылка.ВидыКонтактнойИнформации
//    * Тип              - ПеречислениеСсылка.ТипыКонтактнойИнформации
//    * Значение         - Строка
//    * Представление    - Строка
//    * Дата             - Дата
//    * ИдентификаторСтрокиТабличнойЧасти - Число
//    * ЗначенияПолей    - Строка
//
Функция КонтактнаяИнформацияОбъектов(Знач СсылкиИлиОбъекты, Знач ТипыКонтактнойИнформации = Неопределено, Знач ВидыКонтактнойИнформации = Неопределено, Знач Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.КонтактнаяИнформацияОбъектов(СсылкиИлиОбъекты, ТипыКонтактнойИнформации, ВидыКонтактнойИнформации, Дата);
```
</details>

## ПредставлениеКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает представление контактной информации объекта заданного вида.
//
// Параметры:
//   ТаблицаКИ - ТаблицаЗначений - См. УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъектов.
//   Владелец  - ЛюбаяСсылка                               - Владелец контактной информации.
//   Вид       - СправочникСсылка.ВидыКонтактнойИнформации - Вид контактной информации.
//
// Возвращаемое значение:
//   Строка
//
Функция ПредставлениеКонтактнойИнформации(ТаблицаКИ, Владелец = Неопределено, Вид = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ПредставлениеКонтактнойИнформации(ТаблицаКИ, Владелец, Вид);
```
</details>

## ЗначениеКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает представление контактной информации объекта заданного вида.
//
// Параметры:
//   ТаблицаКИ - ТаблицаЗначений - См. УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъектов.
//   Владелец  - ЛюбаяСсылка                               - Владелец контактной информации.
//   Вид       - СправочникСсылка.ВидыКонтактнойИнформации - Вид контактной информации.
//
// Возвращаемое значение:
//   Строка
//
Функция ЗначениеКонтактнойИнформации(ТаблицаКИ, Владелец = Неопределено, Вид = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.ЗначениеКонтактнойИнформации(ТаблицаКИ, Владелец, Вид);
```
</details>

## НайтиКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит контактную информацию объекта заданного вида.
//
// Параметры:
//   ТаблицаКИ - ТаблицаЗначений - См. УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъектов.
//   Владелец  - ЛюбаяСсылка                               - Владелец контактной информации.
//   Вид       - СправочникСсылка.ВидыКонтактнойИнформации - Вид контактной информации.
//
// Возвращаемое значение:
//   СтрокаТаблицыЗначений, Неопределено
//
Функция НайтиКонтактнуюИнформацию(ТаблицаКИ, Владелец = Неопределено, Вид = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КонтактнаяИнформацияБЗК.НайтиКонтактнуюИнформацию(ТаблицаКИ, Владелец, Вид);
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик для события формы ПриСозданииНаСервере, вызывается после вызова соответствующего метода подсистемы
// УправлениеКонтактнойИнформации. Дополняет элементы отображения полей ввода адресов, полями
// отображающими результаты проверки адресов на корректность.
//
// Параметры:
//    Форма - ФормаКлиентскогоПриложения - Форма объекта-владельца, предназначенная для вывода контактной
//
Процедура ПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
КонтактнаяИнформацияБЗК.ПриСозданииНаСервере(Форма) 
```
</details>

## ОбновитьКонтактнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет (удаляет) поле ввода или комментарий на форму.
//
Процедура ОбновитьКонтактнуюИнформацию(Форма, Результат, ЗависимостиВидовАдресов = Неопределено) Экспорт
```

Пример вызова
```bsl
КонтактнаяИнформацияБЗК.ОбновитьКонтактнуюИнформацию(Форма, Результат, ЗависимостиВидовАдресов);
```
</details>

## ОбновитьПолеВводаАдреса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет представление и отображение поля ввода адреса.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - Обновляемая форма.
//   ИмяПоляВводаПредставления - Строка - Имя поля ввода, связанного с реквизитом формы,
//       в котором хранится представление контактной информации.
//       Пример: "ПредставлениеАдресаОрганизации".
//   ЗначениеКонтактнойИнформации - Строка - Значение контактной информации в XML или JSON.
//
Процедура ОбновитьПолеВводаАдреса(Форма, ИмяПоляВводаПредставления, ЗначениеКонтактнойИнформации) Экспорт
```

Пример вызова
```bsl
КонтактнаяИнформацияБЗК.ОбновитьПолеВводаАдреса(Форма, ИмяПоляВводаПредставления, ЗначениеКонтактнойИнформации) 
```
</details>

## ОбновитьПолеВводаТелефона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет представление и отображение поля ввода телефона.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - Обновляемая форма.
//   ИмяПоляВводаПредставления - Строка - Имя поля ввода, связанного с реквизитом формы,
//       в котором хранится представление контактной информации.
//       Пример: "ПредставлениеАдресаОрганизации".
//   ЗначениеКонтактнойИнформации - Строка - Значение контактной информации в XML или JSON.
//
Процедура ОбновитьПолеВводаТелефона(Форма, ИмяПоляВводаПредставления, ЗначениеКонтактнойИнформации) Экспорт
```

Пример вызова
```bsl
КонтактнаяИнформацияБЗК.ОбновитьПолеВводаТелефона(Форма, ИмяПоляВводаПредставления, ЗначениеКонтактнойИнформации) 
```
</details>

## ОбновитьПолеВводаКонтактнойИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет представление и отображение поля ввода контактной информации.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - Обновляемая форма.
//   ИмяПоляВводаПредставления - Строка - Имя поля ввода, связанного с реквизитом формы,
//       в котором хранится представление контактной информации.
//       Пример: "ПредставлениеАдресаОрганизации".
//   ЗначениеКонтактнойИнформации - Строка - Значение контактной информации в XML или JSON.
//   ТипКонтактнойИнформации - ПеречислениеСсылка.ТипыКонтактнойИнформации
//
Процедура ОбновитьПолеВводаКонтактнойИнформации(Форма, ИмяПоляВводаПредставления, ЗначениеКонтактнойИнформации, ТипКонтактнойИнформации) Экспорт
```

Пример вызова
```bsl
КонтактнаяИнформацияБЗК.ОбновитьПолеВводаКонтактнойИнформации(Форма, ИмяПоляВводаПредставления, ЗначениеКонтактнойИнформации, ТипКонтактнойИнформации) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
