---
title: Медицинские регистры ФРМО
slug: zup/медицинские-регистры-фрмо
---


## GetOrgList
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для чтения данных одной или нескольких организаций.
//
// Параметры:
//  orgTypeId - Число - тип организации:
//      1 - Государственное или муниципальное юридическое лицо.
//      2 - Частное юридическое лицо.
//      3 - Индивидуальный предприниматель.
//  offset    - Число - количество записей, которые нужно пропустить (отступ).
//  limit     - Число - количество записей, которые нужно получить.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистрыКлиентСервер.ПараметрыВызоваМетода.
//
Функция GetOrgList(orgTypeId, offset, limit) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.GetOrgList(orgTypeId, offset, limit) 
```
</details>

## GetOrg
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для чтения данных указанной организации.
//
// Параметры:
//  oid - Строка - идентификатор организации в ЕГИСЗ.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистрыКлиентСервер.ПараметрыВызоваМетода.
//
Функция GetOrg(oid) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.GetOrg(oid) 
```
</details>

## GetOrgDepart
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для чтения данных одного или нескольких подразделений.
//
// Параметры:
//  departTypeId - Число - тип подразделения:
//		1 -	Амбулаторный.
//		2 -	Стационарный.
//		3 -	Лабораторно-диагностический.
//		4 -	Инструментально-диагностический.
//		5 -	Скорая медицинская помощь.
//		6 -	Административно-хозяйственный (вспомогательный).
//		7 -	Фармацевтический.
//  oid - Строка - Идентификатор организации.
//  offset - Число - количество записей, которые нужно пропустить (отступ).
//  limit - Число - количество записей, которые нужно получить.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистрыКлиентСервер.ПараметрыВызоваМетода.
//
Функция GetOrgDepart(departTypeId, oid, offset, limit) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.GetOrgDepart(departTypeId, oid, offset, limit) 
```
</details>

## GetOrgStaff
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для чтения всех сведений медицинского работника.
//
// Параметры:
//  oid - Строка - идентификатор организации в ЕГИСЗ.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистры.ПараметрыВызоваМетода.
//
Функция GetOrgStaff(oid) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.GetOrgStaff(oid) 
```
</details>

## PostPutOrgStaff
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для создания (create)
// или обновления (update) сведений о штатном расписании.
//
// Параметры:
//  oid - Строка - идентификатор организации в ЕГИСЗ.
//  entityId - Строка(36) – Идентификатор (GUID) записи блока данных о штатном расписании,
//                          которые необходимо изменить методом PUT (update)
//                          Для метода POST (create) оставлять в значении Неопределено.
//  StaffData - Структура - Данные штатного расписания.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистрыКлиентСервер.ПараметрыВызоваМетода.
//
Функция PostPutOrgStaff(oid, entityId, StaffData) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.PostPutOrgStaff(oid, entityId, StaffData) 
```
</details>

## StaffData
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры данных о штатном расписании.
//
// Возвращаемое значение:
//  Структура - параметры, необходимые для вызова метода сервиса REST.
//  	staffNum - Строка(20) – Номер штатного расписания.
//  	staffCreateDate - Дата – Дата утверждения.
//  	beginDate - Дата – Дата начала действия.
//  	endDate - Дата – Дата окончания действия.
//  	staffDetails - Массив – Записи штатного расписания (см. Функция staffDetails).
//
Функция StaffData() Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.StaffData() 
```
</details>

## StaffDetails
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры данных о позиции штатного расписания.
//
// Возвращаемое значение:
//  Структура - параметры, необходимые для вызова метода сервиса REST.
//  	nrPmuDepartId - Строка – Идентификатор структурного подразделения МО (OID).
//  	departName - Строка – Наименование структурного подразделения МО.
//  	nrPmuDepartHospitalSubdivisionId - Строка – Идентификатор отделений стационарного подразделения (oid).
//  	hospitalName - Строка – Наименование отделения стационарного подразделения.
//  	postFedCode_code - Число – Код должности по Федеральному справочнику (1.2.643.5.1.13.13.99.2.885).
//  	postFedCode_name - Строка – Наименование должности по Федеральному справочнику (1.2.643.5.1.13.13.99.2.885).
//  	post_code - Число – Код должности (1.2.643.5.1.13.13.99.2.181).
//  	post_name - Строка – Наименование должности (1.2.643.5.1.13.13.99.2.181).
//  	flCount - Число – Количество физических лиц (человек).
//  	averageAge - Число – Средний возраст.
//  	rate - Число – Ставка, ед.
//  	busyRate - Число – Количество занятых штатных единиц.
//  	busyRateMain - Число – Количество занятых штатных единиц по основному месту работы.
//  	externalRate - Число – Количество внешних совместителей.
//  	vacancy - Число – Вакансий.
//  	staffNote - Строка(256) – Примечания к штатному расписанию.
//
Функция StaffDetails() Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.StaffDetails() 
```
</details>

## GetSalaryPeriod
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для чтения всех сведений медицинского работника.
//
// Параметры:
//  oid - Строка - идентификатор организации в ЕГИСЗ.
//  salaryPeriodType - Число - Тип периода заработной платы:
//                             1 – Период фактических показателей.
//                             2 – Период плановых показателей.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистры.ПараметрыВызоваМетода.
//
Функция GetSalaryPeriod(oid, salaryPeriodType, offset, limit) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.GetSalaryPeriod(oid, salaryPeriodType, offset, limit) 
```
</details>

## PostPutSalaryPeriod
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для создания (create)
// или обновления (update) сведений о периоде заработной платы.
//
// Параметры:
//  oid - Строка - идентификатор организации в ЕГИСЗ.
//  entityId - Строка(36) – Идентификатор (GUID) записи блока данных о периоде заработной платы,
//                          которые необходимо изменить методом PUT (update)
//                          Для метода POST (create) оставлять в значении Неопределено.
//  SalaryPeriodData - Структура - Данные периода заработной платы.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистрыКлиентСервер.ПараметрыВызоваМетода.
//
Функция PostPutSalaryPeriod(oid, entityId, SalaryPeriodData) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.PostPutSalaryPeriod(oid, entityId, SalaryPeriodData) 
```
</details>

## PostPutSalaryPeriodRecord
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова rest-метода для создания (create)
// или обновления (update) записи заработной платы.
//
// Параметры:
//  oid - Строка - идентификатор организации в ЕГИСЗ.
//  entityId - Строка(36) – Идентификатор (GUID) записи блока данных записи заработной платы,
//                          которые необходимо изменить методом PUT (update)
//                          Для метода POST (create) оставлять в значении Неопределено.
//  SalaryPeriodRecordData - Структура - Данные записи заработной платы.
//
// Возвращаемое значение:
//  Структура - см. описание функции МедицинскиеРегистрыКлиентСервер.ПараметрыВызоваМетода.
//
Функция PostPutSalaryPeriodRecord(oid, entityId, SalaryPeriodRecordData) Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.PostPutSalaryPeriodRecord(oid, entityId, SalaryPeriodRecordData) 
```
</details>

## SalaryPeriodData
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Конструктор структуры данных о периоде заработной платы.
//
// Возвращаемое значение:
//  Структура - параметры, необходимые для вызова метода сервиса REST.
//  	salaryPeriodId - Строка(GUID) – Идентификатор периода заработной платы.
//                                      Только для обновления существующих записей метод PUT.
//  	salaryPeriodType - Число – Тип периода заработной платы:
//                                 1 – Период фактических показателей.
//                                 2 – Период плановых показателей.
//  	periodDate - Дата(ISO8601) – Отчетный период. Минимальное значение 01.01.2018.
//                                   Пример заполнения ГГГГ-ММ-01.
//                                   Для фактических показателей можно указывать дату только предыдущих месяцев.
//  	staff - Объект – Данные штатного расписания:
//  	                 staffId - Строка – Идентификатор штатного расписания (GUID).
//
Функция SalaryPeriodData() Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.SalaryPeriodData() 
```
</details>

## SalaryPeriodRecordData
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры данных о записи заработной платы.
//
// Возвращаемое значение:
//  Структура - параметры, необходимые для вызова метода сервиса REST.
//  	salaryPeriodRecordId - Строка(GUID) – Идентификатор записи заработной платы.
//                                            Только для обновления существующих записей метод PUT.
//  	salaryPeriod - Объект – Период заработной платы записи:
//  	                 salaryPeriodId - Строка – Идентификатор периода ЗП (GUID).
//  	                 salaryPeriodType - Число – Тип периода заработной платы:
//                                                  1 – Период фактических показателей.
//                                                  2 – Период плановых показателей.
//  	                 periodDate - Дата(ISO8601) – Отчетный период. Минимальное значение 01.01.2018.
//                                                    Пример заполнения ГГГГ-ММ-01.
//                                                    Для фактических показателей можно указывать дату только предыдущих месяцев.
//  	departId - Строка – OID структурного подразделения.
//  	subdivisionId - Строка – OID отделения стационара (заполняется только для стационаров).
//  	postFedCode.code - Число – Код должности по Федеральному справочнику (1.2.643.5.1.13.13.99.2.885).
//  	postFedCode.name - Строка – Наименование должности по Федеральному справочнику (1.2.643.5.1.13.13.99.2.885).
//  	personalFileNumber - Строка – Идентификатор занятости (только для фактических показателей). "AABBBBBCCCCCCCC":
//                                    A - код региона,
//                                    B - код должности по федеральному справочнику 885,
//                                    C - порядковый номер записи ЛД в рамках региона.
//  	personCardId - Строка – Идентификатор личного дела (в записях для позиций ШР не заполняется).
//  	financingSources - Массив объектов – Источники финансирования (см. Функция FinancingSourceData).
//
Функция SalaryPeriodRecordData() Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.SalaryPeriodRecordData() 
```
</details>

## FinancingSourceData
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры данных об источнике финансирования.
//
// Возвращаемое значение:
//  Структура - параметры, необходимые для вызова метода сервиса REST.
//  	financingSourceId - Строка(GUID) – Идентификатор записи источника финансирования.
//                                         Только для обновления существующих записей метод PUT.
//  	financingSource.code - Число – Идентификатор источника финансирования по Федеральному справочнику (1.2.643.5.1.13.13.99.2.1105).
//  	financingSource.name - Строка – Наименование источника финансирования по Федеральному справочнику (1.2.643.5.1.13.13.99.2.1105).
//                                      Не обязательно к заполнению.
//  	financingSourceType - Число – Тип источника финансирования:
//                                 1 – Начисление.
//                                 2 – Удержание.
//  	accrualPurpose.code - Число – Идентификатор назначения начисления по Федеральному справочнику (1.2.643.5.1.13.13.99.2.1106).
//                                    Заполняется только, если financingSourceType = 1.
//  	accrualPurpose.name - Строка – Наименование назначения начисления по Федеральному справочнику (1.2.643.5.1.13.13.99.2.1106).
//                                     Не обязательно к заполнению. Заполняется только, если financingSourceType = 1
//  	retentionPurpose.code - Число – Идентификатор назначения удержания по Федеральному справочнику (1.2.643.5.1.13.13.99.2.1107).
//                                    Заполняется только, если financingSourceType = 2.
//  	retentionPurpose.name - Строка – Наименование назначения удержания по Федеральному справочнику (1.2.643.5.1.13.13.99.2.1107).
//                                     Не обязательно к заполнению. Заполняется только, если financingSourceType = 2
//  	accrual - Число – Начисление. Сумма в рублях, число с 2 знаками после запятой. Минимальное значение 0,01.
//                        Заполняется только, если financingSourceType = 1.
//  	retention - Число – Удержание. Сумма в рублях, число с 2 знаками после запятой. Минимальное значение 0,01.
//                          Заполняется только, если financingSourceType = 2.
//  	overtimeHours - Число – Количество часов переработок. Дробное число с 2 знаками после запятой.
//                              Не обязательно к заполнению.
//  	overtimePayment - Число – Выплата по переработкам. Сумма в рублях, число с 2 знаками после запятой. Минимальное значение 0,01.
//                                Не обязательно к заполнению.
//
Функция FinancingSourceData() Экспорт
```

Пример вызова
```bsl
Результат = МедицинскиеРегистрыФРМО.FinancingSourceData() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
