---
title: Миграция приложений
slug: zup/миграция-приложений
---


## НачатьВыгрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует выгрузку.
//
// Параметры:
//   АдресПриложения - Строка - url приложения, которое создано специально для миграции.
//   Логин - Строка - логин пользователя в этом приложении.
//   Пароль - Строка - пароль пользователя.
//   ВыгружатьНастройкиПользователей - Соответствие из КлючИЗначение - коллекция пользователей, настройки которых нужно выгружать:
//      * Ключ - СправочникСсылка.Пользователи - пользователь, настройки которого нужно выгрузить.
//      * Значение - Строка - новый логин пользователя.
//   ЗавершитьМиграциюАвтоматически - Булево - если Истина, то будет выполнена попытка установить монопольный режим и
//                                             завершить миграцию.
//   ДополнительныеСвойства - Структура - доп. свойства для сохранения.
//
Процедура НачатьВыгрузку(АдресПриложения, Логин, Пароль, ВыгружатьНастройкиПользователей, ЗавершитьМиграциюАвтоматически, ДополнительныеСвойства) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.НачатьВыгрузку(АдресПриложения, Логин, Пароль, ВыгружатьНастройкиПользователей, ЗавершитьМиграциюАвтоматически, ДополнительныеСвойства) 
```
</details>

## ОтменитьВыгрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет выгрузку.
//
Процедура ОтменитьВыгрузку() Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ОтменитьВыгрузку() 
```
</details>

## СостояниеВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает состояние выгрузки.
//
// Возвращаемое значение:
//   Структура - структура с ключами:
//     * ДатаНачала - Дата - универсальная дата начала перехода.
//     * НомерОтправленногоСообщения - Число - номер отправленного сообщения.
//     * НомерПринятогоСообщения - Число - количество обработанных сообщений.
//     * ИзмененоОбъектов - Число - количество зарегистрированных изменений.
//     * ВыгруженоОбъектов - Число - количество выгруженных объектов.
//     * ЗагруженоОбъектов - Число - количество загруженных объектов.
//     * ЗагрузитьОбъектов - Число - количество объектов, которые еще нужно загрузить.
//     * ДатаЗавершения - Дата - универсальная дата завершения перехода.
//     * Состояние - ПеречислениеСсылка.СостоянияМиграцииПриложения - состояние миграции.
//     * Комментарий - Строка - доп. описание состояния.
//
Функция СостояниеВыгрузки() Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.СостояниеВыгрузки() 
```
</details>

## НачатьЗагрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует загрузку.
//
// Параметры:
// ПользователиОбласти - Соответствие - в качестве ключа исходная ссылка, в качестве значения логин пользователя.
//
Процедура НачатьЗагрузку(ПользователиОбласти) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.НачатьЗагрузку(ПользователиОбласти) 
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков.
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

## ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки.
//
// Параметры:
// 	Типы - См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки.Типы
//
Процедура ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки(Типы) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПриЗаполненииТиповИсключаемыхИзВыгрузкиЗагрузки(Типы) 
```
</details>

## ПриОпределенииНастроекРегламентныхЗаданий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. РегламентныеЗаданияПереопределяемый.ПриОпределенииНастроекРегламентныхЗаданий
//
// Параметры:
//	Настройки - см. РегламентныеЗаданияПереопределяемый.ПриОпределенииНастроекРегламентныхЗаданий.Настройки
Процедура ПриОпределенииНастроекРегламентныхЗаданий(Настройки) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПриОпределенииНастроекРегламентныхЗаданий(Настройки) 
```
</details>

## ПриДобавленииОбработчиковОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбновлениеИнформационнойБазыБСП.ПриДобавленииОбработчиковОбновления
//
// Параметры:
//	Обработчики - см. ОбновлениеИнформационнойБазы.НоваяТаблицаОбработчиковОбновления
Процедура ПриДобавленииОбработчиковОбновления(Обработчики) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПриДобавленииОбработчиковОбновления(Обработчики) 
```
</details>

## ПриДобавленииПараметровРаботыКлиентаПриЗапуске
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОбщегоНазначенияПереопределяемый.ПриДобавленииПараметровРаботыКлиентаПриЗапуске.
Процедура ПриДобавленииПараметровРаботыКлиентаПриЗапуске(Параметры) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПриДобавленииПараметровРаботыКлиентаПриЗапуске(Параметры) 
```
</details>

## ЗаданиеВыгрузка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регламентное задание МиграцияПриложенийВыгрузка.
//
Процедура ЗаданиеВыгрузка(ЗавершитьМиграцию = Ложь) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ЗаданиеВыгрузка(ЗавершитьМиграцию);
```
</details>

## ЗаданиеЗагрузка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регламентное задание МиграцияПриложенийЗагрузка.
//
Процедура ЗаданиеЗагрузка() Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ЗаданиеЗагрузка() 
```
</details>

## ПроверитьСоставПланаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет состав плана обмена, в случае некорректного состава вызывается исключение.
// Проверки:
//   1) У всех объектов выключена авторегистрация.
//   2) В составе есть все объекты необходимые для обмена.
//
Процедура ПроверитьСоставПланаОбмена() Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПроверитьСоставПланаОбмена() 
```
</details>

## ПередЗаписьюОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ПередЗаписьюОбъекта.
//
Процедура ПередЗаписьюОбъекта(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПередЗаписьюОбъекта(Источник, Отказ) 
```
</details>

## ПередЗаписьюДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ЗаписьюДокумента.
//
Процедура ПередЗаписьюДокумента(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПередЗаписьюДокумента(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ПередЗаписьюНабора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ПередЗаписьюНабора.
//
Процедура ПередЗаписьюНабора(Источник, Отказ, Замещение) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПередЗаписьюНабора(Источник, Отказ, Замещение) 
```
</details>

## ПередЗаписьюНабораРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ПередЗаписьюНабораРасчета.
//
Процедура ПередЗаписьюНабораРасчета(Источник, Отказ, Замещение, ТолькоЗапись, ЗаписьФактическогоПериодаДействия, ЗаписьПерерасчетов) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПередЗаписьюНабораРасчета(Источник, Отказ, Замещение, ТолькоЗапись, ЗаписьФактическогоПериодаДействия, ЗаписьПерерасчетов) 
```
</details>

## ПередУдалениемОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ПередУдалениемОбъекта.
//
Процедура ПередУдалениемОбъекта(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.ПередУдалениемОбъекта(Источник, Отказ) 
```
</details>

## АбонентыПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получается абонентов пользователя из сервиса.
// Используется во внешней обработке перехода в сервис, которая должна работать на БТС от 1.2.2.
//
// Параметры:
//   ИсточникПараметровДоступа - ФормаКлиентскогоПриложения, Структура -
//
// Возвращаемое значение:
//   СписокЗначений - в качестве значения код, в качестве представления наименование.
//
Функция АбонентыПользователя(ИсточникПараметровДоступа) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.АбонентыПользователя(ИсточникПараметровДоступа) 
```
</details>

## ВызватьМетодПрограммногоИнтерфейса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает метода программного интерфейса менеджера сервиса.
//
// Параметры:
//   ИсточникПараметровДоступа - ФормаКлиентскогоПриложения, Структура -
//   ПараметрыМетода - Структура - параметры вызываемого метода.
//   Метод - Строка, Неопределено - имя метода для подстановки в URL запроса. Если не указано, в менеджере сервиса
//      будет использовано имя метода из параметров запроса.
//
// Возвращаемое значение:
// 	Структура - результат запроса:
//	* Поле - Произвольный - произвольный набор полей.
Функция ВызватьМетодПрограммногоИнтерфейса(ИсточникПараметровДоступа, ПараметрыМетода, Метод = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.ВызватьМетодПрограммногоИнтерфейса(ИсточникПараметровДоступа, ПараметрыМетода, Метод);
```
</details>

## СервисПоддерживаетМиграцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку сервиса.
// Используется во внешней обработке перехода в сервис, которая должна работать на БТС от 1.2.2.
//
// Параметры:
//	ИмяСервера - Строка - имя сервера.
//	АдресПрограммногоИнтерфейса - Строка - выходной параметр.
//	АдресРегистрации - Строка - выходной параметр.
//	АдресВосстановления - Строка - выходной параметр.
//	РегистрацияРазрешена - Булево - выходной параметр.
// Возвращаемое значение:
//   Булево - Истина - в случае если поддерживает миграцию.
//
Функция СервисПоддерживаетМиграцию(ИмяСервера, АдресПрограммногоИнтерфейса, АдресРегистрации, АдресВосстановления, РегистрацияРазрешена) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.СервисПоддерживаетМиграцию(ИмяСервера, АдресПрограммногоИнтерфейса, АдресРегистрации, АдресВосстановления, РегистрацияРазрешена) 
```
</details>

## ПользователиСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает пользователей сервиса.
// Используется во внешней обработке перехода в сервис, которая должна работать на БТС от 1.2.2.
//
// Параметры:
//   ИсточникПараметровДоступа - ФормаКлиентскогоПриложения, Структура -
//
// Возвращаемое значение:
//   Массив Из Структура - описание:
//     * Логин - Строка -
//     * Наименование - Строка -
//     * ЭлектроннаяПочта - Строка -
//     * Роль - см. МиграцияПриложенийКлиентСервер.ПредставлениеРоли
//
Функция ПользователиСервиса(ИсточникПараметровДоступа) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.ПользователиСервиса(ИсточникПараметровДоступа) 
```
</details>

## СоздатьПриложениеДляМиграции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает приложение для миграции в сервисе.
//
// Параметры:
//   ИсточникПараметровДоступа - ФормаКлиентскогоПриложения, Структура -
//   Наименование - Строка - Наименование приложения.
//   ЧасовойПояс - Строка - часовой пояс приложения.
//   ПраваПользователей - ТаблицаЗначений - таблица с колонками:
//     * Логин - Строка - логин пользователя сервиса.
//     * Пользователь - СправочникСсылка.Пользователи - пользователь к которому будет привязан пользователь сервиса.
//     * Право - Строка - см. МиграцияПриложенийКлиентСервер.ИдентификаторAPIПрава.
//   РасширенияДляВосстановления - ТаблицаЗначений - таблица с колонками:
//     * Имя - Строка
//     * Версия - Строка
//
// Возвращаемое значение:
//   Структура - ключи:
//     * АдресПриложения - Строка - url приложения.
//     * Логин - Строка - логин служебного пользователя.
//     * Пароль - Строка - пароль служебного пользователя.
//     * Код - Число - код области.
//
Функция СоздатьПриложениеДляМиграции(ИсточникПараметровДоступа, Наименование, ЧасовойПояс, ПраваПользователей, Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.СоздатьПриложениеДляМиграции(ИсточникПараметровДоступа, Наименование, ЧасовойПояс, ПраваПользователей, );
```
</details>

## ДанныеОбслуживающейОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные обслуживающей организации в сервисе.
//
// Параметры:
//   ИсточникПараметровДоступа - ФормаКлиентскогоПриложения, Структура -
//
// Возвращаемое значение:
//   Структура - ключи:
//     * Код - Число
//     * Наименование - Строка
//     * ЭлектроннаяПочта - Строка
//     * Телефон - Строка
//     * ОписаниеОшибки - Строка
//
Функция ДанныеОбслуживающейОрганизации(ИсточникПараметровДоступа) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.ДанныеОбслуживающейОрганизации(ИсточникПараметровДоступа) 
```
</details>

## Зарегистрироваться
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует в сервисе.
//
// Параметры:
//   ИмяСервера - Строка - имя сервера
//   Наименование - Строка - наименование абонента
//   Логин - Строка -
//   ЭлектроннаяПочта - Строка - адрес электронной почты
//   Пароль - Строка -
//   Телефон - Строка - телефон абонента
//
// Возвращаемое значение:
//   Булево - результат регистрации.
//
Функция Зарегистрироваться(ИмяСервера, Наименование, Логин, ЭлектроннаяПочта, Пароль, Телефон) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.Зарегистрироваться(ИмяСервера, Наименование, Логин, ЭлектроннаяПочта, Пароль, Телефон) 
```
</details>

## ПодтвердитьРегистрацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подтверждает регистрацию в сервисе.
//
// Параметры:
//   ИмяСервера - Строка - имя сервера
//   КодПодтверждения - Строка - код подтверждения регистрации
//
// Возвращаемое значение:
//   Булево - результат подтверждения регистрации.
//
Функция ПодтвердитьРегистрацию(ИмяСервера, КодПодтверждения) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.ПодтвердитьРегистрацию(ИмяСервера, КодПодтверждения) 
```
</details>

## Описание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание данных логического хранилища.
//
// Параметры:
//  ИдентификаторХранилища - Строка - идентификатор логического хранилища.
//  ИдентификаторДанных    - Строка - идентификатор данных хранилища.
//
// Возвращаемое значение:
//   Структура - описание состояния задания очереди:
//    * ИмяФайла - Строка - имя файла.
//    * Размер - Число - размер файла в байтах.
//    * Данные - ДвоичныеДанные - двоичные данные файла описания задания.
//
Функция Описание(ИдентификаторХранилища, ИдентификаторДанных) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.Описание(ИдентификаторХранилища, ИдентификаторДанных) 
```
</details>

## Данные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные логического хранилища.
//
// Параметры:
//  ОписаниеДанных - Структура - описание данных хранилища.
//
// Возвращаемое значение:
//   ДвоичныеДанные -
//
Функция Данные(ОписаниеДанных) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.Данные(ОписаниеДанных) 
```
</details>

## Загрузить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает данные в логическое хранилище.
// Выполняет действия:
// - сохраняет файл данных в файловом хранилище
// - планирует задание очереди заданий на обработки файла
// - возвращается идентификатор задания в ответ.
//
// Возвращаемое значение:
//   Структура - состояние загрузки:
//   * id - Структура:
//    ** Успешно - Булево
//    ** Комментарий - Строка
//    ** СостояниеЗагрузки - см. СостояниеЗагрузки
//
Функция Загрузить(ОписаниеДанных) Экспорт
```

Пример вызова
```bsl
Результат = МиграцияПриложений.Загрузить(ОписаниеДанных) 
```
</details>

## УдалитьВременныхПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик обновления
Процедура УдалитьВременныхПользователей() Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.УдалитьВременныхПользователей() 
```
</details>

## УдалитьВременногоПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьВременногоПользователя(Имя) Экспорт
```

Пример вызова
```bsl
МиграцияПриложений.УдалитьВременногоПользователя(Имя) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
