---
title: Обмен с банками
slug: zup/обмен-с-банками
---


## ИспользуетсяСервисДиректБанк
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, используется ли сервис 1C:ДиректБанк
//
// Возвращаемое значение:
//  Булево - значение функциональной опции.
//
Функция ИспользуетсяСервисДиректБанк() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ИспользуетсяСервисДиректБанк() 
```
</details>

## ВозможенПрямойОбменСБанком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, возможен ли прямой обмен с банком
//
// Параметры:
//  БИК - Строка - БИК банка
//  Проект - Число, Неопределено - Признак проекта, которые поддерживает банк.
//     * 1 - Платежные документы.
//     * 2 - Зарплатные документы.
//     * Неопределено - любой из проектов.
//  Рекомендуется - Булево - (возвращаемый параметр) - признак, что в банке поддержано
//                                                     автоматическое получение настроек обмена.
//
// Возвращаемое значение:
//  Булево - Если Истина, то возможен прямой обмен с банком, иначе Ложь.
//
Функция ВозможенПрямойОбменСБанком(БИК, Проект = Неопределено, Рекомендуется = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ВозможенПрямойОбменСБанком(БИК, Проект, Рекомендуется);
```
</details>

## ФормаПросмотраЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует табличный документ на основании данных электронного документа
//
// Параметры:
//    СообщениеОбмена - ДокументСсылка.СообщениеОбменСБанками - ссылка на сообщение обмена с банком.
//
// Возвращаемое значение:
//    ТабличныйДокумент, Неопределено - сформированная форма просмотра электронного документа или Неопределено.
//
Функция ФормаПросмотраЭД(СообщениеОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ФормаПросмотраЭД(СообщениеОбмена) 
```
</details>

## ГотовыеКОтправкеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет готовые к отправке платежные документы
//
// Параметры:
//  МассивДокументов - Массив из ОпределяемыйТип.ВладелецОбменСБанками - исходный массив документов,
//                     которые предполагается отправить в банк.
//
// Возвращаемое значение:
//   Массив из ОпределяемыйТип.ВладелецОбменСБанками - массив документов, которые можно отправить в банк.
//
Функция ГотовыеКОтправкеДокументы(МассивДокументов) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ГотовыеКОтправкеДокументы(МассивДокументов) 
```
</details>

## НастройкаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производит поиск настройки обмена с банком. Возвращает первую найденную настройку обмена.
//
// Параметры:
//   Организация - ОпределяемыйТип.Организация - организация, указанная в настройке;
//   Банк - ОпределяемыйТип.БанкОбменСБанками - банк, указанный в настройке;
//   ТолькоДействительная - Булево - Истина - поиск только действующей настройки, Ложь - поиск любой настройки.
//
// Возвращаемое значение:
//   СправочникСсылка.НастройкиОбменСБанками, Неопределено - найденная настройка обмена с банком.
//
Функция НастройкаОбмена(Организация, Банк = Неопределено, ТолькоДействительная = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.НастройкаОбмена(Организация, Банк, ТолькоДействительная);
```
</details>

## ПолучитьСтатусыДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает текущие статусы документов.
//
// Параметры:
//  МассивОбъектов - Массив - документы, для которых требуется получить статусы
//    * ДокументСсылка - ссылка на документ информационной базы
//  МассивСтатусов - Массив - статусы документов из первого параметра
//    * ПеречислениеСсылка.СтатусыОбменСБанками - текущий статус электронного документа,
//    * Неопределено - нет актуального электронного документа для документа информационной базы.
//
Процедура ПолучитьСтатусыДокументов(МассивОбъектов, МассивСтатусов) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПолучитьСтатусыДокументов(МассивОбъектов, МассивСтатусов) 
```
</details>

## ПриВыводеНавигационнойСсылкиВФормеОбъектаИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирование текстового представления рекламы 1С:ДиректБанк.
//
// Параметры:
//  ДополнительнаяИнформация - Структура - с полями:
//   * Картинка - Картинка - картинка из библиотеки картинок;
//   * Текст - Строка - форматированный текст надписи с навигационными ссылками.
//  МассивСсылок - Массив - список ссылок на объекты.
Процедура ПриВыводеНавигационнойСсылкиВФормеОбъектаИБ(ДополнительнаяИнформация, МассивСсылок) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриВыводеНавигационнойСсылкиВФормеОбъектаИБ(ДополнительнаяИнформация, МассивСсылок) 
```
</details>

## ПараметрыОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает параметры обмена с банком
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - ссылка на организацию.
//  Банк - ОпределяемыйТип.БанкОбменСБанками - ссылка на банк.
//
// Возвращаемое значение:
//  Неопределено - отсутствует настройка обмена с банком через сервис 1С:ДиректБанк.
//  Структура - текущие параметры обмена с банком. Содержит поля:
//     * НастройкаОбмена - СправочникСсылка.НастройкиОбменСБанками - ссылка на настройку обмена с банком.
//     * Недействительна - Булево - признак отключенной настройки или помеченной на удаление.
//     * ДоступноАвтоматическоеПолучениеВыписки - Булево - по текущей настройке обмена возможно получение выписки в автоматическом режиме.
//     * ПринимаемыеВидыЭД - Массив - виды электронных документов, принимаемых банком. В элементах массива ПеречислениеСсылка.ВидыЭДОбменСБанками.
//     * ДатаПоследнегоПолученияВыписки - Дата - дата последнего получения выписки банка.
//     * ТекстОшибки - Строка - текст ошибки, которая произошла при последнем получении выписки.
//     * ВключеноАвтоматическоеПолучениеВыписки - Булево - по текущей настройке обмена запущено автоматическое получение выписки банка.
//     * ДатаПоследнейСинхронизации - Дата - дата последнего запуска синхронизации с банком.
//
Функция ПараметрыОбмена(Организация, Банк) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПараметрыОбмена(Организация, Банк) 
```
</details>

## НастройкиОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу с настройками обмена по переданной таблице отбора
//
// Параметры:
//  ТаблицаОтбора - ТаблицаЗначений - Таблица отбора, содержит колонки:
//   * Организация - ОпределяемыйТип.Организация - ссылка на организацию
//   * Банк - ОпределяемыйТип.БанкОбменСБанками - ссылка на банк.
//
// Возвращаемое значение:
//  ТаблицаЗначений - содержит таблицу отбора, с дополнительными колонками:
//   * Организация - ОпределяемыйТип.Организация - ссылка на организацию
//   * Банк - ОпределяемыйТип.БанкОбменСБанками - ссылка на банк.
//   * ЕстьНастройкаОбмена - Булево - для данной строки отбора существует действующая настройка обмена.
//   * НастройкаОбмена - СправочникСсылка.НастройкиОбменСБанками - ссылка на настройку обмена с банком.
//
Функция НастройкиОбмена(ТаблицаОтбора) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.НастройкиОбмена(ТаблицаОтбора) 
```
</details>

## БанкиСПрямымОбменом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает таблицу БИКов банков, поддерживающих прямой обмен
//
// Возвращаемое значение:
// 	ТаблицаЗначений - содержит информацию по банкам, поддерживающим прямой обмен
// 	 * БИК - строка - БИК банка
// 	 * ЗарплатныйПроект - Булево - признак поддержки банком зарплатного проекта.
//
Функция БанкиСПрямымОбменом() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.БанкиСПрямымОбменом() 
```
</details>

## ПараметрыСозданияФормыСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ОбменСБанкамиКлиентСервер.ПараметрыСозданияФормыСписка.
// Формирует параметры создания формы списка документов.
//
// Возвращаемое значение:
//   Структура - содержит поля:
//     * ГруппаКоманд - Структура - параметры создания группы команд 1С:ДиректБанк, содержит поля:
//        ** Добавить - Булево - если Истина (по умолчанию), то группа команд будет создана автоматически
//        ** Родитель - ГруппаФормы, ТаблицаФормы, ФормаКлиентскогоПриложения - родитель для добавляемого элемента.
//                      Если не задан, то родителем будет являться ФормаОбъект.КоманднаяПанель.
//        ** МестоРасположения - Строка - имя элемента, перед которым нужно разместить группу команд.
//                                        Если не задан, то группа помещается в конец командной панели формы.
//     * ДинамическийСписок - Структура - параметры изменения запроса динамического списка:
//        ** Изменить - Булево - если Истина (по умолчанию), то в запрос динамического списка добавляются
//                               дополнительные поля.
//        ** ИмяРеквизита - Строка - имя реквизита формы динамического списка. "Список" по-умолчанию.
//     * СписокДокументов - Структура - параметры добавления колонок в список документов:
//        ** ДобавитьКолонки - Булево - если Истина (по умолчанию), то в список добавляются дополнительные колонки.
//        ** ИмяЭлемента - Строка - имя элемента формы динамического списка документов. "Список" по-умолчанию
//        ** ИмяРеквизита - Строка - имя реквизита формы динамического списка документов. "Список" по-умолчанию
//        ** МестоРасположения - Строка - имя элемента, перед которым нужно разместить новую колонку.
//                                        Если не задан, то перемещается в конец колонок таблицы.
//     * ПерепискаСБанками - Структура - параметры добавления ссылки на переписку с банками:
//        ** ДобавитьСсылку - Булево - если Истина (по умолчанию), то добавляется ссылка на переписку с банками.
//        ** Родитель - Строка - имя родителя добавляемого элемента.
//                               Если не указан, то элемент добавляется в конец формы.
//        ** МестоРасположения - Строка - имя элемента, перед которым нужно разместить ссылку на переписку с банками.
//     * Реклама - Структура - параметры отображения рекламы ДиректБанк:
//        ** Добавить - Булево - если Истина (по умолчанию), то на форму добавляется реклама ДиректБанка.
//        ** Родитель - Строка - имя родителя добавляемого элемента.
//                               Если не указан, то элемент добавляется в конец формы.
//        ** МестоРасположения - Строка - имя элемента, перед которым нужно разместить рекламу.
//
Функция ПараметрыСозданияФормыСписка() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПараметрыСозданияФормыСписка() 
```
</details>

## ПараметрыСозданияФормыДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ОбменСБанкамиКлиентСервер.ПараметрыСозданияФормыДокумента.
// Формирует параметры для дополнения формы документа
//
// Возвращаемое значение:
//  Структура - Описание:
//    * МестоРасположенияСостояния - Строка - элемент, перед которым нужно разместить состояние документа.
//    * РодительСостояния - Строка - элемент, в котором нужно разместить состояние.
Функция ПараметрыСозданияФормыДокумента() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПараметрыСозданияФормыДокумента() 
```
</details>

## ПолучитьДанныеВыпискиБанкаДеревоЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает выписку банка в виде дерева значений.
//
// Параметры:
//  ЭлектронныеДокументы - ДокументСсылка.СообщениеОбменСБанками, Массив - содержит выписку банка;
//  ДеревоДанных - ДеревоЗначений - содержит дерево данных выписки.
//
Процедура ПолучитьДанныеВыпискиБанкаДеревоЗначений(ЭлектронныеДокументы, ДеревоДанных) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПолучитьДанныеВыпискиБанкаДеревоЗначений(ЭлектронныеДокументы, ДеревоДанных) 
```
</details>

## ПолучитьДанныеВыпискиБанкаТекстовыйФормат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает выписку банка в текстовом формате, а также массив ссылок на банковские счета организаций в выписке.
//
// Параметры:
//  СообщениеОбмена - ДокументСсылка.СообщениеОбменСБанками, Массив - содержит ссылку или массив ссылок на выписки банка
//  СсылкаНаХранилище - Строка - содержит ссылку на хранилище тестовых данных;
//  МассивСчетов - Массив - содержит ссылки на банковские счета организации.
//
Процедура ПолучитьДанныеВыпискиБанкаТекстовыйФормат( Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПолучитьДанныеВыпискиБанкаТекстовыйФормат();
```
</details>

## ДанныеВыпискиБанкаТаблицаЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает выписку банка в виде таблицы значений.
// Повторяет структуру макета Обработки.ОбменСБанками.Макеты.ВыпискаБанка.
//
// Параметры:
//  ЭлектронныеДокументы - ДокументСсылка.СообщениеОбменСБанками, Массив - содержит выписку банка.
//
// Возвращаемое значение:
//  ТаблицаЗначений - содержит данные выписки.
//                    Структура соответствует макету Обработки.ОбменСБанками.Макеты.ВыпискаБанка.
//
Функция ДанныеВыпискиБанкаТаблицаЗначений(ЭлектронныеДокументы) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ДанныеВыпискиБанкаТаблицаЗначений(ЭлектронныеДокументы) 
```
</details>

## ПравоВыполненияОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность выполнения обмена с банком для текущего пользователя
//
// Параметры:
//  ВыводитьСообщение - Булево - признак необходимости вывода сообщения о недостаточности прав.
//
// Возвращаемое значение:
//  Булево - наличие права на выполнение обмена с банком.
//
Функция ПравоВыполненияОбмена(ВыводитьСообщение = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПравоВыполненияОбмена(ВыводитьСообщение);
```
</details>

## ПравоЧтенияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность чтения данных обмена с банком для текущего пользователя
//
// Параметры:
//  ВыводитьСообщение - Булево - признак необходимости вывода сообщения о недостаточности прав.
//
// Возвращаемое значение:
//  Булево - наличие права на чтение данных обмена с банком.
//
Функция ПравоЧтенияДанных(ВыводитьСообщение = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПравоЧтенияДанных(ВыводитьСообщение);
```
</details>

## ПравоНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность настройки обмена с банком для текущего пользователя
//
// Возвращаемое значение:
//  Булево - наличие права на настройку обмена с банком.
//
Функция ПравоНастройки() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПравоНастройки() 
```
</details>

## ПравоЧтенияНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность чтения настроек обмена с банками для текущего пользователя
//
// Возвращаемое значение:
//  Булево - наличие права на чтение настроек обмена с банком.
//
Функция ПравоЧтенияНастроек() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.ПравоЧтенияНастроек() 
```
</details>

## ПриСозданииФормыСпискаНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет форму списка документов, отправляемых в банк.
//
// Параметры:
//   ФормаОбъект - ФормаКлиентскогоПриложения - дополняемая форма
//   Параметры - см. ОбменСБанкамиКлиентСервер.ПараметрыСозданияФормыСписка
Процедура ПриСозданииФормыСпискаНаСервере(ФормаОбъект, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриСозданииФормыСпискаНаСервере(ФормаОбъект, Параметры);
```
</details>

## ПриСозданииФормыДокументаНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при создании формы документа. Добавляет элементы на форму
//
// Параметры:
//   ФормаОбъект - ФормаКлиентскогоПриложения - дополняемая форма
//   Параметры - см. ПараметрыСозданияФормыДокумента
Процедура ПриСозданииФормыДокументаНаСервере(ФормаОбъект, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриСозданииФормыДокументаНаСервере(ФормаОбъект, Параметры);
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие записи документа из формы. Обновляет текст состояния обмена с банком.
//
// Параметры:
//  ФормаОбъект - ФормаКлиентскогоПриложения - форма, на которой произошла запись объекта.
//  ТекущийОбъект - ОпределяемыйТип.ВладелецОбъектОбменСБанками - записываемый объект.
//  ПараметрыЗаписи - Структура - Структура, содержащая параметры записи.
Процедура ПослеЗаписиНаСервере(ФормаОбъект, ТекущийОбъект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПослеЗаписиНаСервере(ФормаОбъект, ТекущийОбъект, ПараметрыЗаписи) 
```
</details>

## ДоступныНовыеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении уведомления о новых данных.
// В теле следует проверить, необходимы ли эти данные приложению,
// и если да - установить флажок Загружать.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Descriptor.
//   Загружать  - Булево - возвращаемое.
//
Процедура ДоступныНовыеДанные(Знач Дескриптор, Загружать) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ДоступныНовыеДанные(Дескриптор, Загружать) 
```
</details>

## ОбработатьНовыеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после вызова ДоступныНовыеДанные, позволяет разобрать данные.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Дескриптор.
//   ПутьКФайлу - Строка - Полное имя извлеченного файла. Файл будет автоматически удален
//                  после завершения процедуры.
//
Процедура ОбработатьНовыеДанные(Знач Дескриптор, Знач ПутьКФайлу) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ОбработатьНовыеДанные(Дескриптор, ПутьКФайлу) 
```
</details>

## ОбработкаДанныхОтменена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при отмене обработки данных в случае сбоя.
//
// Параметры:
//   Дескриптор - ОбъектXDTO - Descriptor.
//
//@skip-warning
Процедура ОбработкаДанныхОтменена(Знач Дескриптор) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ОбработкаДанныхОтменена(Дескриптор) 
```
</details>

## СостояниеБанковскогоДокументаСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает сводное состояние банковского документа в виде строки.
//
// Параметры:
//  СостояниеЭД - ПеречислениеСсылка.СостоянияОбменСБанками - текущее состояние электронного документооборота.
//
// Возвращаемое значение:
//  Строка - сводное упрощенное состояние.
//
Функция СостояниеБанковскогоДокументаСтрокой(СостояниеЭД) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанками.СостояниеБанковскогоДокументаСтрокой(СостояниеЭД) 
```
</details>

## ОбработатьРегистрПодписываемыеВидыЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет регистр сведений ПодписываемыеВидыЭД
//
// Параметры:
//  Параметры - Структура - параметры обработки обновления.
//
Процедура ОбработатьРегистрПодписываемыеВидыЭД(Параметры) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ОбработатьРегистрПодписываемыеВидыЭД(Параметры) 
```
</details>

## ПеренестиСтатусыЭлектронныхПодписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переносит статусы проверки подписей из документа СообщениеОбменСБанками в справочник СообщениеОбменСБанкамиПрисоединенныеФайлы
//
// Параметры:
//  Параметры - Структура - параметры обработки обновления.
//
Процедура ПеренестиСтатусыЭлектронныхПодписей(Параметры) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПеренестиСтатусыЭлектронныхПодписей(Параметры) 
```
</details>

## ВключитьАвтоматическоеОбновлениеСпискаБанков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включает регламентное задание ЗагрузкаСпискаБанковОбменСБанками
//
// Параметры:
//  Параметры - Структура - параметры обработки обновления.
//
Процедура ВключитьАвтоматическоеОбновлениеСпискаБанков(Параметры) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ВключитьАвтоматическоеОбновлениеСпискаБанков(Параметры) 
```
</details>

## ДобавитьБазовыеПраваЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Добавить базовые права ЭД
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДобавитьБазовыеПраваЭД(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ДобавитьБазовыеПраваЭД(ОписаниеПрофиля) 
```
</details>

## ДобавитьВыполнениеОбменаЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Добавить права на выполнение обмена
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДобавитьВыполнениеОбменаЭД(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ДобавитьВыполнениеОбменаЭД(ОписаниеПрофиля) 
```
</details>

## ДобавитьНастройкуПараметровЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Добавить права на изменение настроек обмена
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДобавитьНастройкуПараметровЭД(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ДобавитьНастройкуПараметровЭД(ОписаниеПрофиля) 
```
</details>

## ДобавитьЧтениеЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Добавить права на чтение настроек обмена
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДобавитьЧтениеЭД(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ДобавитьЧтениеЭД(ОписаниеПрофиля) 
```
</details>

## ПриСозданииФормыПроверкаСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. процедуру ЭлектроннаяПодписьПереопределяемый.ПриСозданииФормыПроверкаСертификата.
//
Процедура ПриСозданииФормыПроверкаСертификата( Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриСозданииФормыПроверкаСертификата();
```
</details>

## ПриПопыткеЗанятьФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. процедуру РаботаСФайламиПереопределяемый.ПриПопыткеЗанятьФайл.
Процедура ПриПопыткеЗанятьФайл(ДанныеФайла, ОписаниеОшибки) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриПопыткеЗанятьФайл(ДанныеФайла, ОписаниеОшибки) 
```
</details>

## ПриОпределенииОбъектовСКомандамиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. процедуру УправлениеПечатьюПереопределяемый.ПриОпределенииОбъектовСКомандамиПечати.
Процедура ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) 
```
</details>

## ПриЗаполненииВидовОграниченийПравОбъектовМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ЭлектронноеВзаимодействие.ПриЗаполненииВидовОграниченийПравОбъектовМетаданных
Процедура ПриЗаполненииВидовОграниченийПравОбъектовМетаданных(Описание) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриЗаполненииВидовОграниченийПравОбъектовМетаданных(Описание) 
```
</details>

## ПриПолученииСпискаШаблонов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ЭлектронноеВзаимодействие.ПриПолученииСпискаШаблонов.
Процедура ПриПолученииСпискаШаблонов(ШаблоныЗаданий) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриПолученииСпискаШаблонов(ШаблоныЗаданий) 
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ЭлектронноеВзаимодействие.ПриОпределенииПсевдонимовОбработчиков.
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

## ПриОпределенииНастроекРегламентныхЗаданий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. процедуру ЭлектронноеВзаимодействие.ПриОпределенииНастроекРегламентныхЗаданий.
//
Процедура ПриОпределенииНастроекРегламентныхЗаданий(Настройки) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриОпределенииНастроекРегламентныхЗаданий(Настройки) 
```
</details>

## ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// СтандартныеПодсистемы.ПрофилиБезопасности
// См. РаботаВБезопасномРежимеПереопределяемый.ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам
Процедура ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) 
```
</details>

## ПриОпределенииВидовПодключаемыхКоманд
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ПодключаемыеКомандыПереопределяемый.ПриОпределенииВидовПодключаемыхКоманд.
Процедура ПриОпределенииВидовПодключаемыхКоманд(ВидыПодключаемыхКоманд) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриОпределенииВидовПодключаемыхКоманд(ВидыПодключаемыхКоманд) 
```
</details>

## ПриОпределенииКомандПодключенныхКОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ПодключаемыеКомандыПереопределяемый.ПриОпределенииКомандПодключенныхКОбъекту.
Процедура ПриОпределенииКомандПодключенныхКОбъекту(НастройкиФормы, Источники, ПодключенныеОтчетыИОбработки, Команды) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриОпределенииКомандПодключенныхКОбъекту(НастройкиФормы, Источники, ПодключенныеОтчетыИОбработки, Команды) 
```
</details>

## ПриОпределенииИспользуемыхВерсийВнешнихКомпонент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. процедуру ПолучениеВнешнихКомпонентВМоделиСервисаПереопределяемый.ПриОпределенииИспользуемыхВерсийВнешнихКомпонент
//
Процедура ПриОпределенииИспользуемыхВерсийВнешнихКомпонент(Идентификаторы) Экспорт
```

Пример вызова
```bsl
ОбменСБанками.ПриОпределенииИспользуемыхВерсийВнешнихКомпонент(Идентификаторы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
