---
title: Обмен с банками клиент
slug: zup/обмен-с-банками-клиент
---


## ОткрытьСоздатьНастройкуОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает настройку обмена с банком или открывает существующую.
// Если банк не известен системе, то открывается форма новой настройки обмена с банком,
// в которой заполнена только Организация и Банк.
// Если банк известен системе, но не поддерживает автоматическое получение настроек,
// то предлагается выбор файла настроек, загружает настройки из файла
// и открывает заполненную форму настроек обмена с банком.
// Если банк известен системе и поддерживает автоматическое получение настроек,
// то настройка создается автоматически и производится тест настроек.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - ссылка на организацию.
//  Банк - СправочникСсылка.КлассификаторБанков - ссылка на банк.
//  НомерБанковскогоСчета - Строка - номер банковского счета.
//  ОбработчикОповещения - ОписаниеОповещения - содержит описание процедуры,
//   которая будет вызвана после создания настройки обмена с банком, не вызывается если настройка обмена уже существует. Параметры процедуры:
//    * НастройкаОбмена - СправочникСсылка.НастройкиОбменСБанками - созданная настройка обмена с банком.
//    * ДополнительныеПараметры - Произвольный - значение, которое было указано при создании объекта ОписаниеОповещения.
//
Процедура ОткрытьСоздатьНастройкуОбмена(Организация, Банк, НомерБанковскогоСчета = "", ОбработчикОповещения = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОткрытьСоздатьНастройкуОбмена(Организация, Банк, НомерБанковскогоСчета, ОбработчикОповещения);
```
</details>

## ОткрытьНастройкиDirectBankСОтбором
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму списка настроек обмена с отбором по организации или банку.
//
// Параметры:
//  СсылкаНаОбъект - СправочникСсылка - ссылка на объект отбора. Ссылка должна быть только на организацию или банк.
//
Процедура ОткрытьНастройкиDirectBankСОтбором(СсылкаНаОбъект) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОткрытьНастройкиDirectBankСОтбором(СсылкаНаОбъект) 
```
</details>

## ОбработкаНавигационнойСсылкиРекламыДиректБанк
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обрабатывает нажатие ссылки форматированной строки рекламы 1С:ДиректБанк.
//
// Параметры:
//  НавигационнаяСсылка - Строка - текст навигационной ссылки;
//  СтандартнаяОбработка - Булево - признак выполнения стандартной обработки события.
//
Процедура ОбработкаНавигационнойСсылкиРекламыДиректБанк(НавигационнаяСсылка, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОбработкаНавигационнойСсылкиРекламыДиректБанк(НавигационнаяСсылка, СтандартнаяОбработка) 
```
</details>

## ВключитьАвтоматическоеПолучениеВыписки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включает автоматическое получение выписки.
//
// Параметры:
//  Оповещение - ОписаниеОповещения - оповещение, вызываемое после выполнения процедуры. Параметры выполнения:
//    Результат - Булево - если Истина, то автоматическое получение выписки подключено успешно.
//  Организация - ОпределяемыйТип.Организация - ссылка на организацию.
//  Банк - ОпределяемыйТип.БанкОбменСБанками - ссылка на банк.
//
Процедура ВключитьАвтоматическоеПолучениеВыписки(Оповещение, Организация, Банк) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ВключитьАвтоматическоеПолучениеВыписки(Оповещение, Организация, Банк) 
```
</details>

## ОтключитьАвтоматическоеПолучениеВыписки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает автоматическое получение выписки.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - ссылка на организацию.
//  Банк - ОпределяемыйТип.БанкОбменСБанками - ссылка на банк.
//
// Возвращаемое значение:
//  Булево - Истина, если автоматическое получение выписки было отключено.
//
Функция ОтключитьАвтоматическоеПолучениеВыписки(Организация, Банк) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанкамиКлиент.ОтключитьАвтоматическоеПолучениеВыписки(Организация, Банк) 
```
</details>

## ПолучитьВыписку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет запрос выписки в банк, а после получения выписки вызывает обработчик из оповещения.
//
// Параметры:
//  Оповещение - ОписаниеОповещения - оповещение, вызываемое после получения выписки банка.
//    * Результат - Структура - содержит следующие поля:
//        ** Успех - Булево - если Истина, то операция успешно выполнена.
//        ** Выписки - Массив - массив документов, содержащих данные выписок.
//             *** ДокументСсылка.СообщениеОбменСБанками - ссылка на сообщение обмена с выпиской банка.
//  БанковскийСчет - ОпределяемыйТип.СчетОрганизацииОбменСБанками - ссылка на банковский счет организации
//  ДатаНачала - Дата - начало периода запроса.
//  ДатаОкончания - Дата - окончание периода запроса.
//
Процедура ПолучитьВыписку(Оповещение, БанковскийСчет, ДатаНачала, Знач ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ПолучитьВыписку(Оповещение, БанковскийСчет, ДатаНачала, ДатаОкончания) 
```
</details>

## СинхронизироватьСБанком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет подготовленные документы в банк и получает новые.
// Если параметры не переданы то выполняется синхронизация по всем настройкам с банками.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - организация из расчетного счета.
//  Банк - СправочникСсылка.КлассификаторБанков - банк из расчетного счета.
//
Процедура СинхронизироватьСБанком(Организация = Неопределено, Банк = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.СинхронизироватьСБанком(Организация, Банк);
```
</details>

## СформироватьПодписатьОтправитьЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура создает, подписывает и отправляет электронный документ.
//
// Параметры:
//  ПараметрКоманды - ДокументСсылка, Массив - ссылки на документы ИБ, которые необходимо отправить в банк.
//  СообщениеОбмена - ДокументСсылка.СообщениеОбменСБанками - электронный документ, который надо подписать, отправить.
//
Процедура СформироватьПодписатьОтправитьЭД(ПараметрКоманды, СообщениеОбмена = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.СформироватьПодписатьОтправитьЭД(ПараметрКоманды, СообщениеОбмена);
```
</details>

## ОтправитьПовторноЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура отправляет повторно электронный документ.
//
// Параметры:
//  ПараметрКоманды - ОпределяемыйТип.ВладелецОбменСБанками - ссылка на объект ИБ,
//                                                            электронные документы которого нужно отправить,
//  СообщениеОбмена - ДокументСсылка.СообщениеОбменСБанками - сообщение, которые нужно отправить.
//
Процедура ОтправитьПовторноЭД(ПараметрКоманды, СообщениеОбмена = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОтправитьПовторноЭД(ПараметрКоманды, СообщениеОбмена);
```
</details>

## ОткрытьАктуальныйЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает актуальный ЭД по документу ИБ
//
// Параметры:
//  ПараметрКоманды - ДокументСсылка- ссылка на документ ИБ;
//  Источник - ФормаКлиентскогоПриложения - Форма источник;
//  ПараметрыОткрытия - Структура - дополнительные параметры просмотра.
//
Процедура ОткрытьАктуальныйЭД(ПараметрКоманды, Источник = Неопределено, ПараметрыОткрытия = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОткрытьАктуальныйЭД(ПараметрКоманды, Источник, ПараметрыОткрытия);
```
</details>

## ОткрытьСписокЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму со списком электронных документов для данного владельца.
//
// Параметры:
//  СсылкаНаОбъект - ДокументСсылка - Ссылка на объект ИБ, электронные документы которого надо увидеть или сообщение обмена.
//  ПараметрыОткрытия - Структура - дополнительные параметры просмотра списка электронных документов.
//
Процедура ОткрытьСписокЭД(СсылкаНаОбъект, ПараметрыОткрытия = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОткрытьСписокЭД(СсылкаНаОбъект, ПараметрыОткрытия);
```
</details>

## СформироватьНовыйЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура создает новый электронный документ.
//
// Параметры:
//  ПараметрКоманды - ОпределяемыйТип.ВладелецОбменСБанками - ссылка на объект ИБ,
//                                                            электронные документы которого надо отправить.
//  Показывать - Булево - признак того что созданный документ будет показан пользователю.
//
Процедура СформироватьНовыйЭД(ПараметрКоманды, Показывать=Истина) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.СформироватьНовыйЭД(ПараметрКоманды, Показывать);
```
</details>

## ОткрытьФормуПросмотраЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму просмотра электронного документа.
//
// Параметры:
//  СообщениеОбмена - ДокументСсылка.СообщениеОбменСБанками - сообщение, в которому привязан открываемый электронный документ.
//
Процедура ОткрытьФормуПросмотраЭлектронногоДокумента(СообщениеОбмена) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОткрытьФормуПросмотраЭлектронногоДокумента(СообщениеОбмена) 
```
</details>

## ПриДополнительнойПроверкеСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из одноименной процедуры модуля ЭлектроннаяПодписьКлиентПереопределяемый.
//
// Параметры:
//  Параметры - Структура - со свойствами:
//  * ОжидатьПродолжения   - Булево - (возвращаемое значение) - если Истина, тогда дополнительная проверка
//                            будет выполнятся асинхронно, продолжение возобновится после выполнения оповещения.
//                            Начальное значение Ложь.
//  * Оповещение           - ОписаниеОповещения - обработка, которую нужно вызывать для продолжения
//                              после асинхронного выполнения дополнительной проверки.
//  * Сертификат           - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования - проверяемый сертификат.
//  * Проверка             - Строка - имя проверки, добавленное в процедуре ПриСозданииФормыПроверкаСертификата
//                              общего модуля ЭлектроннаяПодписьПереопределяемый.
//  * МенеджерКриптографии - МенеджерКриптографии - подготовленный менеджер криптографии для
//                              выполнения проверки.
//                         - Неопределено - если стандартные проверки отключены в процедуре
//                              ПриСозданииФормыПроверкаСертификата общего модуля ЭлектроннаяПодписьПереопределяемый.
//  * ОписаниеОшибки       - Строка - (возвращаемое значение) - описание ошибки, полученной при выполнении проверки.
//                              Это описание сможет увидеть пользователь при нажатии на картинку результата.
//  * ЭтоПредупреждение    - Булево - (возвращаемое значение) - вид картинки Ошибка/Предупреждение
//                            начальное значение Ложь.
//
Процедура ПриДополнительнойПроверкеСертификата(Параметры) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ПриДополнительнойПроверкеСертификата(Параметры) 
```
</details>

## ОбработкаНавигационнойСсылкиВФормеПечатиБСП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обрабатывает нажатие на рекламную ссылку на форме печати БСП.
//
// Параметры:
//  НавигационнаяСсылка - Строка - текст навигационной ссылки;
//  МассивСсылок - Массив - ссылка на объекты ИБ, которые передали на печать.
//
Процедура ОбработкаНавигационнойСсылкиВФормеПечатиБСП(НавигационнаяСсылка, МассивСсылок) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОбработкаНавигационнойСсылкиВФормеПечатиБСП(НавигационнаяСсылка, МассивСсылок) 
```
</details>

## ОбработатьСобытиеНаФормеСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает события нажатия на рекламу или ссылку переписки с банками.
//  Вызывается из процедуры Подключаемый_ОбработатьСобытиеДиректБанк
//   Параметр1 - Произвольный -
//   Параметр2 - Произвольный -
//   Параметр3 - Произвольный -
Процедура ОбработатьСобытиеНаФормеСписка( Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОбработатьСобытиеНаФормеСписка();
```
</details>

## ОбработатьОповещениеФормыСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает оповещение, возникающее на форме списка документов.
//
// Параметры:
//   Объект - ФормаКлиентскогоПриложения - форма, на которой возникло оповещение.
//   ИмяСобытия - Строка - Имя события
//   Параметр - Произвольный - Параметр сообщения
//   Источник - Произвольный - Источник события.
//   ПараметрыСозданияФормыСписка - см. ОбменСБанками.ПараметрыСозданияФормыСписка
Процедура ОбработатьОповещениеФормыСписка( Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОбработатьОповещениеФормыСписка();
```
</details>

## ПослеЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработка события после записи документа. Оповещает об изменении данных обмена с банками,
// т.к. произошла запись нового состояния обмена с банком.
//
// Параметры:
//  Объект - ФормаКлиентскогоПриложения - форма, на которой произошла запись объекта.
//  ПараметрыЗаписи - Структура - Структура, содержащая параметры записи.
Процедура ПослеЗаписи(Объект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ПослеЗаписи(Объект, ПараметрыЗаписи) 
```
</details>

## ОбработатьОповещениеФормыДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при получении оповещения в форме документа.
// Необходима для обновления состояния электронного документа.
//
// Параметры:
//  ФормаОбъект - ФормаКлиентскогоПриложения - форма, получившая оповещение.
//  ИмяСобытия - Строка - идентификатор события
//  Параметр - Произвольный - Параметр сообщения.
//  Источник - Произвольный - Источник события.
Процедура ОбработатьОповещениеФормыДокумента(ФормаОбъект, ИмяСобытия, Параметр, Источник) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОбработатьОповещениеФормыДокумента(ФормаОбъект, ИмяСобытия, Параметр, Источник) 
```
</details>

## ПриВыбореСтрокиИзСпискаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при нажатии на строку динамического списка документов.
//
// Параметры:
//   Элемент - ТаблицаФормы - элемент формы, в котором произошло событие
//   ВыбраннаяСтрока - ОпределяемыйТип.ВладелецОбменСБанками - ссылка на прикладной документ.
//   Поле - ПолеФормы - Активное поле (колонка).
//   СтандартнаяОбработка - Булево - В данный параметр передается признак выполнения стандартной обработки события.
Процедура ПриВыбореСтрокиИзСпискаДокументов(Элемент, ВыбраннаяСтрока, Поле, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ПриВыбореСтрокиИзСпискаДокументов(Элемент, ВыбраннаяСтрока, Поле, СтандартнаяОбработка) 
```
</details>

## ПриНажатииНаГиперссылку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает событие нажатия на гиперссылку в форме списка платежных документов
//
// Параметры:
//  ДокументСсылка - ДокументСсылка.СообщениеОбменСБанками - сообщение обмена с банком
//  СтандартнаяОбработка - Булево - признак стандартной обработки нажатия на ссылку.
//
Процедура ПриНажатииНаГиперссылку(ДокументСсылка, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ПриНажатииНаГиперссылку(ДокументСсылка, СтандартнаяОбработка) 
```
</details>

## ОбновитьРекламуДиректБанк
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обновляет отображение контекстной рекламы 1С:ДиректБанк при оповещении формы.
//
// Параметры:
//  ИмяСобытия - Строка - идентификатор сообщения оповещения формы;
//  ГруппаРекламы - ГруппаФормы - группа элементов контекстной рекламы;
//  ДекорацияТекстРекламы - ДекорацияФормы - декорация, в заголовке которой отображается текст рекламы.
//
Процедура ОбновитьРекламуДиректБанк(ИмяСобытия, ГруппаРекламы, ДекорацияТекстРекламы) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиКлиент.ОбновитьРекламуДиректБанк(ИмяСобытия, ГруппаРекламы, ДекорацияТекстРекламы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
