---
title: Обмен с банками по зарплатным проектам
slug: zup/обмен-с-банками-по-зарплатным-проектам
---


## ДанныеДокументовДляОбменаСБанком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные документов для обмена с банком по зарплатным проектам.
//
// Параметры:
//   Документы - Массив из ОпределяемыйТип.ВедомостьВБанкЗарплатаКадры,
// 		         Массив из ДокументСсылка.ЗаявкаНаОткрытиеЛицевыхСчетовСотрудников,
// 		         Массив из ДокументСсылка.ЗаявкаНаОткрытиеЛицевыхСчетовСотрудников -
// 		                     документы, по которым требуется получить данные.
//   ДатаПолученияДанных - Дата           - дата формирования файла.
//   ПлатежныйДокумент   - ДокументСсылка - платежный документ, в который входят ведомости.
//
// Возвращаемое значение:
//  - Соответствие:
//     * Ключ     - ОпределяемыйТип.ВедомостьВБанкЗарплатаКадры,
// 		            ДокументСсылка.ЗаявкаНаОткрытиеЛицевыхСчетовСотрудников,
// 		            ДокументСсылка.ЗаявкаНаОткрытиеЛицевыхСчетовСотрудников -
// 		                     документ, данные по которому возвращаются.
//     * Значение - Структура - данные документа.
//  - Неопределено - когда нет документов, по которым требуется получить данные.
//
Функция ДанныеДокументовДляОбменаСБанком(Документы, ДатаПолученияДанных, ПлатежныйДокумент = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанкамиПоЗарплатнымПроектам.ДанныеДокументовДляОбменаСБанком(Документы, ДатаПолученияДанных, ПлатежныйДокумент);
```
</details>

## УстановитьДоступностьСпособовЗачисленияПоЗарплатномуПроекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В зависимости от зарплатного проекта устанавливает доступность у соответствия способов зачисления выплат.
//
// Параметры:
//  СпособыЗачисления - см. НовоеСоответствиеСпособовЗачисления(),
//  ЗарплатныйПроект  - СправочникСсылка.ЗарплатныеПроекты.
//
Процедура УстановитьДоступностьСпособовЗачисленияПоЗарплатномуПроекту(СпособыЗачисления, ЗарплатныйПроект) Экспорт
```

Пример вызова
```bsl
ОбменСБанкамиПоЗарплатнымПроектам.УстановитьДоступностьСпособовЗачисленияПоЗарплатномуПроекту(СпособыЗачисления, ЗарплатныйПроект) 
```
</details>

## НовоеСоответствиеСпособовЗачисления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новое соответствие со способами зачисления выплат
//
// Возвращаемое значение:
//  - Соответствие:
//     * Ключ     - ПеречислениеСсылка.СпособыЗачисленияВыплат.
//     * Значение - Булево - доступность способа зачисления.
//
Функция НовоеСоответствиеСпособовЗачисления() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанкамиПоЗарплатнымПроектам.НовоеСоответствиеСпособовЗачисления() 
```
</details>

## СоответствиеФорматовФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие между форматом файла перечислением и цифрой версии формата
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//    * Ключ     - Перечисление.ФорматыФайловОбменаПоЗарплатномуПроекту
//    * Значение - Число - Номер версии формата
//
Функция СоответствиеФорматовФайла() Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанкамиПоЗарплатнымПроектам.СоответствиеФорматовФайла() 
```
</details>

## ЗарплатныйПроектПоддерживаетСпособыЗачисленияВыплат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает поддерживаются ли разные способы зачисления выплат по зарплатному проекту
//
// Параметры:
//  ЗарплатныйПроект - СправочникСсылка.ЗарплатныеПроекты - зарплатный проект.
//
Функция ЗарплатныйПроектПоддерживаетСпособыЗачисленияВыплат(ЗарплатныйПроект) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанкамиПоЗарплатнымПроектам.ЗарплатныйПроектПоддерживаетСпособыЗачисленияВыплат(ЗарплатныйПроект) 
```
</details>

## НомерТелефонаДляОбменаСБанками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает номер телефона в виде 10 цифр
//
// Параметры:
//  НомерТелефонаПредставление - Строка - полный номер телефона со всеми знаками
//
// Возвращаемое значение:
//  Строка
//
Функция НомерТелефонаДляОбменаСБанками(НомерТелефонаПредставление) Экспорт
```

Пример вызова
```bsl
Результат = ОбменСБанкамиПоЗарплатнымПроектам.НомерТелефонаДляОбменаСБанками(НомерТелефонаПредставление) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
