---
title: Общего назначения БЭД клиент сервер
slug: zup/общего-назначения-бэд-клиент-сервер
---


## ПодсистемыБЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имена подсистем для использования в см. ЗаписатьВЖурналРегистрации.
//
// Возвращаемое значение:
// 	Структура:
// * ЭлектронноеВзаимодействие - Строка
// * ОбменСБанками - Строка
// * ОбменСКонтрагентами - Строка
// * ОбменССайтами - Строка
// * РегламентныеЗадания - Строка
// * БизнесСеть - Строка
// * ТорговыеПредложения - Строка
// * ИнтеграцияСЯндексКассой - Строка
// * СопоставлениеНоменклатурыКонтрагентов - Строка
// * Криптография - Строка
// * СервисДоставки - Строка
// * ЭлектронноеАктированиеЕИС - Строка
// * КоммерческиеПредложения - Строка
Функция ПодсистемыБЭД() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ПодсистемыБЭД() 
```
</details>

## ТолькоСимволыВСтроке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Определяет, содержит ли строка только определенные символы.
//
// Параметры:
// 	ИсходнаяСтрока - Строка - строка для проверки
// 	СимволДляПроверки - Строка - символ для проверки
// 	УчитыватьПробелы - Булево - если Истина и в строке помимо указанного символа содержатся пробелы, будет возвращено
// 	                            значение Ложь.
// Возвращаемое значение:
// 	Булево - Истина, если строка содержит только указанные символы
Функция ТолькоСимволыВСтроке(Знач ИсходнаяСтрока, СимволДляПроверки, УчитыватьПробелы = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ТолькоСимволыВСтроке(ИсходнаяСтрока, СимволДляПроверки, УчитыватьПробелы);
```
</details>

## ДополнитьСписокЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьСписокЗначений(Приемник, Источник) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияБЭДКлиентСервер.ДополнитьСписокЗначений(Приемник, Источник) 
```
</details>

## ТекстСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текст сообщения, подставляя значения параметров в шаблоны сообщений.
//
// Параметры:
//  ВидПоля        - Строка - может принимать значения: "Поле", "Колонка", "Список";
//  ВидСообщения   - Строка - может принимать значения: "Заполнение", "Корректность";
//  ИмяПоля        - Строка - имя поля;
//  НомерСтроки    - Строка - номер строки;
//  ИмяСписка      - Строка - имя списка;
//  ТекстСообщения - Строка - текст сообщения о некорректности заполнения.
//
// Возвращаемое значение:
//   Строка - текст сообщения.
//
Функция ТекстСообщения(ВидПоля = "Поле", ВидСообщения = "Заполнение", ИмяПоля = "", НомерСтроки = "", ИмяСписка = "", ТекстСообщения = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ТекстСообщения(ВидПоля, ВидСообщения, ИмяПоля, НомерСтроки, ИмяСписка, ТекстСообщения);
```
</details>

## НовыеПараметрыОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует служебную структуру, которая может быть использована для указания параметров обработки ошибок для
// реквизитов дерева данных электронного документа.
//
// Параметры:
//  КлючДанных			 - ЛюбаяСсылка - ключ данных для обработки через сообщение пользователю (см. СообщениеПользователю).
//  ПутьКДанным			 - Строка - путь к данным для обработки через сообщение пользователю (см. СообщениеПользователю).
//  НавигационнаяСсылка	 - Строка - навигационная ссылка, по которой нужно перейти при клике на ошибку.
//  ИмяФормы			 - Строка - имя формы, которую нужно открыть при клике на ошибку.
//  ПараметрыФормы		 - Структура - параметры, передаваемые в форму, открываемую при клике на ошибку.
//  ТекстОшибки			 - Строка - используется для переопределения стандартного текста ошибки.
//
// Возвращаемое значение:
//  Структура:
//    * КлючСообщения - ЛюбаяСсылка - заполняется из параметра "КлючДанных".
//    * ПутьКДаннымСообщения - Строка - заполняется из параметра "ПутьКДанным".
//    * НавигационнаяСсылка - Строка - заполняется из параметра "НавигационнаяСсылка".
//    * ИмяФормы - Строка - заполняется из параметра "ИмяФормы".
//    * ПараметрыФормы - Структура - заполняется из параметра "ПараметрыФормы".
//    * ТекстОшибки - Строка - заполняется из параметра "ТекстОшибки".
//
Функция НовыеПараметрыОшибки(КлючДанных = Неопределено, ПутьКДанным = "", НавигационнаяСсылка = "", ИмяФормы = "", Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.НовыеПараметрыОшибки(КлючДанных, ПутьКДанным, НавигационнаяСсылка, ИмяФормы, );
```
</details>

## УстановитьСвойствоСтруктуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСвойствоСтруктуры(Структура, Знач ИерархияСвойств, Знач Значение) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияБЭДКлиентСервер.УстановитьСвойствоСтруктуры(Структура, ИерархияСвойств, Значение) 
```
</details>

## СтруктураВСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует ключи и значения элементов структуры в строку.
//
// Параметры:
//	Структура - Структура - структура, ключи и значения которой преобразуются в строку.
//	РазделительКлючЗначение - Строка - разделитель, который вставляется в строку между ключом и значением структуры.
//	РазделительЭлементов - Строка - разделитель, который вставляется в строку между элементами структуры.
//
// Возвращаемое значение:
//	Строка - строка, содержащая ключи и значения элементов структуры разделенные разделителем.
//
Функция СтруктураВСтроку(Структура, РазделительКлючЗначение = "=", РазделительЭлементов = ";") Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.СтруктураВСтроку(Структура, РазделительКлючЗначение, РазделительЭлементов);
```
</details>

## ДатаВремяБезСекунд
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает форматированную дату+время без секунд.
//
// Параметры:
//  ДатаВремя - Дата
//
// Возвращаемое значение:
//  Строка - Форматированная дата
//
Функция ДатаВремяБезСекунд(ДатаВремя) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ДатаВремяБезСекунд(ДатаВремя) 
```
</details>

## ЭтоЦифра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоЦифра(Знач Символ) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ЭтоЦифра(Символ) 
```
</details>

## ЭтоБукваИлиПодчеркивание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоБукваИлиПодчеркивание(Знач Символ) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ЭтоБукваИлиПодчеркивание(Символ) 
```
</details>

## ФИОСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// ФИОСтрокой.
//
// Параметры:
//  ФИОИлиФамилия - Строка - Фамилия
//                - Структура, ОбъектXDTO - объект, владеющий свойствами Фамилия, Имя, Отчество
//  Имя - Строка
//  Отчество - Строка
//
// Варианты вызова:
//  ФИОСтрокой(ФИО) - передается объект, владеющий свойствами Фамилия, Имя и/или Отчество
//  ФИОСтрокой(Фамилия, Имя) - формирование имени без отчества
//  ФИОСтрокой(Фамилия, Имя, Отчество) - формировании полного имени, если в Отчество пустое значение, то будет
//                                       сформирован второй вариант.
//
// Возвращаемое значение:
//  Строка - строка вида "[Фамилия] [Имя] [Отчество]" или "[Фамилия] [Имя]" при отсутствии отчества
Функция ФИОСтрокой(ФИОИлиФамилия, Имя = "", Отчество = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБЭДКлиентСервер.ФИОСтрокой(ФИОИлиФамилия, Имя, Отчество);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
