---
title: Общего назначения ЭДКО клиент
slug: zup/общего-назначения-эдко-клиент
---


## ПолучитьСистемнуюИнформацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание технических характеристик компьютера (только для Windows).
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено           - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * СистемнаяИнформация - ФиксированнаяСтруктура - описание технических характеристик компьютера.
//        ** ИмяОС         - Строка - наименование операционной системы (например, Windows 7, Windows Server 2003 R2 и др.).
//        ** ВерсияОС      - Строка - версия операционной системы в формате РР.П.
//        ** РазрядностьОС - Число - разрядность операционной системы (32 или 64).
//      * ОписаниеОшибки      - Строка - описание ошибки выполнения.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
Процедура ПолучитьСистемнуюИнформацию(ОповещениеОЗавершении, ВыводитьСоообщения = Истина) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияЭДКОКлиент.ПолучитьСистемнуюИнформацию(ОповещениеОЗавершении, ВыводитьСоообщения);
```
</details>

## УстановитьViPNetCSP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет установку криптопровайдера ViPNet CSP.
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено           - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ОписаниеОшибки      - Строка - описание ошибки выполнения.
//
//   ВладелецФормы - ФормаКлиентскогоПриложения - форма, которая будет указана в качестве владельца.
//
Процедура УстановитьViPNetCSP(ОповещениеОЗавершении, ВладелецФормы) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияЭДКОКлиент.УстановитьViPNetCSP(ОповещениеОЗавершении, ВладелецФормы) 
```
</details>

## УстановитьCryptoProCSP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет установку криптопровайдера CryptoPro CSP.
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено           - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ОписаниеОшибки      - Строка - описание ошибки выполнения.
//
//   ВладелецФормы - ФормаКлиентскогоПриложения - форма, которая будет указана в качестве владельца.
//
Процедура УстановитьCryptoProCSP(ОповещениеОЗавершении, ВладелецФормы) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияЭДКОКлиент.УстановитьCryptoProCSP(ОповещениеОЗавершении, ВладелецФормы) 
```
</details>

## СообщитьПользователюОКонфликтеКриптопровайдеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможен ли конфликт установленных криптопровайдеров и при необходимости выдает предупреждение.
Процедура СообщитьПользователюОКонфликтеКриптопровайдеров() Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияЭДКОКлиент.СообщитьПользователюОКонфликтеКриптопровайдеров() 
```
</details>

## ИнформацияОКриптопровайдерах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает версии КриптоПро CSP и ViPNet CSP из реестра.
//
//  Возвращаемое значение - Структура:
//    * ВерсияКриптоПроCSP - Строка - примерный вид: "9.9.9999", при ошибке чтения возвращается пустая строка.
//    * ВерсияViPNetCSP    - Строка - примерный вид: "9.9.9.99999", при ошибке чтения возвращается пустая строка.
//
Функция ИнформацияОКриптопровайдерах() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияЭДКОКлиент.ИнформацияОКриптопровайдерах() 
```
</details>

## ЭтоКриптопровайдерLinux
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что следует использовать криптопровайдер с параметрами, применяемыми в Linux.
//
//  Возвращаемое значение - Булево - Истина для Linux и MacOS.
//
Функция ЭтоКриптопровайдерLinux() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияЭДКОКлиент.ЭтоКриптопровайдерLinux() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
