---
title: Ожидание операций БЭД клиент
slug: zup/ожидание-операций-бэд-клиент
---


## НовыйКонтекст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор контекста ожидания выполнения операции.
//
// Параметры:
// 	ПараметрыОжиданияОперации - см. ОжиданиеОперацийБЭДСлужебныйКлиентСервер.НовыеПараметры
// Возвращаемое значение:
// 	Структура - данные контекста ожидания операции. Для работы с контекстом используются методы данного модуля.
Функция НовыйКонтекст(ПараметрыОжиданияОперации) Экспорт
```

Пример вызова
```bsl
Результат = ОжиданиеОперацийБЭДКлиент.НовыйКонтекст(ПараметрыОжиданияОперации) 
```
</details>

## НовыеПараметры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ОжиданиеОперацийБЭДСлужебныйКлиентСервер.НовыеПараметры
Функция НовыеПараметры() Экспорт
```

Пример вызова
```bsl
Результат = ОжиданиеОперацийБЭДКлиент.НовыеПараметры() 
```
</details>

## ОтметитьНачалоВыполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отмечает, что началось выполнение операции. Требуется для того, чтобы модуль, вызывающий асинхронную операцию, смог
// принять решение, открывать форму ожидания или нет.
//
// Параметры:
// 	КонтекстОжиданияОперации - см. НовыйКонтекст
Процедура ОтметитьНачалоВыполнения(КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ОтметитьНачалоВыполнения(КонтекстОжиданияОперации) 
```
</details>

## УстановитьОбработчикПрерывания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет асинхронной операции установить обработчик, который будет вызван при отмене операции из интерфейса.
//
// Параметры:
// 	Обработчик - ОписаниеОповещения - обработчик оповещения, который будет вызван при интерактивной отмене операции.
// 		Результат в обработчик не передается. Все необходимое для идентификации операции необходимо добавить
// 		в ДополнительныеПараметры обработчика оповещения.
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура УстановитьОбработчикПрерывания(Обработчик, КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.УстановитьОбработчикПрерывания(Обработчик, КонтекстОжиданияОперации) 
```
</details>

## УстановитьОбработчикПередИнтерактивнымДействием
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет подписаться на событие перед выполнением интерактивного действия (запрос пароля, открытие формы запроса
// данных и т.д.). Имеет смысл, когда интерфейс, вызывающий асинхронную операцию, использует вместо стандартной формы
// ожидания операции свои механизмы и хочет реагировать на выполнение интерактивных действий в асинхронной операции.
// Используется только в паре с УстановитьОбработчикОбработчикПослеИнтерактивногоДействия.
//
// Параметры:
// 	Обработчик - ОписаниеОповещения - обработчик, который будет вызван перед выполнением интерактивного действия.
// 		Результат в обработчик не передается. Все необходимое для идентификации операции необходимо добавить
// 		в ДополнительныеПараметры обработчика оповещения.
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура УстановитьОбработчикПередИнтерактивнымДействием(Обработчик, КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.УстановитьОбработчикПередИнтерактивнымДействием(Обработчик, КонтекстОжиданияОперации) 
```
</details>

## УстановитьОбработчикОбработчикПослеИнтерактивногоДействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет подписаться на событие после выполнением интерактивного действия (запрос пароля, открытие формы запроса
// данных и т.д.). Имеет смысл, когда интерфейс, вызывающий асинхронную операцию, использует вместо стандартной формы
// ожидания операции свои механизмы и хочет реагировать на выполнение интерактивных действий в асинхронной операции.
// Используется только в паре с УстановитьОбработчикПередИнтерактивнымДействием.
//
// Параметры:
// 	Обработчик - ОписаниеОповещения - обработчик, который будет вызван после выполнением интерактивного действия.
// 		Результат в обработчик не передается. Все необходимое для идентификации операции необходимо добавить
// 		в ДополнительныеПараметры обработчика оповещения.
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура УстановитьОбработчикОбработчикПослеИнтерактивногоДействия(Обработчик, КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.УстановитьОбработчикОбработчикПослеИнтерактивногоДействия(Обработчик, КонтекстОжиданияОперации) 
```
</details>

## ОперацияВыполняется
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, выполняется ли асинхронная операция.
//
// Параметры:
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
// Возвращаемое значение:
// 	Булево - Истина, если операция выполняется.
Функция ОперацияВыполняется(КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
Результат = ОжиданиеОперацийБЭДКлиент.ОперацияВыполняется(КонтекстОжиданияОперации) 
```
</details>

## ОткрытьФормуОжидания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму ожидания операции.
//
// Параметры:
// 	ФормаВладелец - ФормаКлиентскогоПриложения - форма, которая будет владельцем формы ожидания.
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура ОткрытьФормуОжидания(ФормаВладелец, КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ОткрытьФормуОжидания(ФормаВладелец, КонтекстОжиданияОперации) 
```
</details>

## ОбновитьПрогресс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет параметры формы ожидания операции.
// Для использования асинхронной операцией.
//
// Параметры:
// 	ПараметрыОжиданияОперации - см. НовыеПараметры.
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура ОбновитьПрогресс(ПараметрыОжиданияОперации, КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ОбновитьПрогресс(ПараметрыОжиданияОперации, КонтекстОжиданияОперации) 
```
</details>

## НачатьИнтерактивноеДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Оповещает интерфейс ожидания выполнения операции о начале выполнения интерактивных действий в асинхронной операции.
//
// Параметры:
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура НачатьИнтерактивноеДействие(КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.НачатьИнтерактивноеДействие(КонтекстОжиданияОперации) 
```
</details>

## ЗакончитьИнтерактивноеДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Оповещает интерфейс ожидания выполнения операции об окончании выполнения интерактивных действий в асинхронной операции.
//
// Параметры:
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура ЗакончитьИнтерактивноеДействие(КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ЗакончитьИнтерактивноеДействие(КонтекстОжиданияОперации) 
```
</details>

## ЗакрытьФормуОжидания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Закрывает форму ожидания выполнения операции, см. ОткрытьФормуОжидания.
//
// Параметры:
// 	КонтекстОжиданияОперации - см. НовыйКонтекст.
Процедура ЗакрытьФормуОжидания(КонтекстОжиданияОперации) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ЗакрытьФормуОжидания(КонтекстОжиданияОперации) 
```
</details>

## ИнициализироватьПараметрыОбработчикаОжидания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет структуру параметров значениями по умолчанию.
//
// Параметры:
//  ПараметрыОбработчикаОжидания - Структура - заполняется значениями по умолчанию.
//
//
Процедура ИнициализироватьПараметрыОбработчикаОжидания(ПараметрыОбработчикаОжидания) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ИнициализироватьПараметрыОбработчикаОжидания(ПараметрыОбработчикаОжидания) 
```
</details>

## ОбновитьПараметрыОбработчикаОжидания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет структуру параметров новыми расчетными значениями.
//
// Параметры:
//  ПараметрыОбработчикаОжидания - Структура - заполняется расчетными значениями.
//
//
Процедура ОбновитьПараметрыОбработчикаОжидания(ПараметрыОбработчикаОжидания) Экспорт
```

Пример вызова
```bsl
ОжиданиеОперацийБЭДКлиент.ОбновитьПараметрыОбработчикаОжидания(ПараметрыОбработчикаОжидания) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
