---
title: Операции с файлами ЭДКО клиент
slug: zup/операции-с-файлами-эдко-клиент
---


## СоздатьДвоичныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект для работы с файлами. При необходимо компонента будет установлена.
//
// Параметры:
//  ОповещениеОЗавершении  - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Булево - описание ошибки выполнения.
//
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
Процедура СоздатьДвоичныеДанные(ОповещениеОЗавершении, ВыводитьСообщения = Истина) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.СоздатьДвоичныеДанные(ОповещениеОЗавершении, ВыводитьСообщения);
```
</details>

## ФайлВBase64
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует файл в строку Base64.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * СтрокаBase64   - Строка - файл преобразованный в Base64.
//
//  ИмяФайла          - Строка - файл, который необходимо преобразовать в  строку Base64.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные    - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
//  ПроверятьСуществование - Булево - если необходимо, то будет установлено расширение работы с файлами для проверки существования
//
Процедура ФайлВBase64(ОповещениеОЗавершении, ИмяФайла, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено, ПроверятьСуществование = Истина) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ФайлВBase64(ОповещениеОЗавершении, ИмяФайла, ВыводитьСообщения, ДвоичныеДанные, ПроверятьСуществование);
```
</details>

## ФайлВТекст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает файл как текст.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * Текст          - Строка - текст из файла.
//
//  ИмяФайла          - Строка - файл, который необходимо преобразовать в  строку Base64.
//
//  КодировкаТекста   - Строка - указывается кодировка текста в открываемом файле.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные    - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура ФайлВТекст(ОповещениеОЗавершении, ИмяФайла, КодировкаТекста = "utf-8", ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ФайлВТекст(ОповещениеОЗавершении, ИмяФайла, КодировкаТекста, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## Base64ВФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует строку Base64 в файл.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * ИмяФайла       - Строка - имя файла, в который был сохранен результат.
//
//  СтрокаBase64          - Строка - строка Base64, которую необходимо преобразовать в файл.
//
//  ИмяФайлаИлиРасширение - Строка - имя файла, в который необходимо сохранить результат.
//                                   Также можно указать только расширение создаваемого файла - ".расширение".
//
//  ВыводитьСообщения     - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные        - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура Base64ВФайл(ОповещениеОЗавершении, СтрокаBase64, ИмяФайлаИлиРасширение = Неопределено, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.Base64ВФайл(ОповещениеОЗавершении, СтрокаBase64, ИмяФайлаИлиРасширение, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## ТекстВФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет текст в файл.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * ИмяФайла       - Строка - имя файла, в который был сохранен результат.
//
//  Текст                 - Строка - текст, которую необходимо записать в файл.
//
//  ИмяФайлаИлиРасширение - Строка - имя файла, в который необходимо сохранить результат.
//                                   Также можно указать только расширение создаваемого файла - ".расширение".
//
//  ВыводитьСообщения     - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные        - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура ТекстВФайл(ОповещениеОЗавершении, Текст, ИмяФайлаИлиРасширение = Неопределено, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ТекстВФайл(ОповещениеОЗавершении, Текст, ИмяФайлаИлиРасширение, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## КаталогВременныхФайловНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает имя каталога, который используется программой для размещения временных файлов.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * ИмяКаталога    - Строка - имя каталога временных файлов пользователя, от имени которого запущено приложение.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные    - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура КаталогВременныхФайловНаКлиенте(ОповещениеОЗавершении, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.КаталогВременныхФайловНаКлиенте(ОповещениеОЗавершении, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## СоздатьКаталогНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новый каталог в каталоге временных файлов.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * ИмяКаталога    - Строка - полное имя созданного каталога.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные    - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура СоздатьКаталогНаКлиенте(ОповещениеОЗавершении, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.СоздатьКаталогНаКлиенте(ОповещениеОЗавершении, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## УдалитьФайлыНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет указанные файлы.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//
//  Путь              - Строка - путь к удаляемым файлам.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
Процедура УдалитьФайлыНаКлиенте(ОповещениеОЗавершении = Неопределено, Путь, ВыводитьСообщения = Ложь) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.УдалитьФайлыНаКлиенте(ОповещениеОЗавершении, Путь, ВыводитьСообщения);
```
</details>

## ПолучитьИмяВременногоФайлаНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает уникальное имя временного файла.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * ИмяФайла       - Строка - полное имя временного файла.
//
//  Расширение        - Строка - указывает желаемое расширение имени временного файла.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные    - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура ПолучитьИмяВременногоФайлаНаКлиенте(ОповещениеОЗавершении, Расширение = Неопределено, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ПолучитьИмяВременногоФайлаНаКлиенте(ОповещениеОЗавершении, Расширение, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## ПолучитьСвойстваФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает список свойств файла или каталога.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * СвойстваФайла  - Структура - свойства файла.
//        ** Имя              - Строка - имя файла.
//        ** ИмяБезРасширения - Строка - имя файла (без расширения).
//        ** ПолноеИмя        - Строка - полное имя файла (включающее путь к файлу).
//        ** Путь             - Строка - путь к файлу.
//        ** Расширение       - Строка - расширение имени файла.
//        ** Размер           - Число  - размер файла (в байтах).
//        ** Существует       - Булево - определяет, существует ли файл.
//        ** ЭтоКаталог       - Булево - если Истина, то каталог, иначе - файл.
//
//  ИмяФайла - Строка - полное имя файла или каталога.
//
Процедура ПолучитьСвойстваФайла(ОповещениеОЗавершении, ИмяФайла, ВыводитьСообщения = Ложь) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ПолучитьСвойстваФайла(ОповещениеОЗавершении, ИмяФайла, ВыводитьСообщения);
```
</details>

## ДанныеССервераВФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные с сервера из временного хранилища и сохраняет на клиенте.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * ИмяФайла       - Строка - имя файла, в который был сохранен результат.
//
//  Адрес                 - Строка - адрес файла во временном хранилище.
//
//  ИмяФайлаИлиРасширение - Строка - имя файла, в который необходимо сохранить результат.
//                                   Также можно указать только расширение создаваемого файла - ".расширение".
//
//  ВыводитьСообщения     - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  ДвоичныеДанные        - AddIn  - объект используемый для работы с файлами. Если не задан, то будет создан новый.
//
Процедура ДанныеССервераВФайл(ОповещениеОЗавершении, Адрес, ИмяФайлаИлиРасширение = Неопределено, ВыводитьСообщения = Истина, ДвоичныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ДанныеССервераВФайл(ОповещениеОЗавершении, Адрес, ИмяФайлаИлиРасширение, ВыводитьСообщения, ДвоичныеДанные);
```
</details>

## ДанныеССервераВBase64
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные с сервера в виде Base64.
//
// Параметры:
//  Адрес - Строка - адрес файла во временном хранилище.
//
//  Возвращаемое значение:
//    Строка - файл преобразованный в Base64.
//
Функция ДанныеССервераВBase64(Адрес) Экспорт
```

Пример вызова
```bsl
Результат = ОперацииСФайламиЭДКОКлиент.ДанныеССервераВBase64(Адрес) 
```
</details>

## ОткрытьФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает файл с использованием ассоциированного с ним приложения.
//
// Параметры:
//  ПолноеИмяФайлаИлиАдрес - Строка - полное имя файла, который необходимо открыть.
//                                  - адрес файла на сервере во временном хранилище.
//
//  ИмяФайла               - Строка - указывается имя, с которым необходимо сохранить файл, полученный с сервера.
//
//  ВыводитьСообщения      - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
Процедура ОткрытьФайл(ПолноеИмяФайлаИлиАдрес, ИмяФайла = "", ВыводитьСообщения = Истина) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ОткрытьФайл(ПолноеИмяФайлаИлиАдрес, ИмяФайла, ВыводитьСообщения);
```
</details>

## СохранитьФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет файлы в файловую систему.
//
// Параметры:
//  СохраняемыеФайлы - Массив - описания сохраняемых файлов. Массив структур.
//    * Имя   - Строка - имя сохраняемого файла
//    * Адрес - Строка - адрес с данными в памяти, подлежащие сохранению в файл
//                   - Сруктура - описания сохраняемого файла.
//    * Имя   - Строка - имя сохраняемого файла
//    * Адрес - Строка - адрес с данными в памяти, подлежащие сохранению в файл
//                   - Массив - описания сохраняемых файлов. Массив описаний передаваемых файлов.
//                   - ОписаниеПередаваемогоФайла - описания сохраняемого файла.
//
//  КаталогСохранения - Строка - каталог сохранения файлов.
//    Если не указан, то будет отображен диалог выбора каталога.
//    Если в СохраняемыеФайлы передан массив описаний, то данный параметр игнорируется.
//
//  ВыводитьСообщения - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
Процедура СохранитьФайлы(СохраняемыеФайлы, КаталогСохранения = Неопределено, ВыводитьСообщения = Истина) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.СохранитьФайлы(СохраняемыеФайлы, КаталогСохранения, ВыводитьСообщения);
```
</details>

## ЗапуститьПриложениеНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запуск внешнего приложения либо открытие файла с использованием ассоциированного с ним приложения.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения, Неопределено - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ДвоичныеДанные - AddIn  - объект используемый для работы с файлами. Работать напрямую с объектом запрещено.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//      * КодВозврата    - Число        - код возврата.
//                       - Неопределено - ДождатьсяЗавершения не указан.
//
//  СтрокаКоманды              - Строка - командная строка для запуска приложения либо имя файла, ассоциированного
//                                        с некоторым приложением.
//
//  ДождатьсяЗавершения        - Булево - определяет нужно ли дожидаться завершения запущенного приложения перед
//                                        продолжением работы.
//
//  ВыводитьСообщения          - Булево - устанавливает признак необходимости выводить сообщения об ошибках.
//
//  СсылкаДляПереходаПриОшибке - Строка - ссылка, по которой перейти в случае ошибки
//
Процедура ЗапуститьПриложениеНаКлиенте( Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ЗапуститьПриложениеНаКлиенте();
```
</details>

## СкачатьФайлНаСервереВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает файл из Интернета по протоколу HTTP(s) и сохраняет его во временном хранилище на сервере.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * АдресФайла     - Строка - адрес файла во временном хранилище.
//      * ИмяФайла       - Строка - имя файла, полученное из URL.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//
//  URL                   - Строка - url файла в формате [Протокол://]<Сервер>/<Путь к файлу на сервере>.
//  Параметры             - Структуруа - дополнительные параметры для "тонкой" настройки.
//    * ПоясняющийТекст - Строка - текст, который будет показываться в форме индикатора загрузки.
//    * ВладелецФормы   - ФормаКлиентскогоПриложения - форма, которая будет указана в качестве владельца в форме индикатора.
//
Процедура СкачатьФайлНаСервереВФоне(ОповещениеОЗавершении, Знач URL, Знач Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.СкачатьФайлНаСервереВФоне(ОповещениеОЗавершении, URL, Параметры);
```
</details>

## ДобавитьФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает выбранные пользователем файлы во временное хранилище.
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена и получен результат, иначе см. ОписаниеОшибки.
//      * ОписанияФайлов - Массив - описания файлов во временном хранилище.
//          ** Имя   - Строка - имя файла.
//          ** Адрес - Строка - адрес файла во временном хранилище.
//          ** Размер - Число - размер файла в байтах. Возвращается если задан параметр Параметры.ВозвращатьРазмер.
//      * ОписаниеОшибки - Строка - описание ошибки выполнения.
//
//  ИдентификаторФормы - УникальныйИдентификатор - уникальный идентификатор формы.
//                       Файлы помещаются во временное хранилище и автоматически удаляется после удаления объекта формы.
//  Заголовок          - Строка - текст заголовка окна диалога выбора файлов.
//  Параметры - Структура - дополнительные настройки.
//    * Фильтр - Строка - набор файловых фильтров. См. ДиалогВыбораФайла.Фильтр.
//    * МаксимальныйРазмерФайла - Число - максимальный размер файла в байтах, который можно добавить. 0 - значение неограничено.
//    * ВозвращатьРазмер - Булево - если Истина, то дополниетельно будет получен размер по каждому файлу.
//    * ДопустимыеТипыФайлов - Строка - допустимые типы файлов. Пример: "jpeg;jpg".
//    * МножественныйВыбор - Булево - Если Истина, то при наличии расширения работы с файлами можно выбрать несколько файлов. По умолчанию Истина.
//    * Требования - Структура - см ТребованияКСканам(). Если указаны, то будет выполнено преобразование файлов к этим требованиям.
//
//  ВозможноПродолжениеБезУстановкиРасширения - Булево - возможно ли продолжить без установки расширения работы с файлами.
//
Процедура ДобавитьФайлы(ОповещениеОЗавершении, ИдентификаторФормы = Неопределено, Заголовок = "", Параметры = Неопределено, ВозможноПродолжениеБезУстановкиРасширения = Истина) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ДобавитьФайлы(ОповещениеОЗавершении, ИдентификаторФормы, Заголовок, Параметры, ВозможноПродолжениеБезУстановкиРасширения);
```
</details>

## ДобавитьФайлыСПредпросмотром
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет сканы через форму предпросмотра
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат - Структура:
//      * Выполнено      - Булево - если Истина, то процедура успешно выполнена.
//      * Файлы - Массив - описания файлов во временном хранилище.
//          ** ИсходноеИмя   - Строка - имя файла.
//          ** Адрес         - Строка - адрес файла во временном хранилище.
//          ** Размер        - Число - размер файла в байтах.
//
//  ИдентификаторФормы - УникальныйИдентификатор - уникальный идентификатор формы.
//                       Файлы помещаются во временное хранилище и автоматически удаляется после удаления объекта формы.
//  Заголовок          - Строка - текст заголовка окна диалога выбора файлов.
//  Параметры          - Структура - см метод ПараметрыМетодаДобавитьФайлыСПредпросмотром
//
Процедура ДобавитьФайлыСПредпросмотром(ОповещениеОЗавершении, ИдентификаторФормы, Заголовок, Параметры) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ДобавитьФайлыСПредпросмотром(ОповещениеОЗавершении, ИдентификаторФормы, Заголовок, Параметры) 
```
</details>

## ПараметрыМетодаДобавитьФайлыСПредпросмотром
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыМетодаДобавитьФайлыСПредпросмотром() Экспорт
```

Пример вызова
```bsl
Результат = ОперацииСФайламиЭДКОКлиент.ПараметрыМетодаДобавитьФайлыСПредпросмотром() 
```
</details>

## ТекстСообщенияДляНеобязательнойУстановкиРасширенияРаботыСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстСообщенияДляНеобязательнойУстановкиРасширенияРаботыСФайлами() Экспорт
```

Пример вызова
```bsl
Результат = ОперацииСФайламиЭДКОКлиент.ТекстСообщенияДляНеобязательнойУстановкиРасширенияРаботыСФайлами() 
```
</details>

## ОбработатьКартинки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает изображения в соотвествии с указанными параметрами.
// Файлы, которые не являются изображениями будут возвращены без преобразования.
// Файлы, на преобразовании которых возникла ошибка, не добавляются в Результат.ОписанияФайлов
//
// Параметры:
//  ОповещениеОЗавершении	 - ОписаниеОповещения - описание процедуры, принимающей результат. -
//    Результат - Массив структур - Если массив пустой, значит не удалось обработать ни один файл.
//      * Выполнено      - Булево - если Истина, означает, что возвращено хотя бы один элемент в ОписанияФайлов.
//      * Отменено       - Булево - если Истина, означает загрузка файлов была полностью отменена.
//      * ОписанияФайлов - Массив - описания файлов во временном хранилище.
//          ** Имя   - Строка - имя файла (после обработки может измениться расширение).
//          ** Адрес - Строка - адрес файла во временном хранилище.
//          ** Идентификатор - Произвольный - Произвольное сериализуемое значение для дополнительной идентификации/принадлежности файла при необходимости.
//  * ОписанияФайлов - Массив - описания файлов во временном хранилище.
//     ** Имя   - Строка - имя файла.
//     ** Адрес - Строка - адрес файла во временном хранилище.
//     ** Размер - Число - размер в байтах.
//     ** Идентификатор - Произвольный - Значение сохраняется из входящего параметра.
//     ** Размер - Число - Размер в байта.
//  Требования - Структура - дополнительные настройки, см ТребованияКСканам(). Все эти требования можно посмотреть в свойствах картинки Windows.
//    Обязательные:
//    * ДопустимыеТипыФайлов - Строка - допустимые типы файлов. Пример: "jpeg;jpg".
//                           - Массив - Массив форматов (ФорматКартинки) или строк (расширений) или смешанный (форматов и расширений)
//    * РасширениеПоУмолчанию - Строка - расширение без точки, которое будет указано для картинки неподходящего формата.
//    Необязательные:
//    * ГлубинаЦвета - ГлубинаЦвета, Неопределено - Строка из перечисления Системные перечисления/Интерфейсные/ГлубинаЦвета.
//        Нужна именно срока, так как перечисление ГлубинаЦвета не сериализируется.
//        Если указано, что "Количество бит на компонент = 8" и "Компоненты цвета = 3", то это означает глубинау цвета БитНаПиксел24 (8*3)
//    * ПреобразоватьВОттенкиСерого - Булево - Истина, если надо преобразовать в оттенки серого.
//        ПреобразоватьВОттенкиСерого будет работать только для PNG и TIFF (См СП для ПреобразоватьВОттенкиСерого)
//        Если указано "Цветность: 256 оттенков серого", то нужно ГлубинаЦвета - БитНаПиксел8 и ПреобразоватьВОттенкиСерого = Истина,
//        так как при 8-би́тном цвете максимальное количество цветов, которые могут быть отображены одновременно - 256 (2^8)
//    * МинимальнаяПлотность - Число (число точек на дюйм (DPI)) - минимально допустимая плотность (разрешение) изображения. 0 - значение неограничено.
//    * МаксимальнаяПлотность - Число (число точек на дюйм (DPI)) - максимально допустимая плотность (разрешение) изображения. 0 - значение неограничено.
//    * МаксимальныйРазмерФайла - Число - максимальный размер файла в байтах, который можно добавить. 0 - значение неограничено.
//    * Пояснение - Строка - Любой текст, который нужно вывести в форме требования к сканам
//
Процедура ОбработатьКартинки(ОповещениеОЗавершении, ОписанияФайлов, Требования, ИдентификаторВладельца) Экспорт
```

Пример вызова
```bsl
ОперацииСФайламиЭДКОКлиент.ОбработатьКартинки(ОповещениеОЗавершении, ОписанияФайлов, Требования, ИдентификаторВладельца) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
