---
title: Отражение зарплаты в бухучете
slug: zup/отражение-зарплаты-в-бухучете
---


## ПроцентЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает процент деятельности ЕНВД зарегистрированный в подсистеме ЗарплатаКадры.
//
// Параметры:
//  Организация	 - Тип СправочникСсылка.Организации
//  ПериодРегистрации	   - Тип Дата, первое число месяца, месяц по которому надо получить процент ЕНВД.
//
// Возвращаемое значение:
//  Число от 0 до 100, или Неопределено, если в Организации применяется ЕНВД, но процент на месяц еще не задан.
//
Функция ПроцентЕНВД(Организация, ПериодРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ПроцентЕНВД(Организация, ПериодРегистрации) 
```
</details>

## ПлательщикЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает настройку учетной политики, является ли организация в указанном месяце плательщиком ЕНВД.
//
// Параметры:
//  Организация	 - Тип СправочникСсылка.Организации
//  Период	   	 - Тип Дата, месяц по которому надо получить применение ЕНВД в организации.
//
// Возвращаемое значение:
//  Булево
//
Функция ПлательщикЕНВД(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ПлательщикЕНВД(Организация, Период) 
```
</details>

## ОтражениеВРегламентированномУчетеНастройкиОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает настройку отражения в бухучете из РС ОтражениеВРегламентированномУчетеНастройкиОрганизаций.
//
// Возвращаемое значение:
//	Структура
//	* ФормироватьПроводкиВКонцеПериода - тип Булево, Истина, если хотя бы в одной организации проводки формируются в
//	                                     конце месяца.
//  * ФормироватьПроводкиВКонцеПериодаПоОрганизациям - соответствие, ключ - Организация, значение - значение настройки
//                                                     ФормироватьПроводкиВКонцеПериода.
//
Функция ОтражениеВРегламентированномУчетеНастройкиОрганизаций() Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ОтражениеВРегламентированномУчетеНастройкиОрганизаций() 
```
</details>

## ПараметрыДляРасчетаОценочныхОбязательствОтпусков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с параметрами для расчета оценочных обязательств по отпускам.
//
// Параметры:
//  Организация - организация
//  ПериодРегистрации - Тип Дата, дата на которую получаем данные.
//	Сотрудники - Тип Массив, необязательный.
//				Если параметр не передан, данные будут получены по всем сотрудникам организации.
//
// Возвращаемое значение: Структура, описание см ОтражениеЗарплатыВБухучете.ОписаниеПараметровДляРасчетаОценочныхОбязательствОтпусков.
//
Функция ПараметрыДляРасчетаОценочныхОбязательствОтпусков(Организация, ПериодРегистрации, Сотрудники = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ПараметрыДляРасчетаОценочныхОбязательствОтпусков(Организация, ПериодРегистрации, Сотрудники);
```
</details>

## ФондОплатыТрудаПоОрганизациямДляРасчетаОценочныхОбязательствОтпусков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с фондом оплаты труда по организациям.
//
// Параметры:
//  Организации - массив организаций, головная организация и ее филиалы.
//  ПериодРегистрации - Тип Дата, дата на которую получаем данные.
//
// Возвращаемое значение: Таблица значений
//		* Организация
//		* ФондОплатыТруда - сумма начислений, входящих в расчет отпуска.
//		* СтраховыеВзносы - сумма взносов, приходящихся на начисления, входящие в расчет отпуска.
//
Функция ФондОплатыТрудаПоОрганизациямДляРасчетаОценочныхОбязательствОтпусков(Организации, ПериодРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ФондОплатыТрудаПоОрганизациямДляРасчетаОценочныхОбязательствОтпусков(Организации, ПериодРегистрации) 
```
</details>

## ПараметрыДляИнвентаризацииОценочныхОбязательствОтпусков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает эффективную ставку страховых взносов по сотрудникам.
//
// Параметры:
//  	Организация - Тип СправочникСсылка.Организации, организация для которой получаем данные
//  	ПериодРегистрации - Тип Дата, дата на которую получаем данные.
//		Сотрудники - массив сотрудников, по которым надо получить ставки, необязательный.
//
//	Возвращаемое значение:
//			Структура со свойствами
//				* СтавкиВзносовФСС_НС - таблица значений с колонками: Сотрудник, Ставка
//				* СтавкиСтраховыхВзносов - таблица значений с колонками: Сотрудник, Ставка.
//
Функция ПараметрыДляИнвентаризацииОценочныхОбязательствОтпусков(Организация, ПериодРегистрации, Сотрудники = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ПараметрыДляИнвентаризацииОценочныхОбязательствОтпусков(Организация, ПериодРегистрации, Сотрудники);
```
</details>

## ДанныеДляОтраженияЗарплатыВБухучете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует данные для отражения в бухучете результатов расчета зарплаты.
//
// Параметры:
//  	Организация 		- Тип СправочникСсылка.Организации, организация для которой получаем данные
//  	ПериодРегистрации 	- Тип Дата, дата соответствует месяцу, за которые получаются данные.
//
//	Возвращаемое значение:
//			Структура - см. НоваяСтруктураДанныеДляОтраженияЗарплатыВБухучете()
//				* НачисленнаяЗарплатаИВзносы - ТаблицаЗначений - см. НоваяТаблицаБухучетНачисленнаяЗарплатаИВзносы()
//					* ФизическоеЛицо
//					* Сотрудник
//					* Подразделение
//					* ПодразделениеУчетаЗатрат
//					* ДатаНачала
//					* ВидОперации
//					* Начисление
//					* СпособОтраженияЗарплатыВБухучете
//					* СтатьяФинансирования
//					* СтатьяРасходов
//					* ОблагаетсяЕНВД
//					* ВидНачисленияОплатыТрудаДляНУ
//					* ПериодПринятияРасходов
//					* Сумма
//					* Колонки взносов, состав определяется в ОтражениеЗарплатыВУчете.КолонкиВзносов()
//				* НачисленныйНДФЛ - ТаблицаЗначений - см. НоваяТаблицаБухучетНачисленныйНДФЛ()
//					* ФизическоеЛицо
//					* Сотрудник
//					* ВидОперации
//					* СтатьяФинансирования
//					* СтатьяРасходов
//					* КодПоОКАТО
//					* КодПоОКТМО
//					* КПП
//					* КодНалоговогоОргана
//					* РегистрацияВНалоговомОргане
//					* Сумма
//				* УдержаннаяЗарплата - ТаблицаЗначений - см. НоваяТаблицаБухучетУдержаннаяЗарплата()
//					* ФизическоеЛицо
//					* Сотрудник
//					* Подразделение
//					* ПодразделениеУчетаЗатрат
//					* ДатаНачала
//					* ВидОперации
//					* СтатьяФинансирования
//					* СтатьяРасходов
//					* Контрагент
//					* Сумма
//					* ЯвляетсяОснованиемОформленияКассовогоЧека
//					* ОписаниеУдержанияДляЧека
//					* ДокументОснование
//
Функция ДанныеДляОтраженияЗарплатыВБухучете(Организация, ПериодРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучете.ДанныеДляОтраженияЗарплатыВБухучете(Организация, ПериодРегистрации) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
