---
title: Отражение зарплаты в бухучете переопределяемый
slug: zup/отражение-зарплаты-в-бухучете-переопределяемый
---


## ПроцентЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция предназначена для вычисления процента ЕНВД в текущем месяце по данным бухгалтерского учета.
//
//
//	Параметры:
//	 Организация - СправочникСсылка.Организации,
//	 ПериодРегистрации - Дата, состав дата.
//
//	Возвращаемое значение:
//		Число или Неопределено
//
Функция ПроцентЕНВД(Организация, ПериодРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = ОтражениеЗарплатыВБухучетеПереопределяемый.ПроцентЕНВД(Организация, ПериодРегистрации) 
```
</details>

## СформироватьДвижения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура предназначена для формирования движений по бухучету.
//
// Параметры:
//	Движения - Коллекция движений документа,
//	Отказ - булево, признак отказа от проведения документа.
//	Организация - СправочникСсылка.Организации.
//	МесяцНачисления - тип Дата, месяц, зарплата которого отражается в бухучете.
//	ДанныеДляОтражения - структура. Таблицы значений с данными, которые
//						могут использоваться для формирования движений по бухучету.
//						При вызове процедуры ДанныеДляОтражения может содержать
//						одно или несколько полей с приведенными ниже именами, т.е.
//						Необходимо проверять наличие того или иного элемента структуры.
//
//		Имена полей структуры ДанныеДляОтражения (таблиц значений):
//			НачисленнаяЗарплатаИВзносы
//			НачисленныйНДФЛ
//			УдержаннаяЗарплата
//			ОценочныеОбязательства - эта таблица формируется документом НачислениеОценочныхОбязательствПоОтпускам
//			Депоненты - эта таблица формируется документом Депонирование.
//
//		Структура таблиц значений:
//			НачисленнаяЗарплатаИВзносы.
//				ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//				Подразделение  - СправочникСсылка.ПодразделенияОрганизаций
//				ВидОперации    - ПеречислениеСсылка.ВидыОперацийПоЗарплате
//				СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//				СпособОтраженияЗарплатыВБухучете- СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете
//				ОблагаетсяЕНВД - булево
//				ПериодПринятияРасходов - Дата, для учета РБП, определяет месяц, к которому относятся расходы. Передается дата
//				                         начала месяца.
//				ВидНачисленияОплатыТрудаДляНУ - ПеречислениеСсылка.ВидыНачисленийОплатыТрудаДляНУ
//				Сумма - Число 15.2
//				ПФРПоСуммарномуТарифу - Число 15.2
//				ПФРСПревышения - Число 15.2
//				ПФРСтраховая - Число 15.2
//				ПФРНакопительная - Число 15.2
//				ФСС - Число 15.2
//				ФФОМС - Число 15.2
//				ТФОМС - Число 15.2
//				ПФРНаДоплатуЛетчикам - Число 15.2
//				ПФРНаДоплатуШахтерам - Число 15.2
//				ПФРЗаЗанятыхНаПодземныхИВредныхРаботах - Число 15.2
//				ПФРЗаЗанятыхНаТяжелыхИПрочихРаботах - Число 15.2
//				ФССНесчастныеСлучаи - Число 15.2.
//				ПФРДоПредельнойВеличины - Число 15.2.
//				ПФРЗаЗанятыхНаПодземныхИВредныхРаботахБезСпецОценки - Число 15.2.
//				ПФРЗаЗанятыхНаПодземныхИВредныхРаботахСпецОценка - Число 15.2.
//				ПФРЗаЗанятыхНаТяжелыхИПрочихРаботахБезСпецОценки - Число 15.2.
//				ПФРЗаЗанятыхНаТяжелыхИПрочихРаботахСпецОценка - Число 15.2.
//				ВзносыПоЕдиномуТарифу - Число 15.2.
//
//			НачисленныйНДФЛ
//				ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//				ВидОперации    - ПеречислениеСсылка.ВидыОперацийПоЗарплате
//				СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//				КодПоОКАТО     - Строка, 11
//				КодПоОКТМО     - Строка, 11
//				КПП   - Строка, 9
//				КодНалоговогоОргана - Строка, 4
//				Сумма - Число 15.2
//				РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацияВНалоговомОргане
//												поле может быть не заполнено, тогда регистрацию надо вычислять по КодПоОКАТО,КодПоОКТМО,КПП,КодНалоговогоОргана.
//
//			УдержаннаяЗарплата
//				ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//				Подразделение  - СправочникСсылка.ПодразделенияОрганизаций
//				ВидОперации    - ПеречислениеСсылка.ВидыОперацийПоЗарплате
//				СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//				Контрагент     - СправочникСсылка.Контрагенты, контрагент, в пользу которого произведено удержание.
//				Сумма     - Число 15.2.
//				ОписаниеУдержанияДляЧека - Строка.
//				ЯвляетсяОснованиемОформленияКассовогоЧека - Булево.
//				ДокументОснование - ОпределяемыйТип.ОснованиеУдержания
//
//			ОценочныеОбязательства
//				Подразделение  - СправочникСсылка.ПодразделенияОрганизаций
//				СпособОтраженияЗарплатыВБухучете- СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете
//				СуммаРезерва - Число 15.2
//				СуммаРезерваСтраховыхВзносов - Число 15.2
//				СуммаРезерваНУ - Число 15.2
//				СуммаРезерваСтраховыхВзносовНУ - Число 15.2
//				СуммаРезерваФССНесчастныеСлучаи - Число 15.2
//				СуммаРезерваФССНесчастныеСлучаиНУ - Число 15.2.
//
Процедура СформироватьДвижения(Движения, Отказ, Организация, МесяцНачисления, ДанныеДляОтражения) Экспорт
```

Пример вызова
```bsl
ОтражениеЗарплатыВБухучетеПереопределяемый.СформироватьДвижения(Движения, Отказ, Организация, МесяцНачисления, ДанныеДляОтражения) 
```
</details>

## ТребуетсяУтверждениеДокументаБухгалтером
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подтверждение требуется, если используется обмен в формате ED.
// Уточняется значение ТребуетсяУтверждение.
//
Процедура ТребуетсяУтверждениеДокументаБухгалтером(Организация, ТребуетсяУтверждение) Экспорт
```

Пример вызова
```bsl
ОтражениеЗарплатыВБухучетеПереопределяемый.ТребуетсяУтверждениеДокументаБухгалтером(Организация, ТребуетсяУтверждение) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
