---
title: Перерасчет зарплаты
slug: zup/перерасчет-зарплаты
---


## ТребуетсяПерерасчетПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, требуется ли произвести перерасчет зарплаты по сотрудникам организации
// за указанный месяц.
//
// Параметры:
//		Организация	- СправочникСсылка.Организации
//		Месяц		- Дата
//		Сотрудники	- СправочникСсылка.Сотрудники или массив ссылок.
//
// Возвращаемое значение:
//		Число - Количество сотрудников, для которых требуется выполнить доначисление (перерасчет).
//
Функция ТребуетсяПерерасчетПериода(Организация, Месяц, Сотрудники = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПерерасчетЗарплаты.ТребуетсяПерерасчетПериода(Организация, Месяц, Сотрудники);
```
</details>

## СотрудникиКПерерасчету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив сотрудников по которым необходимо выполнить доначисления (перерасчет)
// в указанной организации и за указанный месяц.
//
// Параметры:
//		Организация	- СправочникСсылка.Организации
//		Месяц		- Дата
//		Сотрудники	- СправочникСсылка.Сотрудники или массив ссылок.
//
// Возвращаемое значение:
//		Массив
//
Функция СотрудникиКПерерасчету(Организация, Месяц, Сотрудники = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПерерасчетЗарплаты.СотрудникиКПерерасчету(Организация, Месяц, Сотрудники);
```
</details>

## УстановитьОтображениеСообщенияОНеобходимостиПерерасчетаВФормеДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает отображение надписи о необходимости произвести перерасчет
// зарплаты в форме документа начисление зарплаты.
//
// Параметры:
//		Форма			- ФормаКлиентскогоПриложения
//
Процедура УстановитьОтображениеСообщенияОНеобходимостиПерерасчетаВФормеДокумента(Форма, Документ) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.УстановитьОтображениеСообщенияОНеобходимостиПерерасчетаВФормеДокумента(Форма, Документ) 
```
</details>

## УстановитьОтображениеСообщенияОНеобходимостиПерерасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает отображение надписи о необходимости произвести перерасчет
// зарплаты в указанном месяце.
//
// Параметры:
//		Форма			- ФормаКлиентскогоПриложения
//		Организация		- СправочникСсылка.Организации
//		Месяц			- Дата
//		СкрытьСообщение - Булево
//
Процедура УстановитьОтображениеСообщенияОНеобходимостиПерерасчета(Форма, Организация, Месяц, СкрытьСообщение = Ложь, СписокСотрудников = Неопределено, Документ = Неопределено) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.УстановитьОтображениеСообщенияОНеобходимостиПерерасчета(Форма, Организация, Месяц, СкрытьСообщение, СписокСотрудников, Документ);
```
</details>

## ЗаполнитьПерерассчитываемыеУдержания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура предназначена для добавления строк перерасчета удержаний сотрудникам.
// Выполняется при выявлении удержаний.
//
// Параметры
//	- МенеджерВременныхТаблиц, содержащий ВТСотрудникиПериоды с полями Сотрудник, Организация, ДатаНачала, ДатаОкончания.
//	- Удержания - таблица значений с полями
//	* ФизическоеЛицо
//	* Организация
//	* Удержание
//	* ДатаНачала
//	* ДатаОкончания
//	- ДополнительныеСвойства - Структура, дополнительные свойства менеджера расчета.
//
Процедура ЗаполнитьПерерассчитываемыеУдержания(МенеджерВременныхТаблиц, Удержания, ДополнительныеСвойства) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ЗаполнитьПерерассчитываемыеУдержания(МенеджерВременныхТаблиц, Удержания, ДополнительныеСвойства) 
```
</details>

## ДополнитьТаблицуФизическихЛицДаннымиПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура предназначена для добавления физических лиц к выявлению удержаний.
//
// Параметры
//	- ТаблицаФизическихЛиц, Таблица значений, см. МенеджерРасчетаЗарплаты.ТаблицаФизическихЛиц
//	- МенеджерРасчета - Обработка.МенеджерРасчетаЗарплаты.
Процедура ДополнитьТаблицуФизическихЛицДаннымиПерерасчетов(ТаблицаФизическихЛиц, МенеджерРасчета) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ДополнитьТаблицуФизическихЛицДаннымиПерерасчетов(ТаблицаФизическихЛиц, МенеджерРасчета) 
```
</details>

## ДоплнитьПредельныеСуммыПерерассчитываемымиУдержаниями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура добавляет предельные суммы по перерассчитываемым удержаниям.
//
// Параметры
//	- ПредельныеСуммыУдержаний - таблица значений с полями предельных сумм удержаний.
//	- МенеджерРасчетаЗарплаты - ОбработкаОбъект.МенеджерРасчетаЗарплаты
//
Процедура ДоплнитьПредельныеСуммыПерерассчитываемымиУдержаниями(ПредельныеСуммыУдержаний, МенеджерРасчетаЗарплаты) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ДоплнитьПредельныеСуммыПерерассчитываемымиУдержаниями(ПредельныеСуммыУдержаний, МенеджерРасчетаЗарплаты) 
```
</details>

## ЗаполнитьРезультатыФиксСторноУдержаний
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет суммы перерассчитываемых удержаний, которых совсем не осталось в составе плановых.
//
// Параметры
//		МенеджерВременныхТаблиц - МенеджерВременныхТаблиц, содержащий ВТСотрудникиПериоды с полями Сотрудник, Организация, ДатаНачала, ДатаОкончания.
//		ОчередностьРасчета	- очередность расчета удержаний, рассчитываемых в данный момент.
//		СтрокиПоИдентификатору	- Соответствие, где Ключ - идентификатор строки, значение строка удержаний.
//
Процедура ЗаполнитьРезультатыФиксСторноУдержаний(МенеджерВременныхТаблиц, ОчередностьРасчета, СтрокиПоИдентификатору) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ЗаполнитьРезультатыФиксСторноУдержаний(МенеджерВременныхТаблиц, ОчередностьРасчета, СтрокиПоИдентификатору) 
```
</details>

## РегистрацияПерерасчетовПоПредварительнымДанным
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует перерасчеты по предварительным данным в регистре ПредварительныеПерерасчеты
//
Процедура РегистрацияПерерасчетовПоПредварительнымДанным(Регистратор = Неопределено, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.РегистрацияПерерасчетовПоПредварительнымДанным(Регистратор, Организация);
```
</details>

## СформироватьДвиженияИсходныеДанныхПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистрам подсистемы.
// Параметры:
//		Движения - коллекция движений регистратора.
//		Организация
//		ПериодРегистрации
//		Начисления - таблица значений с колонками табличных частей начислений документов
//
Процедура СформироватьДвиженияИсходныеДанныхПерерасчетов(Движения, Организация, ПериодРегистрации, Начисления) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.СформироватьДвиженияИсходныеДанныхПерерасчетов(Движения, Организация, ПериодРегистрации, Начисления) 
```
</details>

## РегистрацияПерерасчетовПоПредварительнымДаннымВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует перерасчеты по предварительным данным в регистре ПредварительныеПерерасчеты в фоне.
//
Процедура РегистрацияПерерасчетовПоПредварительнымДаннымВФоне(Регистратор = Неопределено, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.РегистрацияПерерасчетовПоПредварительнымДаннымВФоне(Регистратор, Организация);
```
</details>

## УдалитьПерерасчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет сведения о необходимости произвести перерасчет, по окончании проведения документа
// начисление зарплаты.
//
// Параметры:
//		Регистратор							- ДокументСсылка.НачислениеЗарплаты
//		УдалитьПерерасчетыТекущегоПериода	- Булево, Истина если было произведено перезаполнение
//												формы документа и перерасчеты текущего месяца начисления
//												учтены в таблице начислений
//		ПериодыРасчетаСотрудников			- ТаблицаЗначений, с перерасчетами сотрудников проведенных до перепроведения документа,
//													если в ходе работы с документами были удалены записи перерасчетов, информация
//													о необходимости проведения перерасчетов будет восстановлена
//												* Организация
//												* Сотрудник
//												* ПериодДействия
//
Процедура УдалитьПерерасчеты(Регистратор, УдалитьПерерасчетыТекущегоПериода) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.УдалитьПерерасчеты(Регистратор, УдалитьПерерасчетыТекущегоПериода) 
```
</details>

## УдалитьПерерасчетыПоРегистратору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет сведения о необходимости произвести перерасчет по конкретному документу, по окончании проведения документа
// рассчитывающего начисления не являющемся документом "Начисление зарплаты".
//
// Параметры:
//		Регистратор		- ДокументСсылка
//		Сотрудники		- Массив, ссылки на сотрудников, по которым нужно удалить сведения
//		ФизическиеЛица	- Массив, ссылки на физических лиц, по которым нужно удалить сведения об удержаниях.
//
Процедура УдалитьПерерасчетыПоРегистратору(Регистратор, Сотрудники = Неопределено, ФизическиеЛица = Неопределено) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.УдалитьПерерасчетыПоРегистратору(Регистратор, Сотрудники, ФизическиеЛица);
```
</details>

## УдалитьПерерасчетыПоДополнительнымПараметрам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет сведения о необходимости произвести перерасчет по конкретному документу, в зависимости от значений
// параметров, переданных в ДополнительныеПараметры.
//
// Параметры:
//		Регистратор				- ДокументСсылка
//		ДополнительныеПараметры	- Структура с ключами
//									* УдалитьПерерасчетыЗарплаты		- Булево
//									* СотрудникиПерерасчетаЗаработка	- Массив
//
Процедура УдалитьПерерасчетыПоДополнительнымПараметрам(Регистратор, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.УдалитьПерерасчетыПоДополнительнымПараметрам(Регистратор, ДополнительныеПараметры) 
```
</details>

## ВосстановитьПерерасчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Восстанавливает записи о необходимости проведения перерасчета, при отмене проведения
// документа начисления зарплаты, с заполненной табличной частью начисления перерасчеты.
//
// Параметры:
//		Регистратор	- ДокументСсылка.НачислениеЗарплаты
//		Организация	- СотрудникСсылка.Организации
//
Процедура ВосстановитьПерерасчеты(Регистратор, Организация) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ВосстановитьПерерасчеты(Регистратор, Организация) 
```
</details>

## РегистрыИсточникиПредварительныхПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список регистров, являющихся источниками возможных перерасчетов
//
// Возвращаемое значение:
//		Соответствие
//
Функция РегистрыИсточникиПредварительныхПерерасчетов() Экспорт
```

Пример вызова
```bsl
Результат = ПерерасчетЗарплаты.РегистрыИсточникиПредварительныхПерерасчетов() 
```
</details>

## ИнициализироватьНаборыИсточникиПредварительныхПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет необходимость формирования предварительных перерасчетов для регистров, инициирующих перерасчеты,
//	т.к. анализ будет происходить при проведении документа
//
// Параметры:
//		ДокументОбъект	- ДокументОбъект
//		РежимЗаписи		- РежимЗаписиДокумента
//
Процедура ИнициализироватьНаборыИсточникиПредварительныхПерерасчетов(ДокументОбъект, РежимЗаписи) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ИнициализироватьНаборыИсточникиПредварительныхПерерасчетов(ДокументОбъект, РежимЗаписи) 
```
</details>

## ЗарегистрироватьПредварительныеПерерасчетыПриПроведенииДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует предварительные перерасчеты при проведении документа
//
// Параметры:
//		ДокументОбъект	- ДокументОбъект
//
Процедура ЗарегистрироватьПредварительныеПерерасчетыПриПроведенииДокумента(ДокументОбъект) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ЗарегистрироватьПредварительныеПерерасчетыПриПроведенииДокумента(ДокументОбъект) 
```
</details>

## ЗарегистрироватьПредварительныеПерерасчетыПриЗаписиНабора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует предварительные перерасчеты при записи набора
//
// Параметры:
//		НаборЗаписей	- НаборЗаписей
//
Процедура ЗарегистрироватьПредварительныеПерерасчетыПриЗаписиНабора(НаборЗаписей) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ЗарегистрироватьПредварительныеПерерасчетыПриЗаписиНабора(НаборЗаписей) 
```
</details>

## ЗарегистрироватьПредварительныеПерерасчетыПриИзмененииОбщихГрафиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует предварительные перерасчеты при изменении данных общего графика
//
// Параметры:
//		СотрудникиПериоды	- ТаблицаЗначений, колонки:
//			* Сотрудник - СправочникСсылка.Сотрудники
//			* Месяц - Дата
//		ГрафикРаботы	- СправочникСсылка.ГрафикиРаботыСотрудников
//
Процедура ЗарегистрироватьПредварительныеПерерасчетыПриИзмененииОбщихГрафиков(СотрудникиПериоды, ГрафикРаботы) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ЗарегистрироватьПредварительныеПерерасчетыПриИзмененииОбщихГрафиков(СотрудникиПериоды, ГрафикРаботы) 
```
</details>

## ПараметрыЗаполненияИсходныхДанныхПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыЗаполненияИсходныхДанныхПерерасчетов() Экспорт
```

Пример вызова
```bsl
Результат = ПерерасчетЗарплаты.ПараметрыЗаполненияИсходныхДанныхПерерасчетов() 
```
</details>

## СвернутьНачисленияПерерасчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СвернутьНачисленияПерерасчеты(НачисленияПерерасчет) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.СвернутьНачисленияПерерасчеты(НачисленияПерерасчет) 
```
</details>

## ЗаполнитьИсходныеДанныеПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьИсходныеДанныеПерерасчетов(ПараметрыОбновления, МетаданныеДокумента, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.ЗаполнитьИсходныеДанныеПерерасчетов(ПараметрыОбновления, МетаданныеДокумента, ПараметрыЗаполнения) 
```
</details>

## СторнироватьДвиженияВРегистреИсходныеДанныеПерерасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СторнироватьДвиженияВРегистреИсходныеДанныеПерерасчетов(НаборЗаписей, ИсправленныйДокумент, МетаданныеРегистра, Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
ПерерасчетЗарплаты.СторнироватьДвиженияВРегистреИсходныеДанныеПерерасчетов(НаборЗаписей, ИсправленныйДокумент, МетаданныеРегистра, Записывать);
```
</details>

## ДанныеПерерасчетаПриУвольненииСотрудника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДанныеПерерасчетаПриУвольненииСотрудника(ДокументУвольнения, ИсправленныйДокумент, Сотрудники, Организация, ДатаУвольнения, ПериодПерерасчетов, ИсключаемыеРегистраторы, МенеджерРасчета) Экспорт
```

Пример вызова
```bsl
Результат = ПерерасчетЗарплаты.ДанныеПерерасчетаПриУвольненииСотрудника(ДокументУвольнения, ИсправленныйДокумент, Сотрудники, Организация, ДатаУвольнения, ПериодПерерасчетов, ИсключаемыеРегистраторы, МенеджерРасчета) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
