---
title: Подключение 1С Такском клиент
slug: zup/подключение-1с-такском-клиент
---


## ПолучитьУникальныйИдентификаторАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет получение в сервисе 1С-Такском уникального идентификатора абонента
// электронного документооборота.
//
// Параметры:
//	СертификатЭП - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования - сертификат
//		электронной подписи;
//	Организация - Произвольный - организация, с которой связан сертификат,
//		используется для заполнения данных организации в заявке на получение
//		идентификатора абонента (см. Подключение1СТакскомПереопределяемый.ЗаполнитьРегистрационныеДанныеОрганизации());
//	ОповещениеОЗавершении - ОписаниеОповещения - обработчик, в который
//		передается результат получения идентификатора.
//		Передаваемое значение:
//			Строка - полученный идентификатор абонента;
//			Неопределено - если, идентификатор абонента не был получен.
//	ДополнительныеПараметры - Структура - дополнительные параметры.
//		Поля:
//		* ОбработчикСтатусаЗаявки (не обязательное) - ОписаниеОповещения - вызывается взамен открытия
//			стандартной формы "Статус заявки".
//			В обработчик передается параметр Структура с полями:
//			** СтатусЗаявки - Строка - статус текущей заявки:
//				- "Отсутствует" - заявка не создавалась;
//				- "ОжиданиеОбработки" - заявка создана, но еще не обработана;
//				- "Отклонена" - заявка отклонена;
//				- "Обработана" - заявка успешно обработана;
//			** НомерЗаявки - Строка - номер заявки;
//			** КодОшибки - Строка - код ошибки в сервисе Такском;
//			** ОписаниеОшибки - Строка - описание ошибки обработки последней заявки. <Пустая строка>, если ошибки нет;
//			** ДанныеЗаявки - Структура, Неопределено - данные текущей заявки:
//				*** ИдентификаторАбонента - Строка - идентификатор абонента Такском;
//				*** ОтпечатокСертификата - Строка - отпечаток  сертификата в виде base64-строки,
//					указанного при регистрации заявки;
//				*** Индекс - Строка - почтовый индекс организации;
//				*** КодРегиона - Строка - код региона в адресе организации;
//				*** Район - Строка - Район;
//				*** Город - Строка - Город;
//				*** НаселенныйПункт - Строка - населенный пункт расположения организации;
//				*** Улица - Строка - Улица;
//				*** Дом - Строка - Дом;
//				*** Корпус - Строка - Корпус;
//				*** Квартира - Строка - Квартира;
//				*** Телефон - Строка - телефон организации;
//				*** НаименованиеОрганизации - Строка - наименование организации;
//				*** ИНН - Строка - ИНН организации;
//				*** КПП - Строка - КПП организации;
//				*** ОГРН - Строка - ОГРН организации;
//				*** КодНалоговогоОргана - Строка - код ИМНС организации;
//				*** ЮрФизЛицо - Строка - вид лица, возможные значения: "ЮрЛицо" или "ФизЛицо";
//				*** Фамилия - Строка - фамилия руководителя;
//				*** Имя - Строка - имя руководителя;
//				*** Отчество - Строка - отчество руководителя;
//			** ОбработчикРезультата - ОписаниеОповещения - обработчик, который должен быть вызван при
//				завершении выполнения метода. В обработчик передается результат выполнения метода.
//				Структура с полями:
//				*** Действие - Строка - описание действия, которое необходимо выполнить для продолжения бизнес-процесса.
//					Возможные значения:
//					- "СтандартнаяОбработка" - обработать стандартным способом (показать форму "Статус заявки");
//					- "Завершить" - завершить бизнес-процесс (освободить ресурсы);
//					- "НоваяЗаявка" - создать новую заявку;
//					- "ПроверитьСтатусЗаявки" - проверить статус обработки заявки
//						(только для СтатусЗаявки = "ОжиданиеОбработки");
//		* ОбработчикСозданияЗаявки (не обязательное) - ОписаниеОповещения - вызывается взамен открытия
//			стандартной формы "Заявка на регистрацию участника обмена ЭД".
//			В обработчик передается параметр Структура с полями:
//			** ИдентификаторАбонента - Строка - идентификатор абонента Такском;
//			** ДанныеЗаявки - Структура - предзаполненные данные заявки.
//				Структура с полями:
//				*** ИдентификаторАбонента - Строка - идентификатор абонента Такском;
//				*** ОтпечатокСертификата - Строка - отпечаток  сертификата в виде base64-строки,
//					указанного при регистрации заявки;
//				*** Индекс - Строка - почтовый индекс организации;
//				*** КодРегиона - Строка - код региона в адресе организации;
//				*** Район - Строка - Район;
//				*** Город - Строка - Город;
//				*** НаселенныйПункт - Строка - населенный пункт расположения организации;
//				*** Улица - Строка - Улица;
//				*** Дом - Строка - Дом;
//				*** Корпус - Строка - Корпус;
//				*** Квартира - Строка - Квартира;
//				*** Телефон - Строка - телефон организации;
//				*** НаименованиеОрганизации - Строка - наименование организации;
//				*** ИНН - Строка - ИНН организации;
//				*** КПП - Строка - КПП организации;
//				*** ОГРН - Строка - ОГРН организации;
//				*** КодНалоговогоОргана - Строка - код ИМНС организации;
//				*** ЮрФизЛицо - Строка - вид лица, возможные значения: "ЮрЛицо" или "ФизЛицо";
//				*** Фамилия - Строка - фамилия руководителя;
//				*** Имя - Строка - имя руководителя;
//				*** Отчество - Строка - отчество руководителя;
//			** ОбработчикРезультата - ОписаниеОповещения - обработчик, который должен быть вызван
//				при завершении выполнения метода. В обработчик передается результат выполнения метода.
//				Структура с полями:
//				*** Действие - Строка - действие, которое должно быть выполнено.
//					Возможные значения:
//					- "СтандартнаяОбработка" - обработать стандартным способом
//						(открыть стандартную форму создания заявки);
//					- "Завершить" - завершить бизнес-процесс (освободить ресурсы);
//					- "ОтправитьЗаявку" - отправить данные заявки (необходимо передать данные заявки);
//				*** ДанныеЗаявки - Структура - см. поле ДанныеЗаявки параметра обработчика оповещения.
//
Процедура ПолучитьУникальныйИдентификаторАбонента( Экспорт
```

Пример вызова
```bsl
Подключение1СТакскомКлиент.ПолучитьУникальныйИдентификаторАбонента();
```
</details>

## ЗарегистрироватьСертификатАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет регистрацию в сервисе 1С-Такском нового сертификата абонента
// электронного документооборота.
//
// Параметры:
//	СертификатЭП - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования - сертификат
//		электронной подписи;
//	ИдентификаторАбонента - Строка - уникальный идентификатор абонента,
//		для которого регистрируется сертификат;
//	Организация - Произвольный - организация, с которой связан сертификат,
//		используется для заполнения данных организации в заявке на регистрацию
//		сертификата (см. Подключение1СТакскомПереопределяемый.ЗаполнитьРегистрационныеДанныеОрганизации());
//	ОповещениеОЗавершении - ОписаниеОповещения - обработчик, в который
//		передается результат регистрации сертификата.
//		Передаваемое значение:
//			Булево - результат регистрации сертификата. Истина - если
//				сертификат зарегистрирован успешно, Ложь - в противном случае.
//	ДополнительныеПараметры - Структура - дополнительные параметры.
//		Поля:
//		* ОбработчикСтатусаЗаявки (не обязательное) - ОписаниеОповещения - вызывается взамен открытия
//			стандартной формы "Статус заявки".
//			В обработчик передается параметр Структура с полями:
//			** СтатусЗаявки - Строка - статус текущей заявки:
//				- "Отсутствует" - заявка не создавалась;
//				- "ОжиданиеОбработки" - заявка создана, но еще не обработана;
//				- "Отклонена" - заявка отклонена;
//				- "Обработана" - заявка успешно обработана;
//			** НомерЗаявки - Строка - номер заявки;
//			** КодОшибки - Строка - код ошибки в сервисе Такском;
//			** ОписаниеОшибки - Строка - описание ошибки обработки последней заявки. <Пустая строка>, если ошибки нет;
//			** ДанныеЗаявки - Структура, Неопределено - данные текущей заявки:
//				*** ИдентификаторАбонента - Строка - идентификатор абонента Такском;
//				*** ОтпечатокСертификата - Строка - отпечаток  сертификата в виде base64-строки,
//					указанного при регистрации заявки;
//				*** Индекс - Строка - почтовый индекс организации;
//				*** КодРегиона - Строка - код региона в адресе организации;
//				*** Район - Строка - Район;
//				*** Город - Строка - Город;
//				*** НаселенныйПункт - Строка - населенный пункт расположения организации;
//				*** Улица - Строка - Улица;
//				*** Дом - Строка - Дом;
//				*** Корпус - Строка - Корпус;
//				*** Квартира - Строка - Квартира;
//				*** Телефон - Строка - телефон организации;
//				*** НаименованиеОрганизации - Строка - наименование организации;
//				*** ИНН - Строка - ИНН организации;
//				*** КПП - Строка - КПП организации;
//				*** ОГРН - Строка - ОГРН организации;
//				*** КодНалоговогоОргана - Строка - код ИМНС организации;
//				*** ЮрФизЛицо - Строка - вид лица, возможные значения: "ЮрЛицо" или "ФизЛицо";
//				*** Фамилия - Строка - фамилия руководителя;
//				*** Имя - Строка - имя руководителя;
//				*** Отчество - Строка - отчество руководителя;
//			** ОбработчикРезультата - ОписаниеОповещения - обработчик, который должен быть вызван при
//				завершении выполнения метода. В обработчик передается результат выполнения метода.
//				Структура с полями:
//				*** Действие - Строка - описание действия, которое необходимо выполнить для продолжения бизнес-процесса.
//					Возможные значения:
//					- "СтандартнаяОбработка" - обработать стандартным способом (показать форму "Статус заявки");
//					- "Завершить" - завершить бизнес-процесс (освободить ресурсы);
//					- "НоваяЗаявка" - создать новую заявку;
//					- "ПроверитьСтатусЗаявки" - проверить статус обработки заявки
//						(только для СтатусЗаявки = "ОжиданиеОбработки");
//		* ОбработчикСозданияЗаявки (не обязательное) - ОписаниеОповещения - вызывается взамен открытия
//			стандартной формы "Заявка на регистрацию участника обмена ЭД".
//			В обработчик передается параметр Структура с полями:
//			** ИдентификаторАбонента - Строка - идентификатор абонента Такском;
//			** ДанныеЗаявки - Структура - предзаполненные данные заявки.
//				Структура с полями:
//				*** ИдентификаторАбонента - Строка - идентификатор абонента Такском;
//				*** ОтпечатокСертификата - Строка - отпечаток  сертификата в виде base64-строки,
//					указанного при регистрации заявки;
//				*** Индекс - Строка - почтовый индекс организации;
//				*** КодРегиона - Строка - код региона в адресе организации;
//				*** Район - Строка - Район;
//				*** Город - Строка - Город;
//				*** НаселенныйПункт - Строка - населенный пункт расположения организации;
//				*** Улица - Строка - Улица;
//				*** Дом - Строка - Дом;
//				*** Корпус - Строка - Корпус;
//				*** Квартира - Строка - Квартира;
//				*** Телефон - Строка - телефон организации;
//				*** НаименованиеОрганизации - Строка - наименование организации;
//				*** ИНН - Строка - ИНН организации;
//				*** КПП - Строка - КПП организации;
//				*** ОГРН - Строка - ОГРН организации;
//				*** КодНалоговогоОргана - Строка - код ИМНС организации;
//				*** ЮрФизЛицо - Строка - вид лица, возможные значения: "ЮрЛицо" или "ФизЛицо";
//				*** Фамилия - Строка - фамилия руководителя;
//				*** Имя - Строка - имя руководителя;
//				*** Отчество - Строка - отчество руководителя;
//			** ОбработчикРезультата - ОписаниеОповещения - обработчик, который должен быть вызван
//				при завершении выполнения метода. В обработчик передается результат выполнения метода.
//				Структура с полями:
//				*** Действие - Строка - действие, которое должно быть выполнено.
//					Возможные значения:
//					- "СтандартнаяОбработка" - обработать стандартным способом
//						(открыть стандартную форму создания заявки);
//					- "Завершить" - завершить бизнес-процесс (освободить ресурсы);
//					- "ОтправитьЗаявку" - отправить данные заявки (необходимо передать данные заявки);
//				*** ДанныеЗаявки - Структура - см. поле ДанныеЗаявки параметра обработчика оповещения.
//
Процедура ЗарегистрироватьСертификатАбонента( Экспорт
```

Пример вызова
```bsl
Подключение1СТакскомКлиент.ЗарегистрироватьСертификатАбонента();
```
</details>

## ОткрытьЛичныйКабинетАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает личный кабинет абонента сервиса 1С-Такском.
//
// Параметры:
//	СертификатЭП - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования - сертификат
//		электронной подписи, связанный с абонентом;
//
Процедура ОткрытьЛичныйКабинетАбонента(СертификатЭП) Экспорт
```

Пример вызова
```bsl
Подключение1СТакскомКлиент.ОткрытьЛичныйКабинетАбонента(СертификатЭП) 
```
</details>

## КонфигурацияЗарегистрированаВСервисе1СТакском
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, зарегистрирована ли текущая конфигурация в сервисе
// Интернет-поддержки.
// Проверка выполняется по значению свойства Метаданные.Имя.
//
// Параметры:
//	ОшибкаОбращенияКВебСервису - Булево - в параметре возвращается Истина,
//		если в процессе обращения к сервису ИПП произошла ошибка
//		и "зарегистрированность" конфигурации проверить не удалось;
//
// Возвращаемое значение:
//	Булево - Истина, если конфигурация зарегистрирована в сервисе ИПП,
//		Ложь - если не зарегистрирована или в процессе обращения к сервису ИПП
//			произошла ошибка;
//
Функция КонфигурацияЗарегистрированаВСервисе1СТакском(ОшибкаОбращенияКВебСервису = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = Подключение1СТакскомКлиент.КонфигурацияЗарегистрированаВСервисе1СТакском(ОшибкаОбращенияКВебСервису);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
