---
title: Подписи документов
slug: zup/подписи-документов
---


## ДобавитьОписаниеПодписейОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет описание набора подписей объекта (документа) для организации.
//
// Параметры:
//  ОписаниеПодписей				 - ТаблицаЗначений	 - см. ОписаниеТаблицыПодписей.
//  СтрокаРолей						 - Строка			 - имена ролей, присутствующих в объекте, разделенные запятыми.
//  ПереопределяемыеИменаРеквизитов	 - Соответствие		 - имена реквизитов подписантов, где:
//  		* Ключ - Строка - имя роли
//  		* Значение - Структура - переопределяемые имена реквизитов, см. ОписаниеРеквизитовПодписанта.
//  ИмяРеквизитаОрганизация			 - Строка			 - имя реквизита объекта, который содержит Организацию, к которой относятся подключаемые роли.
//
Процедура ДобавитьОписаниеПодписейОрганизации( Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ДобавитьОписаниеПодписейОрганизации();
```
</details>

## ОписаниеРеквизитовПодписанта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура, описывающая триаду имен реквизитов подписанта.
//
// Возвращаемое значение:
//  Структура - Имена реквизитов подписанта.
//
Функция ОписаниеРеквизитовПодписанта() Экспорт
```

Пример вызова
```bsl
Результат = ПодписиДокументов.ОписаниеРеквизитовПодписанта() 
```
</details>

## ИменаРеквизитовРолиПодписанта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует соответствие с описанием роли уполномоченного лица, подписывающего документы.
//
// Параметры:
//  ИмяРеквизитаФизическоеЛицо	 - Строка	 - имя реквизита документа, в котором хранится ссылка на ответственное лицо,
//  ИмяРеквизитаДолжность		 - Строка	 - имя реквизита документа, в котором хранится должность ответственного лица,
//  ИмяРеквизитаОснованиеПодписи - Строка	 - имя реквизита документа, в котором хранится основание полномочий ответственного лица,
//  ИмяРоли						 - Строка	 - Необязательный, имя роли ответственного лица,
//  	если не задано, принимается равным ИмяРеквизитаФизическоеЛицо.
//
// Возвращаемое значение:
//  Соответствие - ключом выступает имя роли, а значением описание (см. ОписаниеРеквизитовПодписанта).
//
Функция ИменаРеквизитовРолиПодписанта( Экспорт
```

Пример вызова
```bsl
Результат = ПодписиДокументов.ИменаРеквизитовРолиПодписанта();
```
</details>

## ОписаниеТаблицыПодписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую таблиц значений для описания имен реквизитов формы, относящихся к подписям документа.
//
// Возвращаемое значение:
//		Таблица значений - содержит следующие колонки:
//			* Организация		 - признак принадлежности к той или иной организации в форме (их может быть более одной).
//			* Ключ				 - имя роли подписывающего лица (например "Руководитель")
//			* ФизическоеЛицо	 - имя реквизита, содержащего подписанта (например "Директор")
//			* Должность			 - имя реквизита, содержащего должность подписанта (например "ДолжностьДиректора")
//			* ОснованиеПодписи	 - имя реквизита, содержащего текст основания подписи (например "ОснованиеПодписиДиректора")
//
Функция ОписаниеТаблицыПодписей() Экспорт
```

Пример вызова
```bsl
Результат = ПодписиДокументов.ОписаниеТаблицыПодписей() 
```
</details>

## ДобавитьИдентификаторыОтветственныхРаботниковОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет поддерживаемые идентификаторы значений по умолчанию идентификаторами ответственных лиц организаций.
//
// Параметры:
//  ПоддерживаемыеИдентификаторы - Массив - идентификаторы заполняемых по умолчанию значений.
//
Процедура ДобавитьИдентификаторыОтветственныхРаботниковОрганизаций(ПоддерживаемыеИдентификаторы) Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ДобавитьИдентификаторыОтветственныхРаботниковОрганизаций(ПоддерживаемыеИдентификаторы) 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Расширение обработчика ПриСозданииНаСервере формы документа, в котором размещаются подписи.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в котором размещаются подписи.
//	ОписаниеРеквизитовПодписей - ТаблицаЗначений - см. ПодписиДокументов.ОписаниеТаблицыПодписей(),
//  ОписаниеФормыДляПодписей - Соответствие - где ключом является имя реквизита организации,
//								а значением - его описание, созданное с помощью
//								ПодписиДокументовКлиентСервер.ОписаниеФормыОбъектаДляОрганизацииПоУмолчанию().
//
Процедура ПриСозданииНаСервере(Форма, ОписаниеРеквизитовПодписей = Неопределено, ОписаниеФормыДляПодписей = Неопределено) Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ПриСозданииНаСервере(Форма, ОписаниеРеквизитовПодписей, ОписаниеФормыДляПодписей);
```
</details>

## ЗаполнитьПодписиПоОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет подписи документа в форме при смене организации или даты документа.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в котором размещаются подписи.
//  ОписаниеФормыДляПодписей - Соответствие - где ключом является имя реквизита организации,
//								а значением - его описание, созданное с помощью
//								ПодписиДокументовКлиентСервер.ОписаниеФормыОбъектаДляОрганизацииПоУмолчанию().
//  ИмяРеквизитаОрганизация - Строка - имя реквизита, в котором хранится организация.
//
Процедура ЗаполнитьПодписиПоОрганизации(Форма, ОписаниеФормыДляПодписей = Неопределено, ИмяРеквизитаОрганизация = "Организация") Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ЗаполнитьПодписиПоОрганизации(Форма, ОписаниеФормыДляПодписей, ИмяРеквизитаОрганизация);
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Расширение обработчика ПослеЗаписиНаСервере формы документа, в котором размещаются подписи.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в котором размещаются подписи.
//
Процедура ПослеЗаписиНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ПослеЗаписиНаСервере(Форма) 
```
</details>

## ЗаполнитьСведенияОПодписяхДокументовПоОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из общей цепочки заполнения реквизитов, из ПолучитьЗначенияПоУмолчанию()
//
// Параметры:
//  ЗаполняемыеЗначения - Структура - значения по умолчанию, которые будут дополнены сведениями о подписях документа.
//
Процедура ЗаполнитьСведенияОПодписяхДокументовПоОрганизации(ЗаполняемыеЗначения) Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ЗаполнитьСведенияОПодписяхДокументовПоОрганизации(ЗаполняемыеЗначения) 
```
</details>

## ДополнитьТекстОснованиемПодписиИзРеквизитаДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет текст из основания подписи физического лица в дополняемый текст.
//
// Параметры:
//   ДополняемыйТекст - Строка - текст, который необходимо дополнить.
//   ДокументСсылка - ДокументСсылка - ссылка на документ, в котором хранится подписант.
//   ИмяРеквизитаДокумента - Строка - имя реквизита документа.
//
Процедура ДополнитьТекстОснованиемПодписиИзРеквизитаДокумента(ДополняемыйТекст, ДокументСсылка, ИмяРеквизитаДокумента) Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ДополнитьТекстОснованиемПодписиИзРеквизитаДокумента(ДополняемыйТекст, ДокументСсылка, ИмяРеквизитаДокумента) 
```
</details>

## ДополнитьТекстОснованиемПодписиПоИмениРоли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет текст из основания подписи физического лица в дополняемый текст.
//
// Параметры:
//   ДополняемыйТекст - Строка - текст, который необходимо дополнить.
//   ДокументСсылка - ДокументСсылка - ссылка на документ, в котором хранится подписант.
//   ИмяРоли - Строка - имя роли подписанта.
//   ИмяРеквизитаОрганизация - Строка - имя реквизита "Организация" документа.
//
Процедура ДополнитьТекстОснованиемПодписиПоИмениРоли(ДополняемыйТекст, ДокументСсылка, ИмяРоли, ИмяРеквизитаОрганизация = "Организация") Экспорт
```

Пример вызова
```bsl
ПодписиДокументов.ДополнитьТекстОснованиемПодписиПоИмениРоли(ДополняемыйТекст, ДокументСсылка, ИмяРоли, ИмяРеквизитаОрганизация);
```
</details>

## СведенияОПодписяхПоУмолчаниюДляОбъектаМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет получить описание подписей документа по его метаданным.
//
// Параметры:
//   ОбъектМетаданных - ОбъектМетаданных             - Метаданные документа, для которого определяется состав подписей.
//   Организация      - СправочникСсылка.Организации - Организация, для которой определяются ответственные лица.
//
// Возвращаемое значение:
//   Структура - см. СведенияОПодписяхДокументов.
//
Функция СведенияОПодписяхПоУмолчаниюДляОбъектаМетаданных(ОбъектМетаданных, Организация) Экспорт
```

Пример вызова
```bsl
Результат = ПодписиДокументов.СведенияОПодписяхПоУмолчаниюДляОбъектаМетаданных(ОбъектМетаданных, Организация) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
