---
title: Проверки БЗК клиент сервер
slug: zup/проверки-бзк-клиент-сервер
---


## ПериодСоответствуетТребованиям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// АПК:558-выкл Кандидаты в публичный программный интерфейс.
// АПК:559-выкл Кандидаты в публичный программный интерфейс.

// Проверяет корректность заполнения начала и окончания периода в объекте или строке таблицы формы.
//
// Параметры:
//   Форма      - УправляемаяФорма - Форма с датами начала и окончания.
//   ПутьКОбъекту         - Строка - Полный путь к реквизиту формы с датами начала и окончания.
//   ИмяПоляДатыНачала    - Строка - Имя реквизита строки табличной части, в котором хранится дата начала периода.
//   ИмяПоляДатыОкончания - Строка - Имя реквизита строки табличной части, в котором хранится дата окончания.
//   ПредставлениеВРодительномПадеже - Строка - Представление (заголовок) периода в родительном падеже.
//
// Возвращаемое значение:
//   Булево - Признак того, что поля успешно прошли проверку.
//       Возвращает Ложь если была выявлена ошибка.
//
Функция ПериодСоответствуетТребованиям(Форма, ПутьКОбъекту, ИмяПоляДатыНачала, ИмяПоляДатыОкончания, ПредставлениеВРодительномПадеже) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкиБЗККлиентСервер.ПериодСоответствуетТребованиям(Форма, ПутьКОбъекту, ИмяПоляДатыНачала, ИмяПоляДатыОкончания, ПредставлениеВРодительномПадеже) 
```
</details>

## РезультатПроверкиНомераСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет номер расчетного счета на соответствие БИКу и корреспондентскому счету банка.
//
// Параметры:
//   НомерСчета            - Строка
//   БИК                   - Строка
//   КорреспондентскийСчет - Строка
//
// Возвращаемое значение:
//   Структура - Результат проверки:
//       * Успех - Булево - Если Истина, то номер счета прошел проверку. В пояснении будут подробности.
//       * Пояснение - Строка - Текст для вывода результатов в интерфейсе.
//
Функция РезультатПроверкиНомераСчета(Знач НомерСчета, Знач БИК, Знач КорреспондентскийСчет) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкиБЗККлиентСервер.РезультатПроверкиНомераСчета(НомерСчета, БИК, КорреспондентскийСчет) 
```
</details>

## РезультатПроверкиНомераКарты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет номер банковской карты.
//
// Параметры:
//   НомерКарты                         - Строка
//   ЭтоНациональныйПлатежныйИнструмент - Булево, Неопределено
//
// Возвращаемое значение:
//   Структура - Результат проверки:
//       * Успех - Булево - Если Истина, то номер карты прошел проверку. В тексте будут подробности.
//       * Текст - Строка - Текст для вывода результатов в интерфейсе.
//
Функция РезультатПроверкиНомераКарты(Знач НомерКарты, Знач ЭтоНациональныйПлатежныйИнструмент = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкиБЗККлиентСервер.РезультатПроверкиНомераКарты(НомерКарты, ЭтоНациональныйПлатежныйИнструмент);
```
</details>

## НомерКартыЭтоНациональныйПлатежныйИнструмент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НомерКартыЭтоНациональныйПлатежныйИнструмент(Знач НомерКарты) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкиБЗККлиентСервер.НомерКартыЭтоНациональныйПлатежныйИнструмент(НомерКарты) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
