---
title: Расчет зарплаты расширенный
slug: zup/расчет-зарплаты-расширенный
---


## ЗаписатьЗначенияОперативныхПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует значения оперативных показателей расчета зарплаты.
//
// Параметры:
//   Движения              - КоллекцияДвижений            - Движения документа.
//   Организация           - СправочникСсылка.Организации - Организация, выбранная в шапке документа.
//   ОперативныеПоказатели - ТаблицаЗначений              - Сведения о сдельном заработке сотрудников.
//
//     Обязательные колонки:
//       * Дата       - Дата                                       - Период регистрации записи.
//       * Сотрудник  - СправочникСсылка.Сотрудники                - Сотрудник.
//       * Показатель - СправочникСсылка.ПоказателиРасчетаЗарплаты - Показатель.
//       * Значение   - Число                                      - Значение показателя.
//
//     Необязательные колонки:
//       * ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - Физическое лицо.
//       * Сторно         - Булево                          - Истина, если данная запись является сторнирующей.
//       * СтатьяФинансирования             - СправочникСсылка.СтатьиФинансированияЗарплата      - Статья финансирования.
//       * СпособОтраженияЗарплатыВБухучете - СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете - Счет, субконто.
//       * ОтношениеКЕНВД                   - ПеречислениеСсылка.ОтношениеКЕНВДЗатратНаЗарплату  - Отношение к ЕНВД.
//       * Подразделение                    - СправочникСсылка.ПодразделенияОрганизаций          - Подразделение для
//                                                                                                 учета затрат.
//   ЗаписыватьДвижения - Булево - Если Истина, движения будут записаны.
//
Процедура ЗаписатьЗначенияОперативныхПоказателей(Движения, Организация, ОперативныеПоказатели, ЗаписыватьДвижения = Ложь) Экспорт
```

Пример вызова
```bsl
РасчетЗарплатыРасширенный.ЗаписатьЗначенияОперативныхПоказателей(Движения, Организация, ОперативныеПоказатели, ЗаписыватьДвижения);
```
</details>

## ЗарегистрироватьСдельныйЗаработок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует данные о сдельном заработке в движениях по регистру ЗначенияОперативныхПоказателейРасчетаЗарплатыСотрудников.
//
// Параметры:
//   Движения          - КоллекцияДвижений            - Движения документа.
//   Организация       - СправочникСсылка.Организации - Организация, выбранная в шапке документа.
//   СдельныйЗаработок - ТаблицаЗначений              - Сведения о сдельном заработке сотрудников.
//
//     Обязательные колонки:
//       * Дата      - Дата                        - Период регистрации записи.
//       * Сотрудник - СправочникСсылка.Сотрудники - Сотрудник.
//       * Значение  - Число                       - Значение показателя.
//
//     Необязательные колонки:
//       * ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - Физическое лицо.
//       * Сторно         - Булево                          - Истина, если данная запись является сторнирующей.
//       * СтатьяФинансирования             - СправочникСсылка.СтатьиФинансированияЗарплата      - Статья финансирования.
//       * СпособОтраженияЗарплатыВБухучете - СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете - Счет, субконто.
//       * ОтношениеКЕНВД                   - ПеречислениеСсылка.ОтношениеКЕНВДЗатратНаЗарплату  - Отношение к ЕНВД.
//       * Подразделение                    - СправочникСсылка.ПодразделенияОрганизаций          - Подразделение для
//                                                                                                 учета затрат.
//
Процедура ЗарегистрироватьСдельныйЗаработок(Движения, Организация, СдельныйЗаработок) Экспорт
```

Пример вызова
```bsl
РасчетЗарплатыРасширенный.ЗарегистрироватьСдельныйЗаработок(Движения, Организация, СдельныйЗаработок) 
```
</details>

## СоздатьОперативныйПоказатель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет новый показатель расчета зарплаты,
// используемый для ввода оперативных данных.
//
// Параметры:
//  Идентификатор - Строка - Строковый идентификатор показателя.
//                           Используется в формуле начислений, а также для идентификации показателя в исходном коде.
//                           Идентификатор, используемый в формуле начислений, может изменятся пользователем,
//                           но из кода показатель всегда будет доступен при помощи метода
//                           РасчетЗарплатыРасширенный.ОперативныйПоказательПоИдентификатору.
//  Представление        - Строка - Пользовательское представление показателя.
//  КраткоеПредставление - Строка - Пользовательское представление для заголовков колонок в документах ввода.
//                                  Необязательный, по умолчанию совпадает с Представление.
//  Валюта   - СправочникСсылка.Валюты - Валюта показателя. Необязательный, по умолчанию - валюта учета.
//  Точность - Число                   - Точность значения показателя. Необязательный, по умолчанию - целое число.
//
// Возвращаемое значение:
// - СправочникСсылка.ПоказателиРасчетаЗарплаты - ссылка на созданный показатель.
//
Функция СоздатьОперативныйПоказатель(Идентификатор, Представление, КраткоеПредставление = Неопределено, Валюта = Неопределено, Точность = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетЗарплатыРасширенный.СоздатьОперативныйПоказатель(Идентификатор, Представление, КраткоеПредставление, Валюта, Точность);
```
</details>

## ОперативныйПоказательПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает оперативный показатель по служебному идентификатору.
//
// Параметры:
//	- Идентификатор - строка, служебный идентификатор показателя,
//			например, используемый при создании показателя
//			методом СоздатьОперативныйПоказатель.
//
// Возвращаемое значение:
// - СправочникСсылка.ПоказателиРасчетаЗарплаты - ссылка на созданный показатель.
//
Функция ОперативныйПоказательПоИдентификатору(Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = РасчетЗарплатыРасширенный.ОперативныйПоказательПоИдентификатору(Идентификатор) 
```
</details>

## ЗаполнитьНастройкиПечатныхФормПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНастройкиПечатныхФормПоУмолчанию(ОписанияНастроек) Экспорт
```

Пример вызова
```bsl
РасчетЗарплатыРасширенный.ЗаполнитьНастройкиПечатныхФормПоУмолчанию(ОписанияНастроек) 
```
</details>

## ОпределитьПроверкиВеденияУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. КонтрольВеденияУчетаПереопределяемый.ПриОпределенииПроверок.
Процедура ОпределитьПроверкиВеденияУчета(ГруппыПроверок, Проверки) Экспорт
```

Пример вызова
```bsl
РасчетЗарплатыРасширенный.ОпределитьПроверкиВеденияУчета(ГруппыПроверок, Проверки) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
