---
title: Регламентированная отчетность
slug: zup/регламентированная-отчетность
---


## ТекущееСостояниеОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекущееСостояниеОтправки(СохраненныйДок, КонтролирующийОрган) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ТекущееСостояниеОтправки(СохраненныйДок, КонтролирующийОрган) 
```
</details>

## ПоказателиОценкиРискаВыезднойНалоговойПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с показателями регламентированных отчетов,
// необходимыми для оценки риска выездной налоговой проверки.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - организация, по которой отбираются регламентированные отчеты.
//   ДатаНачала - Дата - начало периода, за который отбираются регламентированные отчеты.
//   ДатаОкончания - Дата - конец периода, за который отбираются регламентированные отчеты.
//   ИмяРегламентированногоОтчета - Строка - наименование регламентированного отчета,
//											 для которого возвращается таблица с показателями.
//											 Если наименование регламентированного отчета не указано,
//											 таблица с показателями возвращается для всех регламентированных отчетов.
//
// Возвращаемое значение:
//   ТаблицЗначений - показатели регламентированных отчетов, необходимые
//					  для оценки риска выездной налоговой проверки.
//
Функция ПоказателиОценкиРискаВыезднойНалоговойПроверки(Организация, Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПоказателиОценкиРискаВыезднойНалоговойПроверки(Организация, );
```
</details>

## ПустаяТаблицаОписанияОбъектовРегламентированнойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует шаблон таблицы для получения данных из переопределяемого метода.
//
// Возвращаемое значение:
//   ТаблицаЗначений - шаблон таблицы для получения данных из переопределяемого метода.
//
Функция ПустаяТаблицаОписанияОбъектовРегламентированнойОтчетности() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПустаяТаблицаОписанияОбъектовРегламентированнойОтчетности() 
```
</details>

## ЗаполнитьНаименованиеВТаблицеОписанияОбъектовРегламентированнойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет наименование таблицы для получения данных из переопределяемого метода.
//
// Параметры:
//   ТаблицаОписания - ТаблицаЗначений - таблица описания.
//
Процедура ЗаполнитьНаименованиеВТаблицеОписанияОбъектовРегламентированнойОтчетности(ТаблицаОписания) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаполнитьНаименованиеВТаблицеОписанияОбъектовРегламентированнойОтчетности(ТаблицаОписания) 
```
</details>

## ДобавитьВДеревоРегламентированныхОтчетовОтчетыИзТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет дерево видов отчетов данными из таблицы.
//
// Параметры:
//   ДеревоОтчетов - ДеревоЗначений - дерево регл. отчетов.
//   ТаблицаОписанияОтчетов - ТаблицаЗначений - таблица регл. отчетов.
//
Процедура ДобавитьВДеревоРегламентированныхОтчетовОтчетыИзТаблицы(ДеревоОтчетов, ТаблицаОписанияОтчетов) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДобавитьВДеревоРегламентированныхОтчетовОтчетыИзТаблицы(ДеревоОтчетов, ТаблицаОписанияОтчетов) 
```
</details>

## ТаблицаСозданныхВидовОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу ранее созданных отчетов.
//
// Параметры:
//   Организации - Массив - массив значений типа СправочникСсылка.Организации,
//                          по которым отбираются регламентированные отчеты.
//
// Возвращаемое значение:
//   ТаблицаЗначений - ранее созданные отчеты.
//
Функция ТаблицаСозданныхВидовОтчетов(Организации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ТаблицаСозданныхВидовОтчетов(Организации);
```
</details>

## МассивВнешнихРегламентированныхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив, содержащий подключенные внешние регламентированные отчеты.
//
// Возвращаемое значение:
//   Массив - подключенные внешние регламентированные отчеты.
//
Функция МассивВнешнихРегламентированныхОтчетов() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.МассивВнешнихРегламентированныхОтчетов() 
```
</details>

## ТаблицаДоступныеРегламентированныеОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу, содержащую доступные регламентированные отчеты, ограниченные переданным отбором.
//
// Параметры:
//   Отбор - Массив - массив имен отчетов.
//
// Возвращаемое значение:
//   ТаблицаЗначений - доступные регламентированные отчеты, ограниченные переданным отбором.
//
Функция ТаблицаДоступныеРегламентированныеОтчеты(Отбор) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ТаблицаДоступныеРегламентированныеОтчеты(Отбор) 
```
</details>

## ПоказателиАвтозаполненияБухгалтерскойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие с показателями автозаполнения бухгалтерской отчетности.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - организация, по которой рассчитываются сведения.
//   ДатаНачала - Дата - начало периода, за который расчитываются сведения. Приводится к началу года.
//   ДатаОкончания - Дата - конец периода, за который расчитываются сведения. Приводится к концу месяца,
//                          или к концу года от ДатаНачала, если годы не совпадают.
//   ЗаполнятьБаланс - Булево - признак заполнения баланса.
//
// Возвращаемое значение:
//   Соответствие - показатели автозаполнения бухгалтерской отчетности.
//
Функция ПоказателиАвтозаполненияБухгалтерскойОтчетности(Организация, ДатаНачала, ДатаОкончания, ЗаполнятьБаланс = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПоказателиАвтозаполненияБухгалтерскойОтчетности(Организация, ДатаНачала, ДатаОкончания, ЗаполнятьБаланс);
```
</details>

## ДоступнаФормаРегламентированнаяОтчетностьТекущемуПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак доступности для просмотра формы регламентированной отчетности
// текущему пользователю.
//
// Возвращаемое значение:
//   Булево - признак доступности для просмотра формы регламентированной отчетности
//            текущему пользователю.
//
Функция ДоступнаФормаРегламентированнаяОтчетностьТекущемуПользователю() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ДоступнаФормаРегламентированнаяОтчетностьТекущемуПользователю() 
```
</details>

## ДобавитьКнопкуПрисоединенныеФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в форме регламентированного отчета кнопку ("скрепку")
// для открытия формы с присоединенными файлами.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма регламентированного отчета.
//
Процедура ДобавитьКнопкуПрисоединенныеФайлы(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДобавитьКнопкуПрисоединенныеФайлы(Форма) 
```
</details>

## ЕстьФайлыПрисоединенныеКОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия файлов, присоединенных к объекту.
//
// Параметры:
//   ВладелецФайлов - ДокументСсылка, СправочникСсылка - ссылка на объект в регистре сведений "Журнал
//                    отчетов статусы" или регистре сведений "Журнал отправок в контролирующие органы".
//
Функция ЕстьФайлыПрисоединенныеКОбъекту(ВладелецФайлов) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЕстьФайлыПрисоединенныеКОбъекту(ВладелецФайлов) 
```
</details>

## ЗаполнениеДанныхПоДоговорамДляПроверкиВРЭЦ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет приложенные файлы к договорам контрагентов при проверке ставки 0% в сервисе РЭЦ
Процедура ЗаполнениеДанныхПоДоговорамДляПроверкиВРЭЦ(ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаполнениеДанныхПоДоговорамДляПроверкиВРЭЦ(ПараметрыЗаполнения) 
```
</details>

## СохранитьСтатусОтправкиРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет статус отправки, установленный вручную в форме регламентированного отчета.
// Предназначена для записи в регистр сведений "Журнал отчетов статусы" только по ссылкам
// типа "ДокументСсылка.РегламентированныйОтчет".
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма регламентированного отчета.
//
Процедура СохранитьСтатусОтправкиРеглОтчета(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.СохранитьСтатусОтправкиРеглОтчета(Форма) 
```
</details>

## СохранитьСтатусОтправкиУведомления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет статус отправки, установленный вручную в форме уведомления о спецрежимах налогообложения.
// Предназначена для записи в регистр сведений "Журнал отправок в контролирующие органы" только по
// ссылкам типа "ДокументСсылка.УведомлениеОСпецрежимахНалогообложения".
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма уведомления о спецрежимах налогообложения.
//
Процедура СохранитьСтатусОтправкиУведомления(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.СохранитьСтатусОтправкиУведомления(Форма) 
```
</details>

## СохраненныйСтатусОтправкиРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает статус отправки регламентированного отчета по данным регистра сведений
// "Журнал отчетов статусы" только по ссылкам типа "ДокументСсылка.РегламентированныйОтчет".
//
// Параметры:
//  РеглОтчет: ДокументСсылка.РегламентированныйОтчет - ссылка на объект
//             в регистре сведений "Журнал отчетов статусы".
//
// Возвращаемое значение:
//  Строка - статус отправки.
//
Функция СохраненныйСтатусОтправкиРеглОтчета(РеглОтчет) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СохраненныйСтатусОтправкиРеглОтчета(РеглОтчет) 
```
</details>

## СохраненныйСтатусОтправкиУведомления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает статус отправки уведомления о спецрежимах налогообложения по данным
// регистра сведений "Журнал отправок в контролирующие органы" только по ссылкам типа
// "ДокументСсылка.УведомлениеОСпецрежимахНалогообложения".
//
// Параметры:
//  Уведомление: ДокументСсылка.УведомлениеОСпецрежимахНалогообложения - ссылка на объект
//               в регистре сведений "Журнал отправок в контролирующие органы".
//
// Возвращаемое значение:
//  Строка - статус отправки.
//
Функция СохраненныйСтатусОтправкиУведомления(Уведомление) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СохраненныйСтатусОтправкиУведомления(Уведомление) 
```
</details>

## ПриОпределенииОбъектовСКомандамиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет объекты конфигурации, в модулях менеджеров которых размещена процедура ДобавитьКомандыПечати,
// формирующая список команд печати, предоставляемых этим объектом.
// Синтаксис процедуры ДобавитьКомандыПечати см. в документации к подсистеме.
//
// Параметры:
//  СписокОбъектов - Массив - менеджеры объектов с процедурой ДобавитьКомандыПечати.
//
Процедура ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) 
```
</details>

## Используется1СОтчетность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования отправки регламентированной отчетности.
//
// Возвращаемое значение:
//  Истина - отправка регл. отчетности выполняется в стандартном режиме (при подключенном сервисе "1С-Отчетность");
//  Ложь   - отправка регл. отчетности выполняется через DataTransfer БТС.
//
Функция Используется1СОтчетность() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.Используется1СОтчетность() 
```
</details>

## АдресВФормате9Запятых
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает адрес в формате 9-ти запятых.
//
// Параметры:
//   Запись - СправочникТабличнаяЧастьСтрока.Организации.КонтактнаяИнформация,
//			  СправочникТабличнаяЧастьСтрока.ФизическоеЛицо.КонтактнаяИнформация
//				- контактная информация (например, см. УправлениеКонтактнойИнформацией.КонтактнаяИнформацияОбъекта()).
//
// Возвращаемое значение:
//   Строка - адрес в формате 9-ти запятых.
//
Функция АдресВФормате9Запятых(Запись) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.АдресВФормате9Запятых(Запись) 
```
</details>

## ЭтоПлательщикЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак уплаты налогоплательщиком единого налога на вмененный доход (ЕНВД) за указанный период.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на элемент справочника "Организации".
//   НачалоПериода - Дата - дата начала периода, за который нужно получить признак.
//   КонецПериода  - Дата - дата конца периода, за который нужно получить признак.
//
// Возвращаемое значение:
//   Истина - налогоплательщик уплачивает ЕНВД.
//   Ложь   - налогоплательщик не уплачивает ЕНВД.
//
Функция ЭтоПлательщикЕНВД(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЭтоПлательщикЕНВД(Организация, НачалоПериода, КонецПериода) 
```
</details>

## ГоловнаяОрганизация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает ссылку на головную организацию.
//
// Возвращаемое значение: ссылка на элемент справочника организаций.
//
// Параметры:
// 	Организация - ссылка на элемент справочника организаций.
//
Функция ГоловнаяОрганизация(Организация) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ГоловнаяОрганизация(Организация) 
```
</details>

## ВерсияПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВерсияПрограммы() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВерсияПрограммы() 
```
</details>

## НазваниеПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НазваниеПрограммы() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.НазваниеПрограммы() 
```
</details>

## НазваниеИВерсияПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НазваниеИВерсияПрограммы() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.НазваниеИВерсияПрограммы() 
```
</details>

## ВставитьПоказательВСтруктуру
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВставитьПоказательВСтруктуру(СтруктураПоказателей, ИмяПоказателя, ПризнакАвтозаполнения, ПризнакРасшифровки, ПризнакЗапретаРедактирования = Ложь) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВставитьПоказательВСтруктуру(СтруктураПоказателей, ИмяПоказателя, ПризнакАвтозаполнения, ПризнакРасшифровки, ПризнакЗапретаРедактирования);
```
</details>

## ПолучитьДокФизЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДокФизЛица(ФизЛицо, ДатаЗначения) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьДокФизЛица(ФизЛицо, ДатаЗначения) 
```
</details>

## ПолучитьНомерПачкиВыгруженныхФайловПФР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьНомерПачкиВыгруженныхФайловПФР(Организация, Год) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьНомерПачкиВыгруженныхФайловПФР(Организация, Год) 
```
</details>

## ПолучитьПоКодамРегистрациюВИФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПоКодамРегистрациюВИФНС(Организация, КодНО, КПП = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьПоКодамРегистрациюВИФНС(Организация, КодНО, КПП);
```
</details>

## СвойстваПрочихОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СвойстваПрочихОтчетов(Ссылка, ТолькоВозвращенныеПереопределяемой = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СвойстваПрочихОтчетов(Ссылка, ТолькоВозвращенныеПереопределяемой);
```
</details>

## СвойстваРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СвойстваРегламентированногоОтчета(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СвойстваРегламентированногоОтчета(Ссылка) 
```
</details>

## УстановитьНомерПачкиВыгруженныхФайловПФР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьНомерПачкиВыгруженныхФайловПФР(Организация, Год, НомерПачки) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьНомерПачкиВыгруженныхФайловПФР(Организация, Год, НомерПачки) 
```
</details>

## ПолучитьСсылкуНаРеглОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает массив ссылок на сохраненные первичные регламентированные отчеты заданного вида
// для указанной организации за нужный отчетный период. Ссылки на регл. отчеты отсортированы
// в хронологическом порядке по убыванию.
//
// Возвращаемое значение: массив ссылок.
//
// Параметры:
//	ИсточникОтчета - строка с наименованием регламентированного отчета (совпадает с именем объекта метаданных).
// 	Организация    - ссылка на элемент справочника организаций.
//  ДатаОкончания  - дата окончания отчетного периода (правая граница отчетного периода).
//  КорректирующийОтчет - если значение данного параметра = Истина, то отчет является корректирующим.
//  РегистрацияВНалоговомОргане - отбор по регистрации в налоговом органе (коду налогового органа, КПП);
//             рекомендуется устанавливать этот отбор, если отчет может быть представлен в разные налоговые органы
//             или с указанием разных КПП
//  ФормаОтчета - строка с идентификатором формы отчета
//
// Пример:
// 	РегламентированнаяОтчетность.ПолучитьСсылкуНаРеглОтчет("РегламентированныйОтчетРСВ1", Организация, '20120331');
//
Функция ПолучитьСсылкуНаРеглОтчет(ИсточникОтчета, Организация, ДатаОкончания, КорректирующийОтчет = Ложь, РегистрацияВНалоговомОргане = Неопределено, ФормаОтчета = "") Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьСсылкуНаРеглОтчет(ИсточникОтчета, Организация, ДатаОкончания, КорректирующийОтчет, РегистрацияВНалоговомОргане, ФормаОтчета);
```
</details>

## НомерПачкиРСВ1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает номер пачки регл. отчета РСВ-1.
//
// Возвращаемое значение: номер пачки регл. отчета РСВ-1.
//
// Параметры:
//  СсылкаНаСохрРеглОтчет - ссылка на сохраненный регламентированный отчет РСВ-1, номер пачки которого нужно получить.
//
Функция НомерПачкиРСВ1(СсылкаНаСохрРеглОтчет) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.НомерПачкиРСВ1(СсылкаНаСохрРеглОтчет) 
```
</details>

## ПолучитьРаздел25иРаздел6ФормыРСВ1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает структуру с табличными документами разделов 2.5 и 6 формы РСВ-1.
//
// Параметры:
//  СсылкаНаСохрРеглОтчет           - ссылка на сохраненный документ "РегламентированныйОтчет".
//  СтруктураРазделов               - структура:
//    ключ     - имя раздела;
//    значение - массив структур с полями:
//      Описание          - строка;
//      ТабличныйДокумент - табличный документ;
//  НумероватьСтраницы              - булево;
//  НомерПервойстраницыРаздела25    - число;
//  НомерПоследнейстраницыРаздела25 - число;
//  НомерПервойстраницыРаздела6     - число;
//  ОбщееКоличествоСтраницРаздела6  - число.
//
Процедура ПолучитьРаздел25иРаздел6ФормыРСВ1(СсылкаНаСохрРеглОтчет, СтруктураРазделов, Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПолучитьРаздел25иРаздел6ФормыРСВ1(СсылкаНаСохрРеглОтчет, СтруктураРазделов, );
```
</details>

## ПустаяСтруктураДляРазделовФормыРСВ_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает для формы РСВ-1 пустую структуру с ключами:
//   "Описание", "ТабличныйДокумент", "Идентификатор".
//
Функция ПустаяСтруктураДляРазделовФормыРСВ_1() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПустаяСтруктураДляРазделовФормыРСВ_1() 
```
</details>

## ОписаниеЗапрашиваемыхДанныхРазделаРСВ_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает для формы РСВ-1 структуру с ключами:
//   "СтраницыРаздела", "ПолучатьСтруктуруРаздела", "ПолучатьТабличныеДокументыРаздела".
//
Функция ОписаниеЗапрашиваемыхДанныхРазделаРСВ_1() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ОписаниеЗапрашиваемыхДанныхРазделаРСВ_1() 
```
</details>

## УстановитьНомерПачкиРСВ1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает номер пачки регл. отчета РСВ-1.
//
// Параметры:
//  СсылкаНаСохрРеглОтчет - ссылка на сохраненный регламентированный отчет РСВ-1, номер пачки которого нужно установить.
//  НомерПачки            - номер пачки.
//
Процедура УстановитьНомерПачкиРСВ1(СсылкаНаСохрРеглОтчет, НомерПачки) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьНомерПачкиРСВ1(СсылкаНаСохрРеглОтчет, НомерПачки) 
```
</details>

## ДанныеОтчетаИзмененыВручную
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак изменения данных отчета вручную.
//
// Возвращаемое значение: Истина - данные отчета изменены вручную
//                        Ложь   - данные отчета вручную не изменялись.
//
// Параметры:
//  СсылкаНаСохрРеглОтчет - ссылка на сохраненный регламентированный отчет РСВ-1,
//  для которого необходимо получить признак изменения данных.
//
Функция ДанныеОтчетаИзмененыВручную(СсылкаНаСохрРеглОтчет) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ДанныеОтчетаИзмененыВручную(СсылкаНаСохрРеглОтчет) 
```
</details>

## ПерсонифицированныйУчетВедетсяВоВнешнейПрограмме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак ведения персонифицированного учета во внешней программе.
//
// Возвращаемое значение:
//  Истина - персонифицированный учет ведется во внешней программе;
//  Ложь   - персонифицированный учет ведется в конфигурации.
//
Функция ПерсонифицированныйУчетВедетсяВоВнешнейПрограмме() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПерсонифицированныйУчетВедетсяВоВнешнейПрограмме() 
```
</details>

## РегистрацииОрганизацииВНалоговомОргане
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает массив ссылок на элементы справочника "РегистрацииВНалоговомОргане".
//
// Возвращаемое значение: массив ссылок на элементы справочника "РегистрацииВНалоговомОргане".
//
// Параметры:
//  Организация     - ссылка на элемент справочника организаций.
//  ПараметрыОтбора - структура (необязательный):
//    ключ "КодНО" (необязательный), значение - код налогового органа (строка);
//    ключ "КПП"   (необязательный), значение - КПП (строка);
//    ключ "ОКТМО" (необязательный), значение - код по ОКТМО (строка);
//    ключ "КодыПричиныПостановкиНаУчет" (необязательный), значение - символы в КПП на 5-6 позициях (массив);
//    ключ "ИскатьПоПервымСимволамОКТМО" (необязательный), значение - Булево - если Истина, тогда, вместо проверки на
//                                                         равенство ОКТМО в регистрации - значению по ключу "ОКТМО",
//                                                         будет выполняться проверка на равенство первых символов
//                                                         ОКТМО в регистрации - значению по ключу "ОКТМО".
//
Функция РегистрацииОрганизацииВНалоговомОргане(Организация, ПараметрыОтбора = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.РегистрацииОрганизацииВНалоговомОргане(Организация, ПараметрыОтбора);
```
</details>

## ПолучитьДанныеРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру с данными регламентированного отчета.
// Ключ структуры совпадает с наименованием раздела регл. отчета,
// значение структуры содержит данные раздела регл. отчета.
// Все разделы регл. отчета подразделяются на два вида: одностраничные, многостраничные.
// Одностраничные разделы имеют тип Структура, в которой содержатся имена показателей
// вместе с их значениями.
// Многостраничные разделы имеют тип ТаблицаЗначений. Каждый элемент таблицы значений
// - это отдельная страница раздела. Данные страницы содержатся в колонке Данные
// с типом Структура, в которой содержатся имена показателей вместе с их значениями.
//
// Возвращаемое значение: структура с данными регл. отчета.
//
// Параметры:
//  СсылкаНаСохрРеглОтчет - ссылка на сохраненный регламентированный отчет, данные которого нужно получить.
//
Функция ПолучитьДанныеРеглОтчета(СсылкаНаСохрРеглОтчет) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьДанныеРеглОтчета(СсылкаНаСохрРеглОтчет) 
```
</details>

## ПриОпределенииИспользуемыхВерсийВнешнихКомпонент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриОпределенииИспользуемыхВерсийВнешнихКомпонент(Идентификаторы) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПриОпределенииИспользуемыхВерсийВнешнихКомпонент(Идентификаторы) 
```
</details>

## ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) 
```
</details>

## ПрименяетсяУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения налогоплательщиком упрощенной системы налогообложения (УСН).
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на элемент справочника "Организации".
//   Период      - Дата - дата, на которую нужно определить применение УСН.
//
/// Возвращаемое значение:
//   Истина - налогоплательщик применяет УСН.
//   Ложь   - налогоплательщик не применяет УСН.
//
Функция ПрименяетсяУСН(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПрименяетсяУСН(Организация, Период) 
```
</details>

## ТребованияРосстатаПоОКУД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет сопоставление кодов ОКУД статистических отчетов
// и назначенных Росстатом требований
//
// Параметры:
//  МассивОКУД - Массив - массив ОКУД статистических отчетов (7 знаков)
//
// Возвращаемое значение:
//  Неопределено, ТаблицаЗначений - Требования росстата по ОКУД:
// * ОКУД - строка - запрошенный код ОКУД из параметра
// * Требования - массив - идентификаторы правил списка задач
//                (см. РегламентированнаяОтчетностьПовтИсп.ИсполнителиТребованийРосстата())
Функция ТребованияРосстатаПоОКУД(МассивОКУД) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ТребованияРосстатаПоОКУД(МассивОКУД) 
```
</details>

## ФорматВыгрузкиСтатистическойОтчетностиВЭлектронномВиде
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает значение формата выгрузки статотчетности
//
// Параметры:
//  Организация - СправочникСсылка.Организации
//
// Возвращаемое значение: Число 2.
//  2 - "новый"
//      (актуальный на сегодня формат ПО Росстата «Заполнение форм статистической отчетности», версии 2.4.4).
//
Функция ФорматВыгрузкиСтатистическойОтчетностиВЭлектронномВиде(Организация) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ФорматВыгрузкиСтатистическойОтчетностиВЭлектронномВиде(Организация) 
```
</details>

## КодыДляИмениФайлаВФорматеВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция преобразует значения, из которых формируется имя файла,
// в соответствии с форматом выгрузки статотчетности.
//
Функция КодыДляИмениФайлаВФорматеВыгрузки(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КодыДляИмениФайлаВФорматеВыгрузки(Параметры) 
```
</details>

## АтрибутыВФорматеВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция преобразует выгружаемые атрибуты,
// в соответствии с форматом выгрузки статотчетности.
//
Функция АтрибутыВФорматеВыгрузки(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.АтрибутыВФорматеВыгрузки(Параметры) 
```
</details>

## ПорядковыйНомерПериодаВГоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПорядковыйНомерПериодаВГоду(ДатаВПериоде, Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПорядковыйНомерПериодаВГоду(ДатаВПериоде, Периодичность));
```
</details>

## НачальныеОперацииСМногострочнымиБлоками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НачальныеОперацииСМногострочнымиБлоками(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.НачальныеОперацииСМногострочнымиБлоками(Форма) 
```
</details>

## ДопСведенияОПоказателе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДопСведенияОПоказателе(Форма, ИмяПоказателя, ИмяПараметра) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ДопСведенияОПоказателе(Форма, ИмяПоказателя, ИмяПараметра));
```
</details>

## ПоказательВходитВМногострочнуюЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПоказательВходитВМногострочнуюЧасть(Форма, ИмяПоказателя) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПоказательВходитВМногострочнуюЧасть(Форма, ИмяПоказателя) 
```
</details>

## КонвертированныеЗначенияПоказателейСтатистическойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КонвертированныеЗначенияПоказателейСтатистическойОтчетности(Форма, КонвертируемыеПоказатели, НаправлениеИзКонтейнера = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КонвертированныеЗначенияПоказателейСтатистическойОтчетности(Форма, КонвертируемыеПоказатели, НаправлениеИзКонтейнера);
```
</details>

## НоваяСтраница
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НоваяСтраница() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.НоваяСтраница() 
```
</details>

## СформироватьСтруктуруОбязательныхРеквизитовСтатистическогоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьСтруктуруОбязательныхРеквизитовСтатистическогоОтчета(Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СформироватьСтруктуруОбязательныхРеквизитовСтатистическогоОтчета(Организация);
```
</details>

## ЗаполнитьПоказателиОтчетаНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПоказателиОтчетаНаСервере(Форма, ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаполнитьПоказателиОтчетаНаСервере(Форма, ПоказателиОтчета) 
```
</details>

## ПолучитьПоказателиРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПоказателиРаздела(ДеревоВыгрузки, Раздел) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьПоказателиРаздела(ДеревоВыгрузки, Раздел) 
```
</details>

## ПоказательЗаполнен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПоказательЗаполнен(Показатель, Значение) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПоказательЗаполнен(Показатель, Значение) 
```
</details>

## СтраницаПуста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СтраницаПуста(ДанныеСтраницы, Показатели, ДеревоВыгрузки, НепроверяемыеПараметры, РодМногостр) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СтраницаПуста(ДанныеСтраницы, Показатели, ДеревоВыгрузки, НепроверяемыеПараметры, РодМногостр));
```
</details>

## РазделПуст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РазделПуст(Форма, ДеревоВыгрузки, Раздел, НепроверяемыеПараметры, РодМногостр) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.РазделПуст(Форма, ДеревоВыгрузки, Раздел, НепроверяемыеПараметры, РодМногостр));
```
</details>

## ПроверитьРазделыНаНаличиеИнформации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверитьРазделыНаНаличиеИнформации(Форма, ДеревоВыгрузки, парамРазделы, НепроверяемыеПараметры = Неопределено, РодМногостр = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПроверитьРазделыНаНаличиеИнформации(Форма, ДеревоВыгрузки, парамРазделы, НепроверяемыеПараметры, РодМногостр);
```
</details>

## ЧислоПоФормату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЧислоПоФормату(Значение, СтрокаФормата, УдалитьНезначащиеНулиПослеРазделителя = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЧислоПоФормату(Значение, СтрокаФормата, УдалитьНезначащиеНулиПослеРазделителя);
```
</details>

## ИзменитьВариантЗаполненияЯчейки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьВариантЗаполненияЯчейки(Форма, НовыйВариант, Показатель = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ИзменитьВариантЗаполненияЯчейки(Форма, НовыйВариант, Показатель);
```
</details>

## УстановитьЦветФорматДоступностьЯчеек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЦветФорматДоступностьЯчеек(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьЦветФорматДоступностьЯчеек(Форма) 
```
</details>

## ДобавитьЭлементВСтруктуруОшибок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьЭлементВСтруктуруОшибок(СтруктураОшибок, ТекстФормулы, ОписаниеКС, ОбщееЧислоОшибок, ОбщееЧислоБезОшибок, Расшифровка, Нарушение, Описание, ЭтоОшибка, Комментарий = "") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДобавитьЭлементВСтруктуруОшибок(СтруктураОшибок, ТекстФормулы, ОписаниеКС, ОбщееЧислоОшибок, ОбщееЧислоБезОшибок, Расшифровка, Нарушение, Описание, ЭтоОшибка, Комментарий);
```
</details>

## ДобавитьСтрокуОписанияВвода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСтрокуОписанияВвода(ТаблицаПараметров, Показатель, Длина, Тип = Неопределено, ТекстПриВыборе = Неопределено, Значения = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДобавитьСтрокуОписанияВвода(ТаблицаПараметров, Показатель, Длина, Тип, ТекстПриВыборе, Значения);
```
</details>

## ЗаполнитьНачальныеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНачальныеНастройки(Форма, Таблица = "ТаблицаВариантыЗаполненияПолеТабличногоДокументаФормаОтчета") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаполнитьНачальныеНастройки(Форма, Таблица);
```
</details>

## ЭтоСлужебнаяОбласть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоСлужебнаяОбласть(Имя) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЭтоСлужебнаяОбласть(Имя) 
```
</details>

## УдалитьНомерКорректировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьНомерКорректировки(ТитульнаяСтраница) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьНомерКорректировки(ТитульнаяСтраница) 
```
</details>

## УдалитьСлужебныеОбластиОтчетаСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьСлужебныеОбластиОтчетаСтатистики(СтруктураРеквизитовФормы, ИменаЭлементовУправленияСтроками) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьСлужебныеОбластиОтчетаСтатистики(СтруктураРеквизитовФормы, ИменаЭлементовУправленияСтроками) 
```
</details>

## СформироватьСпискиВыбораВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьСпискиВыбораВФоне(ПараметрыОтчета, АдресХранилища) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.СформироватьСпискиВыбораВФоне(ПараметрыОтчета, АдресХранилища) 
```
</details>

## УстановитьЗначениеИФорматВПоле
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЗначениеИФорматВПоле(ТекТабличноеПоле, ИмяПоказателя, ЗначениеПоказателя) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьЗначениеИФорматВПоле(ТекТабличноеПоле, ИмяПоказателя, ЗначениеПоказателя) 
```
</details>

## УстановитьФорматВыгрузкиСтатистическойОтчетностиВЭлектронномВиде
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции работы со статистическими отчетами.

Процедура УстановитьФорматВыгрузкиСтатистическойОтчетностиВЭлектронномВиде(Организация, Формат) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьФорматВыгрузкиСтатистическойОтчетностиВЭлектронномВиде(Организация, Формат) 
```
</details>

## ДополнитьРеквизитыСтатистическогоОтчетаДляЗагрузкиСправочников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьРеквизитыСтатистическогоОтчетаДляЗагрузкиСправочников(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДополнитьРеквизитыСтатистическогоОтчетаДляЗагрузкиСправочников(Форма) 
```
</details>

## СформироватьСтрокуИсточникОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьСтрокуИсточникОтчета(ДопАтрибуты) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СформироватьСтрокуИсточникОтчета(ДопАтрибуты) 
```
</details>

## ИнформацияЗагруженныхСправочников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИнформацияЗагруженныхСправочников(ИсточникОтчета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИнформацияЗагруженныхСправочников(ИсточникОтчета) 
```
</details>

## ЗагрузитьСправочникиШаблонаВРегистр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьСправочникиШаблонаВРегистр(ИмяФормы, ИсточникОтчета, МакетШаблона) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗагрузитьСправочникиШаблонаВРегистр(ИмяФормы, ИсточникОтчета, МакетШаблона) 
```
</details>

## УзелПуст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УзелПуст(Узел, ПоказателиНеанализируемыеНаЗаполненность = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.УзелПуст(Узел, ПоказателиНеанализируемыеНаЗаполненность);
```
</details>

## СкопироватьУзел
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СкопироватьУзел(Родитель, Узел) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СкопироватьУзел(Родитель, Узел) 
```
</details>

## ПолучитьПервыйПодчиненныйУзелСЗаполненнымКлючом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПервыйПодчиненныйУзелСЗаполненнымКлючом(Родитель) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьПервыйПодчиненныйУзелСЗаполненнымКлючом(Родитель) 
```
</details>

## УдалитьУзел
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьУзел(Узел) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьУзел(Узел) 
```
</details>

## УстановитьЗначениеЭлемента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЗначениеЭлемента(УзелРодитель, ИмяЭлемента, ЗначениеЭлемента) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьЗначениеЭлемента(УзелРодитель, ИмяЭлемента, ЗначениеЭлемента) 
```
</details>

## ВывестиПоказательВXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВывестиПоказательВXML(Узел, ЗначениеПоказателя) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВывестиПоказательВXML(Узел, ЗначениеПоказателя) 
```
</details>

## ПолучитьПодчиненныйЭлемент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПодчиненныйЭлемент(Узел, КодЭлемента) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьПодчиненныйЭлемент(Узел, КодЭлемента) 
```
</details>

## НовыйУзелИзПрототипа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйУзелИзПрототипа(ПрототипУзла) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.НовыйУзелИзПрототипа(ПрототипУзла) 
```
</details>

## ИзвлечьСтруктуруXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИзвлечьСтруктуруXML(ИмяФормы, ИмяМакета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИзвлечьСтруктуруXML(ИмяФормы, ИмяМакета) 
```
</details>

## ПолучитьДеревоВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДеревоВыгрузки(Форма, ИмяМакета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьДеревоВыгрузки(Форма, ИмяМакета) 
```
</details>

## ИмеютсяАналогичныеСоседниеУзлыКлючРаздел
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИмеютсяАналогичныеСоседниеУзлыКлючРаздел(Стр) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИмеютсяАналогичныеСоседниеУзлыКлючРаздел(Стр) 
```
</details>

## ИмеютсяАналогичныеСоседниеУзлыКлюч
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИмеютсяАналогичныеСоседниеУзлыКлюч(Стр) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИмеютсяАналогичныеСоседниеУзлыКлюч(Стр) 
```
</details>

## СоздатьНовыйПотокXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоздатьНовыйПотокXML(Кодировка = "utf-8") Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СоздатьНовыйПотокXML(Кодировка);
```
</details>

## УсловиеВыполнено
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УсловиеВыполнено(Владелец, ПараметрыВыгрузки, Условие, ИмяРаздела = "Титульный", Узел = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.УсловиеВыполнено(Владелец, ПараметрыВыгрузки, Условие, ИмяРаздела, Узел);
```
</details>

## ДополнитьСтруктуруПараметров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьСтруктуруПараметров(мДанныеОтчета, ПараметрыВыгрузки, Узел) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДополнитьСтруктуруПараметров(мДанныеОтчета, ПараметрыВыгрузки, Узел) 
```
</details>

## ДополнитьСтруктуруПараметровПрочиеОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьСтруктуруПараметровПрочиеОтчеты(мДанныеОтчета, ПараметрыВыгрузки, Узел) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДополнитьСтруктуруПараметровПрочиеОтчеты(мДанныеОтчета, ПараметрыВыгрузки, Узел) 
```
</details>

## ЗаписатьУзелДереваВXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьУзелДереваВXML(СтрокаДерева, ПотокXML, ПараметрыВыгрузки) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЗаписатьУзелДереваВXML(СтрокаДерева, ПотокXML, ПараметрыВыгрузки) 
```
</details>

## ЗначениеСоответствуетФормату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗначениеСоответствуетФормату(Форма, Стр) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЗначениеСоответствуетФормату(Форма, Стр) 
```
</details>

## ПредставлениеПоказателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПредставлениеПоказателя(Стр) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПредставлениеПоказателя(Стр) 
```
</details>

## ВывестиПоказательСтатистикиВXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВывестиПоказательСтатистикиВXML(Узел, ЗначениеПоказателя, ФорматПредставленияНуля = "") Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВывестиПоказательСтатистикиВXML(Узел, ЗначениеПоказателя, ФорматПредставленияНуля);
```
</details>

## ДополнитьДеревоВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьДеревоВыгрузки(ДеревоВыгрузки) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДополнитьДеревоВыгрузки(ДеревоВыгрузки) 
```
</details>

## ДополнитьДеревоВыгрузкиРек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьДеревоВыгрузкиРек(СтрДеревоВыгрузки) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДополнитьДеревоВыгрузкиРек(СтрДеревоВыгрузки));
```
</details>

## ОтсечьНезаполненныеНеобязательныеУзлыСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтсечьНезаполненныеНеобязательныеУзлыСтатистики(Узел) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОтсечьНезаполненныеНеобязательныеУзлыСтатистики(Узел) 
```
</details>

## ПроверитьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверитьДанные(Форма, Узел) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПроверитьДанные(Форма, Узел) 
```
</details>

## СформироватьСтруктуруДопАтрибутов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьСтруктуруДопАтрибутов(ИмяФормы, ИмяМакета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СформироватьСтруктуруДопАтрибутов(ИмяФормы, ИмяМакета) 
```
</details>

## ПолучитьВерсиюВыгрузкиСтатОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращеат формат выгрузки стат. отчета в формате **-**-****, например, 16-09-2013
// ИсточникОтчета - Строка, имя отчета, например, РегламентированныйОтчетСтатистикаФормаП1
// ИмяФормы - Строка, имя формы, например, ФормаОтчета2016Кв1
// ДопПараметры - Неопределено или структура с доп. параметрами
Функция ПолучитьВерсиюВыгрузкиСтатОтчета(ИсточникОтчета, ИмяФормы, ДопПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьВерсиюВыгрузкиСтатОтчета(ИсточникОтчета, ИмяФормы, ДопПараметры);
```
</details>

## ОбработатьУсловныеЭлементы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьУсловныеЭлементы(Форма, Знач ПараметрыВыгрузки, Узел) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОбработатьУсловныеЭлементы(Форма, ПараметрыВыгрузки, Узел) 
```
</details>

## ВыгрузитьДеревоВXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВыгрузитьДеревоВXML(ДеревоВыгрузки, ПараметрыВыгрузки, Кодировка = "utf-8") Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВыгрузитьДеревоВXML(ДеревоВыгрузки, ПараметрыВыгрузки, Кодировка);
```
</details>

## ЗаписатьРегламентированныйОтчетВРегистрЖурналОтчетовСтатусы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьРегламентированныйОтчетВРегистрЖурналОтчетовСтатусы(Ссылка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаписатьРегламентированныйОтчетВРегистрЖурналОтчетовСтатусы(Ссылка));
```
</details>

## ПолучитьКодОрганаФСГСРегистрацииРеспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьКодОрганаФСГСРегистрацииРеспондента(РегистрацияРеспондента) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьКодОрганаФСГСРегистрацииРеспондента(РегистрацияРеспондента));
```
</details>

## ПолучитьКодОрганаФСГСПоОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьКодОрганаФСГСПоОрганизации(ОрганизацияОтчета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьКодОрганаФСГСПоОрганизации(ОрганизацияОтчета));
```
</details>

## ПолучитьКодОрганаФСГССтатотчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьКодОрганаФСГССтатотчета(СсылкаНаОтчет) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьКодОрганаФСГССтатотчета(СсылкаНаОтчет) 
```
</details>

## ВидКонтролирующегоОргана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет вид государственного органа, в который сдается отчет переданного вида.
//
// Параметры:
//   ИмяОтчета - Строка - название регламентированного отчета, см. ИмяРеглОтчета().
//
// Возвращаемое значение:
//   ПеречислениеСсылка.ТипыКонтролирующихОрганов - вид государственного органа.
//
Функция ВидКонтролирующегоОргана(ИмяОтчета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВидКонтролирующегоОргана(ИмяОтчета) 
```
</details>

## ЗаписатьПрочиеОтчетыВЖурналОтчетовСтатусы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьПрочиеОтчетыВЖурналОтчетовСтатусы(Ссылка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаписатьПрочиеОтчетыВЖурналОтчетовСтатусы(Ссылка));
```
</details>

## ОпределитьСвойстваОбъектовДляОтображенияВФормеОтчетность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОпределитьСвойстваОбъектовДляОтображенияВФормеОтчетность(Ссылки) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ОпределитьСвойстваОбъектовДляОтображенияВФормеОтчетность(Ссылки) 
```
</details>

## ОпределениеСвойстваОбъектаДляОтображенииВФормеОтчетность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОпределениеСвойстваОбъектаДляОтображенииВФормеОтчетность(Ссылка, ЗначенияЗаполнения) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОпределениеСвойстваОбъектаДляОтображенииВФормеОтчетность(Ссылка, ЗначенияЗаполнения));
```
</details>

## КодОрганаФССИзДанныхОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодОрганаФССИзДанныхОтчета(ХранилищеДанныхОтчета) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КодОрганаФССИзДанныхОтчета(ХранилищеДанныхОтчета));
```
</details>

## ЗаписьОбъектовРегламентированнойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие "ЗаписьОбъектовРегламентированнойОтчетности".
//
Процедура ЗаписьОбъектовРегламентированнойОтчетности(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаписьОбъектовРегламентированнойОтчетности(Источник, Отказ) 
```
</details>

## ВыполнитьДействияПередУдалениемПрисоединенногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие "ВыполнитьДействияПередУдалениемПрисоединенногоФайлаБРО"
// (для изменения индекса картинки в регистре сведений "Журнал отчетов статусы" и признака
// наличия присоединенных файлов в регистре сведений "Журнал отправок в контролирующие органы").
//
// Параметры:
//  Источник   - СправочникОбъект - объект справочника с именем "*ПрисоединенныеФайлы".
//  Отказ      - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//
Процедура ВыполнитьДействияПередУдалениемПрисоединенногоФайла(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВыполнитьДействияПередУдалениемПрисоединенногоФайла(Источник, Отказ) 
```
</details>

## ВыполнитьДействияПриЗаписиПрисоединенногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие "ВыполнитьДействияПриЗаписиПрисоединенногоФайлаБРО"
// (для изменения индекса картинки в регистре сведений "Журнал отчетов статусы" и признака
// наличия присоединенных файлов в регистре сведений "Журнал отправок в контролирующие органы").
//
// Параметры:
//  Источник   - СправочникОбъект - объект справочника с именем "*ПрисоединенныеФайлы".
//  Отказ      - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//
Процедура ВыполнитьДействияПриЗаписиПрисоединенногоФайла(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВыполнитьДействияПриЗаписиПрисоединенногоФайла(Источник, Отказ) 
```
</details>

## ТаблицаОписанияОбъектовРегламентированнойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу для получения данных из переопределяемого метода
Функция ТаблицаОписанияОбъектовРегламентированнойОтчетности() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ТаблицаОписанияОбъектовРегламентированнойОтчетности() 
```
</details>

## РегламентированныйОтчетОтправляетсяВКонтролирующиеОрганы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает переменную "ОбъектОтправляется" в "Ложь", если регламентированный отчет не отправляется в контролирующие органы
Процедура РегламентированныйОтчетОтправляетсяВКонтролирующиеОрганы(ДокСсылка, ОбъектОтправляется) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.РегламентированныйОтчетОтправляетсяВКонтролирующиеОрганы(ДокСсылка, ОбъектОтправляется) 
```
</details>

## ДобавитьВДеревоРегламентированныхОтчетовДругиеОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет дерево видов отчетов другими видами, входящими и не входящими в БРО
Процедура ДобавитьВДеревоРегламентированныхОтчетовДругиеОтчеты(ДеревоОтчетов) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДобавитьВДеревоРегламентированныхОтчетовДругиеОтчеты(ДеревоОтчетов) 
```
</details>

## ДобавитьОтчетВДеревоРегламентированныхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьОтчетВДеревоРегламентированныхОтчетов(ДеревоОтчетов, ЗначенияКолонок) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДобавитьОтчетВДеревоРегламентированныхОтчетов(ДеревоОтчетов, ЗначенияКолонок));
```
</details>

## ФормаРегламентированнойОтчетности_ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормаРегламентированнойОтчетности_ПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ФормаРегламентированнойОтчетности_ПриСозданииНаСервере(Форма) 
```
</details>

## СправочникРегламентированныеОтчеты_ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СправочникРегламентированныеОтчеты_ПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.СправочникРегламентированныеОтчеты_ПриСозданииНаСервере(Форма) 
```
</details>

## КоличествоОбъектовНеЗаписанныхВРегистр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КоличествоОбъектовНеЗаписанныхВРегистр(ПараметрыПроцедуры) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КоличествоОбъектовНеЗаписанныхВРегистр(ПараметрыПроцедуры) 
```
</details>

## ВыполнитьПроверку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьПроверку(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВыполнитьПроверку(Параметры, АдресХранилища) 
```
</details>

## ДобавлениеОбъектовОтсутствующихВРегистре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДобавлениеОбъектовОтсутствующихВРегистре(ПараметрыПроцедуры) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ДобавлениеОбъектовОтсутствующихВРегистре(ПараметрыПроцедуры) 
```
</details>

## ВыполнитьДобавлениеВРегистр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьДобавлениеВРегистр(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВыполнитьДобавлениеВРегистр(Параметры, АдресХранилища) 
```
</details>

## ОбработатьСобытие1СОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьСобытие1СОтчетности(ИмяСобытия, СсылкаНаИсточник = Неопределено, ДопПараметрСтруктура = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОбработатьСобытие1СОтчетности(ИмяСобытия, СсылкаНаИсточник, ДопПараметрСтруктура);
```
</details>

## ПолучитьСписокДоступныхЮридическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает список организаций - юридических лиц.
//
// Параметры:
//  СписокЮрЛиц - СписокЗначений - список организаций, являющихся юридическими лицами
//  Текст       - Строка - подстрока поиска в наименовании организации.
//
Процедура ПолучитьСписокДоступныхЮридическихЛиц(СписокЮрЛиц = Неопределено, Знач Текст = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПолучитьСписокДоступныхЮридическихЛиц(СписокЮрЛиц, Текст);
```
</details>

## ПолучитьСписокДоступныхИндивидуальныхПредпринимателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает список организаций - индивидуальных предпринимателей.
//
// Параметры:
//  СписокФизЛиц - СписокЗначений - список организаций, являющихся индивидуальными предпринимателями
//  Текст        - Строка - подстрока поиска в наименовании организации.
//
Процедура ПолучитьСписокДоступныхИндивидуальныхПредпринимателей(СписокФизЛиц = Неопределено, Знач Текст = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПолучитьСписокДоступныхИндивидуальныхПредпринимателей(СписокФизЛиц, Текст);
```
</details>

## ДополнитьСтрокуСпециальнымиСимволами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательная процедура, дополняющая передаваемую строку спец. символами.
//
// Параметры:
//  Текст - Строка.
//
Процедура ДополнитьСтрокуСпециальнымиСимволами(Знач Текст = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ДополнитьСтрокуСпециальнымиСимволами(Текст);
```
</details>

## ВсеЮрФизЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВсеЮрФизЛица(ЮрЛицо) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВсеЮрФизЛица(ЮрЛицо) 
```
</details>

## ПолучитьМассивФормСтатистикиТолькоДляОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивФормСтатистикиТолькоДляОрганизации() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьМассивФормСтатистикиТолькоДляОрганизации());
```
</details>

## ПолучитьМассивФормСтатистикиТолькоДляИП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивФормСтатистикиТолькоДляИП() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьМассивФормСтатистикиТолькоДляИП());
```
</details>

## УстановитьОтборВФормеВыбораОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОтборВФормеВыбораОтчета(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УстановитьОтборВФормеВыбораОтчета(Форма) 
```
</details>

## ОтчетыОценкиРисков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОтчетыОценкиРисков(Организация, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ОтчетыОценкиРисков(Организация, ДатаНачала, ДатаОкончания));
```
</details>

## НоваяТаблицаПоказателейОценкиРисков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НоваяТаблицаПоказателейОценкиРисков() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.НоваяТаблицаПоказателейОценкиРисков());
```
</details>

## ВставитьПоказательВТаблицуОценкиРисков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВставитьПоказательВТаблицуОценкиРисков(ТаблицаПоказателей, ОписаниеОтчета) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВставитьПоказательВТаблицуОценкиРисков(ТаблицаПоказателей, ОписаниеОтчета));
```
</details>

## ЧислоВСтрокуЧГ0
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЧислоВСтрокуЧГ0(ИсходноеЧисло) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ЧислоВСтрокуЧГ0(ИсходноеЧисло) 
```
</details>

## ЗапомнитьИменаСправочниковОбособленныхПодразделений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗапомнитьИменаСправочниковОбособленныхПодразделений(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗапомнитьИменаСправочниковОбособленныхПодразделений(Форма) 
```
</details>

## ЗаполнитьДанныеВШапкеОбособленныхПодразделений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДанныеВШапкеОбособленныхПодразделений(Форма, ИмяТД = "ПолеТабличногоДокументаФормаОтчета") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаполнитьДанныеВШапкеОбособленныхПодразделений(Форма, ИмяТД);
```
</details>

## ПолучитьСписокДоступныхОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает список организаций - юридических лиц и индивидуальных предпринимателей.
//
// Параметры:
//  СписокЮрФизЛиц - СписокЗначений - список юридических лиц и индивидуальных предпринимателей
//  Текст          - Строка - подстрока поиска в наименовании организации.
//
Процедура ПолучитьСписокДоступныхОрганизаций(СписокЮрФизЛиц = Неопределено, Знач Текст = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПолучитьСписокДоступныхОрганизаций(СписокЮрФизЛиц, Текст);
```
</details>

## ПоказательОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПоказательОтчета(ИсточникСведений, ИмяПоказателя) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПоказательОтчета(ИсточникСведений, ИмяПоказателя) 
```
</details>

## КомментарийКПроверкеВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КомментарийКПроверкеВыгрузки(СсылкаНаСтрокуСообщения) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КомментарийКПроверкеВыгрузки(СсылкаНаСтрокуСообщения));
```
</details>

## КомментарийКВыгрузкеРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КомментарийКВыгрузкеРеглОтчета(СсылкаНаОбъект) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КомментарийКВыгрузкеРеглОтчета(СсылкаНаОбъект));
```
</details>

## КомментарийКСозданиюРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КомментарийКСозданиюРеглОтчета(СсылкаНаОбъект) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.КомментарийКСозданиюРеглОтчета(СсылкаНаОбъект));
```
</details>

## УдалитьДополнительныеФайлыДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет все записи регистра дополнительных файлов, ссылающиеся
// на указанный документ регламентированного отчета.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации.
//
Процедура УдалитьДополнительныеФайлыДекларацииНДС(ДекларацияНДС) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьДополнительныеФайлыДекларацииНДС(ДекларацияНДС) 
```
</details>

## ЗаписатьСегментТабличногоДокументаРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет сформированный сегмент пользовательского представления раздела декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   ИмяРаздела - Строка - имя раздела;
//   НомерПервойСтроки - Число - номер первой строки, отраженной в сегменте;
//   ПредставлениеСегмента - Табличный документ - сегмент пользовательского представления раздела декларации по НДС.
//
Процедура ЗаписатьСегментТабличногоДокументаРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки, ПредставлениеСегмента) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаписатьСегментТабличногоДокументаРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки, ПредставлениеСегмента) 
```
</details>

## СегментТабличногоДокументаРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Считывает из регистра сформированный сегмент пользовательского представления раздела декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   ИмяРаздела - Строка - имя раздела;
//   НомерПервойСтроки - Число - номер первой строки, отраженной в сегменте;
// Возвращаемое значение:
//   Табличный документ - сегмент пользовательского представления раздела декларации по НДС.
//
Функция СегментТабличногоДокументаРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СегментТабличногоДокументаРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки) 
```
</details>

## УдалитьСегментыТабличногоДокументаРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет сегменты пользовательского представления раздела декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   ИмяРаздела - Строка - имя раздела;
//
Процедура УдалитьСегментыТабличногоДокументаРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьСегментыТабличногоДокументаРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) 
```
</details>

## ЗаписатьИтогиРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет итоги для выгрузки электронного представления декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   ИмяРаздела - Строка - имя раздела;
//   Итоги - Структура - Структура с итогами для формирования электронного представления декларации.
//
Процедура ЗаписатьИтогиРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, Итоги) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаписатьИтогиРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, Итоги) 
```
</details>

## ИтогиРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Считывает из регистра итоги для выгрузки электронного представления декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   ИмяРаздела - Строка - имя раздела, с которым связаны данные;
// Возвращаемое значение:
//   Структура - Структура с итогами для формирования электронного представления декларации.
//
Функция ИтогиРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИтогиРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) 
```
</details>

## УдалитьИтогиРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет из регистра итоги для выгрузки электронного представления декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   ИмяРаздела - Строка - имя раздела, с которым связаны данные;
//
Процедура УдалитьИтогиРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьИтогиРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) 
```
</details>

## ЗаписатьСегментДанныхРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет сформированный сегмент данных раздела для выгрузки электронного представления декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   Раздел - Строка - имя раздела;
//   НомерПервойСтроки - Число - номер первой строки, отраженной в сегменте;
//   СегментДанных - Таблица значений - сегмент данных раздела для выгрузки.
//
Процедура ЗаписатьСегментДанныхРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки, СегментДанных) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаписатьСегментДанныхРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки, СегментДанных) 
```
</details>

## СегментДанныхРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Считывает из регистра сегмент данных раздела для выгрузки электронного представления декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   Раздел - Строка - имя раздела;
//   НомерПервойСтроки - Число - номер первой строки, отраженной в сегменте;
// Возвращаемое значение:
//   Таблица значений - сегмент данных раздела для выгрузки.
//
Функция СегментДанныхРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.СегментДанныхРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела, НомерПервойСтроки) 
```
</details>

## УдалитьСегментыДанныхРазделаДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет из регистра сегменты данных раздела для выгрузки электронного представления декларации по НДС.
// Параметры:
//   ДекларацияНДС - ДокументСсылка.РегламентированныйОтчет - ссылка на документ, в котором сохраняются данные декларации;
//   Раздел - Строка - имя раздела;
//
Процедура УдалитьСегментыДанныхРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УдалитьСегментыДанныхРазделаДекларацииНДС(ДекларацияНДС, ИмяРаздела) 
```
</details>

## ПолучитьТекущуюТаблицуФорматов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекущуюТаблицуФорматов() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьТекущуюТаблицуФорматов() 
```
</details>

## ОбновитьШаблоныЧерезВебСервисНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьШаблоныЧерезВебСервисНаСервере(Контекст, ИмяМакета) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОбновитьШаблоныЧерезВебСервисНаСервере(Контекст, ИмяМакета) 
```
</details>

## ОбновитьШаблоныЧерезВебСервисНаСервереВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьШаблоныЧерезВебСервисНаСервереВФоне(ПараметрыКоманды, АдресРезультата = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОбновитьШаблоныЧерезВебСервисНаСервереВФоне(ПараметрыКоманды, АдресРезультата);
```
</details>

## ОбновитьШаблоныСпискомЧерезВебСервисНаСервереВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьШаблоныСпискомЧерезВебСервисНаСервереВФоне(ПараметрыКоманды, АдресРезультата = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОбновитьШаблоныСпискомЧерезВебСервисНаСервереВФоне(ПараметрыКоманды, АдресРезультата);
```
</details>

## ИзменитьВерсиюФорматаСПроверкойСовместимостиШаблонов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьВерсиюФорматаСПроверкойСовместимостиШаблонов(Форма, ИмяМакетаАттрибутов, ИмяМакетаШаблона, ПараметрыВыгрузки) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ИзменитьВерсиюФорматаСПроверкойСовместимостиШаблонов(Форма, ИмяМакетаАттрибутов, ИмяМакетаШаблона, ПараметрыВыгрузки) 
```
</details>

## ПолучитьДанныеШаблона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДанныеШаблона(Форма, ИмяМакетаАттрибутов, ИмяМакетаШаблона, ПараметрыВыгрузки, НоваяВерсия) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьДанныеШаблона(Форма, ИмяМакетаАттрибутов, ИмяМакетаШаблона, ПараметрыВыгрузки, НоваяВерсия) 
```
</details>

## ПроверкаФорматаПоПериодуПрименения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверкаФорматаПоПериодуПрименения(ПараметрыДляПроверки, ВерсияШаблона) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПроверкаФорматаПоПериодуПрименения(ПараметрыДляПроверки, ВерсияШаблона) 
```
</details>

## ИмяФайлаВыгрузкиСНовымКодомФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИмяФайлаВыгрузкиСНовымКодомФормы(ИмяФайлаВыгрузки, НовыйКодФормы) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИмяФайлаВыгрузкиСНовымКодомФормы(ИмяФайлаВыгрузки, НовыйКодФормы));
```
</details>

## ДатаВерсии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДатаВерсии(СтрДата) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ДатаВерсии(СтрДата));
```
</details>

## ПриИнициализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриИнициализации(Форма, Объект) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПриИнициализации(Форма, Объект) 
```
</details>

## ПередЗаписьюНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПередЗаписьюНаСервере(Форма, ТекущийОбъект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПередЗаписьюНаСервере(Форма, ТекущийОбъект, ПараметрыЗаписи) 
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеЗаписиНаСервере(Форма, ТекущийОбъект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПослеЗаписиНаСервере(Форма, ТекущийОбъект, ПараметрыЗаписи) 
```
</details>

## ВыполнитьЗадачу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьЗадачу(Форма, Контекст, Источник) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВыполнитьЗадачу(Форма, Контекст, Источник) 
```
</details>

## УправлениеДоступностьюРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УправлениеДоступностьюРеквизитов(Форма, БлокируемыеЭлементы, ТолькоПросмотр) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.УправлениеДоступностьюРеквизитов(Форма, БлокируемыеЭлементы, ТолькоПросмотр) 
```
</details>

## ПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриЧтенииНаСервере(Форма, Объект) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПриЧтенииНаСервере(Форма, Объект));
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриСозданииНаСервере(Форма, Объект) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ПриСозданииНаСервере(Форма, Объект));
```
</details>

## ЗапретитьРедактированиеРеквизитовСданногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из процедуры "ПриИнициализацииФормыРегламентированногоОтчетаОбщиеДействия"
// размещенной в модуле "РегламентированнаяОтчетностьКлиентСервер".
//
Процедура ЗапретитьРедактированиеРеквизитовСданногоОтчета(Форма, КонтролирующийОрган = "ФНС") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗапретитьРедактированиеРеквизитовСданногоОтчета(Форма, КонтролирующийОрган);
```
</details>

## РазрешитьРедактированиеРеквизитовОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из процедур, вызванных обработчиком команды "РазрешитьРедактированиеРеквизитовОбъекта"
// размещенной в форме регламентированного отчета.
//
Процедура РазрешитьРедактированиеРеквизитовОтчета(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.РазрешитьРедактированиеРеквизитовОтчета(Форма) 
```
</details>

## ЗаполнитьСведенияОПредставителеАвансовогоПлатежаАкциза
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОПредставителеАвансовогоПлатежаАкциза( Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ЗаполнитьСведенияОПредставителеАвансовогоПлатежаАкциза();
```
</details>

## ПолучитьПоКодамСведенияОПредставителеПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПоКодамСведенияОПредставителеПрибыль(Организация, КодНО, КПП = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ПолучитьПоКодамСведенияОПредставителеПрибыль(Организация, КодНО, КПП);
```
</details>

## ИспользуютсяРегистрацииВОрганеСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИспользуютсяРегистрацииВОрганеСтатистики() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ИспользуютсяРегистрацииВОрганеСтатистики() 
```
</details>

## ВывестиШапкуРегистрацияРеспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВывестиШапкуРегистрацияРеспондента(ТабличноеПоле) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ВывестиШапкуРегистрацияРеспондента(ТабличноеПоле) 
```
</details>

## ОбновитьОбластьРегистрацииРеспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьОбластьРегистрацииРеспондента(Форма, ИмяТД = "ПолеТабличногоДокументаФормаОтчета") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетность.ОбновитьОбластьРегистрацииРеспондента(Форма, ИмяТД);
```
</details>

## ВидимостьОбластиРегистрацииРеспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВидимостьОбластиРегистрацииРеспондента(Форма, ИмяТД = "ПолеТабличногоДокументаФормаОтчета") Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетность.ВидимостьОбластиРегистрацииРеспондента(Форма, ИмяТД);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
