---
title: Регламентированная отчетность клиент переопределяемый
slug: zup/регламентированная-отчетность-клиент-переопределяемый
---


## ОткрытьРасшифровкуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции механизма расшифровки.

// Процедура выводит форму расшифровки.
//
// Параметры:
//	 ИДОтчета - Строка - идентификатор отчета (совпадает с именем объекта метаданных).
// 	 ИДРедакцииОтчета - Строка - идентификатор редакции формы отчета (совпадает с именем формы объекта метаданных).
//   ИДИменПоказателей - Массив - массив идентификаторов имен показателей, по которым формируется расшифровка.
//   ПараметрыОтчета - Структура - структура параметров отчета, необходимых для формирования расшифровки.
//
// Пример:
// 	 Если ИДОтчета = "РегламентированныйОтчетБухОтчетность" Тогда
//	 	 Если ИДРедакцииОтчета = "ФормаОтчета2011Кв1" Тогда
//		 	 ОткрытьРасшифровкуБухОтчетностьФормаОтчета2011Кв1(ИДИменПоказателей, ПараметрыОтчета);
//		 КонецЕсли;
// 	 КонецЕсли;
//
Процедура ОткрытьРасшифровкуОтчета(ИДОтчета, ИДРедакцииОтчета, ИДИменПоказателей, ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьРасшифровкуОтчета(ИДОтчета, ИДРедакцииОтчета, ИДИменПоказателей, ПараметрыОтчета) 
```
</details>

## ОткрытьФормуПомощникаПоУчетуНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму помощника по учету НДС.
//
Процедура ОткрытьФормуПомощникаПоУчетуНДС(ПараметрыОткрытияПомощника) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуПомощникаПоУчетуНДС(ПараметрыОткрытияПомощника) 
```
</details>

## ОткрытьФормуНастройкиПодписантов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действия по интерактивному заполнению лиц, ответственных за подписание статистических
// (и, возможно, других) отчетов. Вызывается из контекста формы отчета.
//
// Параметры:
//	 Параметры - Структура - структура со свойствами:
//     * Организация - Справочник.Организации - организация рег. отчета.
//	   * ОбособленноеПодразделение - Справочник.Подразделение - подразделение (если есть на форме).
//	   * ДатаПодписи - Дата - дата подписи отчета.
//	   * ИмяОбъектаМетаданных - Строка - имя метаданных отчета.
//	   * ТекущееПоле - Строка - текущее поле для настройки
//							    (ФИОПодписантСтатистика, ДолжностьПодписантСтатистика,
//								 ТелефонПодписантСтатистика, ЕмейлПодписантСтатистика).
//								Состав полей может быть расширен при необходимости.
//	  ОповещениеОбОкончании - ОписаниеОповещения - вызывается после настройки подписантов (с новыми данными).
//												   В качестве параметров передается структура,
//												   в которой могут быть свойства (состав свойств может быть
//												   расширен при необходимости):
//	    * ФИОПодписантСтатистика - Строка - ФИО подписанта.
//		* ДолжностьПодписантСтатистика - Строка - должность подписанта.
//		* ТелефонПодписантСтатистика - Строка - телефон подписанта.
//		* ЕмейлПодписантСтатистика - Строка - эл. почта подписанта.
//
// Пример реализации:
//	 ПараметрыВыбранного = Новый Структура;
//	 ... // действия по открытию форм (например, регистра ответственных лиц)
//	 ... // получение актуальных данных (например, пользователь изменил телефон ответственного) подписантов и т.п.
//	 ... // заполнение ПараметрыВыбранного актуальными данными
//	 ВыполнитьОбработкуОповещения(ОповещениеОбОкончании, ПараметрыВыбранного);
//
Процедура ОткрытьФормуНастройкиПодписантов(Параметры, ОповещениеОбОкончании) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуНастройкиПодписантов(Параметры, ОповещениеОбОкончании) 
```
</details>

## ИмяФормыДляУплатыНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции календаря бухгалтера.

// Функция возвращает имя формы, используемой для уплаты налога.
//
// Возвращаемое значение:
//   Строка - имя формы, используемой для уплаты налога.
//
// Пример:
//  Возврат "Документ.ПлатежноеПоручение.ФормаОбъекта";
//
Функция ИмяФормыДляУплатыНалога() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентПереопределяемый.ИмяФормыДляУплатыНалога() 
```
</details>

## ОткрытьКалендарь
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции списка задач бухгалтера.

// Процедура открывает форму списка задач бухгалтера.
//
// Параметры:
//   Владелец - Форма - владелец формы.
//   Организация - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ОткрытьКалендарь(Владелец, Организация, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьКалендарь(Владелец, Организация, СтандартнаяОбработка) 
```
</details>

## ПриСозданииРСВ_1ИзСпискаРеглОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции интерфейса взаимодействия с конфигурациями (библиотеками)
// - потребителями.

// Процедура переопределяет создание формы РСВ-1 из списка регламентированных отчетов.
//
// Параметры:
//   ОписаниеРСВ_1 - Структура - структура с полями:
//     * Организация             - СправочникСсылка.Организации - организация;
//     * ДатаНачалаПериодаОтчета - Дата - дата начала периода отчета;
//     * ДатаКонцаПериодаОтчета  - Дата - дата конца периода отчета;
//     * КорректирующаяФорма     - Булево - признак корректирующей формы.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ПриСозданииРСВ_1ИзСпискаРеглОтчетов(ОписаниеРСВ_1, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПриСозданииРСВ_1ИзСпискаРеглОтчетов(ОписаниеРСВ_1, СтандартнаяОбработка) 
```
</details>

## ПриОткрытииРСВ_1ИзЖурналаРеглОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет открытие формы РСВ-1 из журнала регламентированных отчетов.
//
// Параметры:
//   Ссылка - ДокументСсылка.РегламентированныйОтчет - ссылка на регламентированный отчет.
//   ОписаниеРСВ_1 - Структура - структура с полями:
//     * Организация             - СправочникСсылка.Организации - организация;
//     * ДатаНачалаПериодаОтчета - Дата - дата начала периода отчета;
//     * ДатаКонцаПериодаОтчета  - Дата - дата конца периода отчета;
//     * КорректирующаяФорма     - Булево - признак корректирующей формы.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ПриОткрытииРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПриОткрытииРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) 
```
</details>

## ПриПечатиРСВ_1ИзЖурналаРеглОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет поведение при печати формы РСВ-1 из журнала регламентированных отчетов.
//
// Параметры:
//   Ссылка - ДокументСсылка.РегламентированныйОтчет - ссылка на регламентированный отчет.
//   ОписаниеРСВ_1 - Структура - структура с полями:
//     * Организация             - СправочникСсылка.Организации - организация;
//     * ДатаНачалаПериодаОтчета - Дата - дата начала периода отчета;
//     * ДатаКонцаПериодаОтчета  - Дата - дата конца периода отчета;
//     * КорректирующаяФорма     - Булево - признак корректирующей формы.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ПриПечатиРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПриПечатиРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) 
```
</details>

## ПриВыгрузкеРСВ_1ИзЖурналаРеглОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет поведение при выгрузке формы РСВ-1 из журнала регламентированных отчетов.
//
// Параметры:
//   Ссылка - ДокументСсылка.РегламентированныйОтчет - ссылка на регламентированный отчет.
//   ОписаниеРСВ_1 - Структура - структура с полями:
//     * Организация             - СправочникСсылка.Организации - организация;
//     * ДатаНачалаПериодаОтчета - Дата - дата начала периода отчета;
//     * ДатаКонцаПериодаОтчета  - Дата - дата конца периода отчета;
//     * КорректирующаяФорма     - Булево - признак корректирующей формы.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ПриВыгрузкеРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПриВыгрузкеРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) 
```
</details>

## ПриПроверкеВыгрузкиРСВ_1ИзЖурналаРеглОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет поведение при проверке выгрузки формы РСВ-1 из журнала регламентированных отчетов.
//
// Параметры:
//   Ссылка        - ДокументСсылка.РегламентированныйОтчет - ссылка на регламентированный отчет.
//   ОписаниеРСВ_1 - Структура - структура с полями:
//     * Организация             - СправочникСсылка.Организации - организация;
//     * ДатаНачалаПериодаОтчета - Дата - дата начала периода отчета;
//     * ДатаКонцаПериодаОтчета  - Дата - дата конца периода отчета;
//     * КорректирующаяФорма     - Булево - признак корректирующей формы.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ПриПроверкеВыгрузкиРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПриПроверкеВыгрузкиРСВ_1ИзЖурналаРеглОтчетов(Ссылка, ОписаниеРСВ_1, СтандартнаяОбработка) 
```
</details>

## ПредупредитьОбИзменениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает форму с информацией об изменениях.
//
// Параметры:
//  ИмяОтчета - Строка - имя отчета в дереве объектов метаданных;
//  ИмяФормы  - Строка - имя формы отчета;
//  Форма     - УправляемаФорма - форма, из которой вызывается процедура.
//
Процедура ПредупредитьОбИзменениях(ИмяОтчета, ИмяФормы, Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПредупредитьОбИзменениях(ИмяОтчета, ИмяФормы, Форма) 
```
</details>

## ИзменитьПризнакВыводаПредупрежденияОбИзменениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура изменяет признак вывода предупреждения об изменениях.
//
// Параметры:
//  ИмяОтчета - Строка - имя отчета в дереве объектов метаданных;
//  ИмяФормы  - Строка - имя формы отчета;
//  ТребуетсяПредупредитьОбИзменениях - Булево - признак вывода предупреждения об изменениях;
//  Форма     - УправляемаФорма - форма, из которой вызывается процедура.
//
Процедура ИзменитьПризнакВыводаПредупрежденияОбИзменениях(ИмяОтчета, ИмяФормы, ТребуетсяПредупредитьОбИзменениях, Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ИзменитьПризнакВыводаПредупрежденияОбИзменениях(ИмяОтчета, ИмяФормы, ТребуетсяПредупредитьОбИзменениях, Форма) 
```
</details>

## ПередОткрытиемФормыУведомления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Если требуются какие-то особые действия при открытии уведомления надо выставить СтандартнаяОбработка = Ложь
// В этом случае уведомление не создается, а требуемые действия можно проделать в процедуре ОбработчикСозданияУведомления(...)
//
// Параметры:
//   Организация          - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   ВидУведомления       - Перечисление.ВидыУведомленийОСпецрежимахНалогообложения - вид уведомления.
//   СтандартнаяОбработка - Булево - признак стандартной обработки.
//
Процедура ПередОткрытиемФормыУведомления(Организация, ВидУведомления, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПередОткрытиемФормыУведомления(Организация, ВидУведомления, СтандартнаяОбработка) 
```
</details>

## ОбработчикСозданияУведомления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При переопределенном действии при создании уведомления здесь прописывается что именно надо сделать
//
// Параметры:
//   Форма - Форма - форма 1с-отчетности.
//   Параметр - Структура - "Организация", "ВидУведомления".
//
Процедура ОбработчикСозданияУведомления(Форма, Параметр) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОбработчикСозданияУведомления(Форма, Параметр) 
```
</details>

## ПередЗаполнениемОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура уточняет данные для автозаполнения уведомления
//
// Параметры:
//   ИДОтчета             - Строка - имя отчета в дереве объектов метаданных.
//   ПараметрыОтчета      - Структура - структура обязательных параметров.
//   ФормаОтчета          - УправляемаФорма - ссылка на заполняемую форму уведомления.
//   ОписаниеОповещения   - ОписаниеОповещения - процедура для продолжения процедуры автозаполнения.
//   СтандартнаяОбработка - Булево - если Истина то никакой новой информации не добавляется для автозаполнения,
//                                   необходимо продолжить автозаполнение в самой форме.
//
Процедура ПередЗаполнениемОтчета(ИДОтчета, ПараметрыОтчета, ФормаОтчета, ОписаниеОповещения, СтандартнаяОбработка = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПередЗаполнениемОтчета(ИДОтчета, ПараметрыОтчета, ФормаОтчета, ОписаниеОповещения, СтандартнаяОбработка);
```
</details>

## ПодробнееОбОчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет вывод дополнительной информации о регламентированном отчете
//
// Параметры:
//   Ссылка                    - ДокументСсылка.РегламентированныйОтчет - ссылка на регламентированный отчет.
//   ИмяФормыПодробнееОбОтчете - Строка - имя формы, которая будет открыта с параметром "Ссылка" для предоставления дополнительной информации об отчете.
//   СтандартнаяОбработка      - Булево - если Истина - будет открыта форма по имени: "Обработка.ОбщиеОбъектыРеглОтчетности.Форма." + ИмяФормыПодробнееОбОтчете;
//                                        иначе - можно выполнить свой алгоритм обработки ПодробнееОбОчете().
//
Процедура ПодробнееОбОчете(Ссылка, ИмяФормыПодробнееОбОтчете, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПодробнееОбОчете(Ссылка, ИмяФормыПодробнееОбОтчете, СтандартнаяОбработка) 
```
</details>

## ФормаРегламентированнойОтчетности_ОбработкаОповещения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет функционал обработчика "ОбработкаОповещения" общей формы "Регламентированная отчетность",
// здесь можно добавить новую функциональность к существующей обработке оповещения.
//
// Параметры:
//  ИмяСобытия - Строка - Имя события может быть использовано для идентификации сообщений принимающими их формами.
//  Параметр   - Параметр сообщения. Могут быть переданы любые необходимые данные.
//  Источник   - Источник события. Например, в качестве источника может быть указана другая форма.
//  Форма      - ФормаКлиентскогоПриложения - Общая форма "Регламентированная отчетность".
//
// Пример:
//  Если ИмяСобытия = "Получены новые сообщения 1С-Отчетности" И Источник <> Форма Тогда
//      Оповестить("Закрыть форму новых сообщений 1С-Отчетности",, Форма);
//  КонецЕсли;
//
Процедура ФормаРегламентированнойОтчетности_ОбработкаОповещения(ИмяСобытия, Параметр, Источник, Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ФормаРегламентированнойОтчетности_ОбработкаОповещения(ИмяСобытия, Параметр, Источник, Форма) 
```
</details>

## ОткрытьФормуВыбораКодаПоОКВЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает форму выбора кода по ОКВЭД.
//
// Параметры:
//  ВыполняемоеОповещение - ОписаниеОповещения - описание оповещения, которое будет вызвано после выполнения
//  						 данной операции.
//  						 Дополнительные параметры передаются в свойстве ДополнительныеПараметры описания оповещения -
//  						 Структура - структура с полями:
//  						   * ВариантОКВЭД (обязателен)   - Строка - вариант классификатора ("ОКВЭД" или "ОКВЭД2");
//  						   * ТекущийКод   (необязателен) - Строка - код по ОКВЭД (для позиционирования в списке выбора).
//  						 Возвращаемый результат выбора - Структура - структура с полями (обязательными):
//  						   * КодОКВЭД          - Строка - код по ОКВЭД;
//  						   * НаименованиеОКВЭД - Строка - наименование по ОКВЭД.
//  СтандартнаяОбработка  - Булево - признак выполнения ВыполняемоеОповещение.
//  						 Если выполняется - необходимо установить Ложь. Значение по умолчанию - Истина.
//
// Пример:
//  СтандартнаяОбработка = Ложь;
//  ПараметрыФормы = Новый Структура;
//  ПараметрыФормы.Вставить("ТипОбъекта",      "Справочник");
//  ПараметрыФормы.Вставить("НазваниеОбъекта", "Организации");
//  ПараметрыФормы.Вставить("НазваниеМакета",  ВыполняемоеОповещение.ДополнительныеПараметры.ВариантОКВЭД);
//  Если ВыполняемоеОповещение.ДополнительныеПараметры.Свойство("ТекущийКод") Тогда
//  	ПараметрыФормы.Вставить("ТекущийКод", ВыполняемоеОповещение.ДополнительныеПараметры.ТекущийКод);
//  КонецЕсли;
//  ПараметрыФормы.Вставить("ТекущийПериод", ТекущаяДата());
//  ПараметрыФормы.Вставить("Комментарий",   "");
//  ОписаниеОповещения = Новый ОписаниеОповещения("ОткрытьФормуВыбораКодаПоОКВЭДЗавершение",
//  ОбщегоНазначенияКлиент.ОбщийМодуль("РегламентированнаяОтчетностьКлиентПереопределяемый"),
//  ВыполняемоеОповещение);
//  ОткрытьФорму("ОбщаяФорма.ФормаВыбораКода", ПараметрыФормы,,,,, ОписаниеОповещения);
//
// Пример процедуры "ОткрытьФормуВыбораКодаПоОКВЭДЗавершение" (служебного интерфейса):
//  Процедура ОткрытьФормуВыбораКодаПоОКВЭДЗавершение(РезультатВыбора, ВыполняемоеОповещение) Экспорт
//  	Если ТипЗнч(РезультатВыбора) = Тип("Строка") Тогда
//  		ОКВЭД = ОбщегоНазначенияБПВызовСервера.ПолучитьКлассификатор(
//  		ВыполняемоеОповещение.ДополнительныеПараметры.ВариантОКВЭД);
//  		ВозвращаемыйРезультат = Новый Структура(
//  		"КодОКВЭД, НаименованиеОКВЭД", РезультатВыбора, ОКВЭД.Получить(РезультатВыбора));
//  		ВыполнитьОбработкуОповещения(ВыполняемоеОповещение, ВозвращаемыйРезультат);
//  	КонецЕсли;
//  КонецПроцедуры
//
Процедура ОткрытьФормуВыбораКодаПоОКВЭД(ВыполняемоеОповещение, СтандартнаяОбработка = Истина) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуВыбораКодаПоОКВЭД(ВыполняемоеОповещение, СтандартнаяОбработка);
```
</details>

## ОткрытьФормуДляЗаполненияРегистрирующегоОргана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает форму для заполнения регистрирующего органа организации.
//
// Параметры:
//  Организация           - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//  ВыполняемоеОповещение - ОписаниеОповещения - описание оповещения, которое будет вызвано после выполнения
//                          данной операции.
//
// Пример:
//  ПараметрыФормы = Новый Структура;
//  ПараметрыФормы.Вставить("Ключ", Организация);
//  ОткрытьФорму("Справочник.Организации.Форма.ФормаОрганизации", ПараметрыФормы,,,,, ВыполняемоеОповещение);
//
Процедура ОткрытьФормуДляЗаполненияРегистрирующегоОргана(Организация, ВыполняемоеОповещение) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуДляЗаполненияРегистрирующегоОргана(Организация, ВыполняемоеОповещение) 
```
</details>

## ОткрытьФормуНастроекПередАвтозаполнениемРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает форму настроек непосредственно перед автозаполнением регламентированного отчета
// (например, сразу после нажатия кнопки "Заполнить" в форме регламентированного отчета), если в последнем
// поддерживается такая возможность.
//
// Параметры:
//  ВыполняемоеОповещение - ОписаниеОповещения - описание оповещения, которое будет вызвано после выполнения
//                          данной операции.
//                          Параметры передаются в свойстве ДополнительныеПараметры описания оповещения -
//                          Структура - структура с проивольными полями, позволяющими идентифицировать отчет.
//                          Возвращаемый результат - Структура - структура с полями (обязательно одно из полей):
//                            * НастройкиАвтозаполнения - Структура - параметы автозаполнения, которые будут переданы
//                                                        в свойстве "НастройкиАвтозаполнения" параметров отчета
//                                                        процедуры "ЗаполнитьОтчет" общего модуля
//                                                        "РегламентированнаяОтчетностьПереопределяемый";
//                            * ТекстПриОтказе - Строка - текст для выдачи предупреждения и прерывания автозаполнения.
//
// Пример (перед автозаполнением отчета "РегламентированныйОтчетДвижениеСредствПоСчетуВБанкеЗаПределамиРФ"):
//  ПараметрыОповещения = Новый Структура;
//  ПараметрыОповещения.Вставить("ВыполняемоеОповещение", ВыполняемоеОповещение);
//  ОповещениеОВыборе = Новый ОписаниеОповещения("ОткрытьФормуВыбораСчетаЗавершение", ЭтотОбъект, ПараметрыОповещения);
//  ДополнительныеПараметры = ВыполняемоеОповещение.ДополнительныеПараметры;
//  Организация = ДополнительныеПараметры.Организация;
//  СписокИностранныхБанков = УчетДенежныхСредствВызовСервера.СписокИностранныхБанков();
//  НастройкиКомпоновки = Новый НастройкиКомпоновкиДанных;
//  ЭлементОтбора = НастройкиКомпоновки.Отбор.Элементы.Добавить(Тип("ЭлементОтбораКомпоновкиДанных"));
//  ЭлементОтбора.ЛевоеЗначение  = Новый ПолеКомпоновкиДанных("Банк");
//  ЭлементОтбора.ВидСравнения   = ВидСравненияКомпоновкиДанных.ВСписке;
//  ЭлементОтбора.Использование  = Истина;
//  ЭлементОтбора.ПравоеЗначение = СписокИностранныхБанков;
//  ПараметрыОтбора = Новый Структура;
//  ПараметрыОтбора.Вставить("Владелец", Организация);
//  ПараметрыФормы = Новый Структура;
//  ПараметрыФормы.Вставить("ФиксированныеНастройки", НастройкиКомпоновки);
//  ПараметрыФормы.Вставить("Отбор", ПараметрыОтбора);
//  ПараметрыФормы.Вставить("РежимВыбора", Истина);
//  ОткрытьФорму("Справочник.БанковскиеСчета.ФормаВыбора", ПараметрыФормы,,,,, ОповещениеОВыборе);
//
Процедура ОткрытьФормуНастроекПередАвтозаполнениемРеглОтчета(ВыполняемоеОповещение) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуНастроекПередАвтозаполнениемРеглОтчета(ВыполняемоеОповещение) 
```
</details>

## ДобавитьПрикладныеФормыОтправкаОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура дополняет перечень форм, в которые дополнительно встроены функции отправки регламентированной отчетности.
//
// Параметры:
//  ИменаФорм	 - Массив - список имен форм
//
Процедура ДобавитьПрикладныеФормыОтправкаОтчетов(ИменаФорм) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ДобавитьПрикладныеФормыОтправкаОтчетов(ИменаФорм) 
```
</details>

## ОткрытьФормуПомощникаУплатыНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает форму помощника уплаты налога для заполнения регламентированного отчета "Налог на прибыль".
//
// Параметры:
//  Организация      - СправочникСсылка.Организации - организация
//  ДатаКонцаПериода - Дата - дата конца периода отчета
//  ПараметрыПравила - Структура - параметры правила для списка задач бухгалтера
//
Процедура ОткрытьФормуПомощникаУплатыНалога(Организация, ДатаКонцаПериода, ПараметрыПравила) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуПомощникаУплатыНалога(Организация, ДатаКонцаПериода, ПараметрыПравила) 
```
</details>

## ПерейтиВРабочееМестоПФР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Служебные процедуры и функции.

// Процедура вызывается в формах отчета "РегламентированныйОтчетРСВ1"
// при нажатии кнопки перехода в специализированное рабочее место подготовки
// отчетности в ПФР.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   ДатаНачалаПериодаОтчета - Дата - дата начала периода отчета.
//   ДатаКонцаПериодаОтчета - Дата - дата конца периода отчета.
//
Процедура ПерейтиВРабочееМестоПФР(Организация, ДатаНачалаПериодаОтчета, ДатаКонцаПериодаОтчета) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПерейтиВРабочееМестоПФР(Организация, ДатаНачалаПериодаОтчета, ДатаКонцаПериодаОтчета) 
```
</details>

## ВыполнитьНазначаемуюКомандуНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выполняет назначаемую команду формы.
//
// Параметры:
//   Форма - Форма - форма, из которой вызвана команда.
//
Процедура ВыполнитьНазначаемуюКомандуНаКлиенте(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ВыполнитьНазначаемуюКомандуНаКлиенте(Форма) 
```
</details>

## ФормаРегламентированнойОтчетности_ВыполнитьНазначаемуюКомандуНаКлиенте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выполняет назначаемую команду формы "РегламентированнаяОтчетность".
//
// Параметры:
//   Форма   - Форма - форма, из которой вызвана команда.
//   Команда - КомандаФормы - назначенная команда формы.
//
// Пример:
//   Если Команда.Имя = "ОтчетыПоказатьДополнительнуюИнформацию" Тогда
//   	ПоказатьПредупреждение(, "Заполните обработчик команды """ + Команда.Имя + """");
//   КонецЕсли;
//
Процедура ФормаРегламентированнойОтчетности_ВыполнитьНазначаемуюКомандуНаКлиенте(Форма, Команда) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ФормаРегламентированнойОтчетности_ВыполнитьНазначаемуюКомандуНаКлиенте(Форма, Команда) 
```
</details>

## ФормаРегламентированнойОтчетности_ИмяФормыВыбораПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет имя формы выбора периода для установки отбора в форме "1С Отчетность".
//
// Параметры:
//  ПолноеИмяФормыВыбораПериода  - Строка - Полный путь к форме выбора периода.
//
// Пример:
//  ПолноеИмяФормыВыбораПериода = "ОбщаяФорма.ВыборПроизвольногоПериода";
//
Процедура ФормаРегламентированнойОтчетности_ИмяФормыВыбораПериода(ПолноеИмяФормыВыбораПериода) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ФормаРегламентированнойОтчетности_ИмяФормыВыбораПериода(ПолноеИмяФормыВыбораПериода) 
```
</details>

## ФормаРегламентированнойОтчетности_ОпределениеФормыВыбораВидаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет имя и параметры открытия формы выбора отчета для установки отбора в форме "1С Отчетность".
//
// Параметры:
//  ПолноеИмяФормыВыбораВидаОтчета - Строка - Полный путь к форме выбора вида отчета.
//  ПараметрыФормыВыбораВидаОтчета - Структура - Параметры открытия формы выбора вида отчета.
//
// Пример:
//  ПолноеИмяФормыВыбораВидаОтчета = "ОбщаяФорма.ФормаПодбораЗначенийВСписок";
//
Процедура ФормаРегламентированнойОтчетности_ОпределениеФормыВыбораВидаОтчета(ПолноеИмяФормыВыбораВидаОтчета, Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ФормаРегламентированнойОтчетности_ОпределениеФормыВыбораВидаОтчета(ПолноеИмяФормыВыбораВидаОтчета, );
```
</details>

## ПроверитьНастройкиЗаполненияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Процедура проверяет, выполнялась ли ранее настройка автозаполнения.
//
// Параметры:
//   ПараметрыОтчета       - Структура - параметры регл. отчета.
//   ВыполняемоеОповещение - ОписаниеОповещения - Описание оповещения, которое будет вызвано после выполнения данной операции.
//                                                В качестве результата описания оповещения должно передаваться булево значение,
//												  от которого зависит будет ли выполнятся дальнейший код в процедуре,
//												  которая вызвала этот метод.
//
Процедура ПроверитьНастройкиЗаполненияОтчета(ПараметрыОтчета, ВыполняемоеОповещение) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПроверитьНастройкиЗаполненияОтчета(ПараметрыОтчета, ВыполняемоеОповещение) 
```
</details>

## ПроверитьНастройкиАвтозаполненияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет, выполнялась ли ранее настройка автозаполнения.
//
// Параметры:
//   ПараметрыОтчета       - Структура - параметры регл. отчета.
//   ВыполняемоеОповещение - ОписаниеОповещения - Описание оповещения, которое будет вызвано после выполнения данной
//											 	  операции. В качестве результата описания оповещения должно
//												  передаваться булево значение, от которого зависит будет ли выполнятся
//												  дальнейший код в процедуре, которая вызвала этот метод.
//   СтандартнаяОбработка  - Булево - по умолчанию Истина. Если потребитель будет совершать какие-то действия
//														   с последующим выполнением ОписаниеОповещения необходимо
//														   выставить флажок в Ложь.
//
Процедура ПроверитьНастройкиАвтозаполненияОтчета(ПараметрыОтчета, ВыполняемоеОповещение, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПроверитьНастройкиАвтозаполненияОтчета(ПараметрыОтчета, ВыполняемоеОповещение, СтандартнаяОбработка) 
```
</details>

## ОткрытьФормуНастройкиАвтозаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает форму настройки автозаполнения.
//
// Параметры:
//   ПараметрыФормы - Структура - параметры настройки автозаполнения формы.
//
Процедура ОткрытьФормуНастройкиАвтозаполнения(ПараметрыФормы) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуНастройкиАвтозаполнения(ПараметрыФормы) 
```
</details>

## Выгрузить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура реализует выгрузку объектов, отображаемых на закладке Отчеты и Уведомления формы Отчетность.
// Параметры:
//	 Ссылка - СправочникСсылка, ДокументСсылка - ссылка на объект, который необходимо выгрузить.
//                                               Если для данного объекта выгрузка невозможна,
//                                               нужно выдавать соответствующее предупреждение.
//	 УникальныйИдентификаторФормы - УникальныйИдентификатор - уникальный идентификатор вызывающей формы ("1С-Отчетность").
//
Процедура Выгрузить(Ссылка, УникальныйИдентификаторФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.Выгрузить(Ссылка, УникальныйИдентификаторФормы);
```
</details>

## СоздатьНовыйОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура реализует создание объектов, отображаемых на закладке Уведомления и Отчетность формы Отчетность, не входящие в состав БРО.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, по которой нужно создать объект.
//  Тип - Тип - тип объекта, который необходимо создать.
//  СтандартнаяОбработка - Булево - если СтандартнаяОбработка = Истина, то будет выполнено создание объекта стандартным образом.
//
Процедура СоздатьНовыйОбъект(Организация, Тип, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.СоздатьНовыйОбъект(Организация, Тип, СтандартнаяОбработка) 
```
</details>

## ОбработкаВыбораПоляОбособленныхПодразделений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает окно выбора обособленных подразделений в случае, когда стандартный механизм
// по каким-либо причинам не может быть использован.
// Вызывается из форм статистики (ЗП-*, П-4 и некоторых других).
// В качестве callback-процедуры следует использовать РегламентированнаяОтчетностьКлиент.ОбработкаВыбораОбособленногоПодразделения.
//
// Параметры:
//   Форма - Форма - форма отчета откуда открывается выбор подразделения.
//   СтандартнаяОбработка - Булево - если отработано необходимо выставить СтандартнаяОбработка = Ложь.
//
// Пример для ЗУП 3.0 КОРП:
//   Там форма выбора это форма списка с параметром открытия РежимВыбора = Истина
//   СтандартнаяОбработка = Ложь;
//   Отбор = Новый Структура("Владелец, ИмеетНомерТерриториальногоОрганаРосстата", Форма.СтруктураРеквизитовФормы.Организация, Истина);
//   Параметры = Новый Структура("Отбор, РежимВыбора", Отбор, Истина);
//   ОповещениеОЗакрытии = Новый ОписаниеОповещения("ОбработкаВыбораОбособленногоПодразделения", РегламентированнаяОтчетностьКлиент, Новый Структура("Форма", Форма));
//   ОткрытьФорму("Справочник.ПодразделенияОрганизаций.ФормаВыбора",Параметры,Форма,,,,ОповещениеОЗакрытии,РежимОткрытияОкнаФормы.БлокироватьОкноВладельца);
//
Процедура ОбработкаВыбораПоляОбособленныхПодразделений(Форма, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОбработкаВыбораПоляОбособленныхПодразделений(Форма, СтандартнаяОбработка) 
```
</details>

## ПроверитьВладельцаПриОткрытииПрисоединенныхФайловИзСпискаОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура определяет, открывать или нет из формы "1С-Отчетность" файлы, присоединенные к объекту.
//
// Параметры:
//  ПараметрыПроверки - Структура:
//   "Владелец"             - СправочникСсылка, ДокументСсылка - ссылка на объект;
//   "ТекстПредупреждения"  - Строка - если заполнен и СтандартнаяОбработка = Ложь, то будет выведено предупреждение;
//   "СтандартнаяОбработка" - Булево - если Ложь, открытие присоединенных файлов не выполняется.
//
// Пример:
//  Если ТипЗнч(ПараметрыПроверки.Владелец) = Тип("СправочникСсылка.МакетыПенсионныхДел") Тогда
//
//  	ПараметрыПроверки.СтандартнаяОбработка = Ложь;
//
//  	ПараметрыПроверки.ТекстПредупреждения = НСтр(
//  	"ru='Присоединение файлов к ""Макетам пенсионных дел"" из списка отчетов не предусмотрено'");
//
//  КонецЕсли;
//
Процедура ПроверитьВладельцаПриОткрытииПрисоединенныхФайловИзСпискаОтчетов(ПараметрыПроверки) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПроверитьВладельцаПриОткрытииПрисоединенныхФайловИзСпискаОтчетов(ПараметрыПроверки) 
```
</details>

## ОткрытьФормуЗакрытияМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму закрытия месяца.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - ссылка на элемент справочника "Организации".
//  ПериодРегистрации - Дата - закрываемый период.
//
// Пример реализации:
//  ПараметрыФормы = Новый Структура;
//  ПараметрыФормы.Вставить("Организация", Организация);
//  ПараметрыФормы.Вставить("ПериодРегистрации", ПериодРегистрации);
//  ОткрытьФорму("Обработка.ЗакрытиеМесяца.Форма.Форма", ПараметрыФормы, ЭтотОбъект);
//
Процедура ОткрытьФормуЗакрытияМесяца(Организация, ПериодРегистрации) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуЗакрытияМесяца(Организация, ПериодРегистрации) 
```
</details>

## ПроверитьВозможностьАвтоЗаполненияРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность автоматического заполнения регламентированного отчета по данным ИБ конфигурации.
//
// Параметры:
//  ИмяФормы - Строка - имя формы регламентированного отчета;
//  Отказ - Булево - признак отказа от автозаполнения регл. отчета.
//
// Пример реализации:
//  Если НЕ ТарификацияБПВызовСервераПовтИсп.РазрешенУчетРегулярнойДеятельности() Тогда
//  	ТарификацияБПКлиент.ОповеститьОбОграниченииТарифа(ИмяФормы + ".ЗаполнитьАвто");
//      Отказ = Истина;
//  КонецЕсли;
//
Процедура ПроверитьВозможностьАвтоЗаполненияРеглОтчета(ИмяФормы, Отказ) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ПроверитьВозможностьАвтоЗаполненияРеглОтчета(ИмяФормы, Отказ) 
```
</details>

## ОткрытьФормуВыбораСпискаКонтрактов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму для интерактивного выбора контрактов и дальнейшего помещения по адресу во временном хранилище
// коллекции реквизитов, идентифицирующих контракты, используемой для выборочного заполнения отчета
// "РегламентированныйОтчетИсполнениеКонтрактовГОЗ".
//
// Параметры:
//  Организация                        - СправочникСсылка.Организации - ссылка на элемент справочника "Организации".
//  ДатаСоставленияОтчета              - Дата - дата составления отчета "РегламентированныйОтчетИсполнениеКонтрактовГОЗ".
//  АдресВоВременномХранилищеКонтракты - Строка - адрес во временном хранилище, по которому надо поместить коллекцию
//                                       (возможны типы значений коллекции: Массив, ТаблицаЗначений, ДеревоЗначений,
//                                       Структура) реквизитов, идентифицирующих контракты (возможны простые типы
//                                       значений реквизитов).
//
// Пример реализации:
//  ОткрытьФорму("Отчет.ИсполнениеКонтрактовГОЗ.Форма.ФормаВыбораКонтрактов", СтруктураПараметров);
//
Процедура ОткрытьФормуВыбораСпискаКонтрактов(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуВыбораСпискаКонтрактов(СтруктураПараметров) 
```
</details>

## ОткрытьФормуПодбораНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму подбора номерклатуры, возвращает запрашиваемый список параметров
//
// Параметры:
//  СтандартнаяОбработка                - Булево, необходимо установить Истина, если потребитель будет реализовывать данный функционал
//  ОповещениеОЗакрытии                 - ОписаниеОповещения, оповещение, выполняемое после подбора
//  Владелец                            - ФормаКлиентскогоПриложения, рег.отчет/уведомление, открывающее подбор номенклатуры
//  ЗапрашиваемыеПоказатели             - Строка, через запятую перечисляются запрашиваемые параметры
Процедура ОткрытьФормуПодбораНоменклатуры(СтандартнаяОбработка, ОповещениеОЗакрытии, Владелец, ЗапрашиваемыеПоказатели) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентПереопределяемый.ОткрытьФормуПодбораНоменклатуры(СтандартнаяОбработка, ОповещениеОЗакрытии, Владелец, ЗапрашиваемыеПоказатели) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
