---
title: Регламентированная отчетность клиент сервер
slug: zup/регламентированная-отчетность-клиент-сервер
---


## ПолучитьПолноеИмяВременногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует полное имя временного файла во временном каталоге.
// В случае если передан путь каталога, используется переданное значение.
// В случае если передано имя файла, используется переданное имя (вычленяется в общем случае короткое имя без пути).
// В случае передачи некорректных значений имен каталога и/или имени файла - заменяются на сгенерированные.
//
// Имеет смысл использовать в случае когда требуется временный файл во временном каталоге с определенным коротким именем.
// Например при формировании архива ZIP.
// В случаях когда короткое имя файла значения не имеет, нужно использовать ИмяФайла = ПолучитьИмяВременногоФайла().
// В этом случае формируемое имя будет короче на длину имени временного каталога, что иногда имеет значение
// в силу ограничений на максимальную длину полного пути файла.
//
// Параметры:
//		КаталогВремФайлов  - Строка или пустое значение любого типа или неопределено.
//							Возвращается имя каталога для результата.
// 		ИмяФайла		   - Строка или пустое значение любого типа или неопределено.
//							Возвращается короткое имя файла для результата.
//		УдалятьЕслиУжеЕсть - Булево. Необязательный. По умолчанию Истина.
//							Признак необходимости удаления существующего в каталоге КаталогВремФайлов
//							файла с именем ИмяФайла. Если Ложь, генерируется новое ИмяФайла.
//
// Возвращаемое значение:
// 		Строка - полное имя, включая каталог, временного файла во временном каталоге.
//
Функция ПолучитьПолноеИмяВременногоФайла(КаталогВремФайлов, ИмяФайла, УдалятьЕслиУжеЕсть = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПолучитьПолноеИмяВременногоФайла(КаталогВремФайлов, ИмяФайла, УдалятьЕслиУжеЕсть);
```
</details>

## ВернутьЗначениеПараметраСЛиста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает значение текущего показателя.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - управляемая форма регл. отчета.
//   ИмяРаздела - Строка - имя раздела регл. отчета.
//   ИмяОбласти - Строка - имя области.
//
// Возвращаемое значение:
//   Строка - значение текущего показателя.
//
Функция ВернутьЗначениеПараметраСЛиста(Форма, ИмяРаздела, ИмяОбласти) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ВернутьЗначениеПараметраСЛиста(Форма, ИмяРаздела, ИмяОбласти) 
```
</details>

## ПолучитьСвойствоРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства раздела.
//
Функция ПолучитьСвойствоРаздела(Форма, Знач ИмяСтраницы, Знач ИмяСвойства, ВозвращаемоеЗначение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПолучитьСвойствоРаздела(Форма, ИмяСтраницы, ИмяСвойства, ВозвращаемоеЗначение);
```
</details>

## СвойствоОпределено
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак определения свойства.
//
Функция СвойствоОпределено(Объект, ИмяСвойства) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СвойствоОпределено(Объект, ИмяСвойства) 
```
</details>

## СохранитьДанныеМногостраничногоРазделаВактивнойСтранице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет данные многостраничного раздела текущей страницы.
//
Процедура СохранитьДанныеМногостраничногоРазделаВактивнойСтранице(Форма, ИмяТекущейСтраницы, ОчищатьРазделЕслиЕстьМногострочность) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.СохранитьДанныеМногостраничногоРазделаВактивнойСтранице(Форма, ИмяТекущейСтраницы, ОчищатьРазделЕслиЕстьМногострочность) 
```
</details>

## ЯвляетсяЧислом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли переданное значение числом.
//
Функция ЯвляетсяЧислом(Значение) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ЯвляетсяЧислом(Значение) 
```
</details>

## ПредставлениеАдресаВФормате9Запятых
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает адрес в формате 9-ти запятых.
//
Функция ПредставлениеАдресаВФормате9Запятых(Знач АдресВФормате9Запятых, АнализироватьРегион = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПредставлениеАдресаВФормате9Запятых(АдресВФормате9Запятых, АнализироватьРегион);
```
</details>

## ОбновитьСтруктуруМногострочногоРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет структуру многострочного раздела.
//
Процедура ОбновитьСтруктуруМногострочногоРаздела(Форма, ИмяГруппы) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОбновитьСтруктуруМногострочногоРаздела(Форма, ИмяГруппы) 
```
</details>

## ОчиститьТабличноеПоле
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает табличное поле.
//
Процедура ОчиститьТабличноеПоле(Форма, Знач ВыбТабличноеПолеИмя) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОчиститьТабличноеПоле(Форма, ВыбТабличноеПолеИмя) 
```
</details>

## УдалитьДопСтрокиМногострочнойЧастиРегОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет дополнительные строки многострочной части регламентированного отчета.
//
Процедура УдалитьДопСтрокиМногострочнойЧастиРегОтчета(Форма, ИдГруппы, ОбновлятьБлок = Истина) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.УдалитьДопСтрокиМногострочнойЧастиРегОтчета(Форма, ИдГруппы, ОбновлятьБлок);
```
</details>

## ПроставитьВКвадратыЗначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проставляет значения в квадратиках.
//
Процедура ПроставитьВКвадратыЗначения(Форма, Знач Лист, Знач Показатель, Знач Размерность, Знач Значение, ДополнитьЗначение = Ложь, НольКакНоль = Ложь) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПроставитьВКвадратыЗначения(Форма, Лист, Показатель, Размерность, Значение, ДополнитьЗначение, НольКакНоль);
```
</details>

## ДополнитьСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет строку.
//
Функция ДополнитьСтроку(Знач Стр, Длина, Чем=" ", Режим = 0) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ДополнитьСтроку(Стр, Длина, Чем, Режим);
```
</details>

## ОбновитьСтруктуруМногостраничныхРазделов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет структуру многостраничных разделов.
//
Процедура ОбновитьСтруктуруМногостраничныхРазделов(Форма, ИмяСтраницы = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОбновитьСтруктуруМногостраничныхРазделов(Форма, ИмяСтраницы);
```
</details>

## СвойстваГрупповыхЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает свойство групповых значений.
//
Процедура СвойстваГрупповыхЗначений(Форма, ИмяЯчейки, Операция, ЦветФона = Неопределено, ИмяСтраницы = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.СвойстваГрупповыхЗначений(Форма, ИмяЯчейки, Операция, ЦветФона, ИмяСтраницы);
```
</details>

## ПолучитьСмысловуюЧастьИмениЯчейки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает смысловую часть имени ячейки.
//
Функция ПолучитьСмысловуюЧастьИмениЯчейки(ИмяЯчейки, Определение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПолучитьСмысловуюЧастьИмениЯчейки(ИмяЯчейки, Определение);
```
</details>

## ВывестиРазделВТабличныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит раздел в табличный документ.
//
Процедура ВывестиРазделВТабличныйДокумент(Форма, ИмяГруппы, СтруктураГруппы) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ВывестиРазделВТабличныйДокумент(Форма, ИмяГруппы, СтруктураГруппы) 
```
</details>

## ПоказательВходитВМногострочнуюЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, входит ли показатель в многострочную часть.
//
Функция ПоказательВходитВМногострочнуюЧасть(Форма, ИмяПоказателя) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПоказательВходитВМногострочнуюЧасть(Форма, ИмяПоказателя) 
```
</details>

## ПолучитьТаблицуОтчетовДействующихВВыбранныйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу отчетов, действующих в выбранном отчетном периоде.
//
Функция ПолучитьТаблицуОтчетовДействующихВВыбранныйПериод(Форма) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПолучитьТаблицуОтчетовДействующихВВыбранныйПериод(Форма) 
```
</details>

## ОбновитьСтруктуруМногострочныхРазделов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет структуру многострочных разделов.
//
Процедура ОбновитьСтруктуруМногострочныхРазделов(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОбновитьСтруктуруМногострочныхРазделов(Форма) 
```
</details>

## КолвоЛистоВРазделе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает количество листов в разделе.
//
Функция КолвоЛистоВРазделе(Форма, ИмяСтраницыПанели) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.КолвоЛистоВРазделе(Форма, ИмяСтраницыПанели) 
```
</details>

## УстановитьЦветФонаЯчейки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает цвет фона ячейки.
//
Процедура УстановитьЦветФонаЯчейки(Форма, ИмяЯчейки = Неопределено, ВариантЗаполнения = Неопределено, ИмяТекущейСтраницыПанели = "") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.УстановитьЦветФонаЯчейки(Форма, ИмяЯчейки, ВариантЗаполнения, ИмяТекущейСтраницыПанели);
```
</details>

## ОбластьЯвляетсяЯчейкойСоставногоПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли ячейка составным полем.
//
Функция ОбластьЯвляетсяЯчейкойСоставногоПоля(Форма, ИмяЯчейки, БыстраяПроверка = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ОбластьЯвляетсяЯчейкойСоставногоПоля(Форма, ИмяЯчейки, БыстраяПроверка);
```
</details>

## КППСоответствуетТребованиям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет значение КПП на соответствие требованиям.
//
Функция КППСоответствуетТребованиям(Знач КПП) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.КППСоответствуетТребованиям(КПП) 
```
</details>

## ПоказатьКнопкиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает кнопки печати.
//
Процедура ПоказатьКнопкиПечати(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПоказатьКнопкиПечати(Форма) 
```
</details>

## УстановитьФорматВывода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает формат вывода.
//
Процедура УстановитьФорматВывода(Форма, НаимРаздела) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.УстановитьФорматВывода(Форма, НаимРаздела) 
```
</details>

## ПредставлениеДокументаРеглОтч
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление регламентированного отчета.
//
Функция ПредставлениеДокументаРеглОтч(Док) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПредставлениеДокументаРеглОтч(Док) 
```
</details>

## ОКВЭДСоответствуетТребованиям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет значение ОКВЭД на соответствие формату.
//
Функция ОКВЭДСоответствуетТребованиям(Знач ОКВЭД) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ОКВЭДСоответствуетТребованиям(ОКВЭД) 
```
</details>

## РазложитьАдрес
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает разложенную структуру адреса.
//
Функция РазложитьАдрес(Знач СтрокаАдрес) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.РазложитьАдрес(СтрокаАдрес) 
```
</details>

## СохранитьЗначениеВМногостраничномБлоке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет значение в многостраничном блоке.
//
Процедура СохранитьЗначениеВМногостраничномБлоке(Форма, Знач ИмяГруппы, Знач НомерСтрокиНаФорме, Знач ИмяКолонки, Знач ЗначениеПоказателя) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.СохранитьЗначениеВМногостраничномБлоке(Форма, ИмяГруппы, НомерСтрокиНаФорме, ИмяКолонки, ЗначениеПоказателя) 
```
</details>

## ПослеВставкиДополнительнойСтраницы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается после вставки дополнительной страницы.
//
Процедура ПослеВставкиДополнительнойСтраницы(Форма, ИмяВставляемойСтраницы, ПерейтиНаВставленныйЛист = Истина) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПослеВставкиДополнительнойСтраницы(Форма, ИмяВставляемойСтраницы, ПерейтиНаВставленныйЛист);
```
</details>

## ОчиститьПоказателиОтчетаЗаполняемыеИзИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает показатели отчета, заполняемые из ИБ.
//
Процедура ОчиститьПоказателиОтчетаЗаполняемыеИзИБ(Форма, НазванияМногостраничныхРазделовДляУдаления = "") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОчиститьПоказателиОтчетаЗаполняемыеИзИБ(Форма, НазванияМногостраничныхРазделовДляУдаления);
```
</details>

## ОчиститьВариантыЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает варианты заполнения.
//
Процедура ОчиститьВариантыЗаполнения(Форма, Знач Раздел = Неопределено, УстановитьЦветВРазделе = Истина, Знач ИмяСекции = "") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОчиститьВариантыЗаполнения(Форма, Раздел, УстановитьЦветВРазделе, ИмяСекции);
```
</details>

## ИзменитьТаблицуВариантовЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет таблицу вариантов заполнения.
//
Процедура ИзменитьТаблицуВариантовЗаполнения(Форма, ПолныйРучнойВвод = Ложь) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ИзменитьТаблицуВариантовЗаполнения(Форма, ПолныйРучнойВвод);
```
</details>

## ПроставлениеНомеровЛистов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает номера листов.
//
Процедура ПроставлениеНомеровЛистов(Объект, ПризнакНумеруемыхФорм, СписокПечатаемыхЛистов) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПроставлениеНомеровЛистов(Объект, ПризнакНумеруемыхФорм, СписокПечатаемыхЛистов) 
```
</details>

## СформироватьСтруктуруПараметровФайлаВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру параметров файла выгрузки.
//
Функция СформироватьСтруктуруПараметровФайлаВыгрузки(ФайлВыгрузки) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СформироватьСтруктуруПараметровФайлаВыгрузки(ФайлВыгрузки) 
```
</details>

## ПроставитьСведенияОПредставителеОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает сведения о представителе организации.
//
Процедура ПроставитьСведенияОПредставителеОрганизации(Владелец, ФлагТолькоФЛ) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПроставитьСведенияОПредставителеОрганизации(Владелец, ФлагТолькоФЛ) 
```
</details>

## РазобратьСтрокуВМассивПоРазделителю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает строку в массив.
//
Функция РазобратьСтрокуВМассивПоРазделителю(Знач Стр, СтрРазделитель = ".") Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.РазобратьСтрокуВМассивПоРазделителю(Стр, СтрРазделитель);
```
</details>

## ПолучитьРеквизит
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение реквизита.
//
Функция ПолучитьРеквизит(Реквизит1, Реквизит2) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПолучитьРеквизит(Реквизит1, Реквизит2) 
```
</details>

## ПустоеЗначениеТипа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет тип на пустое значение.
//
Функция ПустоеЗначениеТипа(ЗаданныйТип) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПустоеЗначениеТипа(ЗаданныйТип) 
```
</details>

## СформироватьТекстСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст сообщения об ошибке.
//
Функция СформироватьТекстСообщения(Знач ТекстСообщения) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СформироватьТекстСообщения(ТекстСообщения) 
```
</details>

## СообщитьОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сообщение об ошибке.
//
Процедура СообщитьОбОшибке(Знач ТекстСообщения, Отказ, Заголовок = "", Знач Статус = Неопределено, ВызыватьИсключение = Истина) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.СообщитьОбОшибке(ТекстСообщения, Отказ, Заголовок, Статус, ВызыватьИсключение);
```
</details>

## ПослеОчисткиРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается после очистки регламентированного отчета.
//
Процедура ПослеОчисткиРегламентированногоОтчета(Форма, ИмяСтраницы, ЗапускатьОтдельнуюОбработкуПослеОчисткиЛиста) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПослеОчисткиРегламентированногоОтчета(Форма, ИмяСтраницы, ЗапускатьОтдельнуюОбработкуПослеОчисткиЛиста) 
```
</details>

## НайтиЭлементВДанныхФормыДерево
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает найденный элемент дерева.
//
Функция НайтиЭлементВДанныхФормыДерево(ЭлементыДанныхФормыДерево, ИмяКолонки, ИскомоеЗначение) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.НайтиЭлементВДанныхФормыДерево(ЭлементыДанныхФормыДерево, ИмяКолонки, ИскомоеЗначение) 
```
</details>

## КоличествоФормСоответствующихВыбранномуПериоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает количество форм соответствующих выбранному периоду.
//
Функция КоличествоФормСоответствующихВыбранномуПериоду(Форма) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.КоличествоФормСоответствующихВыбранномуПериоду(Форма) 
```
</details>

## ВыборФормыРегламентированногоОтчетаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выбирает форму регламентированного отчета по умолчанию.
//
Процедура ВыборФормыРегламентированногоОтчетаПоУмолчанию(Форма) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ВыборФормыРегламентированногоОтчетаПоУмолчанию(Форма) 
```
</details>

## ЗаполнитьСведенияОбОрганизацииДляОтчетаСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет сведения об организации для статистического отчета.
//
Процедура ЗаполнитьСведенияОбОрганизацииДляОтчетаСтатистики(Форма, ВПрограммеИзмененаДатаПодписи = Ложь, ИмяПоля = "ПолеТабличногоДокументаФормаОтчета", СхемаНаимПолноеКраткое = Ложь) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ЗаполнитьСведенияОбОрганизацииДляОтчетаСтатистики(Форма, ВПрограммеИзмененаДатаПодписи, ИмяПоля, СхемаНаимПолноеКраткое);
```
</details>

## ЗаполнитьСведенияОбОрганизацииДляОтчетаСтатистикиЗП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет сведения об организации для статистического отчета "СтатистикиЗП".
//
Процедура ЗаполнитьСведенияОбОрганизацииДляОтчетаСтатистикиЗП(Форма, ВПрограммеИзмененаДатаПодписи = Ложь) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ЗаполнитьСведенияОбОрганизацииДляОтчетаСтатистикиЗП(Форма, ВПрограммеИзмененаДатаПодписи);
```
</details>

## ПолучитьПредставлениеНуляИзСтрокиФормата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление нуля из строки формата.
//
Функция ПолучитьПредставлениеНуляИзСтрокиФормата(Знач СтрокаФормата) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ПолучитьПредставлениеНуляИзСтрокиФормата(СтрокаФормата) 
```
</details>

## ЗаменитьПредставлениеНуляВСтрокеФормата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заменяет представление нуля в строке формата.
//
Функция ЗаменитьПредставлениеНуляВСтрокеФормата(Знач СтрокаФормата, ПредставлениеНуля) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ЗаменитьПредставлениеНуляВСтрокеФормата(СтрокаФормата, ПредставлениеНуля) 
```
</details>

## СобратьДанныеТекущегоТаблПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Собирает данные текущего табличного поля.
//
Функция СобратьДанныеТекущегоТаблПоля(Форма, ИмяТабличногоПоля) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СобратьДанныеТекущегоТаблПоля(Форма, ИмяТабличногоПоля) 
```
</details>

## ЗаполнитьПоказателиОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет показатели отчета.
//
Процедура ЗаполнитьПоказателиОтчета(Форма, ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ЗаполнитьПоказателиОтчета(Форма, ПоказателиОтчета) 
```
</details>

## РазделТекущейОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя раздела текущей области.
//
Функция РазделТекущейОбласти(Форма, ТекущаяОбласть, ДлИмениОбласти = 13) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.РазделТекущейОбласти(Форма, ТекущаяОбласть, ДлИмениОбласти);
```
</details>

## ДобавитьНеобходимоеКоличествоДопСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет необходимое количество дополнительных строк.
//
Процедура ДобавитьНеобходимоеКоличествоДопСтрок(Форма, ТекТабличноеПоле, ТекТабличноеПолеИмя, ИсходноеКоличествоСтрокГруппы, ТекущееКоличествоСтрокГруппы, ИмяГруппы, СтруктураГруппы) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ДобавитьНеобходимоеКоличествоДопСтрок(Форма, ТекТабличноеПоле, ТекТабличноеПолеИмя, ИсходноеКоличествоСтрокГруппы, ТекущееКоличествоСтрокГруппы, ИмяГруппы, СтруктураГруппы) 
```
</details>

## ОтрисоватьЗначкиУдаленияСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отрисовывает пиктограммы удаления строк.
//
Процедура ОтрисоватьЗначкиУдаленияСтрок(Форма, ДлинаИмениОбластейСДопСтроками = 26) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ОтрисоватьЗначкиУдаленияСтрок(Форма, ДлинаИмениОбластейСДопСтроками);
```
</details>

## НайтиИДВДереве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает найденный уникальный идентификатор элемента дерева.
//
Функция НайтиИДВДереве(Дерево, UID, UID_Пустой) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.НайтиИДВДереве(Дерево, UID, UID_Пустой) 
```
</details>

## ПриИнициализацииФормыРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается при инициализации формы регламентированного отчета.
//
Процедура ПриИнициализацииФормыРегламентированногоОтчета(Форма, КонтролирующийОрган = "ФНС") Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПриИнициализацииФормыРегламентированногоОтчета(Форма, КонтролирующийОрган);
```
</details>

## ПриИнициализацииФормыРегламентированногоОтчетаОбщиеДействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При инициализации формы регламентированного отчета процедура выполняет общие действия.
//
Процедура ПриИнициализацииФормыРегламентированногоОтчетаОбщиеДействия(Форма, КонтролирующийОрган) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ПриИнициализацииФормыРегламентированногоОтчетаОбщиеДействия(Форма, КонтролирующийОрган));
```
</details>

## СообщитьПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сообщение пользователю.
//
Процедура СообщитьПользователю( Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.СообщитьПользователю();
```
</details>

## ОкруглитьЧислоПоФормату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОкруглитьЧислоПоФормату(Владелец, ИсходноеЧисло) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ОкруглитьЧислоПоФормату(Владелец, ИсходноеЧисло) 
```
</details>

## ОкруглитьЧислоПоФорматуДелителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Округляет число по формату делителя.
//
Функция ОкруглитьЧислоПоФорматуДелителя(Форма, ИсходноеЧисло) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ОкруглитьЧислоПоФорматуДелителя(Форма, ИсходноеЧисло) 
```
</details>

## НайтиСвойстваПоказателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства показателей.
//
Функция НайтиСвойстваПоказателя(Форма, КодПоказателя) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.НайтиСвойстваПоказателя(Форма, КодПоказателя) 
```
</details>

## СравнитьКраткиеВерсииОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сравнивает краткие версии отчетов.
//
Функция СравнитьКраткиеВерсииОтчетов(Версия1, Версия2) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СравнитьКраткиеВерсииОтчетов(Версия1, Версия2) 
```
</details>

## ИзменитьРамкиОбластейТабличногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выделяет в табличном документе области с незаполненными показателями
// и снимает выделение областей с заполненными показателями. Предназначена для
// областей, содержащих значения показателей, ввод которых осуществляется вручную.
//
// Параметры:
//   ТаблДок                     - ТабличныйДокумент - табличный документ;
//   ПараметрыВыделяемыхОбластей - Массив - массив структур с ключами:
//     "ИмяОбласти"                               - Строка - имя области табл. документа;
//     "ГраницаСверхуАвто"       (необязательный) - Линия - линия верхней границы (по умолчанию);
//     "ГраницаСнизуАвто"        (необязательный) - Линия - линия нижней границы (по умолчанию);
//     "ГраницаСлеваАвто"        (необязательный) - Линия - линия левой границы (по умолчанию);
//     "ГраницаСправаАвто"       (необязательный) - Линия - линия правой границы (по умолчанию);
//     "ЦветАвто"                (необязательный) - Цвет  - цвет рамки (по умолчанию);
//     "ГраницаСверхуВыделенная" (необязательный) - Линия - линия выделенной верхней границы;
//     "ГраницаСнизуВыделенная"  (необязательный) - Линия - линия выделенной нижней границы;
//     "ГраницаСлеваВыделенная"  (необязательный) - Линия - линия выделенной левой границы;
//     "ГраницаСправаВыделенная" (необязательный) - Линия - линия выделенной правой границы;
//     "ЦветВыделения"           (необязательный) - Цвет  - цвет выделенной рамки;
//
Процедура ИзменитьРамкиОбластейТабличногоДокумента(ТаблДок, ПараметрыВыделяемыхОбластей) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ИзменитьРамкиОбластейТабличногоДокумента(ТаблДок, ПараметрыВыделяемыхОбластей) 
```
</details>

## ИзменитьРамкуОбластиТабличногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выделяет в табличном документе область с заполненным показателем
// и снимает выделение области с заполненным показателем. Предназначена для
// области, содержащей значение показателя, ввод которого осуществляется вручную.
//
// Параметр:
//   ПараметрыИзменения - Структура - ключи:
//     "Область" - ОбластьЯчеекТабличногоДокумента - область, выделение которой изменяется;
//     "ГраницаСверхуАвто"       (необязательный) - Линия - линия верхней границы (по умолчанию);
//     "ГраницаСнизуАвто"        (необязательный) - Линия - линия нижней границы (по умолчанию);
//     "ГраницаСлеваАвто"        (необязательный) - Линия - линия левой границы (по умолчанию);
//     "ГраницаСправаАвто"       (необязательный) - Линия - линия правой границы (по умолчанию);
//     "ЦветАвто"                (необязательный) - Цвет  - цвет рамки (по умолчанию);
//     "ГраницаСверхуВыделенная" (необязательный) - Линия - линия выделенной верхней границы;
//     "ГраницаСнизуВыделенная"  (необязательный) - Линия - линия выделенной нижней границы;
//     "ГраницаСлеваВыделенная"  (необязательный) - Линия - линия выделенной левой границы;
//     "ГраницаСправаВыделенная" (необязательный) - Линия - линия выделенной правой границы;
//     "ЦветВыделения"           (необязательный) - Цвет  - цвет выделенной рамки;
//
Процедура ИзменитьРамкуОбластиТабличногоДокумента(ПараметрыИзменения) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ИзменитьРамкуОбластиТабличногоДокумента(ПараметрыИзменения) 
```
</details>

## УстановитьЗначениеОКВЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значение ОКВЭД.
//
// Параметры:
//  ДатаПодписи - Дата - дата подписи регл. отчета.
//  СтруктураРеквизитовФормы - Структура - структура реквизитов формы регл. отчета.
//  ОКВЭД - Строка - устанавливаемое значение ОКВЭД.
//
Процедура УстановитьЗначениеОКВЭД(ДатаПодписи, СтруктураРеквизитовФормы, ОКВЭД) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.УстановитьЗначениеОКВЭД(ДатаПодписи, СтруктураРеквизитовФормы, ОКВЭД) 
```
</details>

## УстановитьЗначениеВидаЭкономическойДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значение вида экономической деятельности.
//
// Параметры:
//  ДатаПодписи - Дата - дата подписи регл. отчета.
//  СтруктураРеквизитовФормы - Структура - структура реквизитов формы регл. отчета.
//  ВидЭкономическойДеятельности - Строка - устанавливаемое значение вида экономической деятельности.
//
Процедура УстановитьЗначениеВидаЭкономическойДеятельности(ДатаПодписи, СтруктураРеквизитовФормы, ВидЭкономическойДеятельности) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.УстановитьЗначениеВидаЭкономическойДеятельности(ДатаПодписи, СтруктураРеквизитовФормы, ВидЭкономическойДеятельности) 
```
</details>

## ОперацииСРегламентированнымОтчетом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает операции регламентированного отчета с признаками их доступности.
//
// Параметры:
//   ИмяОтчета - Строка - имя регламентированного отчета, например, "РегламентированныйОтчет4ФСС".
//   ИмяФормы - Строка - имя формы регламентированного отчета, например, "ФормаОтчета2022Кв2".
//
// Возвращаемое значение:
//   ФиксированнаяСтруктура - операции с регламентированным отчетом.
//	   * АвтоФормированиеНаСервере - Булево - признак автоматического формирования отчета в тихом режиме на сервере.
//	   * ВыгрузкаНаСервере - Булево - признак выгрузки отчета в тихом режиме на сервере.
//	   * ПечатьСоШтрихкодомPDF417НаСервере - Булево - признак печати отчета со штрихкодом PDF417 в тихом режиме
//													  на сервере.
//	   * ПечатьБезШтрихкодаPDF417НаСервере - Булево - признак печати отчета без штрихкода PDF417 в тихом режиме
//													  на сервере.
//
Функция ОперацииСРегламентированнымОтчетом(ИмяОтчета, ИмяФормы) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ОперацииСРегламентированнымОтчетом(ИмяОтчета, ИмяФормы) 
```
</details>

## ОбъектНеОтправлялсяЧерез1СОтчетность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что объект не отправлялся через "1С-Отчетность".
//
// Параметры:
//  СостояниеСдачи - ПеречислениеСсылка.СостояниеСдачиОтчетности - значение реквизита
//                   "СостояниеСдачиОтчетности" в регистрах сведений "Журнал отчетов
//                   статусы" или "Журнал отправок в контролирующие органы".
//
// Возвращаемое значение:
//  Булево - Истина, если объект не отправлялся через "1С-Отчетность".
//
Функция ОбъектНеОтправлялсяЧерез1СОтчетность(СостояниеСдачи) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ОбъектНеОтправлялсяЧерез1СОтчетность(СостояниеСдачи) 
```
</details>

## ДопускаетсяРучноеИзменениеСтатусаОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что у объекта статус отправки может меняться вручную.
//
// Параметры:
//  ТипКонтролирующегоОргана - Перечисление.ТипыКонтролирующихОрганов - тип контроллирующего органа
//
// Возвращаемое значение:
//  Булево - Истина, если у объекта допускается ручное изменение статуса.
//
Функция ДопускаетсяРучноеИзменениеСтатусаОбъекта(ТипКонтролирующегоОргана) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ДопускаетсяРучноеИзменениеСтатусаОбъекта(ТипКонтролирующегоОргана) 
```
</details>

## СтатусыОбъектовРеглОтчетностиПриРучномВводе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив возможных статусов объектов регламентированной отчетности,
// предназначенных для интерактивного изменения пользователем.
//
// Параметры:
//  ОбъектРеглОтчетности:
//    Вариант 1. ДокументСсылка, СправочникСсылка - ссылка на объект в регистрах сведений
//               "Журнал отчетов статусы" или "Журнал отправок в контролирующие органы",
//               отображаемый на страницах "Отчеты" и "Уведомления" формы "1С-Отчетность";
//    Вариант 2. ФормаКлиентскогоПриложения - экранная форма объекта регламентированной отчетности.
//
// Возвращаемое значение:
//  Массив - статусы (строковые значения).
//
Функция СтатусыОбъектовРеглОтчетностиПриРучномВводе(ОбъектРеглОтчетности = Неопределено, ВидКонтролирующегоОргана = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СтатусыОбъектовРеглОтчетностиПриРучномВводе(ОбъектРеглОтчетности, ВидКонтролирующегоОргана);
```
</details>

## ИспользуютсяРегистрацииВОрганеСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИспользуютсяРегистрацииВОрганеСтатистики() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ИспользуютсяРегистрацииВОрганеСтатистики() 
```
</details>

## ДополнитьОпциональныеПараметрыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьОпциональныеПараметрыОтчета(Форма, Параметры) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСервер.ДополнитьОпциональныеПараметрыОтчета(Форма, Параметры) 
```
</details>

## СуммаПоказателяПоВеткам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определеяет сумму показателя по строкам дерева данных регламентированного отчета по налогу на прибыль.
//
// Параметры:
//  Форма			 - ФормаКлиентскогоПриложения
//  Ветки			 - КоллекцияСтрокДереваЗначений
//  ИмяПоказателя	 - Строка
//  Условия			 - Структура или Неопределено
//
// Возвращаемое значение:
//  Число
//
Функция СуммаПоказателяПоВеткам(Форма, Ветки, ИмяПоказателя, Условия = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СуммаПоказателяПоВеткам(Форма, Ветки, ИмяПоказателя, Условия);
```
</details>

## ВеткаУдовлетворяющаяУсловиямПоиска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет строку дерева данных регламентированного отчета по налогу на прибыль, удовлетворяющую условиям поиска.
//
// Параметры:
//  Ветки	 - КоллекцияСтрокДереваЗначений
//  Условия	 - Структура
//
// Возвращаемое значение:
//  СтрокаДереваЗначений
//  Неопределено
//
Функция ВеткаУдовлетворяющаяУсловиямПоиска(Ветки, Условия) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.ВеткаУдовлетворяющаяУсловиямПоиска(Ветки, Условия) 
```
</details>

## СтрЧГ0
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление числа без разделителей между разрядами.
// При необходимости указывается длина возвращаемого представления, которое, в этом случае,
// может быть дополнено нулями слева. Допускается передача значения Неопределено, которое интерпретируется как 0.
// Для упрощения использования в модулях конфигурации рекомендуется создавать функцию-обертку с аналогичным именем.
//
// Параметры:
//   ФорматируемоеЧисло - Число
//                      - Неопределено
//   ДлинаСтроки - Число - длина возвращаемой строки, если значение не указано,
//                         то длина определяется автоматически
//
// Возвращаемое значение:
//   Строка
//
Функция СтрЧГ0(ФорматируемоеЧисло, ДлинаСтроки = 0) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.СтрЧГ0(ФорматируемоеЧисло, ДлинаСтроки);
```
</details>

## Список
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив из элементов, перечисленных в строке через запятую.
// Незначащие пробелы и переносы строк слева и справа от элементов отсекаются.
// Для упрощения использования в модулях конфигурации рекомендуется создавать функцию-обертку с аналогичным именем.
//
// Параметры:
//   СписокРазделенныйЗапятыми - Строка
//
// Возвращаемое значение:
//   Массив из Строка
//
Функция Список(СписокРазделенныйЗапятыми) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСервер.Список(СписокРазделенныйЗапятыми) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
