---
title: Регламентированная отчетность клиент сервер переопределяемый
slug: zup/регламентированная-отчетность-клиент-сервер-переопределяемый
---


## ОпределитьДоступностьИзмененияВидаРСВ_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции интерфейса взаимодействия с конфигурациями (библиотеками)
// - потребителями.

// Процедура определяет, будет ли доступно для редактирования поле "ВидДокументаПредставление"
// в форме РСВ-1.
//
// Параметры:
//  Доступность - булево.
//
Процедура ОпределитьДоступностьИзмененияВидаРСВ_1(Доступность) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСерверПереопределяемый.ОпределитьДоступностьИзмененияВидаРСВ_1(Доступность) 
```
</details>

## ИмяОсновнойФормыРСВ1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Служебные процедуры и функции.

// Функция возвращает имя основной формы ("ОсновнаяФорма" или "ОсновнаяФормаДополнительная"),
// используемой при открытии регл. отчета "РегламентированныйОтчетРСВ1".
// Если в конфигурации-потребителе используется форма подготовки квартальной отчетности в ПФР из БЗКБ,
// то функция должна возвращать форму "ОсновнаяФормаДополнительная", иначе - "ОсновнаяФорма".
//
// Пример:
//  Возврат "ОсновнаяФормаДополнительная";
//
Функция ИмяОсновнойФормыРСВ1() Экспорт
```

Пример вызова
```bsl
Результат = РегламентированнаяОтчетностьКлиентСерверПереопределяемый.ИмяОсновнойФормыРСВ1() 
```
</details>

## ДополнитьСтатусыОбъектовРеглОтчетностиПриРучномВводе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет массив возможных статусов объектов регламентированной отчетности,
// предназначенных для интерактивного изменения пользователем.
//
// Параметры:
//  Статусы - Массив - статусы (строковые значения), которые можно дополнить.
//  ОбъектРеглОтчетности:
//    Вариант 1. ДокументСсылка, СправочникСсылка - ссылка на объект в регистрах сведений
//               "Журнал отчетов статусы" или "Журнал отправок в контролирующие органы",
//               отображаемый на страницах "Отчеты" и "Уведомления" формы "1С-Отчетность";
//    Вариант 2. ФормаКлиентскогоПриложения - экранная форма объекта регламентированной отчетности.
//
// Пример реализации:
//  Если ТипЗнч(ОбъектРеглОтчетности) = Тип("ФормаКлиентскогоПриложения") Тогда
//  	Если СтрНачинаетсяС(ОбъектРеглОтчетности.ИмяФормы, "Отчет.РегламентированныйОтчетРСВ1") Тогда
//  		Статусы.Добавить("Черновик");
//  	КонецЕсли;
//  ИначеЕсли ТипЗнч(ОбъектРеглОтчетности) = Тип("ДокументСсылка.РегламентированныйОтчет") Тогда
//  	ИсточникОтчета = РегламентированнаяОтчетностьВызовСервера.ИсточникРегламентированногоОтчета(ОбъектРеглОтчетности);
//  	Если ИсточникОтчета = "РегламентированныйОтчетРСВ1" Тогда
//  		Статусы.Добавить("Черновик");
//  	КонецЕсли;
//  КонецЕсли;
//
Процедура ДополнитьСтатусыОбъектовРеглОтчетностиПриРучномВводе(Статусы, ОбъектРеглОтчетности = Неопределено) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСерверПереопределяемый.ДополнитьСтатусыОбъектовРеглОтчетностиПриРучномВводе(Статусы, ОбъектРеглОтчетности);
```
</details>

## ИспользуютсяРегистрацииВОрганеСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИспользуютсяРегистрацииВОрганеСтатистики(ПризнакИспользования) Экспорт
```

Пример вызова
```bsl
РегламентированнаяОтчетностьКлиентСерверПереопределяемый.ИспользуютсяРегистрацииВОрганеСтатистики(ПризнакИспользования) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
