---
title: Сведения об ответственных лицах
slug: zup/сведения-об-ответственных-лицах
---


## ОтветственныеЛицаОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения об ответственных лицах организации.
//
// Параметры:
//	Организация		- СправочникСсылка.Организации - ссылка на организацию.
//	Сведения		- Строка - с идентификаторами, разделенными запятыми.
//	ДатаСведений	- Дата - дата получения сведений.
//
// Возвращаемое значение:
//	Структура - структура со свойствами, совпадающими с параметром «Сведения».
//		Допустимые идентификаторы запрашиваемых значений:
//				(совпадают с колонкой "Ключ" таблицы СведенияОбОтветственныхЛицах.ТаблицаОтветственныхЛицОрганизаций())
//				Руководитель						- Строка - руководитель организации.
//				ГлавныйБухгалтер					- Строка - главный бухгалтер организации.
//				Кассир								- Строка - кассир организации.
//				РуководительКадровойСлужбы			- Строка - Руководитель кадровой службы организации.
//				ОтветственныйЗаВУР 					- Строка - ответственный за военно-учетную работу.
//				ПредставительСФР 					- Строка - Уполномоченный представитель организации для СФР.
//				ОтветственныйЗаОхрануТруда			- Строка - ответственный за охрану труда.
//
Функция ОтветственныеЛицаОрганизации(Организация, Сведения, ДатаСведений = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СведенияОбОтветственныхЛицах.ОтветственныеЛицаОрганизации(Организация, Сведения, ДатаСведений);
```
</details>

## СведенияОбОтветственныхЛицах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения об ответственных лицах организации.
//
// Параметры:
//		Организация - ссылка на организацию.
//		Сведения - строка с идентификаторами, разделенными запятыми.
//		ДатаСведений - дата получения сведений.
//
// Возвращаемое значение:
//		СтруктураДанных - структура со свойствами, совпадающими с параметром «Сведения».
//			Допустимые идентификаторы запрашиваемых значений:
//			Руководитель						- руководитель организации.
//			ДолжностьРуководителя				- должность руководителя.
//			ДолжностьРуководителяСтрокой		- представление должности руководителя.
//
//			ГлавныйБухгалтер					- главный бухгалтер организации.
//
//			Кассир								- кассир организации.
//			ДолжностьКассира					- должность кассира.
//			ДолжностьКассираСтрокой				- представление должности кассира.
//
//			РуководительКадровойСлужбы					- Руководитель кадровой службы организации.
//			ДолжностьРуководителяКадровойСлужбы			- должность руководителя кадровой службы организации.
//			ДолжностьРуководителяКадровойСлужбыСтрокой	- представление должности руководителя кадровой службы организации.
//
//			ОтветственныйЗаВУР 					- ответственный за военно-учетную работу.
//			ДолжностьОтветственногоЗаВУР 		- должность ответственного за военно-учетную работу.
//			ДолжностьОтветственногоЗаВУРСтрокой - представление должности ответственного за военно-учетную работу.
//
//			ПредставительСФР 					- Уполномоченный представитель организации для СФР.
//			ДолжностьПредставителяСФР 			- должность уполномоченного представителя организации для СФР.
//			ДолжностьПредставителяСФРСтрокой 	- представление должности уполномоченного представителя организации для СФР.
//
Функция СведенияОбОтветственныхЛицах(Организация, Сведения, ДатаСведений = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СведенияОбОтветственныхЛицах.СведенияОбОтветственныхЛицах(Организация, Сведения, ДатаСведений);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
