---
title: Синхронизация данных зарплата кадры интеграция подсистем
slug: zup/синхронизация-данных-зарплата-кадры-интеграция-подсистем
---


## ЗаполнитьТаблицуЗависимыхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение соответствия зависимых данных от ведущих данных
// Зависимые данные не мигрируют по узлам, а пересчитываются по ведущим данным в каждом узле.
//
// Параметры:
//		ЗависимыеДанные - ТаблицаЗначений:
//			* ВедущиеМетаданные - ОбъектМетаданных - Метаданные ведущих данных
//			* ЗависимыеМетаданные - ОбъектМетаданных - Метаданные зависимых данных
//
Процедура ЗаполнитьТаблицуЗависимыхДанных(ЗависимыеДанные) Экспорт
```

Пример вызова
```bsl
СинхронизацияДанныхЗарплатаКадрыИнтеграцияПодсистем.ЗаполнитьТаблицуЗависимыхДанных(ЗависимыеДанные) 
```
</details>

## ЗаполнитьТаблицуДанныхРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение списка объектов, при изменении которых требуется зарегистрировать изменение
// организации или структурного подразделения для сотрудников и физических лиц
//
// Параметры:
//		ДанныеРегистрации - ТаблицаЗначений:
//			* ВедущиеМетаданные - ОбъектМетаданных - Метаданные объекта, при изменении которого
//					требуется изменение организации или структурного подразделения
//					сотрудника или физического лица
//
Процедура ЗаполнитьТаблицуДанныхРегистрации(ДанныеРегистрации) Экспорт
```

Пример вызова
```bsl
СинхронизацияДанныхЗарплатаКадрыИнтеграцияПодсистем.ЗаполнитьТаблицуДанныхРегистрации(ДанныеРегистрации) 
```
</details>

## ЗаполнитьЗависимыеДанныеПослеСозданияНовогоУзлаРИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет начальное заполнение данных после создания узла РИБ.
// Вызывается в момент первого запуска подчиненного узла РИБ (в том числе АРМ).
//
// Параметры:
//  ПараметрыОбновления	 - Структура - используется при вызове из обработчика обновления.
//
Процедура ЗаполнитьЗависимыеДанныеПослеСозданияНовогоУзлаРИБ(ПараметрыОбновления = Неопределено) Экспорт
```

Пример вызова
```bsl
СинхронизацияДанныхЗарплатаКадрыИнтеграцияПодсистем.ЗаполнитьЗависимыеДанныеПослеСозданияНовогоУзлаРИБ(ПараметрыОбновления);
```
</details>

## ПриЗаполненииНастроекОбработчиковПравилРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет настройки обработчиков правил регистрации для объекта метаданных.
//
// Параметры:
//  Настройки - см. СинхронизацияДанныхЗарплатаКадрыСервер.НоваяТаблицаНастроекОбработчиковПравилРегистрации
//  ИмяОбъекта - Строка - полное имя объекта метаданных
Процедура ПриЗаполненииНастроекОбработчиковПравилРегистрации(Настройки, ИмяОбъекта) Экспорт
```

Пример вызова
```bsl
СинхронизацияДанныхЗарплатаКадрыИнтеграцияПодсистем.ПриЗаполненииНастроекОбработчиковПравилРегистрации(Настройки, ИмяОбъекта) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
