---
title: Сообщения БЗК
slug: zup/сообщения-бзк
---


## СообщитьОбОшибкеВОбъекте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сообщает об ошибке заполнения в реквизите объекта и включает флажок Отказ.
//
// Параметры:
//   Отказ        - Булево        - Флажок отказа, который включается в данной процедуре.
//   Объект       - ЛюбаяСсылка,
//                  ЛюбойОбъект   - Объект, в котором обнаружена ошибка.
//   Текст        - Строка        - Текст ошибки.
//   ИмяРеквизита - Строка        - Имя реквизита, в котором обнаружена ошибка.
//
Процедура СообщитьОбОшибкеВОбъекте(Отказ, Объект, Текст, ИмяРеквизита = "") Экспорт
```

Пример вызова
```bsl
СообщенияБЗК.СообщитьОбОшибкеВОбъекте(Отказ, Объект, Текст, ИмяРеквизита);
```
</details>

## СообщитьОбОшибкеВСтрокеТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сообщает об ошибке заполнения в реквизите объекта и включает флажок Отказ.
//
// Параметры:
//   Отказ         - Булево                 - Флажок отказа, который включается в данной процедуре.
//   Объект        - ЛюбаяСсылка,
//                   ЛюбойОбъект            - Объект, в котором обнаружена ошибка.
//   ИмяТаблицы    - Строка                 - Имя табличной части.
//   СтрокаТаблицы - Строка табличной части - Строка табличной части.
//   ИмяРеквизита  - Строка                 - Имя реквизита строки табличной части.
//   Текст         - Строка                 - Текст ошибки. Если не указан, то будет сформирован стандартный текст ошибки.
//
Процедура СообщитьОбОшибкеВСтрокеТаблицы(Отказ, Объект, ИмяТаблицы, СтрокаТаблицы, ИмяРеквизита, Текст) Экспорт
```

Пример вызова
```bsl
СообщенияБЗК.СообщитьОбОшибкеВСтрокеТаблицы(Отказ, Объект, ИмяТаблицы, СтрокаТаблицы, ИмяРеквизита, Текст) 
```
</details>

## СообщитьОПроблеме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сообщение предупреждающее о проблеме связанной с указанным полем объекта.
//
// Параметры:
//   Текст  - Строка                   - Текст сообщения.
//   Объект - ЛюбаяСсылка, ЛюбойОбъект - Объект, в котором обнаружена проблема.
//   Поле   - Строка                   - Полное имя реквизита, в котором обнаружена проблема.
//
Процедура СообщитьОПроблеме(Текст, Объект = Неопределено, Поле = "") Экспорт
```

Пример вызова
```bsl
СообщенияБЗК.СообщитьОПроблеме(Текст, Объект, Поле);
```
</details>

## КоличествоСообщенийПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает количество сообщений, которые еще не были выведены пользователю.
//
// Возвращаемое значение:
//   Число
//
Функция КоличествоСообщенийПользователю() Экспорт
```

Пример вызова
```bsl
Результат = СообщенияБЗК.КоличествоСообщенийПользователю() 
```
</details>

## СократитьЧислоСообщений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сокращает число сообщений до указанного количества. Оставляет первые N сообщений, удаляя сообщения с конца стека.
//
// Параметры:
//   Количество - Число - Количество сообщений которое должно остаться чтобы быть выведено пользователю.
//       См. СообщенияБЗК.КоличествоСообщенийПользователю().
//
Процедура СократитьЧислоСообщений(Количество, ТекстыСообщений = Неопределено) Экспорт
```

Пример вызова
```bsl
СообщенияБЗК.СократитьЧислоСообщений(Количество, ТекстыСообщений);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
