---
title: Справки НДФЛ формы
slug: zup/справки-ндфл-формы
---


## ПараметрыПредставленияОписанияДоходовОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую структуру параметров для формирования описания доходов организации.
//
// Возвращаемое значение:
//  ПараметрыПредставления - Структура - содержит:
//    * ДляНалогаНаПрибыль               - Булево
//    * НеВключатьДоходыПоЦеннымБумагам  - Булево
//    * СводнаяСправка                   - Булево
//
Функция ПараметрыПредставленияОписанияДоходовОрганизации() Экспорт
```

Пример вызова
```bsl
Результат = СправкиНДФЛФормы.ПараметрыПредставленияОписанияДоходовОрганизации() 
```
</details>

## УстановитьИнфонадписьОписаниеДоходовОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует надпись о доходах организации на форме
//
// Параметры:
//  Форма                    - ФормаКлиентскогоПриложения
//  ФизическоеЛицо           - СправочникСсылка.ФизическиеЛица
//  ПараметрыПредставления   - см. ПараметрыПредставленияОписанияДоходовОрганизации()
//
Процедура УстановитьИнфонадписьОписаниеДоходовОрганизации(Форма, ФизическоеЛицо = Неопределено, ПараметрыПредставления = Неопределено) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.УстановитьИнфонадписьОписаниеДоходовОрганизации(Форма, ФизическоеЛицо, ПараметрыПредставления);
```
</details>

## ПараметрыПомещенияДанныхСправки2НДФЛВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую структуру параметров для помещения данных справки 2-НДФЛ в хранилище.
//
// Возвращаемое значение:
//  ПараметрыДанныхСправки - Структура - содержит:
//    * ДанныеСотрудника                - ДанныеФормыКоллекция, ДанныеФормыЭлементКоллекции, ДанныеФормыСтруктура
//    * СтрокиСведенийОДоходах          - ДанныеФормыКоллекция, ДанныеФормыЭлементКоллекции
//    * СтрокиСведенийОВычетах          - ДанныеФормыЭлементКоллекции
//    * НомерСправки                    - Число
//    * Ставка                          - Перечисление.НДФЛСтавки
//    * НеВключатьДоходыПоЦеннымБумагам - Булево
//    * УведомленияОПравеНаВычеты       - ДанныеФормыЭлементКоллекции
//    * ПоказыватьИсправляемуюСправку   - Булево
//    * ИсправляемаяСправка             - Документ.СправкиНДФЛДляПередачиВНалоговыйОрган.Ссылка
//    * НомерКорректировки              - Число
//
Функция ПараметрыПомещенияДанныхСправки2НДФЛВХранилище() Экспорт
```

Пример вызова
```bsl
Результат = СправкиНДФЛФормы.ПараметрыПомещенияДанныхСправки2НДФЛВХранилище() 
```
</details>

## ПоместитьДанныеСправки2НДФЛВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные справки во временное хранилище, возвращает адрес во временном хранилище
//
// Параметры:
//  Форма                    - ФормаКлиентскогоПриложения
//  ПараметрыДанныхСправки   - см. ПараметрыПомещенияДанныхСправки2НДФЛВХранилище
//  Ошибки                   - Массив из Строка
//  НоваяСтрока              - Булево
//
// Возвращаемое значение:
//  Строка - адрес во временном хранилище
//
Функция ПоместитьДанныеСправки2НДФЛВХранилище(Форма, ПараметрыДанныхСправки, Ошибки, НоваяСтрока) Экспорт
```

Пример вызова
```bsl
Результат = СправкиНДФЛФормы.ПоместитьДанныеСправки2НДФЛВХранилище(Форма, ПараметрыДанныхСправки, Ошибки, НоваяСтрока) 
```
</details>

## ПараметрыПомещенияДанныхСведенияОДоходахСотрудникаДляСоцВыплатВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую структуру параметров для помещения данных сведений о доходах сотрудника для соц. выплат в хранилище.
//
// Возвращаемое значение:
//  ПараметрыДанныхСправки - Структура - содержит:
//    * ДанныеСотрудника                - ДанныеФормыКоллекция, ДанныеФормыЭлементКоллекции, ДанныеФормыСтруктура
//    * СтрокиСведенийОДоходах          - ДанныеФормыКоллекция, ДанныеФормыЭлементКоллекции
//    * СтрокиСведенийОВычетах          - ДанныеФормыЭлементКоллекции
//    * НомерСправки                    - Число
//    * Ставка                          - Перечисление.НДФЛСтавки
//    * НеВключатьДоходыПоЦеннымБумагам - Булево
//    * УведомленияОПравеНаВычеты       - ДанныеФормыЭлементКоллекции
//    * ПоказыватьИсправляемуюСправку   - Булево
//    * ИсправляемаяСправка             - Документ.СправкиНДФЛДляПередачиВНалоговыйОрган.Ссылка
//    * НомерКорректировки              - Число
//
Функция ПараметрыПомещенияДанныхСведенияОДоходахСотрудникаДляСоцВыплатВХранилище() Экспорт
```

Пример вызова
```bsl
Результат = СправкиНДФЛФормы.ПараметрыПомещенияДанныхСведенияОДоходахСотрудникаДляСоцВыплатВХранилище() 
```
</details>

## ПоместитьДанныеСведенияОДоходахСотрудникаДляСоцВыплатВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные сведений о доходах сотрудника для соц. выплат во временное хранилище, возвращает адрес во временном хранилище
//
// Параметры:
//  Форма                    - ФормаКлиентскогоПриложения
//  ПараметрыДанныхСправки   - см. ПараметрыПомещенияДанныхСведенияОДоходахСотрудникаДляСоцВыплатВХранилище
//  Ошибки                   - Массив из Строка
//  НоваяСтрока              - Булево
//
// Возвращаемое значение:
//  Строка - адрес во временном хранилище
//
Функция ПоместитьДанныеСведенияОДоходахСотрудникаДляСоцВыплатВХранилище(Форма, ПараметрыДанныхСправки, Ошибки, НоваяСтрока) Экспорт
```

Пример вызова
```bsl
Результат = СправкиНДФЛФормы.ПоместитьДанныеСведенияОДоходахСотрудникаДляСоцВыплатВХранилище(Форма, ПараметрыДанныхСправки, Ошибки, НоваяСтрока) 
```
</details>

## ЗаполнитьСписокКонтролируемыхПолей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизит формы СписокКонтролируемыхПолей.
//
// Параметры:
//  Форма                - ФормаКлиентскогоПриложения
//  ДляНалогаНаПрибыль	 - Булево
//
Процедура ЗаполнитьСписокКонтролируемыхПолей(Форма, ДляНалогаНаПрибыль = Ложь) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ЗаполнитьСписокКонтролируемыхПолей(Форма, ДляНалогаНаПрибыль);
```
</details>

## ОтменитьИсправлениеДанныхСотрудника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет данные сотрудника по данным учета за налоговый период на дату документа, отменяя ручные исправления
//
// Параметры:
//  Форма                - ФормаКлиентскогоПриложения
//  СправкаПоСотруднику	 - ДанныеФормыСтруктура
//  НалоговыйПериод		 - Число                      - год налогового периода за который берутся данные сотрудника
//  ДатаДокумента		 - Дата
//
Процедура ОтменитьИсправлениеДанныхСотрудника(Форма, СправкаПоСотруднику, НалоговыйПериод, ДатаДокумента) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ОтменитьИсправлениеДанныхСотрудника(Форма, СправкаПоСотруднику, НалоговыйПериод, ДатаДокумента) 
```
</details>

## ОбновитьИтоги
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет итоги по облагаемой и общей сумме дохода.
//
// Параметры:
//  ДанныеСправки   - ДанныеФормыСтруктура - содержит:
//    * ОблагаемаяСуммаДохода - Число
//    * ОбщаяСуммаДохода      - Число
//  СведенияОДоходах - ДанныеФормыКоллекция
//  СведенияОВычетах - ДанныеФормыКоллекция
//
Процедура ОбновитьИтоги(ДанныеСправки, СведенияОДоходах, СведенияОВычетах) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ОбновитьИтоги(ДанныеСправки, СведенияОДоходах, СведенияОВычетах) 
```
</details>

## ОчиститьДанныеСправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает поля справки.
//
// Параметры:
//  ДанныеСправки        - ДанныеФормыЭлементКоллекции, ДанныеФормыСтруктура
//  ДляНалогаНаПрибыль	 - Булево
//
Процедура ОчиститьДанныеСправки(ДанныеСправки, ДляНалогаНаПрибыль = Ложь) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ОчиститьДанныеСправки(ДанныеСправки, ДляНалогаНаПрибыль);
```
</details>

## ОбновитьНалоги
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет налоги в справках НДФЛ
//
// Параметры:
//  СправкаПоСотруднику	 - ДокументСсылка.СправкаНДФЛ, ДокументСсылка.СправкиНДФЛДляПередачиВНалоговыйОрган
//  ПараметрыСправокНДФЛ - см. СправкиНДФЛ.ПараметрыСправокНДФЛ.
//
Процедура ОбновитьНалоги(СправкаПоСотруднику, ПараметрыСправокНДФЛ) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ОбновитьНалоги(СправкаПоСотруднику, ПараметрыСправокНДФЛ) 
```
</details>

## ДляНалогаНаПрибыльПрочитатьДанныеОДоходахИНалогахСотрудника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДляНалогаНаПрибыльПрочитатьДанныеОДоходахИНалогахСотрудника(Форма, СправкаПоСотруднику, СведенияОДоходах, СведенияОВычетах, НалоговыйПериод, ДатаДокумента, Организация, НомерСправки, Ставка) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ДляНалогаНаПрибыльПрочитатьДанныеОДоходахИНалогахСотрудника(Форма, СправкаПоСотруднику, СведенияОДоходах, СведенияОВычетах, НалоговыйПериод, ДатаДокумента, Организация, НомерСправки, Ставка) 
```
</details>

## ДляНалогаНаПрибыльПрочитатьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДляНалогаНаПрибыльПрочитатьДанные(ДанныеСправок, СведенияОДоходах, СведенияОВычетах, НалоговыйПериод, ДатаДокумента, Организация,  ОбновлятьНеФиксированныеДанные = Истина) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ДляНалогаНаПрибыльПрочитатьДанные(ДанныеСправок, СведенияОДоходах, СведенияОВычетах, НалоговыйПериод, ДатаДокумента, Организация, ОбновлятьНеФиксированныеДанные);
```
</details>

## ДляНалогаНаПрибыльПрочитатьДанныеОДоходахИНалогах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДляНалогаНаПрибыльПрочитатьДанныеОДоходахИНалогах(ДанныеСправок, СведенияОДоходах, СведенияОВычетах, НалоговыйПериод, ДатаДокумента, Организация, НомерСправки = Неопределено, Ставка = Неопределено) Экспорт
```

Пример вызова
```bsl
СправкиНДФЛФормы.ДляНалогаНаПрибыльПрочитатьДанныеОДоходахИНалогах(ДанныеСправок, СведенияОДоходах, СведенияОВычетах, НалоговыйПериод, ДатаДокумента, Организация, НомерСправки, Ставка);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
