---
title: Управление печатью БЗК
slug: zup/управление-печатью-бзк
---


## КонтекстПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров печати.
//
// Параметры:
//   МетаданныеМакета  - ОбъектМетаданных: Макет - Метаданные макета печатной формы.
//   МассивОбъектов    - Массив                  - Список печатаемых объектов.
//   ОбъектыПечати     - СписокЗначений          - Соответствие между объектами и областями табличного документа.
//       Параметры "МассивОбъектов" и "ОбъектыПечати" передаются из процедуры Печать "как есть".
//       См. описание одноименных параметров в УправлениеПечатьюПереопределяемый.ПриПечати.
//   ТабличныйДокумент - ТабличныйДокумент       - Табличный документ для вывода печатной формы.
//       Если параметр "ТабличныйДокумент" не указан, то создается новый табличный документ с параметрами:
//       * ОриентацияСтраницы = ОриентацияСтраницы.Портрет;
//       * АвтоМасштаб = Истина;
//       * КлючПараметровПечати = "ПараметрыПечати_<ИмяМакетаБезПрефикса>".
//
// Возвращаемое значение:
//   Структура - Контекст печати.
//       * МассивОбъектов    - Массив            - Соответствует параметру МассивОбъектов.
//       * ОбъектыПечати     - СписокЗначений    - Соответствует параметру ОбъектыПечати.
//       * ТабличныйДокумент - ТабличныйДокумент - Соответствует параметру ТабличныйДокумент.
//       * Макет             - ТабличныйДокумент - Макет печатной формы.
//       * ИменаПараметровОбластей - Структура   - См. УправлениеПечатьюБЗК.ИменаПараметровОбластейСтандартногоМакета.
//       * ПолноеИмяМакета  - Строка             - Полное имя макета печатной формы.
//       * МетаданныеМакета - ОбъектМетаданных: Макет - Метаданные макета печатной формы.
//
Функция КонтекстПечати(МетаданныеМакета, МассивОбъектов = Неопределено, ОбъектыПечати = Неопределено, ТабличныйДокумент = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.КонтекстПечати(МетаданныеМакета, МассивОбъектов, ОбъектыПечати, ТабличныйДокумент);
```
</details>

## ПараметрыСтандартногоМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров макета конфигурации
// (или указанной области макета).
//
// Параметры:
//  ПутьКМакету - Строка - полный путь к макету в формате:
//                         "Документ.<ИмяДокумента>.<ИмяМакета>"
//                         "Обработка.<ИмяОбработки>.<ИмяМакета>"
//                         "ОбщийМакет.<ИмяМакета>".
//  ИмяОбласти - Строка - Имя области в макете.
//                        Необязательный. Если не указан, возвращаются все параметры в макете.
//
// Возвращаемое значение:
//  Структура - параметры макета, ключ соответствует имени параметра, значение - Неопределено.
//
Функция ПараметрыСтандартногоМакета(ПутьКМакету, Знач ИмяОбласти = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.ПараметрыСтандартногоМакета(ПутьКМакету, ИмяОбласти);
```
</details>

## ПараметрыОбластейСтандартногоМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры указанных областей макета конфигурации.
//
// Параметры:
//  ПутьКМакету   - Строка - полный путь к макету в формате:
//                           "Документ.<ИмяДокумента>.<ИмяМакета>"
//                           "Обработка.<ИмяОбработки>.<ИмяМакета>"
//                           "ОбщийМакет.<ИмяМакета>".
//  Области - Строка, Массив - области в макете, параметры которых необходимо получить.
//                             Необязательный. Если не указан, возвращаются все области макета.
//
// Возвращаемое значение:
//  Структура - ключ соответствует имени области, значение - Структура -  содержит параметры области.
//
Функция ПараметрыОбластейСтандартногоМакета(ПутьКМакету, Знач Области = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.ПараметрыОбластейСтандартногоМакета(ПутьКМакету, Области);
```
</details>

## ИменаПараметровОбластейСтандартногоМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имена параметров всех областей макета конфигурации.
//
// Параметры:
//   ПутьКМакету - Строка - полный путь к макету в формате:
//       "Документ.<ИмяДокумента>.<ИмяМакета>"
//       "Обработка.<ИмяОбработки>.<ИмяМакета>"
//       "ОбщийМакет.<ИмяМакета>".
//
// Возвращаемое значение:
//   Структура - Имена параметров в разрезе имен областей.
//       * Ключ - Строка - Имя области,
//       * Значение - Строка - Имена параметров области через запятую.
//
Функция ИменаПараметровОбластейСтандартногоМакета(ПутьКМакету) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.ИменаПараметровОбластейСтандартногоМакета(ПутьКМакету) 
```
</details>

## ВывестиОбластьСФорматомСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит область макета в табличный документ с собственным форматом строк.
//
// Параметры:
//   ТабличныйДокумент - ТабличныйДокумент - Приемник, в который необходимо вывести область.
//   Макет             - ТабличныйДокумент - Источник, из которого необходимо вывести область.
//   ИмяОбласти        - Строка            - Имя области источника, которую необходимо вывести.
//                                           Если не указано, то выводится весь макет.
//
Процедура ВывестиОбластьСФорматомСтрок(ТабличныйДокумент, Макет, ИмяОбласти = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиОбластьСФорматомСтрок(ТабличныйДокумент, Макет, ИмяОбласти);
```
</details>

## МакетПоПолномуПути
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает макет по полному имени.
//
// Параметры:
//   ПутьКМакету - Строка - полный путь к макету в формате:
//       "Документ.<ИмяДокумента>.<ИмяМакета>"
//       "Обработка.<ИмяОбработки>.<ИмяМакета>"
//       "ОбщийМакет.<ИмяМакета>".
//
// Возвращаемое значение:
//    ТабличныйДокумент - Макет.
//
Функция МакетПоПолномуПути(ПутьКМакету) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.МакетПоПолномуПути(ПутьКМакету) 
```
</details>

## УстановитьОтступ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает размер полей отступа табличного документа в случае,
//  если величина полей отступа не переопределена пользователем
//  и соответствует умолчаниям табличного документа - 10.
//
// Параметры:
//   ТабличныйДокумент - ТабличныйДокумент - Табличный документ для вывода печатной формы.
//   ПолеСлева         - Число             - См. "ТабличныйДокумент.ПолеСлева"  в синтакс-помощнике.
//   ПолеСверху        - Число             - См. "ТабличныйДокумент.ПолеСверху" в синтакс-помощнике.
//   ПолеСправа        - Число             - См. "ТабличныйДокумент.ПолеСправа" в синтакс-помощнике.
//   ПолеСнизу         - Число             - См. "ТабличныйДокумент.ПолеСнизу"  в синтакс-помощнике.
//
Процедура УстановитьОтступ(ТабличныйДокумент, ПолеСлева, ПолеСверху, ПолеСправа, ПолеСнизу) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.УстановитьОтступ(ТабличныйДокумент, ПолеСлева, ПолеСверху, ПолеСправа, ПолеСнизу) 
```
</details>

## ПередПечатьюОчередногоОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит горизонтальный разделитель страниц в случае, если табличный документ не пустой,
//   и запоминает номер строки табличного документа, с которой начинается фрагмент очередного объекта.
//   См. также УправлениеПечатьюБЗК.ПослеОкончанияПечатиОчередногоОбъекта.
//
// Параметры:
//   КонтекстПечати - Структура - См. описание функции УправлениеПечатьюБЗК.КонтекстПечати.
//
Процедура ПередПечатьюОчередногоОбъекта(КонтекстПечати) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ПередПечатьюОчередногоОбъекта(КонтекстПечати) 
```
</details>

## ПослеПечатиОчередногоОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Задает область печати объекта в табличном документе.
//   Вызывается после УправлениеПечатьюБЗК.ПередНачаломПечатиОчередногоОбъекта.
//
// Параметры:
//   КонтекстПечати - Структура - См. описание функции УправлениеПечатьюБЗК.КонтекстПечати.
//   Ссылка - ЛюбаяСсылка - Объект печати. См. описание одноименного параметра
//       процедуры УправлениеПечатью.ЗадатьОбластьПечатиДокумента.
//
Процедура ПослеПечатиОчередногоОбъекта(КонтекстПечати, Ссылка) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ПослеПечатиОчередногоОбъекта(КонтекстПечати, Ссылка) 
```
</details>

## ИдентификаторПредупрежденияВШапкеПечатиДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется для вывода текста сообщения пользователю в виде предупреждения в шапке формы "Печать документов".
//
// Возвращаемое значение:
//   Строка - Значение реквизита Поле объекта СообщениеПользователю.
//       В реквизите Текст объекта СообщениеПользователю может быть как обычный тест,
//       так и шаблон форматированной строки (см. СтроковыеФункции.ФорматированнаяСтрока).
//
Функция ИдентификаторПредупрежденияВШапкеПечатиДокументов() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.ИдентификаторПредупрежденияВШапкеПечатиДокументов() 
```
</details>

## ПечатьДокументовПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. УправлениеПечатьюПереопределяемый.ПечатьДокументовПриСозданииНаСервере.
Процедура ПечатьДокументовПриСозданииНаСервере(Форма, Отказ, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ПечатьДокументовПриСозданииНаСервере(Форма, Отказ, СтандартнаяОбработка) 
```
</details>

## СекцияПечатнойФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает область печати как табличный документ и его параметры.
//
// Параметры:
//   КонтекстПечати - Структура - См. УправлениеПечатьюБЗК.КонтекстПечати.
//   ИмяОбласти     - Строка    - Имя области или адрес в формате "R1C1:R2C2" (пересечение в формате "<Имя1>|<Имя2>").
//
// Возвращаемое значение:
//   Структура - описание
//       * ТабличныйДокумент - ТабличныйДокумент - Табличный документ для вывода.
//       * ГруппыОбластей - Соответствие - См. УправлениеПечатьюБЗК.ГруппыОбластей.
//
Функция СекцияПечатнойФормы(КонтекстПечати, ИмяОбласти) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.СекцияПечатнойФормы(КонтекстПечати, ИмяОбласти) 
```
</details>

## ГруппыОбластей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает области табличного документа сгруппированные по именам.
//
// Параметры:
//   ТабличныйДокумент - ТабличныйДокумент
//
// Возвращаемое значение:
//   Соответствие - Имена и параметры областей.
//       * Ключ     - Строка    - Имя группы областей табличного документа.
//       * Значение - Структура - Описание группы областей табличного документа.
//           * КоличествоОбластей - Число - Количество областей в группе.
//           * Верхи    - Массив из Число - Варианты верхних координат ячеек области для определения количества строк.
//
Функция ГруппыОбластей(ТабличныйДокумент) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПечатьюБЗК.ГруппыОбластей(ТабличныйДокумент) 
```
</details>

## ВывестиАдресПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит адрес по буквам в секцию табличного документа.
//
// Параметры:
//   Секция     - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы;
//   Адрес      - Строка    - Значение контактной информации типа "Адрес" (строка json или xml).
//   Префикс    - Строка    - Префикс для определения областей вывода полей адреса.
//   ИменаПолей - Строка    - Имена полей адреса, перечисленные через запятую.
//       В табличном документе должны присутствовать области с именами "<Префикс>_<ИмяПоля>_<№>".
//
Процедура ВывестиАдресПоБуквам(Секция, Адрес, Префикс, ИменаПолей) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиАдресПоБуквам(Секция, Адрес, Префикс, ИменаПолей) 
```
</details>

## ВывестиТелефонПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит телефон по буквам в секцию табличного документа.
//
// Параметры:
//   Секция           - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы;
//   ЗначениеТелефона - Строка    - Значение контактной информации типа "Телефон" (строка json или xml).
//   ИмяГруппы        - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами "<ИмяГруппы>_<№>".
//
Процедура ВывестиТелефонПоБуквам(Секция, ЗначениеТелефона, ИмяГруппы) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиТелефонПоБуквам(Секция, ЗначениеТелефона, ИмяГруппы) 
```
</details>

## ВывестиДатуПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит дату по буквам в секцию табличного документа.
//
// Параметры:
//   Секция    - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы.
//   Дата      - Дата      - Выводимое значение.
//   ИмяГруппы - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами "<ИмяГруппы>_<№>".
//   ФорматнаяСтрока - Строка - См. описание 2го параметра метода глобального контекста "Формат".
//
Процедура ВывестиДатуПоБуквам(Секция, Дата, ИмяГруппы, ФорматнаяСтрока = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиДатуПоБуквам(Секция, Дата, ИмяГруппы, ФорматнаяСтрока);
```
</details>

## ВывестиСНИЛСПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит СНИЛС по буквам в секцию табличного документа.
//
// Параметры:
//   Секция    - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы.
//   СНИЛС     - Строка    - Страховой номер индивидуального лицевого счета.
//   ИмяГруппы - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами "<ИмяГруппы>_<№>".
//
Процедура ВывестиСНИЛСПоБуквам(Секция, СНИЛС, ИмяГруппы) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиСНИЛСПоБуквам(Секция, СНИЛС, ИмяГруппы) 
```
</details>

## ВывестиСуммуПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сумму числом в рублях и копейках по буквам в секцию табличного документа.
//
// Параметры:
//   Секция  - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы.
//   Сумма   - Число     - Выводимое значение.
//   Префикс - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами
//       "<Префикс>_Рублей_<№>" и "<Префикс>_Копеек_<№>".
//
Процедура ВывестиСуммуПоБуквам(Секция, Сумма, Префикс) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиСуммуПоБуквам(Секция, Сумма, Префикс) 
```
</details>

## ВывестиЧислоПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит число по буквам в секцию табличного документа.
//
// Параметры:
//   Секция    - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы;
//   Текст     - Строка    - Представление выводимого значения.
//   ИмяГруппы - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами "<ИмяГруппы>_<№>".
//   ВыравниваниеПоЛевомуКраю - Булево - Если Истина, то если длина выводимого текста меньше количества областей,
//       то текст прижимается к левому краю (сначала выводятся области слева).
//       Если Ложь - текст прижимается к правому краю (области выводятся с конца).
//
Процедура ВывестиЧислоПоБуквам(Секция, Число, ИмяГруппы, Обязательное = Истина, ФорматнаяСтрока = "ЧДЦ=0; ЧН=0; ЧГ=0") Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиЧислоПоБуквам(Секция, Число, ИмяГруппы, Обязательное, ФорматнаяСтрока);
```
</details>

## ВключитьФлажок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит текст по буквам в секцию табличного документа.
//
// Параметры:
//   Секция    - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы;
//   ИмяГруппы - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами "<ИмяГруппы>_<№>".
//
Процедура ВключитьФлажок(Секция, ИмяГруппы) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВключитьФлажок(Секция, ИмяГруппы) 
```
</details>

## ВывестиПоБуквам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит текст по буквам в секцию табличного документа.
//
// Параметры:
//   Секция    - Структура - См. УправлениеПечатьюБЗК.СекцияПечатнойФормы;
//   Текст     - Строка    - Представление выводимого значения.
//   ИмяГруппы - Строка    - Префикс для определения областей вывода полей адреса.
//       В табличном документе должны присутствовать области с именами "<ИмяГруппы>_<№>".
//   ВыравниваниеПоЛевомуКраю - Булево - Если Истина, то если длина выводимого текста меньше количества областей,
//       то текст прижимается к левому краю (сначала выводятся области слева).
//       Если Ложь - текст прижимается к правому краю (области выводятся с конца).
//
Процедура ВывестиПоБуквам(Секция, Текст, ИмяГруппы, ВыравниваниеПоЛевомуКраю = Истина) Экспорт
```

Пример вызова
```bsl
УправлениеПечатьюБЗК.ВывестиПоБуквам(Секция, Текст, ИмяГруппы, ВыравниваниеПоЛевомуКраю);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
