---
title: Учет депонированной зарплаты
slug: zup/учет-депонированной-зарплаты
---


## ЗарегистрироватьДепонированнуюЗарплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует факт депонирования зарплаты.
//
// Параметры:
//	Движения          - КоллекцияДвижений - наборы записей движений документа-регистратора.
//	Отказ             - Булево            - признак отказа при выполнении операции.
//	Зарплата          - ТаблицаЗначений   - депонируемая зарплата, см. НоваяТаблицаДепонированнойЗарплаты.
//	ОтражатьВБухучете - Булево            - если Истина, то операция будет отражена в бухгалтерском учета.
//
Процедура ЗарегистрироватьДепонированнуюЗарплату(Движения, Отказ, Знач Зарплата, ОтражатьВБухучете = Ложь) Экспорт
```

Пример вызова
```bsl
УчетДепонированнойЗарплаты.ЗарегистрироватьДепонированнуюЗарплату(Движения, Отказ, Зарплата, ОтражатьВБухучете);
```
</details>

## ОстатокДепонированнойЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения об остатках депонированной зарплаты.
//
// Параметры:
//	Регистратор 	- ДокументСсылка - документ-заказчик (его выплаты депонентов не учитываются).
//	Организация		- СправочникСсылка.Организации - Организация.
//	ДатаВыплаты		- Дата   - дата, на которую определяются остатки (дата выплаты депонированных сумм).
//  ФизическиеЛица	- Массив - физические лица (необязательное, если не указано - по всем физлицам).
//	ДепонированоДо	- Дата   - дата депонирования, по которую учитываются депонированные суммы.
//
// Возвращаемое значение:
//		ТаблицаЗначений - таблица с колонками:
//			ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица.
//			Сумма			- Число - остаток депонированной зарплаты.
//			Ведомость		- ДокументСсылка.ВедомостьНаВыплатуЗарплатыВКассу - ведомость, зарплата которой была депонирована.
//
Функция ОстатокДепонированнойЗарплаты(Регистратор, Организация, ДатаВыплаты, ФизическиеЛица = Неопределено, ДепонированоДо = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетДепонированнойЗарплаты.ОстатокДепонированнойЗарплаты(Регистратор, Организация, ДатаВыплаты, ФизическиеЛица, ДепонированоДо);
```
</details>

## СписатьДепонированнуюЗарплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует списание (выдачу) депонированных сумм.
//
// Параметры:
//	Движения     - КоллекцияДвижений - наборы записей движений документа-регистратора.
//	Отказ        - Булево            - признак отказа при выполнении операции.
//	Организация  - СправочникСсылка.Организации - организация.
//	ДатаСписания - Дата - дата списания депонированных сумм/
//	Зарплата     - ТаблицаЗначений - таблица списываемых сумм с колонками:
//	                   * ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - депонент.
//	                   * Сумма          - Число - списываемая (выдаваемая) сумма.
//	                   * Ведомость      - ДокументСсылка.ВедомостьНаВыплатуЗарплатыВКассу - ведомость, по которой была депонирована зарплата.
//	ОтражатьВБухучете        - Булево - если Истина, то операция будет отражена в бухгалтерском учета
//	НомерПлатежногоДокумента - Строка - номер платежного документа, которым выдается депонированная зарплата.
//
Процедура СписатьДепонированнуюЗарплату(Движения, Отказ, Организация, ДатаСписания, Знач Зарплата, ОтражатьВБухучете = Ложь, НомерПлатежногоДокумента = "") Экспорт
```

Пример вызова
```bsl
УчетДепонированнойЗарплаты.СписатьДепонированнуюЗарплату(Движения, Отказ, Организация, ДатаСписания, Зарплата, ОтражатьВБухучете, НомерПлатежногоДокумента);
```
</details>

## НоваяТаблицаДепонированнойЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор таблицы данных о депонируемой зарплате.
//
// Возвращаемое значение:
// 	ТаблицаЗначений - таблица с колонками:
// 		* Дата           - Дата - дата депонирования.
// 		* Организация    - СправочникСсылка.Организации - Организация.
// 		* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - Депонент.
// 		* Сумма - Число  - Депонируемая сумма.
// 		* Ведомость            - ДокументСсылка.ВедомостьНаВыплатуЗарплатыВКассу - ведомость, зарплата которой депонируется.
// 		* СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата   - Статья финансирования.
// 		* СтатьяРасходов       - СправочникСсылка.СтатьиРасходовЗарплата         - Статья расходов.
//
Функция НоваяТаблицаДепонированнойЗарплаты() Экспорт
```

Пример вызова
```bsl
Результат = УчетДепонированнойЗарплаты.НоваяТаблицаДепонированнойЗарплаты() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
