---
title: Учет НДФЛ формы
slug: zup/учет-ндфл-формы
---


## СведенияОДоходахПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает на форме доступность для редактирования полей доходов и вычетов таблицы сведений о доходах
//
// Параметры:
//  Форма                - ФормаКлиентскогоПриложения
//  КодДоходаПутьКДанным - Строка
//  ИмяПоляКодВычета     - Строка
//  ИмяПоляСуммаВычета   - Строка
//
Процедура СведенияОДоходахПриСозданииНаСервере(Форма, КодДоходаПутьКДанным, ИмяПоляКодВычета, ИмяПоляСуммаВычета = "") Экспорт
```

Пример вызова
```bsl
УчетНДФЛФормы.СведенияОДоходахПриСозданииНаСервере(Форма, КодДоходаПутьКДанным, ИмяПоляКодВычета, ИмяПоляСуммаВычета);
```
</details>

## МаксимальныйИдентификаторСтрокиНДФЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает максимальное значение идентификатора строки НДФЛ.
//
// Параметры:
//		ТаблицаНДФЛ - ДанныеФормыКоллекция
//
// Возвращаемое значение:
//		Число
//
Функция МаксимальныйИдентификаторСтрокиНДФЛ(ТаблицаНДФЛ) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДФЛФормы.МаксимальныйИдентификаторСтрокиНДФЛ(ТаблицаНДФЛ) 
```
</details>

## НазначитьИдентификаторыНовымСтрокамТаблицамНДФЛИПримененныеВычетыНаДетейИИмущественные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Назначает идентификаторы строкам таблицы значений НДФЛ и строкам связанной
// таблицы значений ПримененныеВычетыНаДетейИИмущественные, перед добавление в
// коллекции строк табличных частей объектов.
//
// Параметры:
//		МаксимальныйИдентификаторСтрокиНДФЛ - Число
//		ТаблицаНДФЛ - ТаблицаЗначений
//		ПримененныеВычетыНаДетейИИмущественные - ТаблицаЗначений
//
Процедура НазначитьИдентификаторыНовымСтрокамТаблицамНДФЛИПримененныеВычетыНаДетейИИмущественные(Знач МаксимальныйИдентификаторСтрокиНДФЛ, ТаблицаНДФЛ, ПримененныеВычетыНаДетейИИмущественные) Экспорт
```

Пример вызова
```bsl
УчетНДФЛФормы.НазначитьИдентификаторыНовымСтрокамТаблицамНДФЛИПримененныеВычетыНаДетейИИмущественные(МаксимальныйИдентификаторСтрокиНДФЛ, ТаблицаНДФЛ, ПримененныеВычетыНаДетейИИмущественные) 
```
</details>

## ЗаполнитьВторичныеДанныеТабличныхЧастей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет вторичные данные формы.
//
// Параметры:
//		Форма	- ФормаКлиентскогоПриложения
//		Период	- Дата, дата в налоговом периоде, в котором применяются вычеты к доходам.
//
Процедура ЗаполнитьВторичныеДанныеТабличныхЧастей(Форма, Период = '00010101', ВыбранныеСотрудники = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДФЛФормы.ЗаполнитьВторичныеДанныеТабличныхЧастей(Форма, Период, ВыбранныеСотрудники);
```
</details>

## РегистрНалоговогоУчетаПоНДФЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает табличный документ, содержащий печатную форму отчета РегистрНалоговогоУчетаПоНДФЛ,
// сформированный с учетом данных, содержащихся в документе из которого производится вызов.
//
// Параметры:
//		ДокументОбъект - ДокументОбъект, с учетом данных которого формируется отчет.
//		Модифицированность - Булево, признак модифицированности данных формы.
//		ФизическоеЛицо - СправочникСсылка.ФизическиеЛица, по которому формируется отчет.
//		ДатаОтчета - Дата, период за который формируется отчет.
//
// Возвращаемое значение:
//		ТабличныйДокумент
//
Функция РегистрНалоговогоУчетаПоНДФЛ(ДокументОбъект, Модифицированность, ФизическиеЛица, ДатаОтчета) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДФЛФормы.РегистрНалоговогоУчетаПоНДФЛ(ДокументОбъект, Модифицированность, ФизическиеЛица, ДатаОтчета) 
```
</details>

## ДополнитьФормуПанельюВычетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Размещает элементы управления панели вычетов НДФЛ, на управляемой форме, переданной
// в качестве параметра.
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения
//		ОписаниеПанелиВычеты - Структура, описывающая панель вычетов,
//					см. функцию УчетНДФЛКлиентСерверВнутренний.ОписаниеПанелиВычеты.
//
Процедура ДополнитьФормуПанельюВычетов(Форма, ОписаниеПанелиВычеты = Неопределено, ДобавлятьЭлементыФормы = Истина, ДобавлятьРеквизитыФормы = Истина, ОтложенноеИзменение = Ложь) Экспорт
```

Пример вызова
```bsl
УчетНДФЛФормы.ДополнитьФормуПанельюВычетов(Форма, ОписаниеПанелиВычеты, ДобавлятьЭлементыФормы, ДобавлятьРеквизитыФормы, ОтложенноеИзменение);
```
</details>

## ДополнитьМассивРеквизитовПанелиВычетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет реквизиты формы (в коллекцию добавляемых реквизитов), необходимые для работы панели вычетов.
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения
//		МассивДобавляемыхРеквизитов - Массив, в который добавляются новые реквизиты.
//		МассивИменРеквизитовФормы - Массив, строк, содержащих пути к данным реквизитам формы.
//      ОписаниеПанелиВычеты - Структура, описывающая панель вычетов,
//					см. функцию УчетНДФЛКлиентСерверВнутренний.ОписаниеПанелиВычеты.
//
Процедура ДополнитьМассивРеквизитовПанелиВычетов(Форма, МассивДобавляемыхРеквизитов, МассивИменРеквизитовФормы, ОписаниеПанелиВычеты = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДФЛФормы.ДополнитьМассивРеквизитовПанелиВычетов(Форма, МассивДобавляемыхРеквизитов, МассивИменРеквизитовФормы, ОписаниеПанелиВычеты);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
