---
title: Учет пособий социального страхования
slug: zup/учет-пособий-социального-страхования
---


## СформироватьПособия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистрам подсистемы.
// Параметры:
//		Движения - коллекция движений регистратора.
//		Отказ - булево - признак отказа от заполнения движений.
//		Организация - СправочникСсылка.Организации - должно быть непустым значением.
//		ПериодРегистрации
//		Пособия - таблица значений с колонками
//			ФизическоеЛицо: должно быть непустым
//          ВидПособияСоциальногоСтрахования
//          СуммаВсего.
//          Сотрудник - необязательная, может отсутствовать.
//          ВидЗанятости - необязательная, может отсутствовать.
//          ОплаченныеДни - необязательная, может отсутствовать.
//          СтраховыеСлучаи - необязательная, может отсутствовать.
//          ДатаСтраховогоСлучая - необязательная, может отсутствовать.
//          ФинансированиеФедеральнымБюджетом - необязательная, может отсутствовать.
//          СуммаСверхНорм - необязательная, может отсутствовать.
//		ПособияПоУходу - таблица значений с колонками
//			ФизическоеЛицо: должно быть непустым
//          СуммаВсего.
//          Сотрудник - необязательная, может отсутствовать.
//          ВидЗанятости - необязательная, может отсутствовать.
//          СтраховыеСлучаи - необязательная, может отсутствовать.
//          ДатаСтраховогоСлучая - необязательная, может отсутствовать.
//          ФинансированиеФедеральнымБюджетом - необязательная, может отсутствовать.
//          СуммаСверхНорм - необязательная, может отсутствовать.
//		Записывать - булево - признак того, надо ли записывать движения сразу, или они будут записаны позже.
//
Процедура СформироватьПособия(Движения, Отказ, Организация, ПериодРегистрации, Пособия, ПособияПоУходу, Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
УчетПособийСоциальногоСтрахования.СформироватьПособия(Движения, Отказ, Организация, ПериодРегистрации, Пособия, ПособияПоУходу, Записывать);
```
</details>

## ПредельнаяВеличинаБазыСтраховыхВзносов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Составляет соответствие размеров предельной величины базы страховых взносов,
//	действующих на указанные годы.
//
// Параметры:
//	Годы - массив элементов типа число.
//
// Возвращаемое значение - соответствие, где ключом является год, а значением - размер предельной величины.
//
Функция ПредельнаяВеличинаБазыСтраховыхВзносов(Годы) Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахования.ПредельнаяВеличинаБазыСтраховыхВзносов(Годы) 
```
</details>

## ЗарегистрироватьСтраховыеВзносыКакПособие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистрам подсистемы.
// Параметры:
//		Движения - коллекция движений регистратора.
//      	Должна содержать готовую таблицу рег-ра СтраховыеВзносыПоФизическимЛицам с полями:
//				ФизическоеЛицо,
//				Сотрудник,
//				Начисление,
//				ДатаНачала,
//				ПФРПоСуммарномуТарифу и пр. ресурсы рег-ра СтраховыеВзносыПоФизическимЛицам
//		Отказ - булево - признак отказа от заполнения движений.
//		Организация - СправочникСсылка.Организации - должно быть непустым значением.
//		ПериодРегистрации - дата -
//		Записывать - булево - признак того, надо ли записывать движения сразу, или они будут записаны позже.
//
Процедура ЗарегистрироватьСтраховыеВзносыКакПособие(Движения, Отказ, Организация, ПериодРегистрации, Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
УчетПособийСоциальногоСтрахования.ЗарегистрироватьСтраховыеВзносыКакПособие(Движения, Отказ, Организация, ПериодРегистрации, Записывать);
```
</details>

## НестраховойСтаж
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет продолжительность нестраховых периодов стажа на основании сведений о стаже из больничного.
//
// Параметры:
//   Больничный - ДокументОбъект.БольничныйЛист, ДанныеФормыСтруктура, Структура
//       * СтажРасширенныйЛет     - Число
//       * СтажРасширенныйМесяцев - Число
//       * СтажРасширенныйДней    - Число
//       * СтажЛет                - Число
//       * СтажМесяцев            - Число
//       * СтажДней               - Число
//
// Возвращаемое значение:
//    Структура
//        * Лет     - Число
//        * Месяцев - Число
//
Функция НестраховойСтаж(Больничный) Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахования.НестраховойСтаж(Больничный) 
```
</details>

## ПодсчитатьРазностьСтажейВГодахИМесяцах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать НестраховойСтаж.
// Возвращает разность стажей в годах и месяцах.
//
// Параметры:
//  БольшийСтажЛет, БольшийСтажМесяцев, МеньшийСтажЛет, МеньшийСтажМесяцев.
//
// Возвращаемое значение:
//   Структура - РазностьЛет, РазностьМесяцев.
//
Функция ПодсчитатьРазностьСтажейВГодахИМесяцах(БольшийСтажЛет, БольшийСтажМесяцев, МеньшийСтажЛет, МеньшийСтажМесяцев, БольшийСтажДней = 0, МеньшийСтажДней = 0) Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахования.ПодсчитатьРазностьСтажейВГодахИМесяцах(БольшийСтажЛет, БольшийСтажМесяцев, МеньшийСтажЛет, МеньшийСтажМесяцев, БольшийСтажДней, МеньшийСтажДней);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
