---
title: Учет пособий социального страхования расширенный
slug: zup/учет-пособий-социального-страхования-расширенный
---


## ДанныеДляРасчетаСреднегоЗаработкаФСССотрудника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о начислениях, отработанном времени и страхователях
// для расчета среднего заработка ФСС.
//
// Параметры:
//  ДанныеСотрудника - Структура - см. функцию ИсходныеДанныеСотрудникаДляРасчетаСреднегоЗаработкаФСС.
//	ОтборМесяцев - Массив - (необязательный) если определен, данные будут получены только за указанные месяцы.
//	ИсключаемыйРегистратор - (необязательный) документ, движения которого будут исключены из полученных данных.
//	УчитыватьКорректировки - Булево - учет ручных корректировок при получении данных для расчета среднего.
//
// Возвращаемое значение:
// 	Структура - со свойствами:
//     * ДанныеОНачислениях - ТаблицаЗначений - содержит колонки:
//        ** Период - Дата
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаФСС
//        ** СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата
//        ** СпособОтраженияЗарплатыВБухучете - СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете
//        ** СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//        ** ОблагаетсяЕНВД - Булево
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//        ** Сумма - Число
//     * ДанныеОВремени - ТаблицаЗначений - содержит колонки:
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** ГоловнаяОрганизация - СправочникСсылка.Организации
//        ** Период - Дата
//        ** ОтработаноДнейКалендарных - Число
//        ** ДнейБолезниУходаЗаДетьми - Число
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//     * ДанныеСтрахователей - ТаблицаЗначений - содержит колонки:
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** Год - Число
//        ** Страхователь - СправочникСсылка.Организации
//        ** Сумма - Число
//        ** ДнейБолезниУходаЗаДетьми - Число
//     * ПериодыОтсутствий - ТаблицаЗначений - содержит колонки:
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** ГоловнаяОрганизация - СправочникСсылка.Организации
//        ** ВидБолезниУходаЗаДетьми - Строка
//        ** Начало - Дата
//        ** Окончание - Дата
//        ** Дни - Число
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//
Функция ДанныеДляРасчетаСреднегоЗаработкаФСССотрудника( Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахованияРасширенный.ДанныеДляРасчетаСреднегоЗаработкаФСССотрудника();
```
</details>

## ИсходныеДанныеСотрудникаДляРасчетаСреднегоЗаработкаФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для ДанныеДляРасчетаСреднегоЗаработкаФСССотрудника.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//     * Сотрудник - СправочникСсылка.Сотрудники - сотрудник организации.
//     * ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаФСС - правила расчета среднего заработка ФСС.
//     * НачалоПериода - Дата - начало периода расчета среднего заработка.
//     * ОкончаниеПериода - Дата - окончание периода расчета среднего заработка.
//
Функция ИсходныеДанныеСотрудникаДляРасчетаСреднегоЗаработкаФСС() Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахованияРасширенный.ИсходныеДанныеСотрудникаДляРасчетаСреднегоЗаработкаФСС() 
```
</details>

## ДанныеДляРасчетаСреднегоЗаработкаФСССотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о начислениях, отработанном времени и страхователях
// для расчета среднего заработка ФСС.
//
// Параметры:
//  ДанныеСотрудников - ТаблицаЗначений - см. функцию ИсходныеДанныеСотрудниковДляРасчетаСреднегоЗаработкаФСС.
//	ОтборМесяцев - Массив - (необязательный) если определен, данные будут получены только за указанные месяцы.
//	ИсключаемыйРегистратор - (необязательный) документ, движения которого будут исключены из полученных данных.
//	УчитыватьКорректировки - Булево - учет ручных корректировок при получении данных для расчета среднего.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//     * ДанныеОНачислениях - ТаблицаЗначений - содержит колонки:
//        ** Период - Дата
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаФСС
//        ** СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата
//        ** СпособОтраженияЗарплатыВБухучете - СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете
//        ** СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//        ** ОблагаетсяЕНВД - Булево
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//        ** Сумма - Число
//     * ДанныеОВремени - ТаблицаЗначений - содержит колонки:
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** ГоловнаяОрганизация - СправочникСсылка.Организации
//        ** Период - Дата
//        ** ОтработаноДнейКалендарных - Число
//        ** ДнейБолезниУходаЗаДетьми - Число
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//     * ДанныеСтрахователей - ТаблицаЗначений - содержит колонки:
//        ** ФизическоеЛицо - СправочникСсылка.ФизическиеЛица
//        ** Год - Число
//        ** Страхователь - СправочникСсылка.Организации
//        ** Сумма - Число
//        ** ДнейБолезниУходаЗаДетьми - Число
//
Функция ДанныеДляРасчетаСреднегоЗаработкаФСССотрудников( Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахованияРасширенный.ДанныеДляРасчетаСреднегоЗаработкаФСССотрудников();
```
</details>

## ИсходныеДанныеСотрудниковДляРасчетаСреднегоЗаработкаФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую таблицу для ДанныеДляРасчетаСреднегоЗаработкаФСССотрудников.
//
// Возвращаемое значение:
//  ТаблицаЗначений - пустая таблица с колонками:
//     * Сотрудник - СправочникСсылка.Сотрудники - сотрудник организации.
//     * ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаФСС - правила расчета среднего заработка ФСС.
//     * НачалоПериода - Дата - начало периода расчета среднего заработка.
//     * ОкончаниеПериода - Дата - окончание периода расчета среднего заработка.
//
Функция ИсходныеДанныеСотрудниковДляРасчетаСреднегоЗаработкаФСС() Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахованияРасширенный.ИсходныеДанныеСотрудниковДляРасчетаСреднегоЗаработкаФСС() 
```
</details>

## ПредельнаяВеличинаБазыСтраховыхВзносов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать УчетПособийСоциальногоСтрахования.ПредельнаяВеличинаБазыСтраховыхВзносов.
Функция ПредельнаяВеличинаБазыСтраховыхВзносов(Годы) Экспорт
```

Пример вызова
```bsl
Результат = УчетПособийСоциальногоСтрахованияРасширенный.ПредельнаяВеличинаБазыСтраховыхВзносов(Годы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
