---
title: Учет среднего заработка
slug: zup/учет-среднего-заработка
---


## ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о начислениях, отработанном времени и коэффициентах индексации
// для расчета среднего заработка.
//
// Параметры:
//  ДанныеСотрудника - Структура - см. функцию ИсходныеДанныеСотрудникаДляРасчетаОбщегоСреднегоЗаработка.
//	ОтборМесяцев - Массив - (необязательный) если определен, данные будут получены только за указанные месяцы.
//	ИсключаемыйРегистратор - (необязательный) документ, движения которого будут исключены из полученных данных.
//	УчитыватьКорректировки - Булево - учет ручных корректировок при получении данных для расчета среднего.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//     * ДанныеОНачислениях - ТаблицаЗначений - содержит колонки:
//        ** Сотрудник - СправочникСсылка.Сотрудники
//        ** Период - Дата
//        ** ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаОбщий
//        ** СоставнаяЧасть - ПеречислениеСсылка.УчетНачисленийВСреднемЗаработкеОбщий
//        ** Индексируется - Булево
//        ** Сумма - Число
//        ** Год - Число
//        ** ДатаНачалаБазовогоПериода - Дата
//        ** КоличествоМесяцев - Число
//        ** СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата
//        ** СпособОтраженияЗарплатыВБухучете - СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете
//        ** СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//        ** ОблагаетсяЕНВД - Булево
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//     * ДанныеОВремени - ТаблицаЗначений - содержит колонки:
//        ** Сотрудник - СправочникСсылка.Сотрудники
//        ** Период - Дата
//        ** ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаОбщий
//        ** ОтработаноДней - Число
//        ** ОтработаноЧасов - Число
//        ** ОтработаноДнейПятидневка - Число
//        ** ОтработаноЧасовПятидневка - Число
//        ** ОтработаноДнейКалендарных - Число
//        ** ОтработаноДнейШестидневка - Число
//        ** НормаДнейПроизводственныйКалендарь - Число
//        ** НормаЧасовПроизводственныйКалендарь - Число
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//     * ДанныеОбИндексации - ТаблицаЗначений - содержит колонки:
//        ** Сотрудник - СправочникСсылка.Сотрудники
//        ** Период - Дата
//        ** КоэффициентИндексации - Число
//
Функция ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудника( Экспорт
```

Пример вызова
```bsl
Результат = УчетСреднегоЗаработка.ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудника();
```
</details>

## ИсходныеДанныеСотрудникаДляРасчетаОбщегоСреднегоЗаработка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудника.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//     * Сотрудник - СправочникСсылка.Сотрудники - сотрудник организации.
//     * ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаОбщий - правила расчета общего среднего заработка.
//     * ДатаНачалаСобытия - Дата - дата начала отпуска, командировки и т. д.
//     * НачалоПериодаРасчетаСреднего - Дата - начало периода расчета среднего заработка.
//     * ОкончаниеПериодаРасчетаСреднего - Дата - окончание периода расчета среднего заработка.
//
Функция ИсходныеДанныеСотрудникаДляРасчетаОбщегоСреднегоЗаработка() Экспорт
```

Пример вызова
```bsl
Результат = УчетСреднегоЗаработка.ИсходныеДанныеСотрудникаДляРасчетаОбщегоСреднегоЗаработка() 
```
</details>

## ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о начислениях, отработанном времени и коэффициентах индексации
// для расчета среднего заработка.
//
// Параметры:
//  ДанныеСотрудников - ТаблицаЗначений - см. функцию ИсходныеДанныеСотрудниковДляРасчетаОбщегоСреднегоЗаработка.
//	ОтборМесяцев - Массив - (необязательный) если определен, данные будут получены только за указанные месяцы.
//	ИсключаемыйРегистратор - (необязательный) документ, движения которого будут исключены из полученных данных.
//	УчитыватьКорректировки - Булево - учет ручных корректировок при получении данных для расчета среднего.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//     * ДанныеОНачислениях - ТаблицаЗначений - содержит колонки:
//        ** Сотрудник - СправочникСсылка.Сотрудники
//        ** Период - Дата
//        ** ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаОбщий
//        ** СоставнаяЧасть - ПеречислениеСсылка.УчетНачисленийВСреднемЗаработкеОбщий
//        ** Индексируется - Булево
//        ** Сумма - Число
//        ** Год - Число
//        ** ДатаНачалаБазовогоПериода - Дата
//        ** КоличествоМесяцев - Число
//        ** СтатьяФинансирования - СправочникСсылка.СтатьиФинансированияЗарплата
//        ** СпособОтраженияЗарплатыВБухучете - СправочникСсылка.СпособыОтраженияЗарплатыВБухУчете
//        ** СтатьяРасходов - СправочникСсылка.СтатьиРасходовЗарплата
//        ** ОблагаетсяЕНВД - Булево
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//     * ДанныеОВремени - ТаблицаЗначений - содержит колонки:
//        ** Сотрудник - СправочникСсылка.Сотрудники
//        ** Период - Дата
//        ** ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаОбщий
//        ** ОтработаноДней - Число
//        ** ОтработаноЧасов - Число
//        ** ОтработаноДнейПятидневка - Число
//        ** ОтработаноЧасовПятидневка - Число
//        ** ОтработаноДнейКалендарных - Число
//        ** ОтработаноДнейШестидневка - Число
//        ** НормаДнейПроизводственныйКалендарь - Число
//        ** НормаЧасовПроизводственныйКалендарь - Число
//        ** Источник - ПеречислениеСсылка.ИсточникиДанныхДляРасчетаСреднегоЗаработка
//     * ДанныеОбИндексации - ТаблицаЗначений - содержит колонки:
//        ** Сотрудник - СправочникСсылка.Сотрудники
//        ** Период - Дата
//        ** КоэффициентИндексации - Число
//
Функция ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудников( Экспорт
```

Пример вызова
```bsl
Результат = УчетСреднегоЗаработка.ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудников();
```
</details>

## ИсходныеДанныеСотрудниковДляРасчетаОбщегоСреднегоЗаработка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую таблицу для ДанныеДляРасчетаОбщегоСреднегоЗаработкаСотрудников.
//
// Возвращаемое значение:
//  ТаблицаЗначений - пустая таблица с колонками:
//     * Сотрудник - СправочникСсылка.Сотрудники - сотрудник организации.
//     * ПорядокРасчета - ПеречислениеСсылка.ПорядокРасчетаСреднегоЗаработкаОбщий - правила расчета общего среднего заработка.
//     * ДатаНачалаСобытия - Дата - дата начала отпуска, командировки и т. д.
//     * НачалоПериодаРасчетаСреднего - Дата - начало периода расчета среднего заработка.
//     * ОкончаниеПериодаРасчетаСреднего - Дата - окончание периода расчета среднего заработка.
//
Функция ИсходныеДанныеСотрудниковДляРасчетаОбщегоСреднегоЗаработка() Экспорт
```

Пример вызова
```bsl
Результат = УчетСреднегоЗаработка.ИсходныеДанныеСотрудниковДляРасчетаОбщегоСреднегоЗаработка() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
