---
title: Учет страховых взносов
slug: zup/учет-страховых-взносов
---


## СформироватьУплатуВзносовВФонд
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистрам подсистемы.
// Параметры:
//		Движения - коллекция движений регистратора.
//		Отказ - булево - признак отказа от заполнения движений.
//		Организация - СправочникСсылка.Организации - должно быть непустым значением.
//		РасчетыСФондом - ТаблицаЗначений - с колонками.
//			Период: должно быть непустым, дата осуществления платежа.
//          Сумма
//			ВидОбязательногоСтрахованияСотрудников: должно быть непустым
//          ЭтоСтраховыеВзносы (определяется по КБК платежа в бюджет)
//          ГодЗадолженностиПоЕСН: должно быть непустым для уплаты в ПФР, если ЭтоСтраховыеВзносы = Ложь.
//			ПлатежноеПоручениеНомер - Строка - необязательно, но желательно для уплаты взносов в ФСС.
//			ПлатежноеПоручениеДата - Дата - необязательно, но желательно для уплаты взносов в ФСС.
//		Записывать - булево - признак того, надо ли записывать движения сразу, или они будут записаны позже.
//
Процедура СформироватьУплатуВзносовВФонд(Движения, Отказ, Организация, РасчетыСФондом, Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
УчетСтраховыхВзносов.СформироватьУплатуВзносовВФонд(Движения, Отказ, Организация, РасчетыСФондом, Записывать);
```
</details>

## СформироватьВозмещениеРасходовПоСоциальномуСтрахованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистрам подсистемы.
// Параметры:
//		Движения - коллекция движений регистратора.
//		Отказ - булево - признак отказа от заполнения движений.
//		Организация - СправочникСсылка.Организации - должно быть непустым значением.
//		РасчетыСФондом - таблица значений с колонками.
//			Период: должно быть непустым.
//          Сумма
//			ВидОбязательногоСтрахованияСотрудников: должно быть непустым
//          ЭтоСтраховыеВзносы (определяется по назначению платежа в банковской выписке).
//		Записывать - булево - признак того, надо ли записывать движения сразу, или они будут записаны позже.
//
Процедура СформироватьВозмещениеРасходовПоСоциальномуСтрахованию(Движения, Отказ, Организация, РасчетыСФондом, Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
УчетСтраховыхВзносов.СформироватьВозмещениеРасходовПоСоциальномуСтрахованию(Движения, Отказ, Организация, РасчетыСФондом, Записывать);
```
</details>

## ОстатокВзносовКУплате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает остаток взносов к уплате.
//
// Параметры:
//		Организация - СправочникСсылка.Организации - должно быть непустым значением.
//		МесяцРасчетногоПериода - произвольный - необязателен, в алгоритме не используется (!), оставлен для совместимости.
//		ДатаЗаполнения - дата - дата, на конец дня которой определяются остатки.
//		ВидСтрахования - ПеречислениеСсылка.ВидыОбязательногоСтрахованияСотрудников - определяет фонд и конкретный вид страхования.
//      Ссылка - ДокументСсылка - необязателен, если передан регистратор, из остатков будут исключены суммы,
//                                зарегистрированное в учете этим регистратором.
//      ВидПлатежа - произвольный - необязателен, в алгоритме не используется (!), оставлен для совместимости.
//      ЭтоСтраховыеВзносы - булево - необязателен, если Истина, остаток определяется для взносов, введенных с 2010
//                                    года.
//      ГодЗадолженностиПоЕСН - число - необязателен, используется для остатков по ЕСН.
//
// Возвращаемое значение:
//  число - положительный остаток взносов, округленный до целых рублей.
//
Функция ОстатокВзносовКУплате(Организация, МесяцРасчетногоПериода = Неопределено, ДатаЗаполнения, ВидСтрахования, Ссылка = Неопределено, ВидПлатежа = Неопределено, ЭтоСтраховыеВзносы = Ложь, ГодЗадолженностиПоЕСН = 0) Экспорт
```

Пример вызова
```bsl
Результат = УчетСтраховыхВзносов.ОстатокВзносовКУплате(Организация, МесяцРасчетногоПериода, ДатаЗаполнения, ВидСтрахования, Ссылка, ВидПлатежа, ЭтоСтраховыеВзносы, ГодЗадолженностиПоЕСН);
```
</details>

## СформироватьРасчетыСФондом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистрам подсистемы.
// Параметры:
//		Движения - коллекция движений регистратора.
//		Отказ - булево - признак отказа от заполнения движений.
//		Организация - СправочникСсылка.Организации - должно быть непустым значением.
//		РасчетыСФондом - таблица значений с колонками.
//			Период: должно быть непустым.
//          Сумма
//			ВидОбязательногоСтрахованияСотрудников: должно быть непустым
//          ЭтоСтраховыеВзносы
//          ГодЗадолженностиПоЕСН: должно быть непустым, если ЭтоСтраховыеВзносы = Ложь
//          ВидДвижения: ВидДвиженияНакопления.Расход или ВидДвиженияНакопления.Приход.
//          РасчетыПоПособиям - необязательная, может отсутствовать.
//			ПлатежноеПоручениеНомер - Строка - необязательно, но желательно для уплаты взносов в ФСС.
//			ПлатежноеПоручениеДата - Дата - необязательно, но желательно для уплаты взносов в ФСС.
//		Записывать - булево - признак того, надо ли записывать движения сразу, или они будут записаны позже.
//
Процедура СформироватьРасчетыСФондом(Движения, Отказ, Организация, РасчетыСФондом, Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
УчетСтраховыхВзносов.СформироватьРасчетыСФондом(Движения, Отказ, Организация, РасчетыСФондом, Записывать);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
