---
title: Учет фактически полученных доходов
slug: zup/учет-фактически-полученных-доходов
---


## СопоставлениеКодовИКатегорийДоходовНДФЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Таблицу соответствия КодовДоходаНДФЛ, Категории начисления (для кода дохода 4800) и Категории дохода
// Если заполнен параметр КодДоходаНДФЛ тип СправочникСсылка.ВидыДоходовНДФЛ, то соответствие будет возвращено только
// для этого кода.
//
Функция СопоставлениеКодовИКатегорийДоходовНДФЛ(КодДоходаНДФЛ = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетФактическиПолученныхДоходов.СопоставлениеКодовИКатегорийДоходовНДФЛ(КодДоходаНДФЛ);
```
</details>

## СоздатьВТНалогУдержанный
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу "ВТНалогУдержанный" со сведениями об удержанном НДФЛ,
// с заполненной датой выплаты учтенных доходов.
//
// Параметры:
//   МенеджерВременныхТаблиц - МенеджерВременныхТаблиц, в котором будет создана временная таблица
//   ИсточникНДФЛ            - Запрос - источник данных о НДФЛ: запрос с текстом получения таблицы налога и установленными
//                                    параметрами
//                           - ТаблицаЗначений, ТабличнаяЧасть - источник данных о НДФЛ, описание колонок
//                                    см. Документ.ВедомостьНаВыплатуЗарплатыВКассу.НДФЛ
//   ДатаПолученияДохода     - Дата   - уточненная дата получения доходов
//   ИмяВТ                   - Строка - имя создаваемой временной таблицы.
//
Процедура СоздатьВТНалогУдержанный(МенеджерВременныхТаблиц, ИсточникНДФЛ, ДатаПолученияДохода, ИмяВТ = "ВТНалогУдержанный") Экспорт
```

Пример вызова
```bsl
УчетФактическиПолученныхДоходов.СоздатьВТНалогУдержанный(МенеджерВременныхТаблиц, ИсточникНДФЛ, ДатаПолученияДохода, ИмяВТ);
```
</details>

## ЗарегистрироватьНовуюДатуПолученияДохода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переносит ранее зарегистрированный доход на новую дату получения дохода
// Параметры:
//		Регистратор - ДокументСсылка - документ выплаты
//		МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - должен содержать временные таблицы
//      	ВТСписокСотрудников, с данными о выплатах вида:
//				ФизическоеЛицо: должно быть непустым
//          	СуммаВыплаты.
//          	ДокументОснование, необязательная
//          	СтатьяФинансирования, необязательная
//          	СтатьяРасходов, необязательная
//          	СуммаНачисленная, необязательная
//          	СуммаВыплаченная, необязательная,
//			Если колонки СуммаНачисленная, СуммаВыплаченная отсутствуют, возможная частичная выплата не будет учтена.
//		Движения - коллекция движений регистратора.
//		ДатаВыплаты - дата - новая дата получения дохода.
//		ДатаОперации - дата - дата, которой будет зарегистрировано движение.
//		Отказ - признак отказа от заполнения движений.
//
Процедура ЗарегистрироватьНовуюДатуПолученияДохода(Регистратор, Движения, МенеджерВременныхТаблиц, ДатаВыплаты, ДатаОперации, Отказ , Записывать = Ложь) Экспорт
```

Пример вызова
```bsl
УчетФактическиПолученныхДоходов.ЗарегистрироватьНовуюДатуПолученияДохода(Регистратор, Движения, МенеджерВременныхТаблиц, ДатаВыплаты, ДатаОперации, Отказ, Записывать);
```
</details>

## НовоеСоответствиеКодуДохода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НовоеСоответствиеКодуДохода(ТаблицаСоответствий, КодДохода, ОсновнаяКатегория, ДополнительныеКатегории = Неопределено, КатегорияНачисления = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетФактическиПолученныхДоходов.НовоеСоответствиеКодуДохода(ТаблицаСоответствий, КодДохода, ОсновнаяКатегория, ДополнительныеКатегории, КатегорияНачисления);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
