---
title: Физические лица зарплата кадры клиент сервер
slug: zup/физические-лица-зарплата-кадры-клиент-сервер
---


## ФамилияИнициалы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует краткое представление из полного имени физического лица.
//
// Параметры:
//  ФамилияИмяОтчество - Строка - полное имя в виде "Фамилия Имя Отчество";
//                     - Структура - части полного имени:
//                        * Фамилия  - Строка - фамилия;
//                        * Имя      - Строка - имя;
//                        * Отчество - Строка - отчество.
//                        * Инициалы - Строка
//
// Возвращаемое значение:
//  Строка - фамилия и инициалы. Например, "Пупкин В. И.".
//
// Пример:
//  ФизическиеЛицаЗарплатаКадрыКлиентСервер.ФамилияИнициалыФизЛица("Пупкин Василий Иванович") -> "Пупкин В. И.";
//
Функция ФамилияИнициалы(Знач ФамилияИмяОтчество) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаЗарплатаКадрыКлиентСервер.ФамилияИнициалы(ФамилияИмяОтчество) 
```
</details>

## ИнициалыПоИмениОтчеству
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует инициалы имени и отчества физического лица.
//
// Параметры:
//  Имя			- Строка;
//  Отчество	- Строка;
//
// Возвращаемое значение:
//  Строка - инициал имени, отчества.
//
Функция ИнициалыПоИмениОтчеству(Знач Имя, Знач Отчество) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаЗарплатаКадрыКлиентСервер.ИнициалыПоИмениОтчеству(Имя, Отчество) 
```
</details>

## ФИОИзЧастей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует строку вида "Фамилия Имя Отчество".
//
// Параметры:
// 	ЧастиИмени - Структура - см. ФизическиеЛицаКлиентСервер.ЧастиИмени.
//
// Возвращаемое значение:
// 	Строка - Фамилия Имя Отчество.
//
Функция ФИОИзЧастей(ЧастиИмени) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаЗарплатаКадрыКлиентСервер.ФИОИзЧастей(ЧастиИмени) 
```
</details>

## Возраст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает количество полных лет человека по дате его рождения.
// См. также ФизическиеЛицаЗарплатаКадры.Возраст.
//
// Параметры:
//  ДатаРождения - Дата - дата рождения человека, возраст которого нужно рассчитать,
//  ДатаВозраста - Дата - дата, на которую нужно рассчитать возраст.
//
// Возвращаемое значение:
//  Число, Неопределено - количество полных лет на указанную дату,
//						Неопределено, если дата рождения не заполнена.
//
Функция Возраст(ДатаРождения, ДатаВозраста) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаЗарплатаКадрыКлиентСервер.Возраст(ДатаРождения, ДатаВозраста) 
```
</details>

## ПредставлениеВозраста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление возраста человека.
// См. также ФизическиеЛицаЗарплатаКадры.ПредставлениеВозраста
//
// Параметры:
//  ДатаРождения - Дата - дата рождения человека, возраст которого нужно рассчитать,
//  ДатаВозраста - Дата - дата, на которую нужно рассчитать возраст.
//
// Возвращаемое значение:
//  Строка - количество полных лет (или месяцев, если возраст меньше года) на указанную дату с уточнением единицы времени.
//
// Пример:
//  "31 год", "28 лет", "42 года", "3 месяца" и т.д.
//
Функция ПредставлениеВозраста(ДатаРождения, ДатаВозраста) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаЗарплатаКадрыКлиентСервер.ПредставлениеВозраста(ДатаРождения, ДатаВозраста) 
```
</details>

## ПредставлениеПола
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Формирует представление пола физического лица Мужчина / Женщина.
//
// Параметры:
// 	Пол - ПеречислениеСсылка.ПолФизическогоЛица.
// Возвращаемое значение:
// 	Строка, Неопределено - Мужчина или Женщина, Неопределено, если Пол не задан.
//
Функция ПредставлениеПола(Пол) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаЗарплатаКадрыКлиентСервер.ПредставлениеПола(Пол) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
