---
title: Электронное взаимодействие
slug: zup/электронное-взаимодействие
---


## ОбработатьОшибку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает исключительные ситуации по электронным документам.
//
// Параметры:
//   ВидОперации - Строка - вид операции при которой возникло исключение.
//   ПодробныйТекстОшибки - Строка - описание ошибки.
//   ТекстСообщения - Строка - текст ошибки который выводится в виде сообщения.
//   КодСобытия - Строка - код события, используется для стандартизации иерархии событий.
//                Может принимать значения: "ЭлектронноеВзаимодействие" - Общая подсистема,
//                                          "ОбменСБанками" - Обмен с банками,
//                                          "ОбменСКонтрагентами" - Обмен с контрагентами,
//                                          "ОбменССайтами" - Обмен с сайтами,
//                                          "РегламентныеЗадания" - Регламентные задания,
//                                          "БизнесСеть" - Бизнес-сеть,
//                                          "ТорговыеПредложения" - торговые предложения.
//                                          "ИнтеграцияСЯндексКассой" - Интеграция с Яндекс.Кассой.
//   СсылкаНаОбъект - ДокументСсылка, СправочникСсылка - объект с которым связано данное событие.ЗаписатьОшибкуВЖурналРегистрации().
//
Процедура ОбработатьОшибку(ВидОперации, ПодробныйТекстОшибки, ТекстСообщения = "", КодСобытия = "ОбменСКонтрагентами", Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ОбработатьОшибку(ВидОперации, ПодробныйТекстОшибки, ТекстСообщения, КодСобытия, );
```
</details>

## НайтиСсылку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск ссылки на объект информационной базы по типу, идентификатору и дополнительным реквизитам.
//
// Параметры:
//  ТипОбъекта - Строка	 - идентификатор типа объекта, который необходимо найти. Поддерживаемые типы:
//    - Контрагенты
//    - Организации
//    - Банки
//    - БанковскиеСчетаОрганизаций
//    - БанковскиеСчетаКонтрагентов
//    - Валюты
//    - ЕдиницыИзмерения
//    - ВидыКонтактнойИнформации
//    - Номенклатура
//    - Партнеры
//    - ДоговорыКонтрагентов
//  Идентификатор			 - Строка	 - идентификатор объекта заданного типа. Поддерживаемые идентификаторы в разрезе типов:
//    - Контрагенты: отсутствует
//    - Организации: отсутствует
//    - Банки: отсутствует
//    - БанковскиеСчетаОрганизаций: номер счета
//    - БанковскиеСчетаКонтрагентов: номер счета
//    - Валюты: код валюты
//    - ЕдиницыИзмерения: код единицы измерения
//    - ВидыКонтактнойИнформации: "EmailКонтрагента", "ТелефонКонтрагента", "ФаксКонтрагента", "EmailОрганизации", "ТелефонОрганизации", "ФаксОрганизации".
//    - Номенклатура: отсутствует
//    - Партнеры: отсутствуют
//    - ДоговорыКонтрагентов: отсутствует
//  ДополнительныеРеквизиты	 - Структура - набор дополнительных полей объекта для поиска. Поддерживаемые ключи в разрезе типов:
//    - Контрагенты: ИНН, КПП, Наименование
//    - Организации: ИНН, КПП, Наименование
//    - Банки: Код (БИК)
//    - БанковскиеСчетаОрганизаций: Владелец (организация)
//    - БанковскиеСчетаКонтрагентов: Владелец (контрагент)
//    - Валюты: отсутствуют
//    - ЕдиницыИзмерения: наименование единицы
//    - ВидыКонтактнойИнформации: отсутствуют
//    - Номенклатура: Идентификатор (идентификатор номенклатуры поставщика), Артикул
//    - Партнеры: Контрагент
//    - ДоговорыКонтрагентов: НомерДоговора, ДатаДоговора, Организация, Владелец (контрагент)
// Возвращаемое значение:
//  Ссылка - ссылка на найденный объект.
//
Функция НайтиСсылку(ТипОбъекта, Идентификатор = "", ДополнительныеРеквизиты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.НайтиСсылку(ТипОбъекта, Идентификатор, ДополнительныеРеквизиты);
```
</details>

## ИмяНаличиеОбъектаРеквизитаВПрикладномРешении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение имени объекта или реквизита в прикладном решении.
//
// Параметры:
//  ИмяПараметра - Строка - наименование в библиотеке электронных документов.
//
// Возвращаемое значение:
//  Строка - наименование в прикладном решении.
//
Функция ИмяНаличиеОбъектаРеквизитаВПрикладномРешении(ИмяПараметра) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.ИмяНаличиеОбъектаРеквизитаВПрикладномРешении(ИмяПараметра) 
```
</details>

## ЭтоСсылочноеЗначениеДереваРазбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоСсылочноеЗначениеДереваРазбора(ДеревоРазбора, Значение, СтрокаПоСсылке = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.ЭтоСсылочноеЗначениеДереваРазбора(ДеревоРазбора, Значение, СтрокаПоСсылке);
```
</details>

## ЗаполнитьЗначениеРеквизитаВДереве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет значение в дереве данных.
//
// Параметры:
//  Дерево - ДеревоЗначений - дерево, содержащее данные электронного документа
//  Реквизит - Строка - содержит полный путь к реквизиту дерева.
//  Значение - Произвольный - сохраняемое в дереве значение.
//  ПараметрыОбработкиОшибок - Строка - используется, чтобы переопределить текст выводимой по реквизиту ошибки
//                                      без указания параметров действий по клику на ошибке.
//                           - Структура - используется для указания указания параметров действий по клику на ошибке,
//                                         формируется функцией ЭлектронноеВзаимодействиеКлиентСервер.НовыеПараметрыОбработкиОшибки.
//
Процедура ЗаполнитьЗначениеРеквизитаВДереве(Дерево, Реквизит, Значение, ПараметрыОбработкиОшибок = Неопределено) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ЗаполнитьЗначениеРеквизитаВДереве(Дерево, Реквизит, Значение, ПараметрыОбработкиОшибок);
```
</details>

## ЗагрузитьТаблицуВДерево
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает данные из таблицы значений в дерево значений.
//
// Параметры:
//  Дерево - ДеревоЗначений - дерево данных, в котором необходимо сохранить данные.
//  ТаблицаДанных - таблицаЗначений - записываемые в дерево данные. Таблица может предварительно дополняться данными
//                                    для обработки ошибок:
//                                    см. ЭлектронноеВзаимодействие.ДобавитьВТаблицуОбработкуОшибкиЧерезСообщениеПользователю,
//                                    ЭлектронноеВзаимодействие.ДобавитьВТаблицуОбработкуОшибкиЧерезНавигационнуюСсылку,
//                                    ЭлектронноеВзаимодействие.ДобавитьВТаблицуОбработкуОшибкиЧерезОткрытиеФормы.
//
//  НазваниеТаблицы - Строка - название таблицы в дереве.
//
Процедура ЗагрузитьТаблицуВДерево(Дерево, ТаблицаДанных, НазваниеТаблицы) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ЗагрузитьТаблицуВДерево(Дерево, ТаблицаДанных, НазваниеТаблицы) 
```
</details>

## ЗагрузитьСтруктуруВГруппуДерева
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает данные из структуры в группу дерева значений
//
// Параметры:
//  Дерево - ДеревоЗначений - дерево данных, в котором необходимо сохранить данные
//  СтруктураДанных - Структура - данные, которые должны быть загружены в группу
//  Путь - Строка - название группы в дереве.
//
Процедура ЗагрузитьСтруктуруВГруппуДерева(Дерево, СтруктураДанных, Путь) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ЗагрузитьСтруктуруВГруппуДерева(Дерево, СтруктураДанных, Путь) 
```
</details>

## СтрокаДерева
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку дерева значений для заполнения в прикладном решении
//
// Параметры:
//  ДеревоДанных - ДеревоЗначений - дерево с данными
//  НазваниеПоля - Строка - название поля в дереве, содержащее полный путь к реквизиту
//  НайтиРекурсивно - Булево - если требуется рекурсивный поиск.
//
// Возвращаемое значение:
//  СтрокаДереваЗначений - содержит строку дерева.
//
Функция СтрокаДерева(ДеревоДанных, НазваниеПоля, НайтиРекурсивно = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.СтрокаДерева(ДеревоДанных, НазваниеПоля, НайтиРекурсивно);
```
</details>

## ДобавитьДопДанныеВДерево
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре происходит добавление данных из СтруктурыДанных в ДеревоЗначений.
//
// Параметры:
//  СтрокаДерева - ДеревоЗначений, СтрокаДереваЗначений - содержит данные.
//  СтруктураДопДанных - Структура - данные, которые необходимо поместить в дерево.
//  ЮридическиЗначимый - Булево - если Истина - то текущие данные необходимо по возможности поместить в основной ЭД.
//  ДобавлятьНовыеСтроки - Булево - если Истина - разрешает добавление строк с одинаковым путем в дерево.
//
Процедура ДобавитьДопДанныеВДерево(СтрокаДерева, СтруктураДопДанных, ЮридическиЗначимый = Ложь, ДобавлятьНовыеСтроки = Ложь) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ДобавитьДопДанныеВДерево(СтрокаДерева, СтруктураДопДанных, ЮридическиЗначимый, ДобавлятьНовыеСтроки);
```
</details>

## НазваниеКолонки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает название реквизита из полного пути
//
// Параметры:
//  ПолныйПуть - Строка - Полный путь до реквизита в дереве.
//
// Возвращаемое значение:
//  Строка - Название реквизита
//
Функция НазваниеКолонки(ПолныйПуть) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.НазваниеКолонки(ПолныйПуть) 
```
</details>

## СуществуетРеквизитВДереве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет существование реквизита в дереве, по указанному пути.
//
// Параметры:
//  ДеревоДанных - ДеревоЗначений - область данных поиска.
//  ПолныйПуть - Строка - полный путь к реквизиту. Составляющие пути разделяются точками.
//
// Возвращаемое значение:
//  Булево - Истина, если реквизит существует.
//
Функция СуществуетРеквизитВДереве(ДеревоДанных, ПолныйПуть) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.СуществуетРеквизитВДереве(ДеревоДанных, ПолныйПуть) 
```
</details>

## ДанныеЭлементаДереваЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные элемента дерева, находящегося по указанному пути.
//
// Параметры:
// 	ДеревоДанных - ДеревоЗначений - область данных поиска.
//  ПолныйПуть - Строка - полный путь к реквизиту. Составляющие пути разделяются точками.
// Возвращаемое значение:
//  ТаблицаЗначений - в случае, если указанный реквизит имеет тип "Таблица"
//  Структура - если указанный реквизит имеет тип "Выбор" или "Группа"
//  Произвольный - если указанный реквизит является конечным реквизитом дерева.
//
Функция ДанныеЭлементаДереваЭлектронногоДокумента(ДеревоДанных, ПолныйПуть) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.ДанныеЭлементаДереваЭлектронногоДокумента(ДеревоДанных, ПолныйПуть) 
```
</details>

## ЗначениеРеквизитаВДереве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение реквизита в дереве.
//
// Параметры:
//  ДеревоДанных - ДеревоЗначений - объект поиска.
//  ПолныйПуть - Строка - полный путь к реквизиту. Составляющие пути разделяются точками.
//  СообщатьОбОшибке - Булево - если Истина сообщать об ошибках поиска.
//
// Возвращаемое значение:
//  Произвольный - результат поиска.
//
Функция ЗначениеРеквизитаВДереве(ДеревоДанных, ПолныйПуть, СообщатьОбОшибке = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.ЗначениеРеквизитаВДереве(ДеревоДанных, ПолныйПуть, СообщатьОбОшибке);
```
</details>

## ЗначениеРеквизитаСтрокиДереваРазбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Значение реквизита строки дерева разбора.
//
// Параметры:
//  ДеревоРазбора	 - ДеревоЗначений - объект поиска.
//  СтрокаДерева	 - КоллекцияСтрокДереваЗначений - строка дерева значений.
//  ПутьКРеквизиту	 - Строка - путь к реквизиту.
//
// Возвращаемое значение:
//  Произвольный - результат поиска.
//
Функция ЗначениеРеквизитаСтрокиДереваРазбора(ДеревоРазбора, СтрокаДерева, ПутьКРеквизиту) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.ЗначениеРеквизитаСтрокиДереваРазбора(ДеревоРазбора, СтрокаДерева, ПутьКРеквизиту) 
```
</details>

## ДобавитьВРеквизитОбработкуОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Задает параметры обработки ошибок для реквизита дерева электронного документа.
//
// Параметры:
//  Дерево - ДеревоЗначений - дерево, содержащее данные электронного документа
//  Реквизит - Строка - содержит полный путь к реквизиту дерева.
//  ПараметрыОбработкиОшибок - Строка - используется, чтобы переопределить текст выводимой по реквизиту ошибки
//                                      без указания параметров действий по клику на ошибке.
//                           - Структура - используется для указания указания параметров действий по клику на ошибке,
//                                         формируется функцией ЭлектронноеВзаимодействиеКлиентСервер.НовыеПараметрыОбработкиОшибки.
//
Процедура ДобавитьВРеквизитОбработкуОшибки(Дерево, Реквизит, ПараметрыОбработкиОшибок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ДобавитьВРеквизитОбработкуОшибки(Дерево, Реквизит, ПараметрыОбработкиОшибок) 
```
</details>

## ДобавитьВТаблицуОбработкуОшибкиЧерезСообщениеПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет в таблице значений, подлежащей загрузке в дерево электронного документа, параметры ошибок
// для обработки через механизм сообщений пользователю.
//
// Параметры:
//  СтрокиТаблицы	 - Массив - строки таблицы значений, в которых нужно заполнить параметры обработки ошибок.
//                   - ТаблицаЗначений - таблица значений, в каждой строке которой нужно сохранить переданные
//                                       параметры обработки ошибок.
//  ПолеТаблицы		 - Строка - имя колонки таблицы, для которой указываются параметры обработки ошибок.
//  КлючДанных		 - Строка - имя колонки таблицы, значение которой будет использовано в качестве ключа данных
//                              при выводе сообщения пользователю.
//                   - ЛюбаяСсылка - ссылка, значение которой будет использовано в качестве ключа при выводе
//                                   сообщения пользователю.
//  ПутьКДанным		 - Строка - путь к данным, который будет указан в сообщении пользователю. Если указывается путь
//                              к реквизиту таблицы, скобки ("[", "]") указывать не следует. Передача индекса строки
//                              производится через параметр "ПолеНомераСтроки".
//  ТекстОшибки		 - Строка - используется, чтобы переопределить текст выводимой по реквизиту ошибки.
//  ПолеНомераСтроки - Строка - имя колонки таблицы, из которой будет подставляться в параметр "ПутьКДанным"
//                              индекс строки.
//
Процедура ДобавитьВТаблицуОбработкуОшибкиЧерезСообщениеПользователю(СтрокиТаблицы, ПолеТаблицы, КлючДанных = "", Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ДобавитьВТаблицуОбработкуОшибкиЧерезСообщениеПользователю(СтрокиТаблицы, ПолеТаблицы, КлючДанных, );
```
</details>

## ДобавитьВТаблицуОбработкуОшибкиЧерезНавигационнуюСсылку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет в таблице значений, подлежащей загрузке в дерево электронного документа, параметры ошибок
// для обработки через механизм навигационных ссылок.
// Примечание: в данной версии библиотеки не используется.
//
// Параметры:
//  СтрокиТаблицы	        - Массив - строки таблицы значений, в которых нужно заполнить параметры обработки ошибок.
//                          - ТаблицаЗначений - таблица значений, в каждой строке которой нужно сохранить переданные
//                                              параметры обработки ошибок.
//  ПолеТаблицы		        - Строка - имя колонки таблицы, для которой указываются параметры обработки ошибок.
//  ПолеНавигационнойСсылки - Строка - имя колонки таблицы, из которой будет извлекаться навигационная ссылка для
//                                     открытия формы при клике на ошибку.
//
Процедура ДобавитьВТаблицуОбработкуОшибкиЧерезНавигационнуюСсылку(СтрокиТаблицы, ПолеТаблицы, ПолеНавигационнойСсылки) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ДобавитьВТаблицуОбработкуОшибкиЧерезНавигационнуюСсылку(СтрокиТаблицы, ПолеТаблицы, ПолеНавигационнойСсылки) 
```
</details>

## ДобавитьВТаблицуОбработкуОшибкиЧерезОткрытиеФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет в таблице значений, подлежащей загрузке в дерево электронного документа, параметры ошибок
// для обработки через открытие формы.
// Примечание: в данной версии библиотеки не используется.
//
// Параметры:
//  СтрокиТаблицы	           - Массив - строки таблицы значений, в которых нужно заполнить параметры обработки ошибок.
//                             - ТаблицаЗначений - таблица значений, в каждой строке которой нужно сохранить переданные
//                                              параметры обработки ошибок.
//  ПолеТаблицы		           - Строка - имя колонки таблицы, для которой указываются параметры обработки ошибок.
//  ИмяФормы                   - Строка - полное имя формы, которую нужно открыть при клике по ошибке.
//  СтатичныеПараметрыФормы    - Структура - структура, которая будет передана в форму в качестве параметров.
//  ДинамическиеПараметрыФормы - Структура - описывает параметры, передаваемые в открываемую форму, значения по которым
//                                           формируются для каждой строки таблицы индивидуально:
//                                 * Ключ     - Строка - содержит имя параметра.
//                                 * Значение - Строка - имя поля таблицы, содержащего значение параметра.
//
Процедура ДобавитьВТаблицуОбработкуОшибкиЧерезОткрытиеФормы(СтрокиТаблицы, ПолеТаблицы, ИмяФормы, Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействие.ДобавитьВТаблицуОбработкуОшибкиЧерезОткрытиеФормы(СтрокиТаблицы, ПолеТаблицы, ИмяФормы, );
```
</details>

## СтруктураДанныхЮрФизЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует пустую структура данных о юридическом (физическом) лице.
//
// Возвращаемое значение:
//  Структура - возвращаемые данные:
//   * Ссылка                        - СправочникСсылка - ссылка на физическое или юридическое лицо
//   * ИНН                           - Строка - ИНН.
//   * КПП                           - Строка - КПП.
//   * ПолноеНаименование            - Строка - полное наименование.
//   * Наименование                  - Строка - наименование.
//   * Представление                 - Строка - представление юр/физ лица.
//   * СокращенноеНаименование       - Строка - сокращенное наименование.
//   * ОфициальноеНаименование       - Строка - наименование юридического лица.
//   * КодПоОКПО                     - Строка - код ОКПО.
//   * ЮридическийАдрес              - Строка - представление юридического адреса.
//   * ФактическийАдрес              - Строка - представление фактического адреса.
//   * ФактическийАдресИдентификатор - Строка - идентификатор ФИАС фактического адреса. Не обязательно для заполнения.
//   * ПочтовыйАдрес                 - Строка - представление почтового адреса.
//   * Телефоны                      - Строка - представление телефонов.
//   * ЭлектроннаяПочта              - Строка - представление электронной почты.
//   * Фамилия                       - Строка - фамилия.
//   * Имя                           - Строка - имя.
//   * Отчество                      - Строка - отчество.
//   * ЮрФизЛицо                     - ПеречислениеСсылка - тип юр/физ лица.
//   * ОГРН                          - Строка - ОГРН.
//   * СвидетельствоСерияНомер       - Строка - серия и номер свидетельства.
//   * СвидетельствоДатаВыдачи       - Строка - дата выдачи свидетельства.
//   * Банк                          - СправочникСсылка - банк, в котором открыт счет.
//   * БИК                           - Строка - БИК банка, в котором открыт счет.
//   * КоррСчет                      - Строка - Корр счет банка, в котором открыт счет.
//   * НомерСчета                    - Строка - Номер счета.
//   * ЮридическийАдресXML           - Строка - устаревший XML, соответствующий XDTO пакетам Адрес. Для обратной совместимости.
//   * ФактическийАдресXML           - Строка - устаревший XML, соответствующий XDTO пакетам Адрес. Для обратной совместимости.
//   * ПочтовыйАдресXML              - Строка - устаревший XML, соответствующий XDTO пакетам Адрес. Для обратной совместимости.
//   * ТелефоныXML                   - Строка - устаревший XML, соответствующий XDTO пакетам Телефон. Для обратной совместимости.
//
Функция СтруктураДанныхЮрФизЛица() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.СтруктураДанныхЮрФизЛица() 
```
</details>

## СтруктураДанныхФизЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует пустую структура данных о (физическом) лице.
//
// Возвращаемое значение:
//  Структура - возвращаемые данные:
//   * Ссылка                       - СправочникСсылка - ссылка на физическое лицо
//   * ДатаРождения                 - Дата 	 - датаРождения.
//   * ИНН                          - Строка - ИНН.
//   * МестоРождения            	- Строка - местоРождения.
//   * Пол                  		- Строка - пол.
//   * СтраховойНомерПФР            - Строка - страховой номер ПФР.
//   * ФИО       					- Строка - ФИО.
//   * Фамилия       				- Строка - фамилия.
//   * Имя                     		- Строка - имя.
//   * Отчество             		- Строка - отчество.
//   * Гражданство              	- СправочникСсылка - Справочник СтраныМира.
//
Функция СтруктураДанныхФизЛица() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействие.СтруктураДанныхФизЛица() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
