---
title: Электронное взаимодействие клиент переопределяемый
slug: zup/электронное-взаимодействие-клиент-переопределяемый
---


## ВыполнитьПроверкуПроведенияДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет интерактивное проведение документов перед формированием ЭД.
// Если есть непроведенные документы, предлагает выполнить проведение. Спрашивает
// пользователя о продолжении, если какие-то из документов не провелись и имеются проведенные.
//
// Параметры:
//  ДокументыМассив - Массив - Ссылки на документы, которые требуется провести перед формированием электронных документов.
//                             После выполнения функции из массива исключаются непроведенные документы.
//  ОбработкаПродолжения - ОписаниеОповещения - содержит описание процедуры,
//                         которая должна быть вызвана после завершения проверки документов.
//  ФормаИсточник - ФормаКлиентскогоПриложения - форма, из которой была вызвана команда.
//  СтандартнаяОбработка - Булево - если значение установлено в Ложь, то стандартная обработка не выполняется.
//
//@skip-warning
Процедура ВыполнитьПроверкуПроведенияДокументов(ДокументыМассив, ОбработкаПродолжения, ФормаИсточник = Неопределено, СтандартнаяОбработка = Истина) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ВыполнитьПроверкуПроведенияДокументов(ДокументыМассив, ОбработкаПродолжения, ФормаИсточник, СтандартнаяОбработка);
```
</details>

## ОткрытьФормуОбращенияВТехПоддержку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму обращения в службу технической поддержки
//
// Параметры:
//  ДанныеДляТехПоддержки                     - Структура - данные, которые можно передать в переопределенную форму:
//     * АдресФайлаДляТехПоддержки            - Строка - адрес во временном хранилище файла с технической информацией.
//     * ТелефонСлужбыПоддержки               - Строка - телефон службы технической поддержки.
//     * АдресЭлектроннойПочтыСлужбыПоддержки - Строка - email службы технической поддержки.
//     * ТекстОбращения                       - Строка - текст обращения в службу технической поддержки.
//  СтандартнаяОбработка                      - Булево - если метод реализован, то необходимо установить значение Ложь.
//
//@skip-warning
Процедура ОткрытьФормуОбращенияВТехПоддержку(ДанныеДляТехПоддержки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ОткрытьФормуОбращенияВТехПоддержку(ДанныеДляТехПоддержки, СтандартнаяОбработка) 
```
</details>

## ПриОткрытииФормыПодсистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Общие замечания для методов области "ПереопределениеФормПодсистемы".
// Поддерживается переопределение форм со следующим назначением и стандартными элементами:
// * "СопоставлениеНоменклатуры" - форма сопоставления номенклатуры.
//  ** "Характеристика" - колонка характеристики ИБ таблицы сопоставления.
//  ** "Упаковка" - колонка упаковки ИБ таблицы сопоставления.
// Описание параметра "Контекст" для всех методов области:
//  * Назначение - Строка - назначение формы (см. выше).
//  * Форма - ФормаКлиентскогоПриложения - форма, для которой вызвано событие.
//  * Префикс - Строка - префикс имен для новых реквизитов, команд и элементов формы.
//  * СтандартныйЭлемент - Строка - идентификатор стандартного элемента (см. выше), для которого вызвано событие.
//                       - Неопределено - событие вызвано для элемента, добавленного в переопределяемой части.

// Выполняется при открытии формы подсистемы.
// Позволяет выполнить дополнительные действия с формой на клиенте.
//
// Параметры:
//  Контекст - ФиксированнаяСтруктура - контекст создания формы. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Отказ - Булево - аналогичен параметру обработчика события "ПриОткрытии" управляемой формы.
//
// Пример:
//  Если ВРег(Контекст.Назначение) = ВРег("СопоставлениеНоменклатуры") Тогда
//  	// действия с формой на клиенте...
//  КонецЕсли;
//
//@skip-warning
Процедура ПриОткрытииФормыПодсистемы(Контекст, Отказ) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ПриОткрытииФормыПодсистемы(Контекст, Отказ) 
```
</details>

## ЭлементФормыПодсистемыПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ПриИзменении элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыПриИзменении(Контекст, Элемент) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыПриИзменении(Контекст, Элемент) 
```
</details>

## ЭлементФормыПодсистемыНачалоВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события НачалоВыбора элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  ДанныеВыбора - СписокЗначений - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыНачалоВыбора(Контекст, Элемент, ДанныеВыбора, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыНачалоВыбора(Контекст, Элемент, ДанныеВыбора, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыНачалоВыбораИзСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события НачалоВыбораИзСписка элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыНачалоВыбораИзСписка(Контекст, Элемент, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыНачалоВыбораИзСписка(Контекст, Элемент, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыОчистка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события Очистка элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыОчистка(Контекст, Элемент, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыОчистка(Контекст, Элемент, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыСоздание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события Создание элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыСоздание(Контекст, Элемент, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыСоздание(Контекст, Элемент, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыОбработкаВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаВыбора элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  ВыбранноеЗначение - Произвольный - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыОбработкаВыбора(Контекст, Элемент, ВыбранноеЗначение, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыОбработкаВыбора(Контекст, Элемент, ВыбранноеЗначение, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыИзменениеТекстаРедактирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ИзменениеТекстаРедактирования элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  Текст - Строка - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыИзменениеТекстаРедактирования(Контекст, Элемент, Текст, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыИзменениеТекстаРедактирования(Контекст, Элемент, Текст, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыАвтоПодбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события АвтоПодбор элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  Текст - Строка - см. описание параметра события элемента формы.
//  ДанныеВыбора - СписокЗначений  - см. описание параметра события элемента формы.
//  ПараметрыПолученияДанных - Структура, Неопределено - см. описание параметра события элемента формы.
//  Ожидание - Число - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыАвтоПодбор(Контекст, Элемент, Текст, ДанныеВыбора, ПараметрыПолученияДанных, Ожидание, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыАвтоПодбор(Контекст, Элемент, Текст, ДанныеВыбора, ПараметрыПолученияДанных, Ожидание, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыОкончаниеВводаТекста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОкончаниеВводаТекста элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  Текст - Строка - см. описание параметра события элемента формы.
//  ДанныеВыбора - СписокЗначений  - см. описание параметра события элемента формы.
//  ПараметрыПолученияДанных - Структура, Неопределено - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыОкончаниеВводаТекста(Контекст, Элемент, Текст, ДанныеВыбора, ПараметрыПолученияДанных, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыОкончаниеВводаТекста(Контекст, Элемент, Текст, ДанныеВыбора, ПараметрыПолученияДанных, СтандартнаяОбработка) 
```
</details>

## ЭлементФормыПодсистемыНажатие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события Нажатие элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыНажатие(Контекст, Элемент) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыНажатие(Контекст, Элемент) 
```
</details>

## ЭлементФормыПодсистемыОбработкаНавигационнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик события ОбработкаНавигационнойСсылки элемента формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Элемент - ПолеФормы - см. описание параметра события элемента формы.
//  НавигационнаяСсылкаФорматированнойСтроки - Строка - см. описание параметра события элемента формы.
//  СтандартнаяОбработка - Булево - см. описание параметра события элемента формы.
//
//@skip-warning
Процедура ЭлементФормыПодсистемыОбработкаНавигационнойСсылки(Контекст, Элемент, НавигационнаяСсылкаФорматированнойСтроки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.ЭлементФормыПодсистемыОбработкаНавигационнойСсылки(Контекст, Элемент, НавигационнаяСсылкаФорматированнойСтроки, СтандартнаяОбработка) 
```
</details>

## КомандаФормыПодсистемыДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действие команды формы подсистемы.
//
// Параметры:
//  Контекст - Структура - контекст выполнения метода. См. общие замечания области "ПереопределениеФормПодсистемы".
//  Команда - КомандаФормы - см. описание параметра действия команды формы.
//
//@skip-warning
Процедура КомандаФормыПодсистемыДействие(Контекст, Команда) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеКлиентПереопределяемый.КомандаФормыПодсистемыДействие(Контекст, Команда) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
