---
title: Электронный документооборот с ФСС клиент
slug: zup/электронный-документооборот-с-фсс-клиент
---


## ПолучитьДанныеЭЛНИзФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение от веб-сервису СФР и расшифровка, проверка подписи листка нетрудоспособности.
//
// Параметры:
//  ВыполняемоеОповещение       - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат                            - Структура:
//      * ПодписьВалидна                     - Булево - результат проверки подписи.
//      * АдресРасшифрованногоОтветаSOAP     - Строка - адрес во временном хранилище незашифрованного ответа SOAP от веб-сервиса СФР.
//                                         - Неопределено - при ошибке.
//
//  ЗапросДляПолученияЭЛН - Структура:
//    * Организация                - СправочникСсылка.Организации - организация, сертификатом которой для ФСС подписывать.
//    * РегистрационныйНомерФСС    - Строка - регистрационный номер СФР или регистрационный номер ФСС организации.
//    * ЭтоРегистрационныйНомерСФР - Булево или Неопределено - необязательный ключ, указывает на передачу в ключе
//                                   "РегистрационныйНомерФСС" регистрационного номера СФР.
//    * ТекстXML                   - Строка - XML запроса SOAP операции с листком нетрудоспособности без подписи.
//
Процедура ПолучитьДанныеЭЛНИзФСС(ВыполняемоеОповещение, ЗапросДляПолученияЭЛН) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПолучитьДанныеЭЛНИзФСС(ВыполняемоеОповещение, ЗапросДляПолученияЭЛН) 
```
</details>

## ОтправитьВыгрузкуРеестраДанныхЭЛНВСервисФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подписание, шифрование, отправка на веб-сервису ФСС реестра электронных листков нетрудоспособности и получение результатов.
//
// Параметры:
//  ВыполняемоеОповещение   - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат                            - Структура:
//      * ПодписьВалидна                     - Булево - результат проверки подписи.
//      * АдресРасшифрованногоОтветаSOAP     - Строка - адрес во временном хранилище незашифрованного ответа SOAP от веб-сервиса ФСС.
//                                         - Неопределено - при ошибке.
//
//  ВыгрузкаРеестраДанныхЭЛН - Структура:
//    * Организация             - СправочникСсылка.Организации - организация, сертификатом которой для ФСС подписывать.
//    * РегистрационныйНомерФСС - Строка - регистрационный номер организации в ФСС.
//    * ТекстXML                - Строка - XML выгрузки реестра ЭЛН.
//
Процедура ОтправитьВыгрузкуРеестраДанныхЭЛНВСервисФСС( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОтправитьВыгрузкуРеестраДанныхЭЛНВСервисФСС();
```
</details>

## АдресПодписанногоSOAPЗагрузкиЭЛНВФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется в составе ОтправитьВыгрузкуРеестраДанныхЭЛНВСервисФСС.
// Получение адреса подписанного, зашифрованного запроса к веб-сервису ФСС для отправки реестра листков нетрудоспособности.
//
// Параметры:
//  ВыполняемоеОповещение   - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат               - Строка - адрес во временном хранилище подписанного или подписанного и зашифрованного запроса SOAP
//                                       к веб-сервису ФСС.
//                              Неопределено - при ошибке.
//
//  ОрганизацияСсылка       - СправочникСсылка.Организации - организация, сертификатом которой для ФСС подписывать.
//
//  РегистрационныйНомерФСС - Строка - регистрационный номер ФСС.
//
//  ВыгрузкаЭЛН             - Строка - XML выгрузки ЭЛН.
//
//  ЗашифроватьSOAP         - Булево - если Истина, запрос будет подписан и зашифрован, иначе только подписан.
//
Процедура АдресПодписанногоSOAPЗагрузкиЭЛНВФСС( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.АдресПодписанногоSOAPЗагрузкиЭЛНВФСС();
```
</details>

## АдресПодписанногоSOAPОперацииСЭЛНВФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется в составе ПолучитьДанныеЭЛНИзФСС.
// Получение адреса подписанного, зашифрованного запроса к веб-сервису ФСС для выполнения операции с листком нетрудоспособности
// (получения ЭЛН, прекращения действия ЭЛН).
//
// Параметры:
//  ВыполняемоеОповещение       - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат                   - Строка - адрес во временном хранилище подписанного или подписанного и зашифрованного запроса SOAP
//                                           к веб-сервису ФСС.
//                                  Неопределено - при ошибке.
//
//  ОрганизацияСсылка           - СправочникСсылка.Организации - организация, сертификатом которой для ФСС подписывать.
//
//  ВыгрузкаЗапросаОперацииСЭЛН - Строка - XML запроса SOAP операции с листком нетрудоспособности без подписи.
//
//  ЗашифроватьSOAP             - Булево - если Истина, запрос будет подписан и зашифрован, иначе только подписан.
//
Процедура АдресПодписанногоSOAPОперацииСЭЛНВФСС( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.АдресПодписанногоSOAPОперацииСЭЛНВФСС();
```
</details>

## ПроверитьПодписьSOAPОтветаЭЛНВФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется в составе ПолучитьДанныеЭЛНИзФСС и ОтправитьВыгрузкуРеестраДанныхЭЛНВСервисФСС.
// Получение адреса расшифрованного ответа веб-сервиса ФСС на запрос операции с листком нетрудоспособности, а также результатов
// проверки подписи ответа.
//
// Параметры:
//  ВыполняемоеОповещение                - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат                            - Структура:
//      * ПодписьВалидна                     - Булево - результат проверки подписи.
//      * АдресРасшифрованногоОтветаSOAP     - Строка - адрес во временном хранилище незашифрованного ответа SOAP от веб-сервиса ФСС.
//                                         - Неопределено - при ошибке.
//
//  ОрганизацияСсылка                    - СправочникСсылка.Организации - организация, сертификатом которой для ФСС расшифровывать.
//
//  АдресПодписанногоОтветаSOAP          - Строка - адрес во временном хранилище SOAP подписанного или подписанного и зашифрованного
//                                                  ответа SOAP от веб-сервиса ФСС.
//
//  РасшифроватьSOAP                     - Булево - если Истина, будет выполнена дешифрация и проверка подписи, иначе только проверка
//                                                  подписи.
//
Процедура ПроверитьПодписьSOAPОтветаЭЛНВФСС( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПроверитьПодписьSOAPОтветаЭЛНВФСС();
```
</details>

## ПоказатьИнформациюоСроках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьИнформациюоСроках() Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПоказатьИнформациюоСроках() 
```
</details>

## ПолучитьВходящиеСообщенияСЭДОФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные входящих сообщений СЭДО ФСС.
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат                     -  Структура:
//      * БылиОшибки           - Булево - если Истина, то при выполнении операции возникали ошибки.
//      * ОшибкиПоОрганизациям - Соответствие - возвращаются массивы описаний ошибок в разрезе по организациям.
//      * ДанныеСообщенийПоОрганизациям - Соответствие - ключ соответствия организация, значение - массив структур с полями:
//        * Идентификатор           - Строка - идентификатор сообщения.
//        * Тип                     - Число  - тип сообщения согласно спецификации.
//        * Получатель              - Строка - идентификатор получателя.
//        * ТребуетсяПодтверждение  - Булево - требуется подтверждение о прочтении сообщения.
//        * Содержимое              - Строка - текстовое содержимое сообщения.
//        * Новое                   - Булево - признак того, что это это новое сообщение, данные которого ещё не были загружены.
//        * РегистрационныйНомерСФР - Строка - регистрационный номер СФР организации страхователя.
//      * РезультатыПоОрганизациям - Соответствие - ключ соответствия организация, значение - массив структур с полями:
//        * Выполнено            - Булево - признак успешного выполнения операции.
//        * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//        * ДанныеСообщения      - Структура - см. описание структуры ДанныеСообщенийПоОрганизациям.
//        * Идентификатор        - Строка - идентификатор сообщения.
//  Организации                     - Массив - массив организаций, по которым нужно получить сообщения.
//  ЗадаватьВопросОТестовомСервере  - Булево.
//  ПоказыватьДлительнуюОперацию    - Булево.
//  ТипВзаимодействия               - Число - Неопределено или 2 - обмен для страхователя, 3 - для организации (МЧД).
//
Процедура ПолучитьВходящиеСообщенияСЭДОФСС( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПолучитьВходящиеСообщенияСЭДОФСС();
```
</details>

## ПослеПолученияВходящихСообщенийСЭДОФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеПолученияВходящихСообщенийСЭДОФСС(Результат, ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПослеПолученияВходящихСообщенийСЭДОФСС(Результат, ПараметрыОбработчика) 
```
</details>

## ПолучитьМетаданныеВходящихСообщенийСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает список входящих сообщений для организаций-страхователей с сервера СЭДО ФСС.
//
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат.
//    Результат                            - Структура:
//      * Выполнено         - Булево - признак успешного выполнения операции.
//      * ОписаниеОшибки    - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ДанныеСообщенийПоОрганизациям   - Соответствие - соответствие организаций данным сообщений.
//        * Ключ     - СправочникСсылка.Организации - организация, для который были получены данные сообщений.
//        * Значение - Массив - массив структур с данными сообщений:
//          * Идентификатор          - Строка - идентификатор сообщения.
//          * Тип                    - Число  - тип сообщения согласно спецификации.
//          * Получатель             - Строка - идентификатор получателя.
//          * ТребуетсяПодтверждение - Булево - требуется подтверждение о прочтении сообщения.
//          * Новое                  - Булево - признак того, что это новое сообщение, данные которого ещё не были загружены.
//          * РегистрационныйНомерСФР - Строка - регистрационный номер СФР организации страхователя.
//  Организации     - Массив - список организаций, для которых будет запрошен список сообщений.
//  ДатаСообщений  - Дата - дата, за которую будет возвращен список входящих сообщений.
//
Процедура ПолучитьМетаданныеВходящихСообщенийСЭДО(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПолучитьМетаданныеВходящихСообщенийСЭДО(ОповещениеОбратногоВызова, );
```
</details>

## ПолучитьСообщенияСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает содержимое входящих сообщений для страхователя с сервера СЭДО ФСС.
//
// Параметры:
//  ОповещениеОбратногоВызова        - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат  - Структура:
//      * БылиОшибки           - Булево - если Истина, то при выполнении операции возникали ошибки.
//      * Ошибки               - Массив - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ДанныеСообщений   - Массив - массив структур с данными сообщений:
//          * Идентификатор           - Строка - идентификатор сообщения.
//          * Тип                     - Число - тип сообщения согласно спецификации.
//          * Получатель              - Строка - идентификатор получателя.
//          * Содержимое              - Строка - текстовое содержимое сообщения.
//          * ТребуетсяПодтверждение  - Булево - требуется подтверждение о прочтении сообщения
//          * РегистрационныйНомерСФР - Строка - регистрационный номер СФР организации страхователя.
//      * РезультатыПолучения    - Массив - массив структур с полями:
//          * Выполнено            - Булево - признак успешного выполнения операции.
//          * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//          * ДанныеСообщения      - Структура - см. описание структуры ДанныеСообщений.
//          * Идентификатор        - Строка - идентификатор сообщения.
//  Организация                      - СправочникСсылка.Организации - организация страхователь.
//  Идентификаторы                   - Массив - массив строковых идентификаторов сообщений, которые требуется получить.
//  ОткрыватьФормуДлительнойОперации - Булево
//  ЗадаватьВопросОТестовомСервере   - Булево
//  ТипыВзаимодействий               - Массив - типы взаимодействий по идентификаторам сообщений
//                                              при значении Неопределено берутся типы взаимодействия по умолчанию
//                                              ДокументооборотСФССКлиентСервер.ТипВзаимодействияСтраховательСЭДО(),
//                                              для МЧД использовать тип взаимодействия
//                                              ДокументооборотСФССКлиентСервер.ТипВзаимодействияОрганизацияСЭДО().
//
Процедура ПолучитьСообщенияСЭДО( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПолучитьСообщенияСЭДО();
```
</details>

## ПодписатьСотрудниковОрганизацийНаУведомленияПоЭЛН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подписывает сотрудников на уведомления об изменении статусов ЭЛН в ФСС.
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат                     -  Структура:
//      * БылиОшибки           - Булево - если Истина, то при выполнении операции возникали ошибки.
//      * Ошибки               - Массив - содержит описания ошибок.
//      * РезультатыОперации   - Соответствие - результаты операции в разрезе организаций. Поля значения:
//         * Выполнено            - Булево - признак успешного выполнения операции.
//         * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//         * ИдентификаторЗапроса - Строка - идентификатор отправленного запроса.
//  СНИЛСыСотрудниковОрганизаций - Соответствие - СНИЛСы сотрудников в разрезе организаций.
//    * Ключ     - СправочникСсылка.Организации - организация.
//    * Значение - Массив - массив строк со СНИЛС сотрудников, значения СНИЛС должны содержать только цифры.
//  ПринудительноОткрепить - Булево - признак принудительно открепления сотрудников от предыдущего работодателя.
//
Процедура ПодписатьСотрудниковОрганизацийНаУведомленияПоЭЛН(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПодписатьСотрудниковОрганизацийНаУведомленияПоЭЛН(ОповещениеОбратногоВызова, );
```
</details>

## ОтписатьСотрудниковОрганизацийОтУведомленийПоЭЛН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отписывает сотрудников от уведомлений об изменении статусов ЭЛН в ФСС.
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат                     -  Структура:
//      * БылиОшибки           - Булево - если Истина, то при выполнении операции возникали ошибки.
//      * Ошибки               - Массив - содержит описания ошибок.
//      * РезультатыОперации   - Соответствие - результаты операции в разрезе организаций. Поля значения:
//         * Выполнено            - Булево - признак успешного выполнения операции.
//         * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//         * ИдентификаторЗапроса - Строка - идентификатор отправленного запроса.
//  СНИЛСыСотрудниковОрганизаций - Соответствие - СНИЛСы сотрудников в разрезе организаций.
//    * Ключ     - СправочникСсылка.Организации - организация.
//    * Значение - Массив - массив строк со СНИЛС сотрудников, значения СНИЛС должны содержать только цифры.
//
Процедура ОтписатьСотрудниковОрганизацийОтУведомленийПоЭЛН(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОтписатьСотрудниковОрганизацийОтУведомленийПоЭЛН(ОповещениеОбратногоВызова, );
```
</details>

## ПодписатьСтрахователяНаУведомленияПоЭЛН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подписывает страхователя на уведомления об изменения статусов ЭЛН в ФСС.
// Для получения уведомлений требуется также подписка сотрудников (см. ПодписатьСотрудниковНаУведомленияПоЭЛН).
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат                     -  Структура:
//      * Выполнено            - Булево - признак успешного выполнения операции.
//      * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ИдентификаторЗапроса - Строка - идентификатор отправленного запроса.
//  Организация             - СправочникСсылка.Организации - организация страхователь.
//
Процедура ПодписатьСтрахователяНаУведомленияПоЭЛН(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПодписатьСтрахователяНаУведомленияПоЭЛН(ОповещениеОбратногоВызова, );
```
</details>

## ОтписатьСтрахователяОтУведомленийПоЭЛН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отписывает страхователя от уведомлений об изменении статусов ЭЛН в ФСС.
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат                     -  Структура:
//      * Выполнено            - Булево - признак успешного выполнения операции.
//      * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ИдентификаторЗапроса - Строка - идентификатор отправленного запроса.
//  Организация             - СправочникСсылка.Организации - организация страхователь.
//
Процедура ОтписатьСтрахователяОтУведомленийПоЭЛН(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОтписатьСтрахователяОтУведомленийПоЭЛН(ОповещениеОбратногоВызова, );
```
</details>

## ОтправитьПодтверждениеОПолученииСообщенийСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет подтверждение о получении сообщений на сервер СЭДО ФСС.
//
// Параметры:
//  ОповещениеОбратногоВызова       - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат  - Структура:
//      * Выполнено           - Булево - признак успешного выполнения операции.
//      * ОписаниеОшибки      - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ИдентификаторЗапроса - Строка - идентификатор отправленного запроса.
//  Организация             - СправочникСсылка.Организации - организация страхователь.
//  ИдентификаторыСообщений  - Массив, Строка, УникальныйИдентификатор - идентификаторы сообщений, на которые будет отправлено подтверждение.
//  ПослеОтправкиПолучитьВходящие - Булево - если Истина, то после отправки подтверждений будут получены входящие сообщения.
//
Процедура ОтправитьПодтверждениеОПолученииСообщенийСЭДО(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОтправитьПодтверждениеОПолученииСообщенийСЭДО(ОповещениеОбратногоВызова, );
```
</details>

## ОтправитьСообщениеСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет произвольное сообщение на сервер СЭДО ФСС.
//
// Параметры:
//  ОповещениеОбратногоВызова - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат                    - Структура:
//      * Выполнено            - Булево - признак успешного выполнения операции.
//      * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ИдентификаторЗапроса - Строка - идентификатор отправленного запроса.
//      * ИдентификаторПакета  - Строка - идентификатор отправленного пакета (пустая строка при отправке напрямую).
//      * ОбменЧерезОператора  - Булево.
//  ПараметрыСообщения             - Структура - параметры отправки сообщения со структурой, как формируется функцией
//                                               "ЭлектронныйДокументооборотСФСС.ПараметрыОтправитьСообщениеСЭДО"
//  ЗадаватьВопросОТестовомСервере - Булево    - показывать вопрос, если установлен тестовый режим,
//                                               по умолчанию Истина, в случае серии вызовов для непервого вызова
//                                               стоит задавать Ложь.
//
Процедура ОтправитьСообщениеСЭДО( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОтправитьСообщениеСЭДО();
```
</details>

## ПолучитьСообщенияСЭДОЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получет сообщений СЭДО СФР за период.
// Параметры:
//  ОповещениеОбратногоВызова        - ОписаниеОповещения - описание процедуры, принимающей результат:
//    Результат  - Структура:
//      * БылиОшибки           - Булево - если Истина, то при выполнении операции возникали ошибки.
//      * Ошибки               - Массив - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//      * ДанныеСообщений   - Массив - массив структур с данными сообщений:
//          * Идентификатор          - Строка - идентификатор сообщения.
//          * Тип                    - Число - тип сообщения согласно спецификации.
//          * Получатель             - Строка - идентификатор получателя.
//          * Содержимое             - Строка - текстовое содержимое сообщения.
//          * ТребуетсяПодтверждение - Булево - требуется подтверждение о прочтении сообщения.
//      * РезультатыПолучения    - Массив - массив структур с полями:
//          * Выполнено            - Булево - признак успешного выполнения операции.
//          * ОписаниеОшибки       - Строка - содержит описание ошибки в случае, если Выполнено установлено в Ложь.
//          * ДанныеСообщения      - Структура - см. описание структуры ДанныеСообщений.
//          * Идентификатор        - Строка - идентификатор сообщения.
//  Организации                      - Массив из СправочникСсылка.Организации - организации страхователи.
//  ДатаНачала                       - Дата - дата и время начала периода.
//  ДатаОкончания                    - Дата - дата и время окончания периода.
//  ПараметрыПолучения               - Структура - см. ПараметрыПолучитьСообщенияСЭДОЗаПериод.
Процедура ПолучитьСообщенияСЭДОЗаПериод(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ПолучитьСообщенияСЭДОЗаПериод(ОповещениеОбратногоВызова, );
```
</details>

## ПараметрыПолучитьСообщенияСЭДОЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры метода ПолучитьСообщенияСЭДОЗаПериод.
//
// Возвращаемое значение:
//  ОткрыватьФормуДлительнойОперации - Булево - по умолчанию Истина.
//  ЗадаватьВопросОТестовомСервере   - Булево - по умолчанию Истина.
//  ТипВзаимодействия                - Число  - тип взаимодействия с сервером СЭДО (2 - страхователь,
//                                              3 - организация, используется для МЧД).
//  СброситьСвойстваОбменаПоСЭДОЧерезОператора - Булево - по умолчанию Истина.
//  ПринудительноПовторноПолучитьСообщения - Булево - если Истина, то сообщения за период будут загружены,
//                                                    даже если у сообщения снят признак Новое.
Функция ПараметрыПолучитьСообщенияСЭДОЗаПериод() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронныйДокументооборотСФССКлиент.ПараметрыПолучитьСообщенияСЭДОЗаПериод() 
```
</details>

## ИнформационнаяПанельБРОНажатие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод отрабатывает нажатие на элементы в информационной панели БРО для ЗУП
//
// Параметры:
//  Форма	 - УправляемаяФорма - Форма, в которой располагается элемент.
//  Ссылка	 - Строка - Значение, которое пришло в метод формы Подключаемый_ИнформационнаяПанельБРООбработкаНавигационнойСсылки
//             в парамете НавигационнаяСсылкаФорматированнойСтроки.
//  СтандартнаяОбработка - Булево - Значение, которое пришло в метод формы
//             Подключаемый_ИнформационнаяПанельБРООбработкаНавигационнойСсылки в парамете ОбработкаНавигационнойСсылки.
//
Процедура ИнформационнаяПанельБРОНажатие(Форма, Ссылка, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ИнформационнаяПанельБРОНажатие(Форма, Ссылка, СтандартнаяОбработка) 
```
</details>

## ОткрытьУведомлениеИзПанелиСтатуса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОткрытьУведомлениеИзПанелиСтатуса(Форма) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОткрытьУведомлениеИзПанелиСтатуса(Форма) 
```
</details>

## ОткрытьУведомлениеИзПанелиСтатусаЗавершение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОткрытьУведомлениеИзПанелиСтатусаЗавершение(Результат, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОткрытьУведомлениеИзПанелиСтатусаЗавершение(Результат, ДополнительныеПараметры) 
```
</details>

## ОткрытьУведомлениеИзСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОткрытьУведомлениеИзСписка(Элемент) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОткрытьУведомлениеИзСписка(Элемент) 
```
</details>

## ОткрытьУведомлениеИзСпискаЗавершение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОткрытьУведомлениеИзСпискаЗавершение(Результат, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССКлиент.ОткрытьУведомлениеИзСпискаЗавершение(Результат, ДополнительныеПараметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
