---
title: Электронный документооборот с ФСС переопределяемый
slug: zup/электронный-документооборот-с-фсс-переопределяемый
---


## ПослеЗагрузкиУведомленийОНовыхСообщенияхСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении данных о новых сообщениях на сервере СЭДО ФСС.
//
// Параметры:
//   Страхователь - СправочникСсылка.Организации - организация, для который были получены входящие сообщения.
//   Уведомления - Массив - массив структур с полями:
//     * Идентификатор           - Строка - идентификатор сообщения в форме текстового представления UUID.
//     * Дата                    - Дата   - дата сообщения.
//     * Тип                     - Число  - тип сообщения.
//     * Получатель              - Строка - регистрационный номер ФСС получателя сообщения.
//     * ТребуетсяПодтверждение  - Булево - признак того, что получатель должен подтвердить получения сообщения.
//     * Новое                   - Булево - признак того, что это новое сообщение.
//     * СрокДействия            - Дата   - срок действия сообщения.
//     * РегистрационныйНомерСФР - Строка - регистрационный номер СФР организации страхователя.
//   ОбработанныеУведомления - Массив - массив с структур с данными обработанных сообщений.
//
Процедура ПослеЗагрузкиУведомленийОНовыхСообщенияхСЭДО(Страхователь, Уведомления, ОбработанныеУведомления) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПослеЗагрузкиУведомленийОНовыхСообщенияхСЭДО(Страхователь, Уведомления, ОбработанныеУведомления) 
```
</details>

## ПослеРасшифровкиСообщенияСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после расшифровки данных сообщения СЭДО ФСС.
//
// Параметры:
//   Страхователь - СправочникСсылка.Организации - организация, получатель сообщения.
//   Сообщение - Структура - данные сообщения:
//     * Идентификатор           - Строка - идентификатор сообщения в форме текстового представления UUID.
//     * Тип                     - Строка - тип сообщения.
//     * Получатель              - Строка - регистрационный номер ФСС получателя сообщения.
//     * ТребуетсяПодтверждение  - Булево - признак того, что получатель должен подтвердить получения сообщения.
//     * Новое                   - Булево - признак того, что это новое сообщение.
//     * ТекстСообщения          - Строка - содержимое сообщения.
//     * СрокДействия            - Дата   - срок действия сообщения.
//     * РегистрационныйНомерСФР - Строка - регистрационный номер СФР организации страхователя.
//   Результат - Структура - результат обработки сообщения:
//     * Обработано      - Булево - признак того, что сообщение было успешно обработано.
//     * ОшибкаОбработки - Булево - признак того, что при обработке сообщения возникла ошибка.
//     * ОписаниеОшибки  - Строка - описание ошибки обработки.
//
Процедура ПослеРасшифровкиСообщенияСЭДО(Страхователь, Сообщение, Результат) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПослеРасшифровкиСообщенияСЭДО(Страхователь, Сообщение, Результат) 
```
</details>

## ПослеПолученияОшибокЛогическогоКонтроляСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении ошибок логического контроля в сообщении с типом 14.
//
// Параметры:
//   Страхователь - СправочникСсылка.Организации - организация, получатель сообщения.
//   ИсходноеСообщение - Структура - данные исходного сообщения:
//     * Идентификатор          - Строка - идентификатор сообщения в форме текстового представления UUID.
//     * Тип                    - Строка - тип сообщения.
//     * Дата                   - Дата   - дата отправки сообщения.
//     * ТипВзаимодействия      - Число  - 0 до начала хранения реквизита, 2 для страхователя, 3 для МЧД.
//   ТекстОшибки - Строка - текст ошибки логического контроля.
//   Результат - Структура - результат обработки сообщения:
//     * Обработано      - Булево - признак того, что сообщение было успешно обработано.
//     * ОшибкаОбработки - Булево - признак того, что при обработке сообщения возникла ошибка.
//     * ОписаниеОшибки  - Строка - описание ошибки обработки.
//
Процедура ПослеПолученияОшибокЛогическогоКонтроляСЭДО(Страхователь, ИсходноеСообщение, ТекстОшибки, Результат) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПослеПолученияОшибокЛогическогоКонтроляСЭДО(Страхователь, ИсходноеСообщение, ТекстОшибки, Результат) 
```
</details>

## ПроверитьНеобходимостьЗапускаРегламентногоЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из регламентного задания, после обращения к серверу СЭДО ФСС
// и при подключении организации к обмену с ФСС в настройках.
// Если как минимум по одной из организаций требуется запуск, то необходимо установить значение флага
// ТребуетсяЗапуск в ИСТИНА.
// Устанавливать значение флага ТребуетсяЗапуск = ЛОЖЬ не нужно.
//
// Параметры:
//   Страхователи    - Массив - массив ссылок СправочникСсылка.Организации - организации,
//						по которым требуется проверить необходимость запуска регл.задания.
//   ТребуетсяЗапуск - Булево - флаг запуска рег.задания.
//								Потребители могут устанавливать у флага только значение ИСТИНА.
//
Процедура ПроверитьНеобходимостьЗапускаРегламентногоЗадания(Страхователи, ТребуетсяЗапуск) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПроверитьНеобходимостьЗапускаРегламентногоЗадания(Страхователи, ТребуетсяЗапуск) 
```
</details>

## ПослеПолученияОтветаНаПодтверждениеОПрочтении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении сообщения с типом 11 в ответ на подтверждение о прочтении входящего сообщения.
//   Страхователь - СправочникСсылка.Организации - организация, получатель сообщения.
//   РезультатыПодтверждений - Массив - массив структур:
//     * ИдентификаторСообщения - Строка - идентификатор исходного сообщения СЭДО, по которому отправлялось подтверждение.
//     * Тип                    - Число  - тип исходного сообщения СЭДО, по которому отправлялось подтверждение.
//     * ТекстОшибки            - Строка - ошибка приема подтверждения.
//     * ТекстПредупреждения    - Строка - предупреждение приема подтверждения.
//   Результат - Структура - результат обработки сообщения:
//     * Обработано      - Булево - признак того, что сообщение было успешно обработано.
//     * ОшибкаОбработки - Булево - признак того, что при обработке сообщения возникла ошибка.
//     * ОписаниеОшибки  - Строка - описание ошибки обработки.
//
Процедура ПослеПолученияОтветаНаПодтверждениеОПрочтении(Страхователь, РезультатыПодтверждений, Результат) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПослеПолученияОтветаНаПодтверждениеОПрочтении(Страхователь, РезультатыПодтверждений, Результат) 
```
</details>

## ПослеПолученияПодтвержденияДоставкиОператоромСообщенияСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении подтверждения доставки оператором в СФР с типом 1000011.
//
// Параметры:
//   Страхователь - СправочникСсылка.Организации - организация, получатель сообщения.
//   ИсходноеСообщение - Структура - данные исходного сообщения:
//     * Идентификатор          - Строка - идентификатор исходного сообщения в форме текстового представления UUID.
//     * Тип                    - Строка - тип исходного сообщения.
//     * Дата                   - Дата   - дата отправки исходного сообщения.
//     * ТипВзаимодействия      - Число  - 0 до начала хранения реквизита, 2 для страхователя, 3 для МЧД
//                                         для исходного сообщения.
//   СтатусПодтверждения - Строка - сейчас всегда "SUCCESS", так как в случае ошибки оператор отправляет тип 1000014
//                                  (см. процедуру "ПослеПолученияОшибкиДоставкиОператоромСообщенияСЭДО").
//   Результат - Структура - результат обработки сообщения:
//     * Обработано      - Булево - признак того, что сообщение было успешно обработано.
//     * ОшибкаОбработки - Булево - признак того, что при обработке сообщения возникла ошибка.
//     * ОписаниеОшибки  - Строка - описание ошибки обработки.
//
Процедура ПослеПолученияПодтвержденияДоставкиОператоромСообщенияСЭДО( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПослеПолученияПодтвержденияДоставкиОператоромСообщенияСЭДО();
```
</details>

## ПослеПолученияОшибкиДоставкиОператоромСообщенияСЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении ошибок доставки доставки оператором в СФР с типом 1000014.
//
// Параметры:
//   Страхователь - СправочникСсылка.Организации - организация, получатель сообщения.
//   ИсходноеСообщение - Структура - данные исходного сообщения:
//     * Идентификатор          - Строка - идентификатор сообщения в форме текстового представления UUID.
//     * Тип                    - Строка - тип сообщения.
//     * Дата                   - Дата   - дата отправки сообщения.
//     * ТипВзаимодействия      - Число  - 0 до начала хранения реквизита, 2 для страхователя, 3 для МЧД.
//   ТекстОшибки - Строка - текст ошибки логического контроля.
//   Результат - Структура - результат обработки сообщения:
//     * Обработано      - Булево - признак того, что сообщение было успешно обработано.
//     * ОшибкаОбработки - Булево - признак того, что при обработке сообщения возникла ошибка.
//     * ОписаниеОшибки  - Строка - описание ошибки обработки.
//
Процедура ПослеПолученияОшибкиДоставкиОператоромСообщенияСЭДО( Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ПослеПолученияОшибкиДоставкиОператоромСообщенияСЭДО();
```
</details>

## ЗаполнитьИдентификаторыПроактивБезОтвета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре следует заполнить сведения об актуальных запросах по проактивным выплатам, по которым не удалось отправить ответ
//
// Параметры:
//   ТаблицаЗапросов - ТаблицаЗначений - таблица с колонками:
//   	* Организация - СправочникСсылка.Организации - страхователь,
//		* ВидДокумента - Строка - константа "Запрос недостающих сведений для проактивной выплаты"
//		* ИдентификаторФСС - Строка - идентификатор сообщения 100 (идентификатор входящего запроса)
//		* НомерПроблемы - Число - константа 2
//		* ТипСообщенияСЭДО" - Строка - тип сообщения, константа "100" (не обязательно заполнять)
//   СписокИдентификаторов - СписокЗначений - пустой список значений, необходимо заполнить значениями из колонки "ИдентификаторФСС" таблицы ТаблицаЗапросов
//   МинимальнаяДатаОтвета - Дата - минимальная серверная дата создания документа.
//   	Если не указана, то в качестве минимальной даты создания документа следует взять текущую дату сервера и отнять 3 календарных дня.
//   	Дополнительно в качестве максимальной даты создания документа рекомендуется добавить к текущей дате сервера 30 календарных дней.
//
Процедура ЗаполнитьИдентификаторыПроактивБезОтвета(ТаблицаЗапросов, СписокИдентификаторов, МинимальнаяДатаОтвета = Неопределено) Экспорт
```

Пример вызова
```bsl
ЭлектронныйДокументооборотСФССПереопределяемый.ЗаполнитьИдентификаторыПроактивБезОтвета(ТаблицаЗапросов, СписокИдентификаторов, МинимальнаяДатаОтвета);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
