---
title: Интерфейсы взаимодействия БРО
slug: zup/интерфейсы-взаимодействия-бро
---


## ЭтоИностраннаяОрганизацияПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак - является ли организация иностранной в зависимости от ИНН.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на элемент справочника "Организации".
//
// Возвращаемое значение:
//   Истина - организация является иностранной;
//   Ложь   - организация не является иностранной.
//
//
Функция ЭтоИностраннаяОрганизацияПоИНН(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЭтоИностраннаяОрганизацияПоИНН(Организация) 
```
</details>

## СоответствиеЗаменяемыхКодовОргановФСГС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Коды органов ФСГС, заменяемые в связи с поддержкой взаимодействия с ЦЕМПОС.
//
// Возвращаемое значение:
//  Соответствие - для кодов органов ФСГС возвращаются коды, на которые их следует заменить в справочниках
//                 (организаций, подразделений).
//
Функция СоответствиеЗаменяемыхКодовОргановФСГС(Знач ОпрашиватьСервис = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СоответствиеЗаменяемыхКодовОргановФСГС(ОпрашиватьСервис);
```
</details>

## АвтономноеСоответствиеЗаменяемыхКодовТОГС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция АвтономноеСоответствиеЗаменяемыхКодовТОГС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.АвтономноеСоответствиеЗаменяемыхКодовТОГС());
```
</details>

## ПоляКоторыеНеВсегдаТребуетсяЗаполнять
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции интерфейса взаимодействия с прикладным кодом
// автоматического заполнения данных статистической отчетности.

// Возвращает поля, которые не требуется заполнять.
//
Функция ПоляКоторыеНеВсегдаТребуетсяЗаполнять(ИмяРеглОтчета, ИмяФормы, Период) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПоляКоторыеНеВсегдаТребуетсяЗаполнять(ИмяРеглОтчета, ИмяФормы, Период) 
```
</details>

## КраткоеПредставлениеФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Краткое представление формы, которое выводится, например, в заголовке диалога настройки.
//
// Параметры:
//  РегламентированныйОтчет - ДокументСсылка.РегламентированныйОтчет
//
// Возвращаемое значение:
//   Строка - краткое представление формы.
//
Функция КраткоеПредставлениеФормы(РегламентированныйОтчет) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.КраткоеПредставлениеФормы(РегламентированныйОтчет) 
```
</details>

## ВидыКлассификаторов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список классификаторов, про которые знает БРО.
//
// Возвращаемое значение:
//   СписокЗначений - "ВидыДеятельности", "ВидыПродукцииОпт", "ВидыПродукцииПроизводство",
//                    "ВидыПродукцииРозница", "УслугиНаселению".
//
Функция ВидыКлассификаторов() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВидыКлассификаторов() 
```
</details>

## ВерсииКлассификатора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список версий классификатора
//
// Параметры:
//  ВидКласификатора - строка
//
// Возвращаемое значение:
//   СписокЗначений - версии классификатора.
//   Например: для ВидКласификатора = "ВидыПродукцииОпт"
//   вернем список версий ("2010кв1", "2012кв1", "2013кв1", "2013кв4", "2014кв1")
//   с представлением.
//
Функция ВерсииКлассификатора(ВидКласификатора) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВерсииКлассификатора(ВидКласификатора) 
```
</details>

## ДанныеКлассификатора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По классификатору и версии вернем таблицу значений
//
// Параметры:
//   ВидКласификатора - строка
//   Версия - строка
//
// Возвращаемое значение:
//   ТаблицаЗначений - данные классификатора.
//   Возвращаем таблицу значений с 4 колонками:
//   Код, Наименование, НаименованиеЕдиницыИзмерения, КодЕдиницыИзмерения
//   Все колонки имеют тип "строка"
//
Функция ДанныеКлассификатора(ВидКласификатора, ВерсияКлассификатора) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ДанныеКлассификатора(ВидКласификатора, ВерсияКлассификатора) 
```
</details>

## ПолучитьПоляФормыСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции описания форм статистики.

// Функция читает структуру XML переданной формы статистики.
//
// Параметры:
// 	 ИмяОтчета - Строка - имя отчета.
//   ИмяСхемыВыгрузки - Строка - имя схемы выгрузки.
//
// Возвращаемое значение:
//   ТаблицаЗначений - содежит иерархию полей формы статистики.
//
Функция ПолучитьПоляФормыСтатистики(ИмяОтчета, ИмяСхемыВыгрузки) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПолучитьПоляФормыСтатистики(ИмяОтчета, ИмяСхемыВыгрузки) 
```
</details>

## ПолучитьВерсииСписковОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция считывает версии списков отчета.
//
// Парамеры:
//   ИмяОтчета - Строка - идентификатор отчета, для которого нужно вернуть версии списков.
//
// Возвращаемое значение:
//   СписокЗначений - версии списков отчета.
//
Функция ПолучитьВерсииСписковОтчета(ИмяОтчета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПолучитьВерсииСписковОтчета(ИмяОтчета) 
```
</details>

## ПолучитьРасположениеКлассификатораСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру содержащую 2 параметра:
//
// Параметры:
//   ИмяКлассификатора - Строка
//   Назначение - Строка
// Возвращаемое значение:
//   Структура - расположение классификатор форм статистики.
//
Функция ПолучитьРасположениеКлассификатораСтатистики(ИмяКлассификатора, Назначение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПолучитьРасположениеКлассификатораСтатистики(ИмяКлассификатора, Назначение);
```
</details>

## ПолучитьЗначенияИзСпискаВыбораОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные переданного списка выбора отчета.
//
// Параметры:
//    ИмяОтчета - Строка - Идентификатор отчета содежащего искомый список.
//    ИмяМакета - Строка - Идентификатор макета в котором хранятся списки отчета.
//    ИмяСписка - Строка - Имя искомого списка в макете "Списки" отчета.
//    ДополнятьКодСлева - Булево - дополнять код слева (по умолчанию) символом "0"
//	                      до длины кода (по умолчанию) 12, длина кода и символ дополнения могут быть определены
//                        параметрами.
//	  ДлинаКода - Число - длина кода классификатора, коды классификатора будут приведены к этой длине.
//	  СимволДополненияКода - Строка - символ которым нужно дополнить код слева, до заданной длины.
//
// Возвращаемое значение:
// 	 ТаблицаЗначений - данные списка.
//
Функция ПолучитьЗначенияИзСпискаВыбораОтчета(ИмяОтчета, ИмяМакета, ИмяСписка, ДополнятьКодСлева = Ложь, ДлинаКода = Неопределено, СимволДополненияКода = "0") Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПолучитьЗначенияИзСпискаВыбораОтчета(ИмяОтчета, ИмяМакета, ИмяСписка, ДополнятьКодСлева, ДлинаКода, СимволДополненияКода);
```
</details>

## СформироватьАвтоматическиРеглОтчетВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции интерфейса взаимодействия с потребителями БРО.

// Формирует автоматически в фоне формы регламентированных отчетов для выбранных налоговых органов.
// Предназначена для автоформирования регл. отчетов:
//   "6-НДФЛ (с 2021 года)";
//   "6-НДФЛ";
//   "Декларация по ЕНВД (за периоды, начиная с 01.01.2016)".
//
// Параметры:
//   СтруктураПараметров - Структура - ключи:
//     "ИмяОтчета" - Строка - имя регламентированного отчета;
//     "Организация" - СправочникСсылка.Организации - ссылка на организацию;
//     "ДатаНачалаПериодаОтчета" - Дата - дата начала периода отчета;
//     "ДатаКонцаПериодаОтчета" - Дата - дата конца периода отчета;
//     "НалоговыеОрганы" - СписокЗначений - список элементов справочника "РегистрацииВНалоговомОргане";
//     "АдресВоВременномХранилищеРезультатаАвтоформирования" - Строка - адрес во временном хранилище результата автоформирования;
//   НеиспользуемыйАдресХранилища - Строка - обязателен для совместимости с БСП, если процедура применяется как
//                                           диспетчер запуска автоформирования регламентированных отчетов в фоне
//                                           (необязателен в остальных случаях).
//
Процедура СформироватьАвтоматическиРеглОтчетВФоне(СтруктураПараметров, НеиспользуемыйАдресХранилища = "") Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетВФоне(СтруктураПараметров, НеиспользуемыйАдресХранилища);
```
</details>

## ОбновитьДанныеРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обновляет сохраненные данные регламентированного отчета
// заданного вида для указанной организации за нужный отчетный период.
//
// Параметры:
//	 ИсточникОтчета - Строка - строка с наименованием регламентированного отчета (совпадает с именем объекта метаданных).
// 	 Организация - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   ДатаНачала - Дата - дата начала отчетного периода (левая граница отчетного преиода).
//   ДатаОкончания - Дата - дата окончания отчетного периода (правая граница отчетного периода).
//   СсылкаНаСохрРеглОтчет - ДокументСсылка.РегламентированныйОтчет - ссылка на сохраненный регламентированный отчет, данные которого нужно получить.
//
// Пример:
//   ИнтерфейсыВзаимодействия.ОбновитьДанныеРеглОтчета("РегламентированныйОтчетРСВ1", Организация, '20120101', '20121231', СсылкаНаСохрРеглОтчет);
//
Процедура ОбновитьДанныеРеглОтчета(ИсточникОтчета, Организация, ДатаНачала, ДатаОкончания, СсылкаНаСохрРеглОтчет) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ОбновитьДанныеРеглОтчета(ИсточникОтчета, Организация, ДатаНачала, ДатаОкончания, СсылкаНаСохрРеглОтчет) 
```
</details>

## СформироватьАвтоматическиРеглОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция автоматически формирует регламентированный отчет заданного вида для указанной организации
// за нужный отчетный период, сохраняет его в ИБ и возвращает ссылку.
//
// Параметры:
//   ИсточникОтчета      - Строка - строка с наименованием регламентированного отчета (совпадает с именем объекта метаданных).
//   Организация         - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   ДатаНачала          - Дата - дата начала отчетного периода (левая граница отчетного преиода).
//   ДатаОкончания       - Дата - дата окончания отчетного периода (правая граница отчетного периода).
//   КорректирующийОтчет - Булево - признак корректирующего отчета.
//   ИмяФормыОтчета      - Строка - строка с именем формы регламентированного отчета (определяет нужную из форм,
//                                  действующих в отчетном периоде).
//   ПараметрыАвтоФормирования - Структура - параметры автоматического формирования регл. отчета.
//
// Возвращемое значение:
//   ДокументСсылка.РегламентированныйОтчет - ссылка на документ "РегламентированныйОтчет".
//
// Пример:
//   ИнтерфейсыВзаимодействия.СформироватьАвтоматическиРеглОтчет("РегламентированныйОтчетРСВ1", Организация, '20120101', '20121231');
//
Функция СформироватьАвтоматическиРеглОтчет(ИсточникОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет = Ложь, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчет(ИсточникОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, );
```
</details>

## УстановитьВидФормыРСВ_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает значение реквизита "Вид" формы РСВ-1.
//
// Параметры:
//   Ссылка              - ДокументСсылка.РегламентированныйОтчет - ссылка на регл. отчет.
//   КорректирующаяФорма - Булево - признак корректирующей формы.
//
Процедура УстановитьВидФормыРСВ_1(Ссылка, КорректирующаяФорма) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.УстановитьВидФормыРСВ_1(Ссылка, КорректирующаяФорма) 
```
</details>

## ПодключенДокументооборотСКонтролирующимОрганом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет для организации, подключен ли документооборот с контролирующим органом.
//
// Параметры:
//  Организация			 - СправочникСсылка.Организации - Организация, для которой определяется
//		наличие подключенного документооборота с контролирующим органом.
//  КонтролирующийОрган	 - Перечисление.ТипыКонтролирующихОрганов - контролирующий орган, для
//		которого определяется наличие подключения.
//  ПроверятьДляТекущегоПользователя - Булево - Если истина, доступ проверяется для текущего пользователя
// 		иначе в целом по организации. Если Организация не указана, то флаг ПроверятьДляТекущегоПользователя игнорируется
// Возвращаемое значение:
//  Булево - Истина, если документооборот с контролирующим органом подключен.
Функция ПодключенДокументооборотСКонтролирующимОрганом( Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПодключенДокументооборотСКонтролирующимОрганом();
```
</details>

## ОрганизацияИмеетУчетнуюЗапись
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет, имеет ли организация учетную запись.
//
// Параметры:
//  Организация			 - СправочникСсылка.Организации - Организация, для которой определяется
//		наличие подключенного документооборота с контролирующим органом.
// Возвращаемое значение:
//  Булево - Истина, учетная запись есть.
Функция ОрганизацияИмеетУчетнуюЗапись(Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ОрганизацияИмеетУчетнуюЗапись(Организация);
```
</details>

## НовыйПараметрыАвтоформированияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметров автоматического формирования регламентированных отчетов без открытия формы.
//
// Возвращаемое значение:
//   Структура - Содержит ключи с параметрами автоформирования.
//
Функция НовыйПараметрыАвтоформированияОтчета() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НовыйПараметрыАвтоформированияОтчета() 
```
</details>

## СправкиОДоходахИСуммахНалогаФизическихЛицИзОтчетов6_НДФЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает справки о доходах и суммах налога физических лиц из регламентированных отчетов "6-НДФЛ (с 2021 года)".
//
// Параметры:
//  СтруктураПараметров - Структура - свойства:
//     * Организация    - СправочникСсылка.Организации - организация, для которой будет выполняться поиск
//                        отчетов "6-НДФЛ (с 2021 года)";
//     * ДатаОкончания  - Дата - дата окончания отчетного периода для поиска отчетов "6-НДФЛ (с 2021 года)";
//     * ИмяФормыОтчета - Строка - имя формы отчета "6-НДФЛ (с 2021 года)", например, "ФормаОтчета2024Кв2"
//                        (необязательное свойство; если отсутствует, значение будет получено автоматически).
//
// Возвращаемое значение:
//  Массив - массив структур с данными отчетов (пустой массив, если отчетов не найдено).
//  Каждая структура (случай непустого массива) - Структура - имеет свойства:
//     * НомерКорректировки - Число - номер корректировки из отчета "6-НДФЛ (с 2021 года)";
//     * КПП - Строка - КПП из отчета "6-НДФЛ (с 2021 года)";
//     * ОКТМО - Строка - код по ОКТМО из отчета "6-НДФЛ (с 2021 года)";
//     * СправкиОДоходахИСуммахНалогаФизическихЛиц - ДеревоЗначений - справки о доходах и
//                            суммах налога физических лиц из отчета "6-НДФЛ (с 2021 года)".
//
Функция СправкиОДоходахИСуммахНалогаФизическихЛицИзОтчетов6_НДФЛ(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СправкиОДоходахИСуммахНалогаФизическихЛицИзОтчетов6_НДФЛ(СтруктураПараметров) 
```
</details>

## ПерсонифицированныеСведенияОЗастрахованныхЛицахИзРасчетовПоСтраховымВзносам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает персонифицированные сведения о застрахованных лицах из регламентированных отчетов
// "Расчет по страховым взносам".
//
// Параметры:
//  СтруктураПараметров - Структура - свойства:
//     * Организация    - СправочникСсылка.Организации - организация, для которой будет выполняться поиск отчетов
//                        "Расчет по страховым взносам";
//     * ДатаОкончания  - Дата - дата окончания отчетного периода для поиска отчетов "Расчет по страховым взносам";
//     * ИмяФормыОтчета - Строка - имя формы отчета "Расчет по страховым взносам", например, "ФормаОтчета2023Кв1"
//                        (необязательное свойство; если отсутствует, значение будет получено автоматически).
//
// Возвращаемое значение:
//  Массив - массив структур с данными отчетов (пустой массив, если отчетов не найдено).
//  Каждая структура (случай непустого массива) - Структура - имеет свойства:
//     * НомерКорректировки - Число - номер корректировки из отчета "Расчет по страховым взносам";
//     * ПерсонифицированныеСведенияОЗастрахованныхЛицах - ДеревоЗначений - персонифицированные
//                     сведения о застрахованных лицах из отчета "Расчет по страховым взносам".
//
Функция ПерсонифицированныеСведенияОЗастрахованныхЛицахИзРасчетовПоСтраховымВзносам(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПерсонифицированныеСведенияОЗастрахованныхЛицахИзРасчетовПоСтраховымВзносам(СтруктураПараметров) 
```
</details>

## ПерсональныеДанныеИВыплатыИзПерсонифицированныхСведенийОФизическихЛицах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает персональные данные физических лиц и сведения о суммах выплат и иных вознаграждений в их пользу
// из регламентированных отчетов "Персонифицированные сведения о физических лицах".
//
// Параметры:
//  СтруктураПараметров - Структура - свойства:
//     * Организация    - СправочникСсылка.Организации - организация, для которой будет выполняться поиск отчетов
//                        "Персонифицированные сведения о физических лицах";
//     * ДатаОкончания  - Дата - дата окончания отчетного периода для поиска отчетов "Персонифицированные сведения
//                        о физических лицах";
//     * ИмяФормыОтчета - Строка - имя формы отчета "Персонифицированные сведения о физических лицах", например,
//                        "ФормаОтчета2023Кв1" (необязательное свойство; если отсутствует, значение будет получено
//                        автоматически).
//
// Возвращаемое значение:
//  Массив - массив структур с данными отчетов (пустой массив, если отчетов не найдено).
//  Каждая структура (случай непустого массива) - Структура - имеет свойства:
//     * НомерКорректировки - Число - номер корректировки из отчета "Персонифицированные сведения о физических лицах";
//     * ПерсональныеДанныеИВыплаты - ДеревоЗначений - персональные данные физических лиц и сведения о суммах выплат
//                                    и иных вознаграждений в их пользу из из отчета "Персонифицированные сведения о
//                                    физических лицах".
//
Функция ПерсональныеДанныеИВыплатыИзПерсонифицированныхСведенийОФизическихЛицах(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПерсональныеДанныеИВыплатыИзПерсонифицированныхСведенийОФизическихЛицах(СтруктураПараметров) 
```
</details>

## РассчитатьПоказателиРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает значения показателей экземпляра раздела регламентированного отчета.
// Для работы требуется наличие одноименной экспортной процедуры в модуле объекта
// регламентированного отчета, для которой предусмотрена аналогичная параметризация.
//
// Параметры:
//   ПараметрыРасчета - Cтруктура со свойствами:
//     * ИмяОтчета   - Строка - имя регламентированного отчета (обязательное);
//     * ИмяФормы    - Строка - имя формы регламентированного отчета (обязательное);
//     * ИмяРаздела  - Строка - имя раздела регламентированного отчета (обязательное);
//     * Разрядность - Число  - число знаков дробной части, до которых округлять (0 - до целого, 1 - до десятых, т.д.),
//                              значение по умолчанию 0.
//     * Класс       - Число  - соответствует формату отображаемого значения (1 - в единицах, 1000 - в тысячах,
//                     1000000 - в миллионах, т.д.), значение по умолчанию 1.
//   Данные - Структура - немногострочные данные раздела регламентированного отчета: ключ - имя показателя,
//            значение - значение показателя.
//
// Пример параметризации:
//	ПараметрыРасчета = Новый Структура;
//	ПараметрыРасчета.Вставить("ИмяОтчета",  "РегламентированныйОтчетЗемельныйНалог");
//	ПараметрыРасчета.Вставить("ИмяФормы",   "ФормаОтчета2018Кв1");
//	ПараметрыРасчета.Вставить("ИмяРаздела", "Раздел2");
//
Процедура РассчитатьПоказателиРеглОтчета(ПараметрыРасчета, Данные) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РассчитатьПоказателиРеглОтчета(ПараметрыРасчета, Данные) 
```
</details>

## ПерсонифицированныеСведенияОЗастрахованныхЛицахДляПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Машиночитаемые бланки персонифицированных сведений о застрахованных лицах, сформированные алгоритмами печати
// отчета "Расчет по страховым взносам".
//
// Параметры:
//  СтруктураПараметров - Структура - свойства:
//     * Организация (обязательное) - СправочникСсылка.Организации - организация (см. в форме "Расчет по страховым
//                   взносам");
//     * МассивФизическихЛиц (обязательное) - Массив - произвольные идентификаторы, используемые для отбора сведений,
//                   а также устанавливаемые в качестве Ключей в возвращаемое Соответствие (в случае отсутствия
//                   указанных идентификаторов, в качестве Ключей в возвращаемое Соответствие устанавливаются
//                   сгенерированные значения уникальных идентификаторов);
//     * ДатаПодписи (обязательное) - Дата - дата подписи (см. в форме "Расчет по страховым взносам");
//     * ДатаКонцаПериодаОтчета (обязательное) - Дата - дата конца квартала, определяющая расчетный (отчетный) период
//                   (см. в форме "Расчет по страховым взносам");
//     * ДатаНачалаПериодаОтчета (необязательное) - Дата - дата начала расчетного (отчетного) периода (см. в форме
//                   "Расчет по страховым взносам"; если отсутствует, будет установлена дата начала календарного года,
//                   получанная из ДатаКонцаПериодаОтчета).
//
// Возвращаемое значение:
//  Соответствие или Неопределено. Ключи Соответствия идентифицируют физических лиц, а сопоставляемые с ними Значения -
//  Массивы Табличных документов (бланков). Неопределено будет возвращено, если отсутствует возможность сформировать
//  бланки при заданных параметрах.
//
Функция ПерсонифицированныеСведенияОЗастрахованныхЛицахДляПечати(ПараметрыПечати) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПерсонифицированныеСведенияОЗастрахованныхЛицахДляПечати(ПараметрыПечати) 
```
</details>

## РазделБРО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции автозаполнения по данным ИБ конфигурации - потребителя БРО.

// Процедура получает из коллекции раздел отчета и проверяет, что он может быть заполнен в этом модуле
//
// Параметры:
//   Контейнер - Структура - данные регл. отчета.
//   ИмяРазделаБРО - Строка - имя раздела регл. отчета.
//
// Возвращаемое значение:
//   ТаблицаЗначений - разделы отчета.
//
Функция РазделБРО(Контейнер, ИмяРазделаБРО) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РазделБРО(Контейнер, ИмяРазделаБРО) 
```
</details>

## ДобавитьСтраницуБРО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет новую страницу.
//
Процедура ДобавитьСтраницуБРО(РазделБРО) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ДобавитьСтраницуБРО(РазделБРО) 
```
</details>

## РаспаковатьПоказателиБРО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Распаковывает показатели.
//
Функция РаспаковатьПоказателиБРО(СтраницаБРО) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РаспаковатьПоказателиБРО(СтраницаБРО) 
```
</details>

## ПоместитьЗначениеПоказателяНаСтраницуБРО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает значение показателя на страницу.
//
Процедура ПоместитьЗначениеПоказателяНаСтраницуБРО(СтраницаБРО, НомерЯчейкиБРО, Значение) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ПоместитьЗначениеПоказателяНаСтраницуБРО(СтраницаБРО, НомерЯчейкиБРО, Значение) 
```
</details>

## ВидКонтролирующегоОргана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет вид государственного органа, в который сдается отчет переданного вида.
//
// Параметры:
//   ИмяОтчета - Строка - название регламентированного отчета, см. ИмяРеглОтчета().
//
// Возвращаемое значение:
//   ПеречислениеСсылка.ТипыКонтролирующихОрганов - вид государственного органа.
//
Функция ВидКонтролирующегоОргана(ИмяОтчета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВидКонтролирующегоОргана(ИмяОтчета) 
```
</details>

## РеглОтчетыИсполнителиТребований
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции интерфейса взаимодействия с сервисом "Список задач
// бухгалтера".

// Описывает перечень требований, которые могут быть исполнены объектами БРО.
//
// Возвращаемое значение:
//  Соответствие -
//   Ключ - Строка, имя требования (может содержать точку - ".")
//   Значение - Строка, имя регл. отчета
Функция РеглОтчетыИсполнителиТребований() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РеглОтчетыИсполнителиТребований() 
```
</details>

## РеглОтчетыИсполнителиЗадачБухгалтера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает перечень задач бухгалтера (налогов, отчетов), которые могут быть исполнены объектами БРО.
//
// Возвращаемое значение:
//  Соответствие -
//   Ключ - Строка, имя задачи (не содержит точку - ".")
//   Значение - Массив строк - имен регл. отчетов
Функция РеглОтчетыИсполнителиЗадачБухгалтера() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РеглОтчетыИсполнителиЗадачБухгалтера() 
```
</details>

## ТребованиеОбрабатывается
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, обрабатывает ли БРО указанное требование.
//
// Параметры:
//   Требование - Строка - имя требования (может содержать точку - ".").
//
// Возвращаемое значение:
//   Булево - признак обработки БРО указанных требований.
//
Функция ТребованиеОбрабатывается(Требование) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ТребованиеОбрабатывается(Требование) 
```
</details>

## ОписаниеФормыРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает форму нового или существующего регл. отчета, который позволяет выполнить требование
//
// Параметры:
//   Требование    - Строка - имя требования (может содержать точку - ".").
//   Организация   - СправочникСсылка.Организации - ссылка на элемент справочника "Организации".
//   РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане - ссылка на элемент справочника "РегистрацииВНалоговомОргане".
//   НачалоПериода - Дата - дата начала периода.
//   КонецПериода  - Дата - дата окончания периода.
//   Периодичность - ПеречислениеСсылка.Периодичность - периодичность.
//
// Возвращаемое значение:
//   Структура - содержит ключи:
//     * Имя - Строка - имя формы;
//     * Параметры - Структура - параметры формы.
//
Функция ОписаниеФормыРеглОтчета(Требование, Организация, РегистрацияВНалоговомОргане, Знач НачалоПериода, Знач КонецПериода, Знач Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ОписаниеФормыРеглОтчета(Требование, Организация, РегистрацияВНалоговомОргане, НачалоПериода, КонецПериода, Периодичность) 
```
</details>

## ДанныеРеглОтчетаДляУплатыНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные, сохраненные в регл. отчете - о суммах, которые следует уплатить по декларации.
//
// Параметры:
//   Требование - Строка - имя требования (может содержать точку - ".").
//   Организация - СправочникСсылка.Организации - ссылка на организацию.
//   РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане - ссылка на элемент справочника "РегистрацииВНалоговомОргане".
//   ПериодДекларации - Дата - дата окончания периода (без времени).
//   ДополнительныеПараметры - Структура - дополнительные параметры, если необходимо уточнение получения данных (необязательный параметр),
//                             при этом функция "ДанныеРеглОтчета" соответствующего регламентированного отчета должна поддерживать работу с этим параметром
//                             (пример см. в модуле менеджера отчета "РегламентированныйОтчетНДС").
//                             Также нужно для поиска декларации по налогу на прибыль, см. АктуальныйОтчет.
//
// Возвращаемое значение:
//   Неопределено,
//   ТаблицаЗначений - описанная в НовыйТаблицаДанныхРеглОтчета().
//
Функция ДанныеРеглОтчетаДляУплатыНалога(Требование, Организация, РегистрацияВНалоговомОргане, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ДанныеРеглОтчетаДляУплатыНалога(Требование, Организация, РегистрацияВНалоговомОргане, );
```
</details>

## АктуальныйОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает последний отчет за налоговый период
//
// Параметры:
//  ИсточникОтчета - Строка - наименование регламентированного отчета (совпадает с именем объекта метаданных)
//  Организация - СправочникСсылка.Организации
//  ПериодДекларации  - Дата - правая граница отчетного периода
//  РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане
//  ФормаОтчета - Строка
//  ДополнительныеПараметры - Структура
//
// Возвращаемое значение:
//   РегламентированныйОтчетСсылка
//
Функция АктуальныйОтчет(ИсточникОтчета, Организация, ПериодДекларации, РегистрацияВНалоговомОргане = Неопределено, ФормаОтчета = "", ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.АктуальныйОтчет(ИсточникОтчета, Организация, ПериодДекларации, РегистрацияВНалоговомОргане, ФормаОтчета, ДополнительныеПараметры);
```
</details>

## ДанныеУведомленияДляУплатыНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные, сохраненные в уведомлении/уведомлениях - о суммах, которые следует уплатить по декларации.
//
// Параметры:
//   Требование  - Строка - имя требования (может содержать точку - ".").
//   Организация - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   Конец       - Дата - дата окончания периода (без времени).
//
// Возвращаемое значение:
//   Неопределено,
//   ТаблицаЗначений - описанная в НовыйТаблицаДанныхРеглОтчета().
//
Функция ДанныеУведомленияДляУплатыНалога(Требование, Организация, Конец) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ДанныеУведомленияДляУплатыНалога(Требование, Организация, Конец) 
```
</details>

## ПлательщикТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Информирует о необходимости платить торговый сбор в указанном периоде (по наличию/отсутствию уведомлений по форме ТС-1/ТС-2).
//
// Параметры:
//   Организация   - СправочникСсылка.Организации - ссылка на элемент справочника организаций.
//   НачалоПериода - Дата - дата начала периода (без времени).
//   КонецПериода  - Дата - дата окончания периода (без времени).
//
// Возвращаемое значение:
//   Булево - Истина - организация должно платить торговый сбор в периоде (есть соответствующие уведомления),
//            Ложь - иначе.
//
Функция ПлательщикТорговогоСбора(НачалоПериода, КонецПериода, Организация) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПлательщикТорговогоСбора(НачалоПериода, КонецПериода, Организация) 
```
</details>

## НовыйТаблицаДанныхРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает структуру таблицы значений с данными регл. отчета
//
// Возвращаемое значение:
//   ТаблицаЗначений - данные регл. отчета.
//
Функция НовыйТаблицаДанныхРеглОтчета() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НовыйТаблицаДанныхРеглОтчета() 
```
</details>

## ПредставлениеФормыРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предоставляет пользовательское представление формы регл. отчета.
//
// Параметры:
//   Требование   - Строка - имя требования (может содержать точку - ".").
//   ПериодОтчета - Дата - дата окончания периода (без времени).
//
// Возвращаемое значение:
//   Строка - представление формы регламентированного отчета.
//
Функция ПредставлениеФормыРегламентированногоОтчета(Требование, ПериодОтчета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПредставлениеФормыРегламентированногоОтчета(Требование, ПериодОтчета) 
```
</details>

## РеглОтчетыСверхТребований
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список регл. отчетов, которые не предназначены для выполнения каких-либо формализованных требований.
// Служит для проверки, что в календаре бухгалтера внесены все требования, которые может исполнять программа.
//
// Возвращаемое значение:
//   Массив - массив строк.
//
Функция РеглОтчетыСверхТребований() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РеглОтчетыСверхТребований() 
```
</details>

## ИмяРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет имя регл. отчета, который позволяет исполнить требование.
//
// Параметры:
//   Требование - Строка - имя требования (может содержать точку - ".").
//   ИсполнителиТребований - Соответствие - возвращаемое РеглОтчетыИсполнителиТребований().
//                           Следует передавать, если функция используется многократно (в цикле).
//
// Возвращаемое значение:
//   Строка - имя регламентированного отчета.
//
Функция ИмяРеглОтчета(Знач Требование, ИсполнителиТребований = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ИмяРеглОтчета(Требование, ИсполнителиТребований);
```
</details>

## РеглОтчетыКоторыеНельзяСкрыватьНастройкамиКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает регл. отчеты, экземпляры которых присутствуют в информационной базе.
// Такие отчеты должны быть видны в списке экземпляров отчетов, несмотря на настройки конфигурации.
//
// Параметры:
//   Организации - СправочникСсылка.Организации - ссылка на организацию.
//   РеглОтчеты - Массив - массив строк имен регл. отчетов, среди которых надо найти те, которые нельзя скрывать.
//
// Возвращаемое значение:
//   Массив строк - имена объектов метаданных "Отчет".
//
Функция РеглОтчетыКоторыеНельзяСкрыватьНастройкамиКонфигурации(Организации, РеглОтчеты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РеглОтчетыКоторыеНельзяСкрыватьНастройкамиКонфигурации(Организации, РеглОтчеты);
```
</details>

## ИмяНалогаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет имя задачи бухгалтера (налога, отчета) по имени требования.
// Имя требования начинается с имени задач. Имя задачи отделено точкой - "."
//
// Параметры:
//   Требование - Строка - имя требования (содержит точку - ".").
//
// Возвращаемое значение:
//   Строка - имя задачи (не содержит точку - ".").
//
Функция ИмяНалогаОтчета(Требование) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ИмяНалогаОтчета(Требование) 
```
</details>

## ЗаполнитьСсылкиНаРеглОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура получает ссылки на сохраненные регламентированные отчеты заданного вида.
// В переданную таблицу ПараметрыРеглОтчетов добавляется колонка Документы с колонками:
//  * Ссылка                   - ДокументСсылка.РегламетированныйОтчет - Ссылка на отчет.
//  * Дата                     - Дата - Дата подписи регламентированного отчета.
//  * Статус                   - Строка - Описание статуса сдачи отчета.
//  * СостояниеСдачиОтчетности - ПеречислениеСсылка.СостояниеСдачиОтчетности - Статус отправки через 1С-Отчетность.
//  * НаименованиеОтчета       - Строка - Пользовательское представление отчета.
//  * ФинансовыйПериод         - Строка - Пользовательское представление периода отчета.
//  * ВариантОтчета            - Строка - Описание варианта отчета (П - первичный, К/N - корректировочный).
//  * ПредставлениеКонтролирующегоОргана - Строка - Название контролирующего органа, в который предоставляется отчет.
//  * Комментарий                        - Строка - Пользовательский комментарий к отчету.
//
// Ссылки на регл. отчеты отсортированы в хронологическом порядке по убыванию.
//
//  Параметры:
//   * ПараметрыРеглОтчетов - ТаблицаЗначений - Определяет параметры отбора отчетов:
//   	** ИсточникОтчета      - Строка - Наименование регламентированного отчета (совпадает с именем объекта метаданных).
//   	** Организация         - СправочникСсылка.Организации - Организация отчета.
//   	** ДатаОкончания       - Дата (без времени) - Дата окончания отчетного периода (правая граница отчетного периода).
//   	** РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане - Налоговый орган.
//   	** Правило                     - СправочникСсылка.ПравилаПредставленияОтчетовУплатыНалогов - Может не заполняться, но должна присутствовать в таблице.
//   * ОтборПоВыбраннойФормеРеглОтчета - Булево - Признак, нужно ли, чтобы отчет был по форме, действующей в отчетном периоде.
//
Процедура ЗаполнитьСсылкиНаРеглОтчеты(ПараметрыРеглОтчетов, ОтборПоВыбраннойФормеРеглОтчета = Ложь) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСсылкиНаРеглОтчеты(ПараметрыРеглОтчетов, ОтборПоВыбраннойФормеРеглОтчета);
```
</details>

## ПредставлениеСостоянияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет пользовательское представление состояния передачи в учреждение отчета или иного документа
// - при передаче в электронном виде - состояние отправки;
// - при передаче иным способом - статус, установленный пользователем.
//
// Параметры:
//  Документ - ДокументСсылка, СправочникСсылка - отправляемый документ (отчет или уведомление).
//
// Возвращаемое значение:
//  Строка - представление состояния передачи в учреждение.
//
Функция ПредставлениеСостоянияДокумента(Документ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПредставлениеСостоянияДокумента(Документ) 
```
</details>

## СостояниеДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет сведения о состоянии передачи в учреждение отчета или иного документа
// - при передаче в электронном виде - состояние отправки;
// - при передаче иным способом - статус, установленный пользователем.
//
// Параметры:
//  Документ - ДокументСсылка, СправочникСсылка - отправляемый документ (отчет или уведомление).
//	КонтролирующийОрган - Строка
//
// Возвращаемое значение:
//  Структура
//    * Представление - Строка - представление состояния передачи в учреждение.
//    * Сдано         - Булево - Истина, если отчет сдан любым способом.
//    * Отправлено    - Булево - Истина, если отчет отправлен в учреждение в электронном виде.
//
Функция СостояниеДокумента(Документ, КонтролирующийОрган = "ФНС") Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СостояниеДокумента(Документ, КонтролирующийОрган);
```
</details>

## СохранитьСтатусОтправкиУведомления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает в регистр сведений "Журнал отправок в контролирующие органы" значение статуса отправки,
// установленного вручную для объекта регламентированной отчетности, отображаемого на закладке "Уведомления"
// формы "1С-Отчетность".
//
// Параметры:
//   Документ - ДокументСсылка, СправочникСсылка - ссылка на объект регламентированной отчетности.
//   Статус - Строка - сохраняемый статус.
//
Процедура СохранитьСтатусОтправкиУведомления(Документ, Статус) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьСтатусОтправкиУведомления(Документ, Статус) 
```
</details>

## СвойстваОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет основные сведения о регламентированном отчете или уведомлении.
//
// Параметры:
//   Документ - ДокументСсылка - ссылка на регл. отчет.
//
// Возвращаемое значение:
//   Структура - структура
//				 из ЭлектронныйДокументооборотСКонтролирующимиОрганамиВызовСервера.ПараметрыОтображенияВЖурналеОтчетов()
//               дополненная ключом "ИсточникОтчета" - имя отчета или полное имя объекта метаданных
//				 (для отчетов не обрабатываемых БРО).
//
Функция СвойстваОтчета(Документ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СвойстваОтчета(Документ) 
```
</details>

## ДопускаетсяРучнойСтатус
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДопускаетсяРучнойСтатус(Ссылка, Статус, СостояниеСдачиОтчетности) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ДопускаетсяРучнойСтатус(Ссылка, Статус, СостояниеСдачиОтчетности) 
```
</details>

## ПараметрыОткрытияФормыРеглОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с параметрами по умолчанию для открытия формы регламентированного отчета.
//
// Параметры:
//	 ИмяРеглОтчета - Строка - Имя регламентированного отчета (совпадает с именем объекта метаданных).
//   Организация   - СправочникСсылка.Организации - Организации, по которой формируется отчет.
//   РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане - Регистрация в налоговом органе. Может быть не заполнена.
//   НачалоПериода - Дата - Дата начала периода.
//   КонецПериода  - Дата - Дата окончания периода.
//   Периодичность - ПеречислениеСсылка.Периодичность - Периодичность предоставления отчета.
//
// Возвращаемое значение:
//	Структура или Неопределено - Параметры открытия формы или Неопределено, если отчет не доступен.
//
Функция ПараметрыОткрытияФормыРеглОтчета(ИмяРеглОтчета, Организация, РегистрацияВНалоговомОргане, НачалоПериода, КонецПериода, Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПараметрыОткрытияФормыРеглОтчета(ИмяРеглОтчета, Организация, РегистрацияВНалоговомОргане, НачалоПериода, КонецПериода, Периодичность) 
```
</details>

## ВыгрузитьРегламентированныйОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выгружает сохраненный регламентированный отчет без открытия формы в соответствии с форматом выгрузки.
// Выгрузка без открытия формы возможна только при условии, что данный отчет ее поддерживает.
//
// Параметры:
//   СохраненныйОтчет - ДокументСсылка.РегламентированныйОтчет - ссылка на сохраненный регл. отчет.
//   ДополнительныеПараметрыВыгрузки - Структура - необязательный параметр, используемый для передачи
//												   дополнительных параметров выгрузки регламентированного отчета:
//	   * РеглОтчетВыгружаетсяВБанк - Булево - признак выгрузки регламентированного отчета в кредитную организацию.
//											  Истина - регламентированный отчет выгружается в кредитную организацию.
//											  Ложь - регламентированный отчет выгружается в гос. орган.
//											  Используется при выгрузке следующих отчетов:
//											  - "РегламентированныйОтчетБухОтчетность",
//											  - "РегламентированныйОтчетБухОтчетностьМП".
//     * КешСхемВыгрузки - Структура - для оптимизации кешированием.
//     * Отбор - Структура - ключ = имя поля отбора; значение = значение отбора.
//
// Возвращаемое значение:
//   Структура - результат выгрузки (см. РегламентированнаяОтчетность.НовыйРезультатВыгрузкиРеглОтчета()).
//
Функция ВыгрузитьРегламентированныйОтчет(СохраненныйОтчет, ДополнительныеПараметрыВыгрузки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВыгрузитьРегламентированныйОтчет(СохраненныйОтчет, ДополнительныеПараметрыВыгрузки);
```
</details>

## ВыгрузитьПакетПоСдачеОтчетностиВФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для переданного регламентированного отчета получает файлы документооборота с ФНС, в котором участвовал этот отчет.
//
// Параметры:
//  РегламентированныйОтчет - ДокументСсылка.РегламентированныйОтчет - отчет, по которому происходило электронное взаимодействие с ФНС.
//
// Возвращаемое значение:
//   Структура - описание архива с файлами отчета, квитанций и ЭЦП:
//		* ИмяФайла - имя архива с файлами;
//      * Адрес - адрес временного хранилища, куда был помещен файл архива;
//      * Всего - количество файлов в архиве;
//      * ОписаниеОшибки - если заполнено, то содержит текст ошибки, из-за которой не удалось сформировать архив.
//   ВключитьДополнительныеСведения - Булево - Если Истина, то в выгрузку добавляются PDF-файлы квитанций и извещение о вводе
//
Функция ВыгрузитьПакетПоСдачеОтчетностиВФНС(РегламентированныйОтчет, ВключитьДополнительныеСведения = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВыгрузитьПакетПоСдачеОтчетностиВФНС(РегламентированныйОтчет, ВключитьДополнительныеСведения);
```
</details>

## ПечатныйБланкРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует печатный бланк без штрихкода PDF417 сохраненного регламентированного отчета без открытия формы.
//
// Параметры:
//   СохраненныйОтчет - ДокументСсылка.РегламентированныйОтчет - ссылка на сохраненный регламентированный отчет.
//   ДополнительныеПараметрыПечати - Структура - необязательный параметр, используемый для передачи
//												 дополнительных параметров печати регламентированного отчета:
//	   * ПечататьЭкраннуюФормуРазделов8_12 - Булево - признак печати разделов 8-12 декларации по НДС в виде экранной формы.
//											 Истина - разделы 8-12 декларации по НДС выводятся на печать в виде экранной формы.
//											 Ложь - разделы 8-12 декларации по НДС выводятся на печать в виде утвержденного печатного бланка.
//											 Используется при печати следующих отчетов:
//											 - "РегламентированныйОтчетНДС".
//
// Возвращаемое значение:
//   Структура - содержит ключи:
//     * АдресПечатногоБланка - Строка - адрес во временном хранилище, в котором располагается в формате
//										 PDF сформированный печатный бланк без штрихкода PDF417;
//     * ИмяФайлаПечатногоБланка - Строка - имя файла сформированного печатного бланка для сохранения.
//	 Если печатный бланк не сформирован, вместо структуры возвращается пустая строка.
//
Функция ПечатныйБланкРегламентированногоОтчета(СохраненныйОтчет, ДополнительныеПараметрыПечати = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПечатныйБланкРегламентированногоОтчета(СохраненныйОтчет, ДополнительныеПараметрыПечати);
```
</details>

## ВыгрузитьДанныеАлгоритмамиРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выгружает внешние данные алгоритмами выгрузки регламентированного отчета,
// в соответствии с форматом выгрузки, без сохранения регламентированного отчета.
// Такая выгрузка возможна только при условии, что данный отчет ее поддерживает.
//
// Параметры:
//   Контейнер               - Структура - см. СтруктураКонтейнераДанных(Параметры).
//   ДополнительныеПараметры - Структура - необязательный параметр, используемый
//                                         для передачи дополнительных параметров.
//
// Возвращаемое значение:
//   Структура - результат выгрузки (см. РегламентированнаяОтчетность.НовыйРезультатВыгрузкиРеглОтчета()).
//
// Пример реализации:
//   Парам = Новый Структура;
//   Парам.Вставить("ИсточникОтчета", "РегламентированныйОтчетПрослеживаемыеТоварыОстатки");
//   Парам.Вставить("ВыбраннаяФорма", "ФормаОтчета2021Кв3");
//   Парам.Вставить("ВерсияФормата",  "5.01");
//   Парам.Вставить("СсылкаНаВнешнийОбъект", СсылкаНаДокумент);
//   Контейнер = ИнтерфейсыВзаимодействияБРО.СтруктураКонтейнераДанных(Парам);
//   Результат = ИнтерфейсыВзаимодействияБРО.ВыгрузитьДанныеАлгоритмамиРегламентированногоОтчета(Контейнер);
//
Функция ВыгрузитьДанныеАлгоритмамиРегламентированногоОтчета(Контейнер, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВыгрузитьДанныеАлгоритмамиРегламентированногоОтчета(Контейнер, ДополнительныеПараметры);
```
</details>

## ПечатныйБланкСформированныйАлгоритмамиРегламентированныхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует печатный бланк без штрихкода PDF417 по внешним данным алгоритмами печати регламентированного отчета, без
// сохранения регламентированного отчета. Такая печать возможна только при условии, что данный отчет ее поддерживает.
//
// Параметры:
//   Контейнер - Структура - см. СтруктураКонтейнераДанных(Параметры).
//
// Возвращаемое значение:
//   Массив - адреса во временном хранилище, в котором располагаются табличные документы - страницы сформированного
//            печатного бланка без штрихкода PDF417.
//   Если печатный бланк не сформирован, вместо массива возвращается пустая строка.
//
// Пример реализации:
//   Парам = Новый Структура;
//   Парам.Вставить("ИсточникОтчета", "РегламентированныйОтчетПрослеживаемыеТоварыОстатки");
//   Парам.Вставить("ВыбраннаяФорма", "ФормаОтчета2021Кв3");
//   Парам.Вставить("ВерсияФормата",  "5.01");
//   Парам.Вставить("СсылкаНаВнешнийОбъект", СсылкаНаДокумент);
//   Контейнер = ИнтерфейсыВзаимодействияБРО.СтруктураКонтейнераДанных(Парам);
//   Результат = ИнтерфейсыВзаимодействияБРО.ПечатныйБланкСформированныйАлгоритмамиРегламентированныхОтчетов(Контейнер);
//
Функция ПечатныйБланкСформированныйАлгоритмамиРегламентированныхОтчетов(Контейнер) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПечатныйБланкСформированныйАлгоритмамиРегламентированныхОтчетов(Контейнер) 
```
</details>

## СтруктураКонтейнераДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает контейнер для наполнения внешними данными и последующей передачи в алгоритмы
// выгрузки или печати регламентированного отчета, без сохранения регламентированного отчета.
// Получение такого контейнера возможно только при условии, что данный отчет поддерживает
// выгрузку или печать регламентированного отчета, без сохранения регламентированного отчета.
//
// Параметры:
//   Параметры - Структура - данные, необходимые для получения контейнера:
//     * ИсточникОтчета        - Строка - имя объекта регламентированного отчета.
//     * ВыбраннаяФорма        - Строка - имя формы объекта регламентированного отчета.
//     * ВерсияФормата         - Строка - версия формата выгрузки.
//     * СсылкаНаВнешнийОбъект - Любая ссылка - ссылка на объект данных (например, ссылка на документ,
//                                              для которого выполняется получение контейнера).
//
// Возвращаемое значение:
//   Структура - контейнер для наполнения внешними данными.
//
// Пример реализации:
//   Парам = Новый Структура;
//   Парам.Вставить("ИсточникОтчета", "РегламентированныйОтчетПрослеживаемыеТоварыОстатки");
//   Парам.Вставить("ВыбраннаяФорма", "ФормаОтчета2021Кв3");
//   Парам.Вставить("ВерсияФормата",  "5.01");
//   Парам.Вставить("СсылкаНаВнешнийОбъект", СсылкаНаДокумент);
//   Контейнер = ИнтерфейсыВзаимодействияБРО.СтруктураКонтейнераДанных(Парам);
//
Функция СтруктураКонтейнераДанных(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СтруктураКонтейнераДанных(Параметры) 
```
</details>

## СохранитьСтатусОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает в регистр сведений "Журнал отчетов статусы" значение статуса отправки,
// установленного вручную в экранной форме объекта, отображаемого на закладке "Отчеты"
// формы "1С-Отчетность".
//
// Параметры:
//   СтруктураПараметров - Cтруктура со свойствами:
//     * СсылкаНаОбъект - ДокументСсылка, СправочникСсылка - ссылка на объект, отображаемый
//                        на закладке "Отчеты" формы "1С-Отчетность";
//     * Форма - ФормаКлиентскогоПриложения - экранная форма объекта, отображаемого на закладке "Отчеты"
//                                            формы "1С-Отчетность".
//     * Статус - Строка
//
Процедура СохранитьСтатусОтправки(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьСтатусОтправки(СтруктураПараметров) 
```
</details>

## НачалоНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет дату начала налогового периода с учетом даты регистрации организации (требований ст. 55 НК РФ). Налоговый
// период может быть расширен или отсутствовать, если организация зарегистрирована в конце обычного периода (например,
// 30 декабря). Налоговый период может быть сокращен, если организация зарегистрирована не в конце обычного периода
// (например, 10 января).
//
// Параметры:
//  Организация                              - СправочникСсылка.Организации - организация, для которой определяется
//                                             дата начала налогового периода;
//  Период                                   - Дата - дата в периоде, начало которого определяется;
//  ВариантРасширенногоПервогоПериода        - ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода -
//                                             проверяемый вариант требований закона;
//  СтандартнаяДлительностьНалоговогоПериода - ПеречислениеСсылка.Периодичность - длительность налогового периода;
//  СокращатьНалоговыйПериод                 - Булево - Ложь, если для совместимости важно, чтобы дата регистрации
//                                                      возвращалась только для расширенного периода (не сокращенного),
//                                                      при этом ст. 55 будет выполнена в неполном объеме);
//                                                      Истина, если требуется выполнение ст. 55 в части сокращения
//                                                      периода.
//  ДатаРегистрации                          - Дата - дата регистрации организации;
//                                             если не передана, определяется из свойств организации.
//  ДатаПостановкиНаУчет                     - Дата - дата постановки на учет в качестве налогоплательщика;
//
// Возвращаемое значение (варианты):
//  Дата         - дата начала налогового периода;
//  Неопределено - в этом периоде обязанностей налогоплательщика у организации нет.
//
Функция НачалоНалоговогоПериода(Организация, Период, ВариантРасширенногоПервогоПериода, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НачалоНалоговогоПериода(Организация, Период, ВариантРасширенногоПервогоПериода, );
```
</details>

## БлижайшийНалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет границы ближайшего налогового периода с учетом даты регистрации (постановки на учет в качестве налогоплательщика).
//
// Параметры:
//  Организация                              - СправочникСсылка.Организации - организация, для которой определяются
//                                             границы ближайшего налогового периода;
//  Период                                   - Дата - дата в периоде, границы которого определяются;
//  ВариантРасширенногоПервогоПериода        - ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода -
//                                             проверяемый вариант требований закона;
//  СтандартнаяДлительностьНалоговогоПериода - ПеречислениеСсылка.Периодичность - длительность налогового периода.
//  ДатаРегистрации                          - Дата - дата регистрации организации;
//                                             если не передана, определяется из свойств организации.
//  ДатаПостановкиНаУчет                     - Дата - дата постановки на учет в качестве налогоплательщика;
//
// Возвращаемое значение:
//  Структура - границы периода
//    * Период - Дата - стандартное начало налогового периода (например, 01 июля для третьего квартала);
//    * Начало - Дата - фактическое начало налогового периода (может совпадать со стандартным началом или
//               датой регистрации организации;
//    * Конец  - Дата - дата с указанием времени.
//
Функция БлижайшийНалоговыйПериод(Организация, Знач ПроверяемыйПериод, ВариантРасширенногоПервогоПериода, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.БлижайшийНалоговыйПериод(Организация, ПроверяемыйПериод, ВариантРасширенногоПервогоПериода, );
```
</details>

## СтандартнаяДлительностьНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет стандартную длительность налогового периода по переданному варианту периода регистрации организации.
//
// Параметры:
//  ВариантРасширенногоПервогоПериода - ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода - вариант
//                                      требований закона.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.Периодичность - длительность периода; пустая ссылка, если установить не удалось.
//
Функция СтандартнаяДлительностьНалоговогоПериода(Вариант) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СтандартнаяДлительностьНалоговогоПериода(Вариант) 
```
</details>

## ПропущенныйНалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет налоговый период, относящийся к дате регистрации (постановки на учет), пропускаемый для целей уплаты налогов
// (представления отчетов). Требования установлены ст. 55 НК РФ и п. 3 ст. 15 закона "О бухгалтерском учете".
//
// Например, если организация зарегистрирована в конце года, то некоторую отчетность за этот год она не представляет
// (и некоторые налоги не платит), а показатели деятельности за период с даты регистрации до конца следующего года
// включает в отчетность за следующий год. Таким образом, первый налоговый период у организации может быть длинее,
// чем последующие (т.е., может быть "расширенным").
//
// Другими словами, если дата регистрации попадает в определенные периоды, то не требуется представлять отчетность
// и/или уплачивать налоги за эти периоды.
//
// Законом определены несколько вариантов периодов, в зависимости от даты регистрации организации.
//
// Параметры:
//  Вариант         - ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода - вариант требований закона;
//  Организация     - СправочникСсылка.Организации - организация, для которой определяется пропущенный период;
//  ДатаРегистрации - Дата - дата регистрации организации; если не передана, определяется из свойств организации;
//  ДатаПостановкиНаУчет - Дата - дата постановки на учет в качестве налогоплательщика;
//
// Возвращаемое значение (варианты):
//  Дата         - дата начала пропущенного периода;
//  Неопределено - нет оснований для пропуска периода.
//
Функция ПропущенныйНалоговыйПериод(Вариант, Организация, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПропущенныйНалоговыйПериод(Вариант, Организация, );
```
</details>

## НалоговыйПериодПропущен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что не требуется сдавать отчетность и уплачивать налог за переданный период.
//
// Параметры:
//  Организация                       - СправочникСсылка.Организации - проверяемая организация
//  Период                            - Дата - проверяемый период
//  ВариантРасширенногоПервогоПериода - ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода - вариант требований закона;
//  ДатаРегистрации                   - Дата - дата регистрации организации; если не передана, определяется из свойств организации;
//  ДатаПостановкиНаУчет              - Дата - дата постановки на учет в качестве налогоплательщика;
//
// Возвращаемое значение:
//   Булево   - Если ИСТИНА, это пропущенный период
//              (организация зарегистрирована в декабре переданного года, и для нее актуальны требования п.2 статьи 55 НК РФ).
//
Функция НалоговыйПериодПропущен(Организация, Период, ВариантРасширенногоПервогоПериода, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НалоговыйПериодПропущен(Организация, Период, ВариантРасширенногоПервогоПериода, );
```
</details>

## ПервыйНалоговыйПериодНачинаетсяСДатыПостановкиНаУчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет какой период расширяется в соответствии с выбранным вариантом.
//
// Параметры:
//  ВариантРасширенногоПервогоПериода - ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода - вариант требований закона;
//
// Возвращаемое значение:
//  Истина - расширяемый налоговый период начинается с даты постановки на учет в качестве налогоплательщика;
//  Ложь - расширяемый налоговый период начинается с даты регистрации организации.
//
Функция ПервыйНалоговыйПериодНачинаетсяСДатыПостановкиНаУчет(ВариантРасширенногоПервогоПериода) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПервыйНалоговыйПериодНачинаетсяСДатыПостановкиНаУчет(ВариантРасширенногоПервогоПериода) 
```
</details>

## АдресВФорматеФИАС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. РегламентированнаяОтчетность.АдресВФорматеФИАС.
Функция АдресВФорматеФИАС(Адрес, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.АдресВФорматеФИАС(Адрес, ДополнительныеПараметры);
```
</details>

## ПараметрыСпискаРеглОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Ранее функция использовалась в функционале "Монитор налогов и отчетности".
// Описывает структуру таблицы значений для получения списка регл. отчетов.
//
// Возвращаемое значение:
//   ТаблицаЗначений - подготовленная таблица для получения списка регл. отчетов по периодам.
//
Функция ПараметрыСпискаРеглОтчетов() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПараметрыСпискаРеглОтчетов() 
```
</details>

## ПолучитьСписокРеглОтчетовПоПериодам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Ранее процедура использовалась в функционале "Монитор налогов и отчетности".
// Помещает в переданный менеджер временных таблиц сформированные сведения о регламентированной отчетности
// в разрезе запрашиваемых правил и отчетных периодов.
//
// Параметры:
//  МенеджерВТ          - МенеджерВременныхТаблиц - исх. параметр, в менеджер помещается временная таблица "ВТ_РеглОтчеты" со следующими колонками:
//   * Ссылка           - ДокументСсылка.РегламентированныйОтчет - ссылка на отчет;
//   * ПериодСобытия    - Дата - финансовый период, к которому относится отчет;
//   * ПолноеИмяПравила - Строка - скомпонованное имя правила, формируемое как идентификатор(код) задачи-владельца правила + "." + идентификатор(код) самого правила;
//   * Статус           - Строка - состояние отправки отчета в контролирующие органы.
//  Организация                - СправочникСсылка.Организации - организация, по которой запрашивается отчетность.
//  ПараметрыСпискаРеглОтчетов - ТаблицаЗначений - см. функцию ПараметрыСпискаРеглОтчетов().
//
Процедура ПолучитьСписокРеглОтчетовПоПериодам(МенеджерВТ, Организация, ПараметрыСпискаРеглОтчетов) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ПолучитьСписокРеглОтчетовПоПериодам(МенеджерВТ, Организация, ПараметрыСпискаРеглОтчетов) 
```
</details>

## ЭтоДекларацияПоНалогуНаПрибыльОбособленногоПодразделения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Можно сразу использовать Отчеты[ИмяРеглОтчета].ЭтоДекларацияПоНалогуНаПрибыльОбособленногоПодразделения()
Функция ЭтоДекларацияПоНалогуНаПрибыльОбособленногоПодразделения(СсылкаНаРеглОтчет) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЭтоДекларацияПоНалогуНаПрибыльОбособленногоПодразделения(СсылкаНаРеглОтчет) 
```
</details>

## УТекущегоПользователяЕстьДоступКЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие доступа к электронному документообороту.
//
// Возвращаемое значение:
//  Булево - Истина, если доступ есть
//
Функция УТекущегоПользователяЕстьДоступКЭДО() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.УТекущегоПользователяЕстьДоступКЭДО() 
```
</details>

## ПолучитьОтветыНаЗапросИОН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Получить ответы на запрос ИОН
//
// Параметры:
//  Запрос	 - ДокументСсылка.ЗапросНаИнформационноеОбслуживаниеНалогоплательщика - ссылка на запрос
//
// Возвращаемое значение:
//  ТаблицаЗначений или Неопределено. Таблица значений имеет поля: ИмяФайла, Размер, ТипСодержимого, Данные, ВАрхиве.
//		Неопределено будет возвращено если у пользователя нет доступа к ЭДО.
//
Функция ПолучитьОтветыНаЗапросИОН(Запрос) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПолучитьОтветыНаЗапросИОН(Запрос) 
```
</details>

## ФайлыРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файлы регламентированного отчета, сохраненного в информационной базе, для передачи в банк
//
// Параметры:
//   СохраненныйОтчет - ДокументСсылка.РегламентированныйОтчет
//   БезБланков - Булево
//
// Возвращаемое значение:
//   Структура:
//     ОписаниеОшибки:
//       Строка - Подробное описание ошибки или пустая строка, если ошибок не было.
//     ФайлыОтчета:
//       Массив - содержит структуры:
//         * ВидФайла - Строка - вид файла отчета
//         * ИмяФайла - Строка - имя файла
//         * СодержимоеФайла - Произвольный - содержимое файла
//
Функция ФайлыРегламентированногоОтчета(СохраненныйОтчет, БезБланков = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ФайлыРегламентированногоОтчета(СохраненныйОтчет, БезБланков);
```
</details>

## ПараметрыАвтозаполненияРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметров автозаполнения регламентированного отчета.
//
// Параметры:
//   ИсточникОтчета - Строка - наименование регламентированного отчета (совпадает с именем объекта метаданных).
//   ИмяФормыОтчета - Строка - имя формы регламентированного отчета, для которой требуются параметры автозаполнения.
//   ДополнительныеПараметры - Структура - необязательный параметр, используемый для передачи дополнительных параметров.
//
// Возвращаемое значение:
//   Структура - содержит элементы, необходимые для работы процедур автозаполнения отчета.
//
Функция ПараметрыАвтозаполненияРегламентированногоОтчета(ИсточникОтчета, ИмяФормыОтчета, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПараметрыАвтозаполненияРегламентированногоОтчета(ИсточникОтчета, ИмяФормыОтчета, );
```
</details>

## СведенияПоЗарегистрированнымЛицамИзОтчетовЕФС1СЗПГос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения по зарегистрированным лицам из регламентированных отчетов "ЕФС-1: Сведения о заработной плате
// и условиях осуществления деятельности работников государственных (муниципальных) учреждений".
//
// Параметры:
//  СтруктураПараметров - Структура - свойства:
//     * Организация    - СправочникСсылка.Организации - организация, для которой будет выполняться поиск отчетов
//                        "ЕФС-1: Сведения о заработной плате и условиях осуществления деятельности работников
//                        государственных (муниципальных) учреждений";
//     * ДатаОкончания  - Дата - дата окончания отчетного периода для поиска отчетов "ЕФС-1: Сведения о заработной
//                        плате и условиях осуществления деятельности работников государственных (муниципальных)
//                        учреждений";
//     * ПоискПоИмениФормыОтчета - Булево - признак использования имени формы при поиске отчетов "ЕФС-1: Сведения
//                        о заработной плате и условиях осуществления деятельности работников государственных
//                        (муниципальных) учреждений" (необязательное свойство; если отсутствует или если Истина,
//                        тогда имя формы отчета используется при поиске; если Ложь, тогда имя формы отчета
//                        не используется при поиске);
//     * ИмяФормыОтчета - Строка - имя формы отчета "ЕФС-1: Сведения о заработной плате и условиях осуществления
//                        деятельности работников государственных (муниципальных) учреждений", например,
//                        "ФормаОтчета2024Кв1" (необязательное свойство; не используется при
//                        ПоискПоИмениФормыОтчета = Ложь; если отсутствует, то при ПоискПоИмениФормыОтчета = Истина
//                        значение будет получено автоматически).
//
// Возвращаемое значение:
//  Массив - массив структур с данными отчетов (пустой массив, если отчетов не найдено).
//  Каждая структура (случай непустого массива) - Структура - имеет свойства:
//     * НомерКорректировки - Число - номер корректировки из отчета "ЕФС-1: Сведения о заработной плате и условиях
//                            осуществления деятельности работников государственных (муниципальных) учреждений";
//     * СведенияПоЗЛ - ДеревоЗначений - сведения по зарегистрированным лицам из отчета "ЕФС-1: Сведения о заработной
//                            плате и условиях осуществления деятельности работников государственных (муниципальных)
//                            учреждений".
//
Функция СведенияПоЗарегистрированнымЛицамИзОтчетовЕФС1СЗПГос(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СведенияПоЗарегистрированнымЛицамИзОтчетовЕФС1СЗПГос(СтруктураПараметров) 
```
</details>

## ПолучитьДоверенностиОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив ссылок МЧД ФНС
//
// Параметры:
// 	Отбор - структура:
//   * Доверитель       - ОпределяемыйТип.Организация - Организация предприятия
//   * Сертификат       - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования, СертификатКриптографии -
//                      Сертификат представителя.
//   * ПредставительИНН - Строка - ИНН представителя, используется, если Сертификат равен Неопределено.
//
// Возвращаемое значение:
// 	Массив из СправочникСсылка.МашиночитаемыеДоверенностиФНС,
// 	СправочникСсылка.МашиночитаемыеДоверенностиРаспределенныйРеестр
//
Функция ПолучитьДоверенностиОрганизации(Отбор) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ПолучитьДоверенностиОрганизации(Отбор) 
```
</details>

## ДанныеДляЗаполненияОтчетаВПомощнике
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные для заполнения регламентированного отчета "Налог на прибыль" в помощнике.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - организация
//  ДатаКонцаПериода - Дата - дата конца периода отчета
//
// Возвращаемое значение:
//  Структура:
//    * ОтчетМожноЗаполнитьВПомощнике - Булево - Истина, если отчет можно заполнить в форме помощника
//    * ПараметрыПравила - Структура - параметры правила для списка задач бухгалтера
//
Функция ДанныеДляЗаполненияОтчетаВПомощнике(Организация, ДатаКонцаПериода) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ДанныеДляЗаполненияОтчетаВПомощнике(Организация, ДатаКонцаПериода) 
```
</details>

## СформироватьАвтоматическиРеглОтчет6НДФЛФормаОтчета2017Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчет6НДФЛФормаОтчета2017Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчет6НДФЛФормаОтчета2017Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## СформироватьАвтоматическиРеглОтчет6НДФЛФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчет6НДФЛФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчет6НДФЛФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчет6НДФЛФормаОтчета2017Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчет6НДФЛФормаОтчета2017Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчет6НДФЛФормаОтчета2017Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчет6НДФЛФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчет6НДФЛФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчет6НДФЛФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## СохранитьДанныеРазделаРеглОтчет6НДФЛФормаОтчета2017Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчет6НДФЛФормаОтчета2017Кв4(НаимРаздела, ТабличныйДокумент, РазделыОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчет6НДФЛФормаОтчета2017Кв4(НаимРаздела, ТабличныйДокумент, РазделыОтчета));
```
</details>

## СохранитьДанныеРазделаРеглОтчет6НДФЛФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчет6НДФЛФормаОтчета2016Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчет6НДФЛФормаОтчета2016Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчет6НДФЛФормаОтчета2017Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчет6НДФЛФормаОтчета2017Кв4(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчет6НДФЛФормаОтчета2017Кв4(ДеревоСтраницОтчета));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчет6НДФЛФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчет6НДФЛФормаОтчета2016Кв1(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчет6НДФЛФормаОтчета2016Кв1(ДеревоСтраницОтчета));
```
</details>

## ЗаписатьРеглОтчет6НДФЛФормаОтчета2017Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчет6НДФЛФормаОтчета2017Кв4(ИсточникОтчета, ИмяФормыОтчета, РазделыОтчета, ДанныеРеглОтчета, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчет6НДФЛФормаОтчета2017Кв4(ИсточникОтчета, ИмяФормыОтчета, РазделыОтчета, ДанныеРеглОтчета, );
```
</details>

## ЗаписатьРеглОтчет6НДФЛФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчет6НДФЛФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, РазделыОтчета, ДанныеРеглОтчета, Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчет6НДФЛФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, РазделыОтчета, ДанныеРеглОтчета, );
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчет6НДФЛФормаОтчета2017Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчет6НДФЛФормаОтчета2017Кв4(Организация, РазделыОтчета, ДатаПодписи, Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчет6НДФЛФормаОтчета2017Кв4(Организация, РазделыОтчета, ДатаПодписи, );
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчет6НДФЛФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчет6НДФЛФормаОтчета2016Кв1(Организация, РазделыОтчета, ДатаПодписи, Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчет6НДФЛФормаОтчета2016Кв1(Организация, РазделыОтчета, ДатаПодписи, );
```
</details>

## СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв3(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв3(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2018Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2017Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2017Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетЕНВДФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, КорректирующийОтчет, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв3(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв3(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетЕНВДФормаОтчета2018Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчетЕНВДФормаОтчета2017Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетЕНВДФормаОтчета2017Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## ЗаполнитьРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьРеглОтчетЕНВДФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетЕНВДФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ПараметрыАвтоФормирования));
```
</details>

## РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв4(ТаблицаРаздела2, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв4(ТаблицаРаздела2, ДатаНачала, ДатаОкончания));
```
</details>

## РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв3(ТаблицаРаздела2, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв3(ТаблицаРаздела2, ДатаНачала, ДатаОкончания));
```
</details>

## РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв1(ТаблицаРаздела2, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2018Кв1(ТаблицаРаздела2, ДатаНачала, ДатаОкончания));
```
</details>

## РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2017Кв1(ТаблицаРаздела2, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2017Кв1(ТаблицаРаздела2, ДатаНачала, ДатаОкончания));
```
</details>

## РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2016Кв1(ТаблицаРаздела2, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РассчитатьДниОсуществленияДеятельностиЕНВДФормаОтчета2016Кв1(ТаблицаРаздела2, ДатаНачала, ДатаОкончания));
```
</details>

## СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв4(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв4(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв3(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв3(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2018Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2017Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2017Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2016Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетЕНВДФормаОтчета2016Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв4(ДеревоСтраницОтчета, Организация) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв4(ДеревоСтраницОтчета, Организация));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв3(ДеревоСтраницОтчета, Организация) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв3(ДеревоСтраницОтчета, Организация));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв1(ДеревоСтраницОтчета, Организация) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2018Кв1(ДеревоСтраницОтчета, Организация));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2017Кв1(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2017Кв1(ДеревоСтраницОтчета));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2016Кв1(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетЕНВДФормаОтчета2016Кв1(ДеревоСтраницОтчета));
```
</details>

## ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв4(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет);
```
</details>

## ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв3(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв3(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет);
```
</details>

## ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетЕНВДФормаОтчета2018Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет);
```
</details>

## ЗаписатьРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетЕНВДФормаОтчета2017Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетЕНВДФормаОтчета2017Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет);
```
</details>

## ЗаписатьРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетЕНВДФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетЕНВДФормаОтчета2016Кв1(ИсточникОтчета, ИмяФормыОтчета, Организация, ДатаНачала, ДатаОкончания, РазделыОтчета, ДанныеРеглОтчета, СсылкаНаСохрРеглОтчет);
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв4(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв4(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв3(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв3(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2018Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2017Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2017Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2016Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетЕНВДФормаОтчета2016Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## РасчетРеглОтчетЕНВДФормаОтчета2018Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетЕНВДФормаОтчета2018Кв4(РазделыОтчета, ИмяРаздела = "", ДатаОкончания = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетЕНВДФормаОтчета2018Кв4(РазделыОтчета, ИмяРаздела, ДатаОкончания);
```
</details>

## РасчетРеглОтчетЕНВДФормаОтчета2018Кв3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетЕНВДФормаОтчета2018Кв3(РазделыОтчета, ИмяРаздела = "", ДатаОкончания = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетЕНВДФормаОтчета2018Кв3(РазделыОтчета, ИмяРаздела, ДатаОкончания);
```
</details>

## РасчетРеглОтчетЕНВДФормаОтчета2018Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетЕНВДФормаОтчета2018Кв1(РазделыОтчета, ИмяРаздела = "", ДатаОкончания = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетЕНВДФормаОтчета2018Кв1(РазделыОтчета, ИмяРаздела, ДатаОкончания);
```
</details>

## РасчетРеглОтчетЕНВДФормаОтчета2017Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетЕНВДФормаОтчета2017Кв1(РазделыОтчета, ИмяРаздела = "", ДатаОкончания = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетЕНВДФормаОтчета2017Кв1(РазделыОтчета, ИмяРаздела, ДатаОкончания);
```
</details>

## РасчетРеглОтчетЕНВДФормаОтчета2016Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетЕНВДФормаОтчета2016Кв1(РазделыОтчета, ИмяРаздела = "", ДатаОкончания = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетЕНВДФормаОтчета2016Кв1(РазделыОтчета, ИмяРаздела, ДатаОкончания);
```
</details>

## СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2023Кв1(ПараметрыАвтоформирования, КорректирующийОтчет) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2023Кв1(ПараметрыАвтоформирования, КорректирующийОтчет));
```
</details>

## СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2021Кв1(ПараметрыАвтоформирования, КорректирующийОтчет) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2021Кв1(ПараметрыАвтоформирования, КорректирующийОтчет));
```
</details>

## СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2015Кв1(ПараметрыАвтоформирования, КорректирующийОтчет) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетУСНФормаОтчета2015Кв1(ПараметрыАвтоформирования, КорректирующийОтчет));
```
</details>

## НовыйРазделыРеглОтчетаУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйРазделыРеглОтчетаУСНФормаОтчета2023Кв1() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НовыйРазделыРеглОтчетаУСНФормаОтчета2023Кв1());
```
</details>

## НовыйРазделыРеглОтчетаУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйРазделыРеглОтчетаУСНФормаОтчета2021Кв1() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НовыйРазделыРеглОтчетаУСНФормаОтчета2021Кв1());
```
</details>

## НовыйРазделыРеглОтчетаУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйРазделыРеглОтчетаУСНФормаОтчета2015Кв1() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.НовыйРазделыРеглОтчетаУСНФормаОтчета2015Кв1());
```
</details>

## ЗаполнитьРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеглОтчетУСНФормаОтчета2023Кв1(ПараметрыАвтоформирования, КорректирующийОтчет, РазделыОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетУСНФормаОтчета2023Кв1(ПараметрыАвтоформирования, КорректирующийОтчет, РазделыОтчета));
```
</details>

## ЗаполнитьРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеглОтчетУСНФормаОтчета2021Кв1(ПараметрыАвтоформирования, КорректирующийОтчет, РазделыОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетУСНФормаОтчета2021Кв1(ПараметрыАвтоформирования, КорректирующийОтчет, РазделыОтчета));
```
</details>

## ЗаполнитьРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеглОтчетУСНФормаОтчета2015Кв1(ПараметрыАвтоформирования, КорректирующийОтчет, РазделыОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьРеглОтчетУСНФормаОтчета2015Кв1(ПараметрыАвтоформирования, КорректирующийОтчет, РазделыОтчета));
```
</details>

## РасчетРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетУСНФормаОтчета2023Кв1(РазделыОтчета, ИмяРаздела = "", ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетУСНФормаОтчета2023Кв1(РазделыОтчета, ИмяРаздела, ДопПараметры));
```
</details>

## РасчетРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетУСНФормаОтчета2021Кв1(РазделыОтчета, ИмяРаздела = "", ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетУСНФормаОтчета2021Кв1(РазделыОтчета, ИмяРаздела, ДопПараметры));
```
</details>

## РасчетРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетРеглОтчетУСНФормаОтчета2015Кв1(РазделыОтчета, ИмяРаздела = "", ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.РасчетРеглОтчетУСНФормаОтчета2015Кв1(РазделыОтчета, ИмяРаздела, ДопПараметры));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2023Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2023Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2021Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2021Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2015Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОбОрганизацииРеглОтчетУСНФормаОтчета2015Кв1(Организация, РазделыОтчета, ДатаПодписи, ДатаОкончания));
```
</details>

## СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2023Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2023Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2021Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2021Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2015Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СохранитьДанныеРазделаРеглОтчетУСНФормаОтчета2015Кв1(НаимРаздела, ТабличныйДокумент, РазделыОтчета, ДопПараметры));
```
</details>

## ЗаписатьРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетУСНФормаОтчета2023Кв1(ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетУСНФормаОтчета2023Кв1(ПараметрыЗаписи));
```
</details>

## ЗаписатьРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетУСНФормаОтчета2021Кв1(ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетУСНФормаОтчета2021Кв1(ПараметрыЗаписи));
```
</details>

## ЗаписатьРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаписатьРеглОтчетУСНФормаОтчета2015Кв1(ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ЗаписатьРеглОтчетУСНФормаОтчета2015Кв1(ПараметрыЗаписи));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2023Кв1(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2023Кв1(ДеревоСтраницОтчета));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2021Кв1(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2021Кв1(ДеревоСтраницОтчета));
```
</details>

## ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2015Кв1(ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ФормироватьСтруктуруСтраницРеглОтчетУСНФормаОтчета2015Кв1(ДеревоСтраницОтчета));
```
</details>

## СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2023Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2023Кв1(Организация, ПериодОтчета, ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2023Кв1(Организация, ПериодОтчета, ДеревоСтраницОтчета));
```
</details>

## СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2021Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2021Кв1(Организация, ПериодОтчета, ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2021Кв1(Организация, ПериодОтчета, ДеревоСтраницОтчета));
```
</details>

## СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2015Кв1(Организация, ПериодОтчета, ДеревоСтраницОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.СкрытьРазделыПоОбъектуНалогообложенияРеглОтчетУСНФормаОтчета2015Кв1(Организация, ПериодОтчета, ДеревоСтраницОтчета));
```
</details>

## СформироватьАвтоматическиРеглОтчетСтатистикаФорма1Предприниматель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьАвтоматическиРеглОтчетСтатистикаФорма1Предприниматель(ПараметрыАвтоФормирования, КорректирующийОтчет) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СформироватьАвтоматическиРеглОтчетСтатистикаФорма1Предприниматель(ПараметрыАвтоФормирования, КорректирующийОтчет) 
```
</details>

## ЗаполнитьСведенияОПодписантах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияОПодписантах(Организация, РазделыОтчета, ДатаПодписи, ПереопределяемыеИменаПоказателей = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьСведенияОПодписантах(Организация, РазделыОтчета, ДатаПодписи, ПереопределяемыеИменаПоказателей);
```
</details>

## ЗаполнитьНачальныеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНачальныеНастройки(ИсточникОтчета, ИмяФормыОтчета, ИмяМакета, СтруктураВариантыЗаполнения) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьНачальныеНастройки(ИсточникОтчета, ИмяФормыОтчета, ИмяМакета, СтруктураВариантыЗаполнения));
```
</details>

## ЗаполнитьПоказателиОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПоказателиОтчета(РазделыОтчета, ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьПоказателиОтчета(РазделыОтчета, ПоказателиОтчета));
```
</details>

## ЗаполнитьПустыеСтруктурыДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПустыеСтруктурыДанных(ИсточникОтчета, ИмяФормыОтчета, РазделыОтчета, ДопПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьПустыеСтруктурыДанных(ИсточникОтчета, ИмяФормыОтчета, РазделыОтчета, ДопПараметры);
```
</details>

## ОбновитьСтруктуруМногострочногоРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтруктуруМногострочногоРаздела(ДанныеДопСтрок, ТабличныйДокумент) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ОбновитьСтруктуруМногострочногоРаздела(ДанныеДопСтрок, ТабличныйДокумент));
```
</details>

## СуммаПоказателяПоВсемСтраницам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммаПоказателяПоВсемСтраницам(ДанныеРаздела, Показатель, Условия = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СуммаПоказателяПоВсемСтраницам(ДанныеРаздела, Показатель, Условия);
```
</details>

## ЗаполнитьЗначенияСвойствСтруктурыПоИсточнику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьЗначенияСвойствСтруктурыПоИсточнику(СтруктураПриемник, СтруктураИсточник) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьЗначенияСвойствСтруктурыПоИсточнику(СтруктураПриемник, СтруктураИсточник));
```
</details>

## ВыполняютсяУсловияЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВыполняютсяУсловияЗаполнения(СтруктураДанных, Условия) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ВыполняютсяУсловияЗаполнения(СтруктураДанных, Условия));
```
</details>

## СобратьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СобратьДанные(ТабличныйДокумент) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СобратьДанные(ТабличныйДокумент));
```
</details>

## ОкруглитьЧислоПоФормату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОкруглитьЧислоПоФормату(СтруктураРеквизитов, ИсходноеЧисло) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.ОкруглитьЧислоПоФормату(СтруктураРеквизитов, ИсходноеЧисло));
```
</details>

## СтруктураРеквизитовОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СтруктураРеквизитовОтчета(ДанныеОтчета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.СтруктураРеквизитовОтчета(ДанныеОтчета);
```
</details>

## РелевантнаяДатаОкончанияОтчетногоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РелевантнаяДатаОкончанияОтчетногоПериода(СвойстваОтчета) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсыВзаимодействияБРО.РелевантнаяДатаОкончанияОтчетногоПериода(СвойстваОтчета));
```
</details>

## НайтиОбластиТабличногоДокументаПоНачалуИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НайтиОбластиТабличногоДокументаПоНачалуИмени(ИменаОбластей, ТабличныйДокумент, Знач НачалоИмени, Исключения = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.НайтиОбластиТабличногоДокументаПоНачалуИмени(ИменаОбластей, ТабличныйДокумент, НачалоИмени, Исключения);
```
</details>

## ЗаполнитьАктуальныйОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьАктуальныйОтчет(АктуальныйОтчет, РеглОтчеты, ИсточникОтчета, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
ИнтерфейсыВзаимодействияБРО.ЗаполнитьАктуальныйОтчет(АктуальныйОтчет, РеглОтчеты, ИсточникОтчета, ДополнительныеПараметры));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
